#!/bin/bash
# ******************************************************************************
# * FILE PURPOSE: Environment Setup for building PDK
# ******************************************************************************
# * FILE NAME: pdksetupenv.sh
# *
# * DESCRIPTION: 
# *  Configures and sets up the Build Environment for PDK. 
# *
# *  The batch file expects an optional argument:PDK_INSTALL_PATH: Location of the PDK package.
# *   If the argument is not specified the  batch file assumes that the PDK is installed in the same location 
# *   where the batch file is located and is being executed.
# *
# * USAGE:
# *  ./pdksetupenv.sh ~/ti/pdk_keystone2_<version>/packages 
# *      --- OR ---
# *  ./pdksetupenv.sh
# *
# * Copyright (C) 2012-2014, Texas Instruments, Inc.
# *****************************************************************************

# *******************************************************************************
# ********************** GET PARAMETERS PASSED THROUGH ARGUMENT   ***************
# *******************************************************************************
# Parameter Validation: Check if the argument was passed to the batch file and
# if so we use that else we default to the working directory where the batch 
# file was invoked from

if  [ -z $PDK_INSTALL_PATH ]; then
tempVar=$1
if [ ! -z $tempVar ];then
export PDK_INSTALL_PATH=$tempVar
else
export PDK_INSTALL_PATH=${PWD}
fi
fi

# Output directory for generated libraries
export LIBDIR=./lib

# *******************************************************************************
# ********************** CHECK REQUIRED ENVIRONMENT DEFINES BEGIN ***************
# *******************************************************************************
if [ -z ${C6X_GEN_INSTALL_PATH} ];then
echo "C6X_GEN_INSTALL_PATH: Code gen NOT CONFIGURED!!!!. REQUIRED FOR BUILD"
fi

if [ -z $XDC_INSTALL_PATH ];then
 echo "XDC_INSTALL_PATH: XDC NOT CONFIGURED!!!!. REQUIRED FOR XDC BUILD"
fi

if [ -z $CG_XML_BIN_INSTALL_PATH ];then
 echo "CG_XML_BIN_INSTALL_PATH: CG XML NOT CONFIGURED!!!!. REQUIRED FOR XDC BUILD"
fi

# *******************************************************************************
# ********************** CHECK REQUIRED ENVIRONMENT DEFINES END ***************
# *******************************************************************************


# *******************************************************************************
# *************************** OPTIONAL ENVIRONMENT DEFINES **********************
# *************************** NOT REQUIRED FOR BUILDING THE PDK *****************
# *******************************************************************************
# STATIC_ANALYZE_PATH: Environment Variable for tool to do STATIC Analysis 
#                      of the code
# 
# DOXYGEN_INSTALL_PATH: DOXYGEN Version 1.7.3 [Only needed for generating Doxygen]
# 
# HTML_HELP_WORKSHOP_INSTALL_PATH: HTML Help compiler.[Only needed for generating Doxygen]
# 
# PDSP_CGEN_INSTALL_PATH: PDSP CGEN TOOLS [Only needed for PA firmware]
# *******************************************************************************
# *******************************************************************************
# *******************************************************************************

# C66x tool executable path
# export C6X_GEN_INSTALL_PATH=/apps/CGT/bin
echo "C6X_GEN_INSTALL_PATH set to $C6X_GEN_INSTALL_PATH"

# EDMA3 LLD install path (required for TCP3D driver build)
#export EDMA3LLD_BIOS6_INSTALLDIR=$HOME/ti/edma3_lld_02_11_07_04
echo "EDMA3LLD_BIOS6_INSTALLDIR set to $EDMA3LLD_BIOS6_INSTALLDIR"

# Run pdkbuilder.sh to build C66x libraries
echo "Run pdkbuilder.sh script to build C66x libraries"

# Keystone 2 AIF2 LLD 
export SOC_FAMILY=KeyStone2
# PDK PARTNO
export PARTNO=keystone2

export CGTOOLS=$C6X_GEN_INSTALL_PATH

# *******************************************************************************
# ** Convert C6X_GEN_INSTALL_PATH and PDK_INSTALL_PATH to short name and to UNIX STYLE PATH  for XDC build **
# *******************************************************************************
if [ ! -z $XDC_INSTALL_PATH ]; then
	export PATH=$PATH:$XDC_INSTALL_PATH/packages/xdc/services/io/release
fi

export XDCCGROOT=$C6X_GEN_INSTALL_PATH
echo CGTOOL INSTALL Directory $C6X_GEN_INSTALL_PATH
echo PDK Directory $PDK_INSTALL_PATH
echo EDMA3 BIOS6 Directory $EDMA3LLD_BIOS6_INSTALLDIR

# *******************************************************************************
# *************************** XDC PATH Configuration ****************************
# *******************************************************************************

# Ensure that all the components inside PDK are a part of the XDC Path; such that
# one component can use another.
export XDCPATH="../../..;$XDC_INSTALL_PATH/packages;$PDK_INSTALL_PATH/.;$C6X_GEN_INSTALL_PATH/include"
export XDCPATH="$XDCPATH;$EDMA3LLD_BIOS6_INSTALLDIR/packages"

# Eclipse Help Plugin (Not required by customers)
if [ ! -z $XDC_ECLIPSE_PLUGIN_INSTALL_PATH ]; then
export XDCPATH="$XDCPATH;$XDC_ECLIPSE_PLUGIN_INSTALL_PATH/."
fi

if [ ! -z $XDC_FILTER_INSTALL_PATH ]; then 
export XDCPATH="$XDCPATH;$XDC_FILTER_INSTALL_PATH/."
fi

# *******************************************************************************
# ************************** Build Tools Configuration **************************
# *******************************************************************************

# XDC Tools location:
export PATH=$PATH:$XDC_INSTALL_PATH:$XDC_INSTALL_PATH/bin

# Compiler Tools: 
export PATH=$PATH:$C6X_GEN_INSTALL_PATH/bin

# CG-XML Package:
export PATH=$PATH:$CG_XML_BIN_INSTALL_PATH

# Third Party Tools: Doxygen
if [ ! -z $DOXYGEN_INSTALL_PATH ];then
export PATH=$PATH:$DOXYGEN_INSTALL_PATH
fi

# Third Party Tools: HTML Help compiler.
if [ ! -z $HTML_HELP_WORKSHOP_INSTALL_PATH ]; then
export PATH=$PATH:$HTML_HELP_WORKSHOP_INSTALL_PATH
fi

# Third Party Tools: Install-Jammer (Not required by customers)
if [ ! -z $INSTALL_JAMMER_DIR ]; then 
export PATH=$PATH:$INSTALL_JAMMER_DIR
fi

# Third Party Tools: Coverity 
if [ ! -z $STATIC_ANALYZE_PATH ]; then
export PATH=$PATH:$STATIC_ANALYZE_PATH/bin
fi

# PDSP CGEN TOOL for PA firmware building
if [ ! -z $PDSP_CGEN_INSTALL_PATH ];then
export PATH=$PATH:$PDSP_CGEN_INSTALL_PATH;
fi

# Set the Title Window appropiately.
#Title PDK Build Environment

echo PDK BUILD ENVIRONMENT CONFIGURED
echo "*******************************************************************************"