/*

 * Copyright (C) 2012-2013 Texas Instruments Incorporated - http://www.ti.com/

 *

 *

 *  Redistribution and use in source and binary forms, with or without

 *  modification, are permitted provided that the following conditions

 *  are met:

 *

 *    Redistributions of source code must retain the above copyright

 *    notice, this list of conditions and the following disclaimer.

 *

 *    Redistributions in binary form must reproduce the above copyright

 *    notice, this list of conditions and the following disclaimer in the

 *    documentation and/or other materials provided with the

 *    distribution.

 *

 *    Neither the name of Texas Instruments Incorporated nor the names of

 *    its contributors may be used to endorse or promote products derived

 *    from this software without specific prior written permission.

 *

 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS

 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT

 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR

 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT

 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,

 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT

 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,

 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY

 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT

 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE

 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 *

*/



/********************************************************************

* file: cslr_ale.h

*

* Brief: This file contains the Register Description for ale

*

*********************************************************************/

#ifndef _CSLR_ALE_H_

#define _CSLR_ALE_H_



#include <ti/csl/cslr.h>

#include <ti/csl/tistdtypes.h>





/* Minimum unit = 1 byte */



/**************************************************************************\

* Register Overlay Structure

\**************************************************************************/

typedef struct  {

    volatile Uint32 IDVER_REG; /* ID / Version */

    volatile Uint32 STATUS_REG; /* Status */

    volatile Uint32 CONTROL_REG; /* Control */

    volatile Uint32 CONTROL2_REG;
    volatile Uint32 PRESCALE_REG; /* Prescale */

    volatile Uint32 AGING_TIMER_REG; /* Aging Timer */

    volatile Uint8 RSVD1[8];

    volatile Uint32 TABLE_CONTROL_REG; /* Table Control */

    volatile Uint8 RSVD2[16];

    volatile Uint32 TABLE_WORD2_REG; /* Table Word 2 */

    volatile Uint32 TABLE_WORD1_REG; /* Table Word 1 */

    volatile Uint32 TABLE_WORD0_REG; /* Table Word 0 */

    volatile Uint32 PORT_CONTROL_REG[8]; /* Port N Control */

    volatile Uint8 RSVD3[48];

    volatile Uint32 UNKNOWN_VLAN_REG; /* Unknown VLAN Member List */

    volatile Uint32 UNKNOWN_MCAST_FLOOD_REG; /* Unknown VLAN Multicast Flood Mask */

    volatile Uint32 UNKNOWN_REG_MCAST_FLOOD_REG; /* Unknown VLAN Multicast Flood Mask */

    volatile Uint32 FORCE_UNTAGGED_EGRESS_REG; /* Unknown VLAN Force Untagged Egress */

    volatile Uint8 RSVD4[32];

    volatile Uint32 VLAN_MASK_MUX_REG[8]; /* VLAN Mask Mux n Select */

} CSL_AleRegs;



/**************************************************************************\

* Field Definition Macros

\**************************************************************************/



/* IDVER_REG */



#define CSL_ALE_IDVER_REG_MINOR_VER_MASK (0x000000FFu)

#define CSL_ALE_IDVER_REG_MINOR_VER_SHIFT (0x00000000u)

#define CSL_ALE_IDVER_REG_MINOR_VER_RESETVAL (0x00000004u)



#define CSL_ALE_IDVER_REG_MAJOR_VER_MASK (0x00000700u)

#define CSL_ALE_IDVER_REG_MAJOR_VER_SHIFT (0x00000008u)

#define CSL_ALE_IDVER_REG_MAJOR_VER_RESETVAL (0x00000001u)



#define CSL_ALE_IDVER_REG_RTL_VER_MASK   (0x0000F800u)

#define CSL_ALE_IDVER_REG_RTL_VER_SHIFT  (0x0000000Bu)

#define CSL_ALE_IDVER_REG_RTL_VER_RESETVAL (0x00000002u)



#define CSL_ALE_IDVER_REG_IDENT_MASK     (0xFFFF0000u)

#define CSL_ALE_IDVER_REG_IDENT_SHIFT    (0x00000010u)

#define CSL_ALE_IDVER_REG_IDENT_RESETVAL (0x00000029u)



#define CSL_ALE_IDVER_REG_RESETVAL       (0x00291104u)



/* STATUS_REG */



#define CSL_ALE_STATUS_REG_KLUENTRIES_MASK (0x0000001Fu)

#define CSL_ALE_STATUS_REG_KLUENTRIES_SHIFT (0x00000000u)

#define CSL_ALE_STATUS_REG_KLUENTRIES_RESETVAL (0x00000001u)



#define CSL_ALE_STATUS_REG_POLCNTDIV8_MASK (0x0000FF00u)

#define CSL_ALE_STATUS_REG_POLCNTDIV8_SHIFT (0x00000008u)

#define CSL_ALE_STATUS_REG_POLCNTDIV8_RESETVAL (0x00000004u)



#define CSL_ALE_STATUS_REG_RESETVAL      (0x00000401u)



/* CONTROL_REG */



#define CSL_ALE_CONTROL_REG_ENABLE_RATE_LIMIT_MASK (0x00000001u)

#define CSL_ALE_CONTROL_REG_ENABLE_RATE_LIMIT_SHIFT (0x00000000u)

#define CSL_ALE_CONTROL_REG_ENABLE_RATE_LIMIT_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_ENABLE_AUTH_MODE_MASK (0x00000002u)

#define CSL_ALE_CONTROL_REG_ENABLE_AUTH_MODE_SHIFT (0x00000001u)

#define CSL_ALE_CONTROL_REG_ENABLE_AUTH_MODE_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_VLAN_AWARE_MASK (0x00000004u)

#define CSL_ALE_CONTROL_REG_VLAN_AWARE_SHIFT (0x00000002u)

#define CSL_ALE_CONTROL_REG_VLAN_AWARE_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_RATE_LIMIT_TX_MASK (0x00000008u)

#define CSL_ALE_CONTROL_REG_RATE_LIMIT_TX_SHIFT (0x00000003u)

#define CSL_ALE_CONTROL_REG_RATE_LIMIT_TX_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_BYPASS_MASK  (0x00000010u)

#define CSL_ALE_CONTROL_REG_BYPASS_SHIFT (0x00000004u)

#define CSL_ALE_CONTROL_REG_BYPASS_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_ENABLE_OUI_DENY_MASK (0x00000020u)

#define CSL_ALE_CONTROL_REG_ENABLE_OUI_DENY_SHIFT (0x00000005u)

#define CSL_ALE_CONTROL_REG_ENABLE_OUI_DENY_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_EN_VID0_MODE_MASK (0x00000040u)

#define CSL_ALE_CONTROL_REG_EN_VID0_MODE_SHIFT (0x00000006u)

#define CSL_ALE_CONTROL_REG_EN_VID0_MODE_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_LEARN_NO_VID_MASK (0x00000080u)

#define CSL_ALE_CONTROL_REG_LEARN_NO_VID_SHIFT (0x00000007u)

#define CSL_ALE_CONTROL_REG_LEARN_NO_VID_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_UNI_FLOOD_TO_HOST_MASK (0x00000100u)

#define CSL_ALE_CONTROL_REG_UNI_FLOOD_TO_HOST_SHIFT (0x00000008u)

#define CSL_ALE_CONTROL_REG_UNI_FLOOD_TO_HOST_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_MACSEC_MODE_MASK (0x00000200u)

#define CSL_ALE_CONTROL_REG_MACSEC_MODE_SHIFT (0x00000009u)

#define CSL_ALE_CONTROL_REG_MACSEC_MODE_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_UVLAN_NO_LEARN_MASK (0x00002000u)

#define CSL_ALE_CONTROL_REG_UVLAN_NO_LEARN_SHIFT (0x0000000Du)

#define CSL_ALE_CONTROL_REG_UVLAN_NO_LEARN_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_UPD_BW_CTL_MASK (0x00E00000u)

#define CSL_ALE_CONTROL_REG_UPD_BW_CTL_SHIFT (0x00000015u)

#define CSL_ALE_CONTROL_REG_UPD_BW_CTL_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_AGE_OUT_NOW_MASK (0x20000000u)

#define CSL_ALE_CONTROL_REG_AGE_OUT_NOW_SHIFT (0x0000001Du)

#define CSL_ALE_CONTROL_REG_AGE_OUT_NOW_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_CLEAR_TABLE_MASK (0x40000000u)

#define CSL_ALE_CONTROL_REG_CLEAR_TABLE_SHIFT (0x0000001Eu)

#define CSL_ALE_CONTROL_REG_CLEAR_TABLE_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_ENABLE_MASK  (0x80000000u)

#define CSL_ALE_CONTROL_REG_ENABLE_SHIFT (0x0000001Fu)

#define CSL_ALE_CONTROL_REG_ENABLE_RESETVAL (0x00000000u)



#define CSL_ALE_CONTROL_REG_RESETVAL     (0x00000000u)



/* CONTROL2_REG */

#define CSL_ALE_CONTROL2_REG_TRK_EN_DST_MASK (0x80000000u)
#define CSL_ALE_CONTROL2_REG_TRK_EN_DST_SHIFT (0x0000001Fu)
#define CSL_ALE_CONTROL2_REG_TRK_EN_DST_RESETVAL (0x00000000u)

#define CSL_ALE_CONTROL2_REG_TRK_EN_SRC_MASK (0x40000000u)
#define CSL_ALE_CONTROL2_REG_TRK_EN_SRC_SHIFT (0x0000001Eu)
#define CSL_ALE_CONTROL2_REG_TRK_EN_SRC_RESETVAL (0x00000000u)

#define CSL_ALE_CONTROL2_REG_TRK_EN_PRI_MASK (0x20000000u)
#define CSL_ALE_CONTROL2_REG_TRK_EN_PRI_SHIFT (0x0000001Du)
#define CSL_ALE_CONTROL2_REG_TRK_EN_PRI_RESETVAL (0x00000000u)

#define CSL_ALE_CONTROL2_REG_TRK_EN_VLAN_MASK (0x10000000u)
#define CSL_ALE_CONTROL2_REG_TRK_EN_VLAN_SHIFT (0x0000001Cu)
#define CSL_ALE_CONTROL2_REG_TRK_EN_VLAN_RESETVAL (0x00000000u)

#define CSL_ALE_CONTROL2_REG_TRK_EN_SIP_MASK (0x02000000u)
#define CSL_ALE_CONTROL2_REG_TRK_EN_SIP_SHIFT (0x00000019u)
#define CSL_ALE_CONTROL2_REG_TRK_EN_SIP_RESETVAL (0x00000000u)

#define CSL_ALE_CONTROL2_REG_TRK_EN_DIP_MASK (0x01000000u)
#define CSL_ALE_CONTROL2_REG_TRK_EN_DIP_SHIFT (0x00000018u)
#define CSL_ALE_CONTROL2_REG_TRK_EN_DIP_RESETVAL (0x00000000u)

#define CSL_ALE_CONTROL2_REG_TRK_BASE_MASK (0x00070000u)
#define CSL_ALE_CONTROL2_REG_TRK_BASE_SHIFT (0x00000010u)
#define CSL_ALE_CONTROL2_REG_TRK_BASE_RESETVAL (0x00000000u)

#define CSL_ALE_CONTROL2_REG_MIRROR_MIDX_MASK (0x000003FFu)
#define CSL_ALE_CONTROL2_REG_MIRROR_MIDX_SHIFT (0x00000000u)
#define CSL_ALE_CONTROL2_REG_MIRROR_MIDX_RESETVAL (0x00000000u)

#define CSL_ALE_CONTROL2_REG_RESETVAL    (0x00000000u)

/* PRESCALE_REG */



#define CSL_ALE_PRESCALE_REG_PRESCALE_MASK (0x000FFFFFu)

#define CSL_ALE_PRESCALE_REG_PRESCALE_SHIFT (0x00000000u)

#define CSL_ALE_PRESCALE_REG_PRESCALE_RESETVAL (0x00000000u)



#define CSL_ALE_PRESCALE_REG_RESETVAL    (0x00000000u)



/* AGING_TIMER_REG */



#define CSL_ALE_AGING_TIMER_REG_AGING_TIMER_MASK (0x00FFFFFFu)

#define CSL_ALE_AGING_TIMER_REG_AGING_TIMER_SHIFT (0x00000000u)

#define CSL_ALE_AGING_TIMER_REG_AGING_TIMER_RESETVAL (0x00000000u)



#define CSL_ALE_AGING_TIMER_REG_PRESCALE_2_DISABLE_MASK (0x40000000u)

#define CSL_ALE_AGING_TIMER_REG_PRESCALE_2_DISABLE_SHIFT (0x0000001Eu)

#define CSL_ALE_AGING_TIMER_REG_PRESCALE_2_DISABLE_RESETVAL (0x00000000u)



#define CSL_ALE_AGING_TIMER_REG_PRESCALE_1_DISABLE_MASK (0x80000000u)

#define CSL_ALE_AGING_TIMER_REG_PRESCALE_1_DISABLE_SHIFT (0x0000001Fu)

#define CSL_ALE_AGING_TIMER_REG_PRESCALE_1_DISABLE_RESETVAL (0x00000000u)



#define CSL_ALE_AGING_TIMER_REG_RESETVAL (0x00000000u)



/* TABLE_CONTROL_REG */



#define CSL_ALE_TABLE_CONTROL_REG_ENTRY_POINTER_MASK (0x000007FFu)

#define CSL_ALE_TABLE_CONTROL_REG_ENTRY_POINTER_SHIFT (0x00000000u)

#define CSL_ALE_TABLE_CONTROL_REG_ENTRY_POINTER_RESETVAL (0x00000000u)



#define CSL_ALE_TABLE_CONTROL_REG_WRITE_RDZ_MASK (0x80000000u)

#define CSL_ALE_TABLE_CONTROL_REG_WRITE_RDZ_SHIFT (0x0000001Fu)

#define CSL_ALE_TABLE_CONTROL_REG_WRITE_RDZ_RESETVAL (0x00000000u)



#define CSL_ALE_TABLE_CONTROL_REG_RESETVAL (0x00000000u)



/* TABLE_WORD2_REG */



#define CSL_ALE_TABLE_WORD2_REG_ENTRY_71_64_MASK (0x000000FFu)

#define CSL_ALE_TABLE_WORD2_REG_ENTRY_71_64_SHIFT (0x00000000u)

#define CSL_ALE_TABLE_WORD2_REG_ENTRY_71_64_RESETVAL (0x00000000u)



#define CSL_ALE_TABLE_WORD2_REG_RESETVAL (0x00000000u)



/* TABLE_WORD1_REG */



#define CSL_ALE_TABLE_WORD1_REG_ENTRY_63_32_MASK (0xFFFFFFFFu)

#define CSL_ALE_TABLE_WORD1_REG_ENTRY_63_32_SHIFT (0x00000000u)

#define CSL_ALE_TABLE_WORD1_REG_ENTRY_63_32_RESETVAL (0x00000000u)



#define CSL_ALE_TABLE_WORD1_REG_RESETVAL (0x00000000u)



/* TABLE_WORD0_REG */



#define CSL_ALE_TABLE_WORD0_REG_ENTRY_31_0_MASK (0xFFFFFFFFu)

#define CSL_ALE_TABLE_WORD0_REG_ENTRY_31_0_SHIFT (0x00000000u)

#define CSL_ALE_TABLE_WORD0_REG_ENTRY_31_0_RESETVAL (0x00000000u)



#define CSL_ALE_TABLE_WORD0_REG_RESETVAL (0x00000000u)



/* PORT_CONTROL_REG */



#define CSL_ALE_PORT_CONTROL_REG_PORT_STATE_MASK (0x00000003u)

#define CSL_ALE_PORT_CONTROL_REG_PORT_STATE_SHIFT (0x00000000u)

#define CSL_ALE_PORT_CONTROL_REG_PORT_STATE_RESETVAL (0x00000000u)



#define CSL_ALE_PORT_CONTROL_REG_DROP_UNTAGGED_MASK (0x00000004u)

#define CSL_ALE_PORT_CONTROL_REG_DROP_UNTAGGED_SHIFT (0x00000002u)

#define CSL_ALE_PORT_CONTROL_REG_DROP_UNTAGGED_RESETVAL (0x00000000u)



#define CSL_ALE_PORT_CONTROL_REG_VID_INGRESS_CHECK_MASK (0x00000008u)

#define CSL_ALE_PORT_CONTROL_REG_VID_INGRESS_CHECK_SHIFT (0x00000003u)

#define CSL_ALE_PORT_CONTROL_REG_VID_INGRESS_CHECK_RESETVAL (0x00000000u)



#define CSL_ALE_PORT_CONTROL_REG_NO_LEARN_MASK (0x00000010u)

#define CSL_ALE_PORT_CONTROL_REG_NO_LEARN_SHIFT (0x00000004u)

#define CSL_ALE_PORT_CONTROL_REG_NO_LEARN_RESETVAL (0x00000000u)



#define CSL_ALE_PORT_CONTROL_REG_NO_SA_UPDATE_MASK (0x00000020u)

#define CSL_ALE_PORT_CONTROL_REG_NO_SA_UPDATE_SHIFT (0x00000005u)

#define CSL_ALE_PORT_CONTROL_REG_NO_SA_UPDATE_RESETVAL (0x00000000u)



#define CSL_ALE_PORT_CONTROL_REG_MACSEC_PORTS_MASK (0x00000040u)

#define CSL_ALE_PORT_CONTROL_REG_MACSEC_PORTS_SHIFT (0x00000006u)

#define CSL_ALE_PORT_CONTROL_REG_MACSEC_PORTS_RESETVAL (0x00000000u)



#define CSL_ALE_PORT_CONTROL_REG_DISABLE_AUTH_MODE_MASK (0x00001000u)

#define CSL_ALE_PORT_CONTROL_REG_DISABLE_AUTH_MODE_SHIFT (0x0000000Cu)

#define CSL_ALE_PORT_CONTROL_REG_DISABLE_AUTH_MODE_RESETVAL (0x00000000u)



#define CSL_ALE_PORT_CONTROL_REG_MCAST_LIMIT_MASK (0x00FF0000u)

#define CSL_ALE_PORT_CONTROL_REG_MCAST_LIMIT_SHIFT (0x00000010u)

#define CSL_ALE_PORT_CONTROL_REG_MCAST_LIMIT_RESETVAL (0x00000000u)



#define CSL_ALE_PORT_CONTROL_REG_BCAST_LIMIT_MASK (0xFF000000u)

#define CSL_ALE_PORT_CONTROL_REG_BCAST_LIMIT_SHIFT (0x00000018u)

#define CSL_ALE_PORT_CONTROL_REG_BCAST_LIMIT_RESETVAL (0x00000000u)



#define CSL_ALE_PORT_CONTROL_REG_RESETVAL (0x00000000u)



/* UNKNOWN_VLAN_REG */



#define CSL_ALE_UNKNOWN_VLAN_REG_LIST_MASK (0x0000001Fu)

#define CSL_ALE_UNKNOWN_VLAN_REG_LIST_SHIFT (0x00000000u)

#define CSL_ALE_UNKNOWN_VLAN_REG_LIST_RESETVAL (0x00000000u)



#define CSL_ALE_UNKNOWN_VLAN_REG_RESETVAL (0x00000000u)



/* UNKNOWN_MCAST_FLOOD_REG */



#define CSL_ALE_UNKNOWN_MCAST_FLOOD_REG_MASK_MASK (0x0000001Fu)

#define CSL_ALE_UNKNOWN_MCAST_FLOOD_REG_MASK_SHIFT (0x00000000u)

#define CSL_ALE_UNKNOWN_MCAST_FLOOD_REG_MASK_RESETVAL (0x00000000u)



#define CSL_ALE_UNKNOWN_MCAST_FLOOD_REG_RESETVAL (0x00000000u)



/* UNKNOWN_REG_MCAST_FLOOD_REG */



#define CSL_ALE_UNKNOWN_REG_MCAST_FLOOD_REG_MASK_MASK (0x0000001Fu)

#define CSL_ALE_UNKNOWN_REG_MCAST_FLOOD_REG_MASK_SHIFT (0x00000000u)

#define CSL_ALE_UNKNOWN_REG_MCAST_FLOOD_REG_MASK_RESETVAL (0x00000000u)



#define CSL_ALE_UNKNOWN_REG_MCAST_FLOOD_REG_RESETVAL (0x00000000u)



/* FORCE_UNTAGGED_EGRESS_REG */



#define CSL_ALE_FORCE_UNTAGGED_EGRESS_REG_MASK_MASK (0x0000001Fu)

#define CSL_ALE_FORCE_UNTAGGED_EGRESS_REG_MASK_SHIFT (0x00000000u)

#define CSL_ALE_FORCE_UNTAGGED_EGRESS_REG_MASK_RESETVAL (0x00000000u)



#define CSL_ALE_FORCE_UNTAGGED_EGRESS_REG_RESETVAL (0x00000000u)



/* VLAN_MASK_MUX_REG */



#define CSL_ALE_VLAN_MASK_MUX_REG_MASK_MASK (0x0000001Fu)

#define CSL_ALE_VLAN_MASK_MUX_REG_MASK_SHIFT (0x00000000u)

#define CSL_ALE_VLAN_MASK_MUX_REG_MASK_RESETVAL (0x00000000u)



#define CSL_ALE_VLAN_MASK_MUX_REG_RESETVAL (0x00000000u)



#endif

