/********************************************************************
* Copyright (C) 2003-2008 Texas Instruments Incorporated.
* All Rights Reserved
*********************************************************************
* file: cslr_bcp_rd.h
*
* Brief: This file contains the Register Description for bcp_rd
*
*********************************************************************/
#ifndef _CSLR_BCP_RD_MMR_H_
#define _CSLR_BCP_RD_MMR_H_

#include <ti/csl/cslr.h>

#include <ti/csl/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure for RD Interrupt Registers
\**************************************************************************/
typedef struct  {
    volatile Uint32 RD_INTR_IRS; /* BCP Raw Status Register */
    volatile Uint32 RD_INTR_IRS_SET; /* BCP Set Raw Status Register */
    volatile Uint32 RD_INTR_IRS_CLR; /* BCP Clear Raw Status Register */
    volatile Uint32 RD_INTR_EN; /* BCP Enable RD_intr0 Register */
    volatile Uint32 RD_INTR_EN_SET; /* BCP Set Enable RD_intr0 Register */
    volatile Uint32 RD_INTR_EN_CLR; /* BCP Clear Enable RD_intr0 Register */
    volatile Uint32 RD_INTR_EN_STS; /* BCP Enabled RD_intr0 Register */
} CSL_Bcp_rdRd_interrupt_registersRegs; /* RD interrupt register group */

/**************************************************************************\
* Register Overlay Structure for RD Data Logger
\**************************************************************************/
typedef struct  {
    volatile Uint32 RD_DLG_GLOBAL_HDR; /* Data logger control Register */
    volatile Uint32 RD_DLG_TM_SW_TIMESTAMP; /* Data logger control Register */
    volatile Uint32 RD_DLG_HW_TIMESTAMP_ENG_ERR; /* Data logger control Register */
    volatile Uint8 RSVD0[4];
} CSL_Bcp_rdRd_data_loggerRegs; /* Data Logger */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 RD_VBUSM_PRIORITY; /* BCP RD Vbusm priority Register */
    volatile Uint32 LTE_SATVAL; /* LTE LLR and Beta saturation values register */
    volatile Uint32 WIMAX_SATVAL; /* WIMAX LLR saturation values register */
    volatile Uint32 XCDMA_HSPA_SATVAL; /* XCMA HSPA LLR and Beta saturation values register */
    volatile Uint32 XCDMA_R99_SATVAL; /* XCMA R99 LLR and Beta saturation values register */
    volatile Uint8 RSVD1[108];
    CSL_Bcp_rdRd_interrupt_registersRegs RD_INTERRUPT_REGISTERS[4];
    volatile Uint32 RD_DATA_LOGGER_CTL; /* Data logger control Register */
    volatile Uint32 RD_DATA_LOGGER_STATUS; /* Datalogger Status Register */
    volatile Uint32 RD_GLOBAL_HDR; /* RD Global Header Register */
    volatile Uint8 RSVD2[37892];
    CSL_Bcp_rdRd_data_loggerRegs RD_DATA_LOGGER[256];
} CSL_Bcp_rdRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* RD_intr_irs */

#define CSL_BCP_RD_RD_INTR_IRS_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_RD_RD_INTR_IRS_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_INTR_IRS_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_IRS_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_RD_RD_INTR_IRS_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_RD_RD_INTR_IRS_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_IRS_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_RD_RD_INTR_IRS_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_RD_RD_INTR_IRS_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_INTR_IRS_RESETVAL  (0x00000000u)

/* RD_intr_irs_set */

#define CSL_BCP_RD_RD_INTR_IRS_SET_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_RD_RD_INTR_IRS_SET_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_INTR_IRS_SET_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_IRS_SET_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_RD_RD_INTR_IRS_SET_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_RD_RD_INTR_IRS_SET_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_IRS_SET_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_RD_RD_INTR_IRS_SET_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_RD_RD_INTR_IRS_SET_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_INTR_IRS_SET_RESETVAL (0x00000000u)

/* RD_intr_irs_clr */

#define CSL_BCP_RD_RD_INTR_IRS_CLR_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_RD_RD_INTR_IRS_CLR_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_INTR_IRS_CLR_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_IRS_CLR_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_RD_RD_INTR_IRS_CLR_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_RD_RD_INTR_IRS_CLR_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_IRS_CLR_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_RD_RD_INTR_IRS_CLR_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_RD_RD_INTR_IRS_CLR_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_INTR_IRS_CLR_RESETVAL (0x00000000u)

/* RD_intr_en */

#define CSL_BCP_RD_RD_INTR_EN_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_RD_RD_INTR_EN_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_INTR_EN_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_EN_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_RD_RD_INTR_EN_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_RD_RD_INTR_EN_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_EN_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_RD_RD_INTR_EN_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_RD_RD_INTR_EN_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_INTR_EN_RESETVAL   (0x00000000u)

/* RD_intr_en_set */

#define CSL_BCP_RD_RD_INTR_EN_SET_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_RD_RD_INTR_EN_SET_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_INTR_EN_SET_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_EN_SET_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_RD_RD_INTR_EN_SET_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_RD_RD_INTR_EN_SET_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_EN_SET_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_RD_RD_INTR_EN_SET_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_RD_RD_INTR_EN_SET_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_INTR_EN_SET_RESETVAL (0x00000000u)

/* RD_intr_en_clr */

#define CSL_BCP_RD_RD_INTR_EN_CLR_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_RD_RD_INTR_EN_CLR_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_INTR_EN_CLR_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_EN_CLR_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_RD_RD_INTR_EN_CLR_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_RD_RD_INTR_EN_CLR_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_EN_CLR_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_RD_RD_INTR_EN_CLR_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_RD_RD_INTR_EN_CLR_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_INTR_EN_CLR_RESETVAL (0x00000000u)

/* RD_intr_en_sts */

#define CSL_BCP_RD_RD_INTR_EN_STS_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_RD_RD_INTR_EN_STS_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_INTR_EN_STS_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_EN_STS_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_RD_RD_INTR_EN_STS_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_RD_RD_INTR_EN_STS_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_INTR_EN_STS_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_RD_RD_INTR_EN_STS_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_RD_RD_INTR_EN_STS_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_INTR_EN_STS_RESETVAL (0x00000000u)

/* rd_dlg_global_hdr */

#define CSL_BCP_RD_RD_DLG_GLOBAL_HDR_GLOBAL_HDR_MASK (0xFFFFFFFFu)
#define CSL_BCP_RD_RD_DLG_GLOBAL_HDR_GLOBAL_HDR_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_DLG_GLOBAL_HDR_GLOBAL_HDR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_DLG_GLOBAL_HDR_RESETVAL (0x00000000u)

/* rd_dlg_tm_sw_timestamp */

#define CSL_BCP_RD_RD_DLG_TM_SW_TIMESTAMP_TM_SW_TIMESTAMP_MASK (0xFFFFFFFFu)
#define CSL_BCP_RD_RD_DLG_TM_SW_TIMESTAMP_TM_SW_TIMESTAMP_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_DLG_TM_SW_TIMESTAMP_TM_SW_TIMESTAMP_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_DLG_TM_SW_TIMESTAMP_RESETVAL (0x00000000u)

/* rd_dlg_hw_timestamp_eng_err */

#define CSL_BCP_RD_RD_DLG_HW_TIMESTAMP_ENG_ERR_TM_HW_TIMESTAMP_MASK (0x00FFFFFFu)
#define CSL_BCP_RD_RD_DLG_HW_TIMESTAMP_ENG_ERR_TM_HW_TIMESTAMP_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_DLG_HW_TIMESTAMP_ENG_ERR_TM_HW_TIMESTAMP_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_DLG_HW_TIMESTAMP_ENG_ERR_ENG_ERR_MASK (0xFF000000u)
#define CSL_BCP_RD_RD_DLG_HW_TIMESTAMP_ENG_ERR_ENG_ERR_SHIFT (0x00000018u)
#define CSL_BCP_RD_RD_DLG_HW_TIMESTAMP_ENG_ERR_ENG_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_DLG_HW_TIMESTAMP_ENG_ERR_RESETVAL (0x00000000u)

/* RD_vbusm_priority */

#define CSL_BCP_RD_RD_VBUSM_PRIORITY_DIO_VBUSM_PRIORITY_MASK (0x00000007u)
#define CSL_BCP_RD_RD_VBUSM_PRIORITY_DIO_VBUSM_PRIORITY_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_VBUSM_PRIORITY_DIO_VBUSM_PRIORITY_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_VBUSM_PRIORITY_RESETVAL (0x00000000u)

/* lte_satval */

#define CSL_BCP_RD_LTE_SATVAL_LLRSAT_0_MASK (0x000000FFu)
#define CSL_BCP_RD_LTE_SATVAL_LLRSAT_0_SHIFT (0x00000000u)
#define CSL_BCP_RD_LTE_SATVAL_LLRSAT_0_RESETVAL (0x0000001Fu)

#define CSL_BCP_RD_LTE_SATVAL_LLRSAT_1_MASK (0x0000FF00u)
#define CSL_BCP_RD_LTE_SATVAL_LLRSAT_1_SHIFT (0x00000008u)
#define CSL_BCP_RD_LTE_SATVAL_LLRSAT_1_RESETVAL (0x0000007Fu)

#define CSL_BCP_RD_LTE_SATVAL_BETASAT_0_MASK (0x00FF0000u)
#define CSL_BCP_RD_LTE_SATVAL_BETASAT_0_SHIFT (0x00000010u)
#define CSL_BCP_RD_LTE_SATVAL_BETASAT_0_RESETVAL (0x000000FFu)

#define CSL_BCP_RD_LTE_SATVAL_BETASAT_1_MASK (0xFF000000u)
#define CSL_BCP_RD_LTE_SATVAL_BETASAT_1_SHIFT (0x00000018u)
#define CSL_BCP_RD_LTE_SATVAL_BETASAT_1_RESETVAL (0x000000FFu)

#define CSL_BCP_RD_LTE_SATVAL_RESETVAL   (0xFFFF7F1Fu)

/* wimax_satval */

#define CSL_BCP_RD_WIMAX_SATVAL_LLRSAT_0_MASK (0x000000FFu)
#define CSL_BCP_RD_WIMAX_SATVAL_LLRSAT_0_SHIFT (0x00000000u)
#define CSL_BCP_RD_WIMAX_SATVAL_LLRSAT_0_RESETVAL (0x0000001Fu)

#define CSL_BCP_RD_WIMAX_SATVAL_LLRSAT_1_MASK (0x0000FF00u)
#define CSL_BCP_RD_WIMAX_SATVAL_LLRSAT_1_SHIFT (0x00000008u)
#define CSL_BCP_RD_WIMAX_SATVAL_LLRSAT_1_RESETVAL (0x0000007Fu)


#define CSL_BCP_RD_WIMAX_SATVAL_RESETVAL (0x00007F1Fu)

/* xcdma_hspa_satval */

#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_LLRSAT_0_MASK (0x000000FFu)
#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_LLRSAT_0_SHIFT (0x00000000u)
#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_LLRSAT_0_RESETVAL (0x0000001Fu)

#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_LLRSAT_1_MASK (0x0000FF00u)
#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_LLRSAT_1_SHIFT (0x00000008u)
#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_LLRSAT_1_RESETVAL (0x0000007Fu)

#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_BETASAT_0_MASK (0x00FF0000u)
#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_BETASAT_0_SHIFT (0x00000010u)
#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_BETASAT_0_RESETVAL (0x000000FFu)

#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_BETASAT_1_MASK (0xFF000000u)
#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_BETASAT_1_SHIFT (0x00000018u)
#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_BETASAT_1_RESETVAL (0x000000FFu)

#define CSL_BCP_RD_XCDMA_HSPA_SATVAL_RESETVAL (0xFFFF7F1Fu)

/* xcdma_r99_satval */

#define CSL_BCP_RD_XCDMA_R99_SATVAL_LLRSAT_0_MASK (0x000000FFu)
#define CSL_BCP_RD_XCDMA_R99_SATVAL_LLRSAT_0_SHIFT (0x00000000u)
#define CSL_BCP_RD_XCDMA_R99_SATVAL_LLRSAT_0_RESETVAL (0x0000001Fu)

#define CSL_BCP_RD_XCDMA_R99_SATVAL_LLRSAT_1_MASK (0x0000FF00u)
#define CSL_BCP_RD_XCDMA_R99_SATVAL_LLRSAT_1_SHIFT (0x00000008u)
#define CSL_BCP_RD_XCDMA_R99_SATVAL_LLRSAT_1_RESETVAL (0x0000007Fu)


#define CSL_BCP_RD_XCDMA_R99_SATVAL_RESETVAL (0x00007F1Fu)

/* RD_data_logger_ctl */

#define CSL_BCP_RD_RD_DATA_LOGGER_CTL_DLG_CTL_MASK (0x00000007u)
#define CSL_BCP_RD_RD_DATA_LOGGER_CTL_DLG_CTL_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_DATA_LOGGER_CTL_DLG_CTL_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_DATA_LOGGER_CTL_DLG_ERR_MASK_MASK (0x01FF0000u)
#define CSL_BCP_RD_RD_DATA_LOGGER_CTL_DLG_ERR_MASK_SHIFT (0x00000010u)
#define CSL_BCP_RD_RD_DATA_LOGGER_CTL_DLG_ERR_MASK_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_DATA_LOGGER_CTL_RESETVAL (0x00000000u)

/* RD_data_logger_status */

#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_WR_PTR_MASK (0x000000FFu)
#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_WR_PTR_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_WR_PTR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_WR_WRAP_MASK (0x0000FF00u)
#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_WR_WRAP_SHIFT (0x00000008u)
#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_WR_WRAP_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_MEM_HAS_ERROR_MASK (0x00010000u)
#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_MEM_HAS_ERROR_SHIFT (0x00000010u)
#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_MEM_HAS_ERROR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_RUNNING_MASK (0x00020000u)
#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_RUNNING_SHIFT (0x00000011u)
#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_DLG_RUNNING_RESETVAL (0x00000000u)


#define CSL_BCP_RD_RD_DATA_LOGGER_STATUS_RESETVAL (0x00000000u)

/* RD_global_hdr */

#define CSL_BCP_RD_RD_GLOBAL_HDR_GLOBAL_HDR_MASK (0xFFFFFFFFu)
#define CSL_BCP_RD_RD_GLOBAL_HDR_GLOBAL_HDR_SHIFT (0x00000000u)
#define CSL_BCP_RD_RD_GLOBAL_HDR_GLOBAL_HDR_RESETVAL (0x00000000u)

#define CSL_BCP_RD_RD_GLOBAL_HDR_RESETVAL (0x00000000u)

#endif
