/*
 * Copyright (C) 2012-2013 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

/********************************************************************
* file: cslr_ecc_aggr.h
*
* Brief: This file contains the Register Description for ecc_aggr
*
*********************************************************************/
#ifndef _CSLR_ECC_AGGR_H_
#define _CSLR_ECC_AGGR_H_

#include <ti/csl/cslr.h>
#include <ti/csl/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 REVISION; /* The Revision Register contains the ID and revision information. */
    volatile Uint8 RSVD0[4];
    volatile Uint32 VECTOR; /* ECC RAM ID to select the ECC RAM to control or read status. */
    volatile Uint32 MISC_STATUS; /* Miscellaneous status register. */
    volatile Uint32 WRAPPER_REVISION; /* The Revision Register contains the ID and revision information for the ECC wrapper. */
    volatile Uint32 CONTROL; /* The Control Register controls the ECC control bits for the selected ECC RAM. */
    volatile Uint32 ERROR_CONTROL1; /* This register contains ECC error control bits for the selected ECC RAM. */
    volatile Uint32 ERROR_CONTROL2; /* This register contains ECC error control bits for the selected ECC RAM. */
    volatile Uint32 ERROR_STATUS1; /* This register contains ECC status bits for the selected ECC RAM. */
    volatile Uint32 ERROR_STATUS2; /* This register contains ECC status bits for the selected ECC RAM. */
    volatile Uint8 RSVD1[20];
    volatile Uint32 EOI; /* This is the EOI register for the interrupt to the host. */
    volatile Uint32 INT_STATUS[16]; /* These are the raw level interrupt status bits where each bit corresponds to the pending status from an ECC RAM. */
    volatile Uint32 INT_ENABLE[16]; /* These are interrupt enables associated with the interrupt from each of the ECC RAMs. Writing a 1 to a bit position in the register enables the interrupt from the associated ECC RAM. */
    volatile Uint32 INT_CLEAR[16]; /* These are interrupt enable clear bits associated with the interrupt from each of the ECC RAMs. Writing a 1 to a bit position in the register disables the interrupt from the associated ECC RAM. */
} CSL_Ecc_aggrRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* REVISION */

#define CSL_ECC_AGGR_REVISION_SCHEME_MASK (0xC0000000u)
#define CSL_ECC_AGGR_REVISION_SCHEME_SHIFT (0x0000001Eu)
#define CSL_ECC_AGGR_REVISION_SCHEME_RESETVAL (0x00000001u)

#define CSL_ECC_AGGR_REVISION_MODID_MASK (0x0FFF0000u)
#define CSL_ECC_AGGR_REVISION_MODID_SHIFT (0x00000010u)
#define CSL_ECC_AGGR_REVISION_MODID_RESETVAL (0x00000E10u)

#define CSL_ECC_AGGR_REVISION_REVRTL_MASK (0x0000F800u)
#define CSL_ECC_AGGR_REVISION_REVRTL_SHIFT (0x0000000Bu)
#define CSL_ECC_AGGR_REVISION_REVRTL_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_REVISION_REVMAJ_MASK (0x00000700u)
#define CSL_ECC_AGGR_REVISION_REVMAJ_SHIFT (0x00000008u)
#define CSL_ECC_AGGR_REVISION_REVMAJ_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_REVISION_REVCUSTOM_MASK (0x000000C0u)
#define CSL_ECC_AGGR_REVISION_REVCUSTOM_SHIFT (0x00000006u)
#define CSL_ECC_AGGR_REVISION_REVCUSTOM_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_REVISION_REVMIN_MASK (0x0000003Fu)
#define CSL_ECC_AGGR_REVISION_REVMIN_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_REVISION_REVMIN_RESETVAL (0x00000001u)

#define CSL_ECC_AGGR_REVISION_RESETVAL   (0x4E100001u)

/* VECTOR */

#define CSL_ECC_AGGR_VECTOR_READ_DONE_MASK (0x01000000u)
#define CSL_ECC_AGGR_VECTOR_READ_DONE_SHIFT (0x00000018u)
#define CSL_ECC_AGGR_VECTOR_READ_DONE_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_VECTOR_READ_ADDRESS_MASK (0x00FF0000u)
#define CSL_ECC_AGGR_VECTOR_READ_ADDRESS_SHIFT (0x00000010u)
#define CSL_ECC_AGGR_VECTOR_READ_ADDRESS_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_VECTOR_TRIGGER_READ_MASK (0x00008000u)
#define CSL_ECC_AGGR_VECTOR_TRIGGER_READ_SHIFT (0x0000000Fu)
#define CSL_ECC_AGGR_VECTOR_TRIGGER_READ_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_VECTOR_RAM_ID_MASK  (0x000007FFu)
#define CSL_ECC_AGGR_VECTOR_RAM_ID_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_VECTOR_RAM_ID_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_VECTOR_RESETVAL     (0x00000000u)

/* MISC_STATUS */

#define CSL_ECC_AGGR_MISC_STATUS_NUM_RAMS_MASK (0x000007FFu)
#define CSL_ECC_AGGR_MISC_STATUS_NUM_RAMS_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_MISC_STATUS_NUM_RAMS_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_MISC_STATUS_RESETVAL (0x00000000u)

/* WRAPPER_REVISION */

#define CSL_ECC_AGGR_WRAPPER_REVISION_SCHEME_MASK (0xC0000000u)
#define CSL_ECC_AGGR_WRAPPER_REVISION_SCHEME_SHIFT (0x0000001Eu)
#define CSL_ECC_AGGR_WRAPPER_REVISION_SCHEME_RESETVAL (0x00000001u)

#define CSL_ECC_AGGR_WRAPPER_REVISION_MODID_MASK (0x0FFF0000u)
#define CSL_ECC_AGGR_WRAPPER_REVISION_MODID_SHIFT (0x00000010u)
#define CSL_ECC_AGGR_WRAPPER_REVISION_MODID_RESETVAL (0x00000E11u)

#define CSL_ECC_AGGR_WRAPPER_REVISION_REVRTL_MASK (0x0000F800u)
#define CSL_ECC_AGGR_WRAPPER_REVISION_REVRTL_SHIFT (0x0000000Bu)
#define CSL_ECC_AGGR_WRAPPER_REVISION_REVRTL_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_WRAPPER_REVISION_REVMAJ_MASK (0x00000700u)
#define CSL_ECC_AGGR_WRAPPER_REVISION_REVMAJ_SHIFT (0x00000008u)
#define CSL_ECC_AGGR_WRAPPER_REVISION_REVMAJ_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_WRAPPER_REVISION_REVCUSTOM_MASK (0x000000C0u)
#define CSL_ECC_AGGR_WRAPPER_REVISION_REVCUSTOM_SHIFT (0x00000006u)
#define CSL_ECC_AGGR_WRAPPER_REVISION_REVCUSTOM_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_WRAPPER_REVISION_REVMIN_MASK (0x0000003Fu)
#define CSL_ECC_AGGR_WRAPPER_REVISION_REVMIN_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_WRAPPER_REVISION_REVMIN_RESETVAL (0x00000001u)

#define CSL_ECC_AGGR_WRAPPER_REVISION_RESETVAL (0x4E110001u)

/* CONTROL */

#define CSL_ECC_AGGR_CONTROL_ERROR_ONCE_MASK (0x00000040u)
#define CSL_ECC_AGGR_CONTROL_ERROR_ONCE_SHIFT (0x00000006u)
#define CSL_ECC_AGGR_CONTROL_ERROR_ONCE_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_CONTROL_FORCE_N_ROW_MASK (0x00000020u)
#define CSL_ECC_AGGR_CONTROL_FORCE_N_ROW_SHIFT (0x00000005u)
#define CSL_ECC_AGGR_CONTROL_FORCE_N_ROW_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_CONTROL_FORCE_DED_MASK (0x00000010u)
#define CSL_ECC_AGGR_CONTROL_FORCE_DED_SHIFT (0x00000004u)
#define CSL_ECC_AGGR_CONTROL_FORCE_DED_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_CONTROL_FORCE_SEC_MASK (0x00000008u)
#define CSL_ECC_AGGR_CONTROL_FORCE_SEC_SHIFT (0x00000003u)
#define CSL_ECC_AGGR_CONTROL_FORCE_SEC_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_CONTROL_ENABLE_RMW_MASK (0x00000004u)
#define CSL_ECC_AGGR_CONTROL_ENABLE_RMW_SHIFT (0x00000002u)
#define CSL_ECC_AGGR_CONTROL_ENABLE_RMW_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_CONTROL_ECC_CHECK_MASK (0x00000002u)
#define CSL_ECC_AGGR_CONTROL_ECC_CHECK_SHIFT (0x00000001u)
#define CSL_ECC_AGGR_CONTROL_ECC_CHECK_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_CONTROL_ECC_ENABLE_MASK (0x00000001u)
#define CSL_ECC_AGGR_CONTROL_ECC_ENABLE_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_CONTROL_ECC_ENABLE_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_CONTROL_RESETVAL    (0x00000000u)

/* ERROR_CONTROL1 */

#define CSL_ECC_AGGR_ERROR_CONTROL1_ECC_BIT1_MASK (0xFFFF0000u)
#define CSL_ECC_AGGR_ERROR_CONTROL1_ECC_BIT1_SHIFT (0x00000010u)
#define CSL_ECC_AGGR_ERROR_CONTROL1_ECC_BIT1_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_CONTROL1_ECC_ROW_MASK (0x0000FFFFu)
#define CSL_ECC_AGGR_ERROR_CONTROL1_ECC_ROW_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_ERROR_CONTROL1_ECC_ROW_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_CONTROL1_RESETVAL (0x00000000u)

/* ERROR_CONTROL2 */

#define CSL_ECC_AGGR_ERROR_CONTROL2_ECC_BIT2_MASK (0x0000FFFFu)
#define CSL_ECC_AGGR_ERROR_CONTROL2_ECC_BIT2_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_ERROR_CONTROL2_ECC_BIT2_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_CONTROL2_RESETVAL (0x00000000u)

/* ERROR_STATUS1 */

#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_ROW_MASK (0xFFFF0000u)
#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_ROW_SHIFT (0x00000010u)
#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_ROW_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_STATUS1_CLR_ECC_OTHER_MASK (0x00000400u)
#define CSL_ECC_AGGR_ERROR_STATUS1_CLR_ECC_OTHER_SHIFT (0x0000000Au)
#define CSL_ECC_AGGR_ERROR_STATUS1_CLR_ECC_OTHER_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_STATUS1_CLR_ECC_DED_MASK (0x00000200u)
#define CSL_ECC_AGGR_ERROR_STATUS1_CLR_ECC_DED_SHIFT (0x00000009u)
#define CSL_ECC_AGGR_ERROR_STATUS1_CLR_ECC_DED_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_STATUS1_CLR_ECC_SEC_MASK (0x00000100u)
#define CSL_ECC_AGGR_ERROR_STATUS1_CLR_ECC_SEC_SHIFT (0x00000008u)
#define CSL_ECC_AGGR_ERROR_STATUS1_CLR_ECC_SEC_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_OTHER_MASK (0x00000004u)
#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_OTHER_SHIFT (0x00000002u)
#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_OTHER_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_DED_MASK (0x00000002u)
#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_DED_SHIFT (0x00000001u)
#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_DED_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_SEC_MASK (0x00000001u)
#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_SEC_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_ERROR_STATUS1_ECC_SEC_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_STATUS1_RESETVAL (0x00000000u)

/* ERROR_STATUS2 */

#define CSL_ECC_AGGR_ERROR_STATUS2_ECC_BIT1_MASK (0x0000FFFFu)
#define CSL_ECC_AGGR_ERROR_STATUS2_ECC_BIT1_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_ERROR_STATUS2_ECC_BIT1_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_ERROR_STATUS2_RESETVAL (0x00000000u)

/* EOI */

#define CSL_ECC_AGGR_EOI_EOI_WR_MASK     (0x00000001u)
#define CSL_ECC_AGGR_EOI_EOI_WR_SHIFT    (0x00000000u)
#define CSL_ECC_AGGR_EOI_EOI_WR_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_EOI_RESETVAL        (0x00000000u)

/* INT_STATUS */

#define CSL_ECC_AGGR_INT_STATUS_BITMASK_MASK (0xFFFFFFFFu)
#define CSL_ECC_AGGR_INT_STATUS_BITMASK_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_INT_STATUS_BITMASK_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_INT_STATUS_RESETVAL (0x00000000u)

/* INT_ENABLE */

#define CSL_ECC_AGGR_INT_ENABLE_BITMASK_MASK (0xFFFFFFFFu)
#define CSL_ECC_AGGR_INT_ENABLE_BITMASK_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_INT_ENABLE_BITMASK_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_INT_ENABLE_RESETVAL (0x00000000u)

/* INT_CLEAR */

#define CSL_ECC_AGGR_INT_CLEAR_BITMASK_MASK (0xFFFFFFFFu)
#define CSL_ECC_AGGR_INT_CLEAR_BITMASK_SHIFT (0x00000000u)
#define CSL_ECC_AGGR_INT_CLEAR_BITMASK_RESETVAL (0x00000000u)

#define CSL_ECC_AGGR_INT_CLEAR_RESETVAL  (0x00000000u)

#endif
