/********************************************************************
 * Copyright (C) 2003-2011 Texas Instruments Incorporated.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
/*********************************************************************
* file: cslr_usimocp.h
*
* Brief: This file contains the Register Description for usimocp
*
*********************************************************************/
#ifndef _CSLR_USIMOCP_H_
#define _CSLR_USIMOCP_H_

/* CSL Modification:
 *  The file has been modified from the AUTOGEN file for the following
 *  reasons:-
 *      a)  Modified the header file includes to be RTSC compliant
 */
#include <ti/csl/cslr.h>
#include <ti/csl/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure for __ALL__
\**************************************************************************/
typedef struct  {
    volatile Uint32 REVISION;
    volatile Uint32 IDENT;
    volatile Uint8 RSVD0[8];
    volatile Uint32 SYSCONFIG;
    volatile Uint32 SYSSTATUS;
    volatile Uint32 IRQSTATUS;
    volatile Uint32 IRQENABLE;
    volatile Uint32 WAKEUPEN;
    volatile Uint32 USIMCMD;
    volatile Uint32 USIMSTAT;
    volatile Uint32 USIMCONF1;
    volatile Uint32 USIMCONF2;
    volatile Uint32 USIMCONF3;
    volatile Uint32 USIM_DRX;
    volatile Uint32 USIM_DTX;
    volatile Uint32 USIM_FIFOS;
    volatile Uint32 USIM_CGT;
    volatile Uint32 USIM_CWT;
    volatile Uint32 USIM_BWT;
    volatile Uint32 DEBUG_REG;
    volatile Uint32 CONF_SAM1_DIV;
    volatile Uint32 CONF4_REG;
    volatile Uint32 ATR_CLK_PRD_NBS;
    volatile Uint32 CONF_ETU_DIV;
    volatile Uint32 CONF5_REG;
    volatile Uint32 TC_GUARD_TIME_ADD;
    volatile Uint32 USIM_RXFIFO_LEVEL;
    volatile Uint32 USIM_RXFIFO_BYTECNT;
} CSL_Usimocp__all__Regs;

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    CSL_Usimocp__all__Regs __ALL__;
} CSL_UsimocpRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* REVISION */

#define CSL_USIMOCP_REVISION_REV_MASK    (0x000000FFu)
#define CSL_USIMOCP_REVISION_REV_SHIFT   (0x00000000u)
#define CSL_USIMOCP_REVISION_REV_RESETVAL (0x00000000u)

#define CSL_USIMOCP_REVISION_RESERVED_24_MASK (0xFFFFFF00u)
#define CSL_USIMOCP_REVISION_RESERVED_24_SHIFT (0x00000008u)
#define CSL_USIMOCP_REVISION_RESERVED_24_RESETVAL (0x00000000u)

#define CSL_USIMOCP_REVISION_RESETVAL    (0x00000000u)

/* IDENT */

#define CSL_USIMOCP_IDENT_VC_MASK        (0x0000FFFFu)
#define CSL_USIMOCP_IDENT_VC_SHIFT       (0x00000000u)
#define CSL_USIMOCP_IDENT_VC_RESETVAL    (0x00000000u)

#define CSL_USIMOCP_IDENT_RESERVED_16_31_MASK (0xFFFF0000u)
#define CSL_USIMOCP_IDENT_RESERVED_16_31_SHIFT (0x00000010u)
#define CSL_USIMOCP_IDENT_RESERVED_16_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IDENT_RESETVAL       (0x00000000u)

/* SYSCONFIG */

#define CSL_USIMOCP_SYSCONFIG_AUTOIDLE_MASK (0x00000001u)
#define CSL_USIMOCP_SYSCONFIG_AUTOIDLE_SHIFT (0x00000000u)
#define CSL_USIMOCP_SYSCONFIG_AUTOIDLE_RESETVAL (0x00000000u)
/*----AUTOIDLE Tokens----*/
#define CSL_USIMOCP_SYSCONFIG_AUTOIDLE_AUTOIDLE_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_SYSCONFIG_AUTOIDLE_AUTOIDLE_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_SYSCONFIG_SOFTRESET_MASK (0x00000002u)
#define CSL_USIMOCP_SYSCONFIG_SOFTRESET_SHIFT (0x00000001u)
#define CSL_USIMOCP_SYSCONFIG_SOFTRESET_RESETVAL (0x00000000u)
/*----SOFTRESET Tokens----*/
#define CSL_USIMOCP_SYSCONFIG_SOFTRESET_SOFTRESET_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_SYSCONFIG_SOFTRESET_SOFTRESET_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_SYSCONFIG_ENAWAKEUP_MASK (0x00000004u)
#define CSL_USIMOCP_SYSCONFIG_ENAWAKEUP_SHIFT (0x00000002u)
#define CSL_USIMOCP_SYSCONFIG_ENAWAKEUP_RESETVAL (0x00000000u)
/*----ENAWAKEUP Tokens----*/
#define CSL_USIMOCP_SYSCONFIG_ENAWAKEUP_ENAWAKEUP_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_SYSCONFIG_ENAWAKEUP_ENAWAKEUP_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_SYSCONFIG_IDLEMODE_MASK (0x00000018u)
#define CSL_USIMOCP_SYSCONFIG_IDLEMODE_SHIFT (0x00000003u)
#define CSL_USIMOCP_SYSCONFIG_IDLEMODE_RESETVAL (0x00000000u)
/*----IDLEMODE Tokens----*/
#define CSL_USIMOCP_SYSCONFIG_IDLEMODE_IDLEMODE_VALUE_3 (0x00000003u)
#define CSL_USIMOCP_SYSCONFIG_IDLEMODE_IDLEMODE_VALUE_2 (0x00000002u)
#define CSL_USIMOCP_SYSCONFIG_IDLEMODE_IDLEMODE_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_SYSCONFIG_IDLEMODE_IDLEMODE_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_SYSCONFIG_EMUFREE_MASK (0x00000020u)
#define CSL_USIMOCP_SYSCONFIG_EMUFREE_SHIFT (0x00000005u)
#define CSL_USIMOCP_SYSCONFIG_EMUFREE_RESETVAL (0x00000000u)
/*----EMUFREE Tokens----*/
#define CSL_USIMOCP_SYSCONFIG_EMUFREE_EMUFREE_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_SYSCONFIG_EMUFREE_EMUFREE_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_SYSCONFIG_RESERVED_6_7_MASK (0x000000C0u)
#define CSL_USIMOCP_SYSCONFIG_RESERVED_6_7_SHIFT (0x00000006u)
#define CSL_USIMOCP_SYSCONFIG_RESERVED_6_7_RESETVAL (0x00000000u)

#define CSL_USIMOCP_SYSCONFIG_CLOCKACTIVITY_MASK (0x00000300u)
#define CSL_USIMOCP_SYSCONFIG_CLOCKACTIVITY_SHIFT (0x00000008u)
#define CSL_USIMOCP_SYSCONFIG_CLOCKACTIVITY_RESETVAL (0x00000000u)

#define CSL_USIMOCP_SYSCONFIG_RESERVED_22_MASK (0xFFFFFC00u)
#define CSL_USIMOCP_SYSCONFIG_RESERVED_22_SHIFT (0x0000000Au)
#define CSL_USIMOCP_SYSCONFIG_RESERVED_22_RESETVAL (0x00000000u)

#define CSL_USIMOCP_SYSCONFIG_RESETVAL   (0x00000000u)

/* SYSSTATUS */

#define CSL_USIMOCP_SYSSTATUS_RESETDONE_MASK (0x00000001u)
#define CSL_USIMOCP_SYSSTATUS_RESETDONE_SHIFT (0x00000000u)
#define CSL_USIMOCP_SYSSTATUS_RESETDONE_RESETVAL (0x00000000u)
/*----RESETDONE Tokens----*/
#define CSL_USIMOCP_SYSSTATUS_RESETDONE_RESETDONE_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_SYSSTATUS_RESETDONE_RESETDONE_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_SYSSTATUS_RESERVED_31_MASK (0xFFFFFFFEu)
#define CSL_USIMOCP_SYSSTATUS_RESERVED_31_SHIFT (0x00000001u)
#define CSL_USIMOCP_SYSSTATUS_RESERVED_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_SYSSTATUS_RESETVAL   (0x00000000u)

/* IRQSTATUS */

#define CSL_USIMOCP_IRQSTATUS_USIM_NATR_MASK (0x00000001u)
#define CSL_USIMOCP_IRQSTATUS_USIM_NATR_SHIFT (0x00000000u)
#define CSL_USIMOCP_IRQSTATUS_USIM_NATR_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_USIM_WT_MASK (0x00000002u)
#define CSL_USIMOCP_IRQSTATUS_USIM_WT_SHIFT (0x00000001u)
#define CSL_USIMOCP_IRQSTATUS_USIM_WT_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_USIM_RXFULL_MASK (0x00000004u)
#define CSL_USIMOCP_IRQSTATUS_USIM_RXFULL_SHIFT (0x00000002u)
#define CSL_USIMOCP_IRQSTATUS_USIM_RXFULL_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_USIM_TX_MASK (0x00000008u)
#define CSL_USIMOCP_IRQSTATUS_USIM_TX_SHIFT (0x00000003u)
#define CSL_USIMOCP_IRQSTATUS_USIM_TX_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_USIM_RX_MASK (0x00000010u)
#define CSL_USIMOCP_IRQSTATUS_USIM_RX_SHIFT (0x00000004u)
#define CSL_USIMOCP_IRQSTATUS_USIM_RX_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_USIM_CD_MASK (0x00000020u)
#define CSL_USIMOCP_IRQSTATUS_USIM_CD_SHIFT (0x00000005u)
#define CSL_USIMOCP_IRQSTATUS_USIM_CD_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_USIM_EOB_MASK (0x00000040u)
#define CSL_USIMOCP_IRQSTATUS_USIM_EOB_SHIFT (0x00000006u)
#define CSL_USIMOCP_IRQSTATUS_USIM_EOB_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_USIM_TOC_MASK (0x00000080u)
#define CSL_USIMOCP_IRQSTATUS_USIM_TOC_SHIFT (0x00000007u)
#define CSL_USIMOCP_IRQSTATUS_USIM_TOC_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_USIM_TOB_MASK (0x00000100u)
#define CSL_USIMOCP_IRQSTATUS_USIM_TOB_SHIFT (0x00000008u)
#define CSL_USIMOCP_IRQSTATUS_USIM_TOB_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_USIM_RESENT_MASK (0x00000200u)
#define CSL_USIMOCP_IRQSTATUS_USIM_RESENT_SHIFT (0x00000009u)
#define CSL_USIMOCP_IRQSTATUS_USIM_RESENT_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_TS_ERROR_MASK (0x00000400u)
#define CSL_USIMOCP_IRQSTATUS_TS_ERROR_SHIFT (0x0000000Au)
#define CSL_USIMOCP_IRQSTATUS_TS_ERROR_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_IT_EMV_ATR_LENGTH_TIME_OUT_MASK (0x00000800u)
#define CSL_USIMOCP_IRQSTATUS_IT_EMV_ATR_LENGTH_TIME_OUT_SHIFT (0x0000000Bu)
#define CSL_USIMOCP_IRQSTATUS_IT_EMV_ATR_LENGTH_TIME_OUT_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_RESERVED_17_MASK (0xFFFF8000u)
#define CSL_USIMOCP_IRQSTATUS_RESERVED_17_SHIFT (0x0000000Fu)
#define CSL_USIMOCP_IRQSTATUS_RESERVED_17_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_USIM_STOP_CLK_MASK (0x00001000u)
#define CSL_USIMOCP_IRQSTATUS_USIM_STOP_CLK_SHIFT (0x0000000Cu)
#define CSL_USIMOCP_IRQSTATUS_USIM_STOP_CLK_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_PAR_ERR_LEVEL_REACHED_MASK (0x00002000u)
#define CSL_USIMOCP_IRQSTATUS_PAR_ERR_LEVEL_REACHED_SHIFT (0x0000000Du)
#define CSL_USIMOCP_IRQSTATUS_PAR_ERR_LEVEL_REACHED_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_FRAME_ERR_MASK (0x00004000u)
#define CSL_USIMOCP_IRQSTATUS_FRAME_ERR_SHIFT (0x0000000Eu)
#define CSL_USIMOCP_IRQSTATUS_FRAME_ERR_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQSTATUS_RESETVAL   (0x00000000u)

/* IRQENABLE */

#define CSL_USIMOCP_IRQENABLE_RESERVED_17_MASK (0xFFFF8000u)
#define CSL_USIMOCP_IRQENABLE_RESERVED_17_SHIFT (0x0000000Fu)
#define CSL_USIMOCP_IRQENABLE_RESERVED_17_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_EMV_ATR_LENGTH_TIME_OUT_EN_MASK (0x00000800u)
#define CSL_USIMOCP_IRQENABLE_EMV_ATR_LENGTH_TIME_OUT_EN_SHIFT (0x0000000Bu)
#define CSL_USIMOCP_IRQENABLE_EMV_ATR_LENGTH_TIME_OUT_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_TS_ERR_EN_MASK (0x00000400u)
#define CSL_USIMOCP_IRQENABLE_TS_ERR_EN_SHIFT (0x0000000Au)
#define CSL_USIMOCP_IRQENABLE_TS_ERR_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_RESENT_EN_MASK (0x00000200u)
#define CSL_USIMOCP_IRQENABLE_RESENT_EN_SHIFT (0x00000009u)
#define CSL_USIMOCP_IRQENABLE_RESENT_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_TOB_EN_MASK (0x00000100u)
#define CSL_USIMOCP_IRQENABLE_TOB_EN_SHIFT (0x00000008u)
#define CSL_USIMOCP_IRQENABLE_TOB_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_TOC_EN_MASK (0x00000080u)
#define CSL_USIMOCP_IRQENABLE_TOC_EN_SHIFT (0x00000007u)
#define CSL_USIMOCP_IRQENABLE_TOC_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_EOB_EN_MASK (0x00000040u)
#define CSL_USIMOCP_IRQENABLE_EOB_EN_SHIFT (0x00000006u)
#define CSL_USIMOCP_IRQENABLE_EOB_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_CD_EN_MASK (0x00000020u)
#define CSL_USIMOCP_IRQENABLE_CD_EN_SHIFT (0x00000005u)
#define CSL_USIMOCP_IRQENABLE_CD_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_RX_EN_MASK (0x00000010u)
#define CSL_USIMOCP_IRQENABLE_RX_EN_SHIFT (0x00000004u)
#define CSL_USIMOCP_IRQENABLE_RX_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_TX_EN_MASK (0x00000008u)
#define CSL_USIMOCP_IRQENABLE_TX_EN_SHIFT (0x00000003u)
#define CSL_USIMOCP_IRQENABLE_TX_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_RXFULL_EN_MASK (0x00000004u)
#define CSL_USIMOCP_IRQENABLE_RXFULL_EN_SHIFT (0x00000002u)
#define CSL_USIMOCP_IRQENABLE_RXFULL_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_WT_EN_MASK (0x00000002u)
#define CSL_USIMOCP_IRQENABLE_WT_EN_SHIFT (0x00000001u)
#define CSL_USIMOCP_IRQENABLE_WT_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_NATR_EN_MASK (0x00000001u)
#define CSL_USIMOCP_IRQENABLE_NATR_EN_SHIFT (0x00000000u)
#define CSL_USIMOCP_IRQENABLE_NATR_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_STOP_CLK_MASK (0x00001000u)
#define CSL_USIMOCP_IRQENABLE_STOP_CLK_SHIFT (0x0000000Cu)
#define CSL_USIMOCP_IRQENABLE_STOP_CLK_RESETVAL (0x00000000u)

#define CSL_USIMOCP_IRQENABLE_PAR_ERR_LEVEL_REACHED_EN_MASK (0x00002000u)
#define CSL_USIMOCP_IRQENABLE_PAR_ERR_LEVEL_REACHED_EN_SHIFT (0x0000000Du)
#define CSL_USIMOCP_IRQENABLE_PAR_ERR_LEVEL_REACHED_EN_RESETVAL (0x00000000u)
/*----PAR_ERR_LEVEL_REACHED_EN Tokens----*/
#define CSL_USIMOCP_IRQENABLE_PAR_ERR_LEVEL_REACHED_EN_DISABLE (0x00000000u)
#define CSL_USIMOCP_IRQENABLE_PAR_ERR_LEVEL_REACHED_EN_ENABLE (0x00000001u)

#define CSL_USIMOCP_IRQENABLE_FRAME_ERR_EN_MASK (0x00004000u)
#define CSL_USIMOCP_IRQENABLE_FRAME_ERR_EN_SHIFT (0x0000000Eu)
#define CSL_USIMOCP_IRQENABLE_FRAME_ERR_EN_RESETVAL (0x00000000u)
/*----FRAME_ERR_EN Tokens----*/
#define CSL_USIMOCP_IRQENABLE_FRAME_ERR_EN_DISABLE (0x00000000u)
#define CSL_USIMOCP_IRQENABLE_FRAME_ERR_EN_ENABLE (0x00000001u)

#define CSL_USIMOCP_IRQENABLE_RESETVAL   (0x00000000u)

/* WAKEUPEN */

#define CSL_USIMOCP_WAKEUPEN_STOP_CLK_MASK (0x00001000u)
#define CSL_USIMOCP_WAKEUPEN_STOP_CLK_SHIFT (0x0000000Cu)
#define CSL_USIMOCP_WAKEUPEN_STOP_CLK_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_NATR_EN_MASK (0x00000001u)
#define CSL_USIMOCP_WAKEUPEN_NATR_EN_SHIFT (0x00000000u)
#define CSL_USIMOCP_WAKEUPEN_NATR_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_WT_EN_MASK  (0x00000002u)
#define CSL_USIMOCP_WAKEUPEN_WT_EN_SHIFT (0x00000001u)
#define CSL_USIMOCP_WAKEUPEN_WT_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_RXFULL_EN_MASK (0x00000004u)
#define CSL_USIMOCP_WAKEUPEN_RXFULL_EN_SHIFT (0x00000002u)
#define CSL_USIMOCP_WAKEUPEN_RXFULL_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_TX_EN_MASK  (0x00000008u)
#define CSL_USIMOCP_WAKEUPEN_TX_EN_SHIFT (0x00000003u)
#define CSL_USIMOCP_WAKEUPEN_TX_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_RX_EN_MASK  (0x00000010u)
#define CSL_USIMOCP_WAKEUPEN_RX_EN_SHIFT (0x00000004u)
#define CSL_USIMOCP_WAKEUPEN_RX_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_CD_EN_MASK  (0x00000020u)
#define CSL_USIMOCP_WAKEUPEN_CD_EN_SHIFT (0x00000005u)
#define CSL_USIMOCP_WAKEUPEN_CD_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_EOB_EN_MASK (0x00000040u)
#define CSL_USIMOCP_WAKEUPEN_EOB_EN_SHIFT (0x00000006u)
#define CSL_USIMOCP_WAKEUPEN_EOB_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_TOC_EN_MASK (0x00000080u)
#define CSL_USIMOCP_WAKEUPEN_TOC_EN_SHIFT (0x00000007u)
#define CSL_USIMOCP_WAKEUPEN_TOC_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_TOB_EN_MASK (0x00000100u)
#define CSL_USIMOCP_WAKEUPEN_TOB_EN_SHIFT (0x00000008u)
#define CSL_USIMOCP_WAKEUPEN_TOB_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_RESENT_EN_MASK (0x00000200u)
#define CSL_USIMOCP_WAKEUPEN_RESENT_EN_SHIFT (0x00000009u)
#define CSL_USIMOCP_WAKEUPEN_RESENT_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_TS_ERR_EN_MASK (0x00000400u)
#define CSL_USIMOCP_WAKEUPEN_TS_ERR_EN_SHIFT (0x0000000Au)
#define CSL_USIMOCP_WAKEUPEN_TS_ERR_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_EMV_ATR_LENGTH_TIME_OUT_EN_MASK (0x00000800u)
#define CSL_USIMOCP_WAKEUPEN_EMV_ATR_LENGTH_TIME_OUT_EN_SHIFT (0x0000000Bu)
#define CSL_USIMOCP_WAKEUPEN_EMV_ATR_LENGTH_TIME_OUT_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_RESERVED_17_MASK (0xFFFF8000u)
#define CSL_USIMOCP_WAKEUPEN_RESERVED_17_SHIFT (0x0000000Fu)
#define CSL_USIMOCP_WAKEUPEN_RESERVED_17_RESETVAL (0x00000000u)

#define CSL_USIMOCP_WAKEUPEN_PAR_ERR_LEVEL_REACHED_EN_MASK (0x00002000u)
#define CSL_USIMOCP_WAKEUPEN_PAR_ERR_LEVEL_REACHED_EN_SHIFT (0x0000000Du)
#define CSL_USIMOCP_WAKEUPEN_PAR_ERR_LEVEL_REACHED_EN_RESETVAL (0x00000000u)
/*----PAR_ERR_LEVEL_REACHED_EN Tokens----*/
#define CSL_USIMOCP_WAKEUPEN_PAR_ERR_LEVEL_REACHED_EN_DISABLE (0x00000000u)
#define CSL_USIMOCP_WAKEUPEN_PAR_ERR_LEVEL_REACHED_EN_ENABLE (0x00000001u)

#define CSL_USIMOCP_WAKEUPEN_FRAME_ERR_EN_MASK (0x00004000u)
#define CSL_USIMOCP_WAKEUPEN_FRAME_ERR_EN_SHIFT (0x0000000Eu)
#define CSL_USIMOCP_WAKEUPEN_FRAME_ERR_EN_RESETVAL (0x00000000u)
/*----FRAME_ERR_EN Tokens----*/
#define CSL_USIMOCP_WAKEUPEN_FRAME_ERR_EN_DISBALE (0x00000000u)
#define CSL_USIMOCP_WAKEUPEN_FRAME_ERR_EN_ENABLE (0x00000001u)

#define CSL_USIMOCP_WAKEUPEN_RESETVAL    (0x00000000u)

/* USIMCMD */

#define CSL_USIMOCP_USIMCMD_RESERVED_0_MASK (0x00000001u)
#define CSL_USIMOCP_USIMCMD_RESERVED_0_SHIFT (0x00000000u)
#define CSL_USIMOCP_USIMCMD_RESERVED_0_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCMD_CMDSTOP_MASK (0x00000002u)
#define CSL_USIMOCP_USIMCMD_CMDSTOP_SHIFT (0x00000001u)
#define CSL_USIMOCP_USIMCMD_CMDSTOP_RESETVAL (0x00000000u)
/*----CMDSTOP Tokens----*/
#define CSL_USIMOCP_USIMCMD_CMDSTOP_CMDSTOP_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCMD_CMDSTOP_CMDSTOP_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCMD_CMDSTART_MASK (0x00000004u)
#define CSL_USIMOCP_USIMCMD_CMDSTART_SHIFT (0x00000002u)
#define CSL_USIMOCP_USIMCMD_CMDSTART_RESETVAL (0x00000000u)
/*----CMDSTART Tokens----*/
#define CSL_USIMOCP_USIMCMD_CMDSTART_CMDSTART_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCMD_CMDSTART_CMDSTART_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCMD_MODULE_CLK_EN_MASK (0x00000008u)
#define CSL_USIMOCP_USIMCMD_MODULE_CLK_EN_SHIFT (0x00000003u)
#define CSL_USIMOCP_USIMCMD_MODULE_CLK_EN_RESETVAL (0x00000000u)
/*----MODULE_CLK_EN Tokens----*/
#define CSL_USIMOCP_USIMCMD_MODULE_CLK_EN_MODULE_CLK_EN_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCMD_MODULE_CLK_EN_MODULE_CLK_EN_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCMD_CMD_WARM_RST_MASK (0x00000010u)
#define CSL_USIMOCP_USIMCMD_CMD_WARM_RST_SHIFT (0x00000004u)
#define CSL_USIMOCP_USIMCMD_CMD_WARM_RST_RESETVAL (0x00000000u)
/*----CMD_WARM_RST Tokens----*/
#define CSL_USIMOCP_USIMCMD_CMD_WARM_RST_WARM_RST_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIMCMD_CMD_WARM_RST_WARM_RST_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIMCMD_CMD_CLOCK_STOP_MASK (0x00000020u)
#define CSL_USIMOCP_USIMCMD_CMD_CLOCK_STOP_SHIFT (0x00000005u)
#define CSL_USIMOCP_USIMCMD_CMD_CLOCK_STOP_RESETVAL (0x00000000u)
/*----CMD_CLOCK_STOP Tokens----*/
#define CSL_USIMOCP_USIMCMD_CMD_CLOCK_STOP_CLOCK_STOP_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIMCMD_CMD_CLOCK_STOP_CLOCK_STOP_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIMCMD_RESERVED_7_31_MASK (0xFFFFFF80u)
#define CSL_USIMOCP_USIMCMD_RESERVED_7_31_SHIFT (0x00000007u)
#define CSL_USIMOCP_USIMCMD_RESERVED_7_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCMD_STOP_EMV_ATR_LENGTH_TIMER_MASK (0x00000040u)
#define CSL_USIMOCP_USIMCMD_STOP_EMV_ATR_LENGTH_TIMER_SHIFT (0x00000006u)
#define CSL_USIMOCP_USIMCMD_STOP_EMV_ATR_LENGTH_TIMER_RESETVAL (0x00000000u)
/*----STOP_EMV_ATR_LENGTH_TIMER Tokens----*/
#define CSL_USIMOCP_USIMCMD_STOP_EMV_ATR_LENGTH_TIMER_STOP_EMV_ATR_LENGTH_TIMER_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIMCMD_STOP_EMV_ATR_LENGTH_TIMER_STOP_EMV_ATR_LENGTH_TIMER_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIMCMD_RESETVAL     (0x00000000u)

/* USIMSTAT */

#define CSL_USIMOCP_USIMSTAT_STATNOCARD_MASK (0x00000001u)
#define CSL_USIMOCP_USIMSTAT_STATNOCARD_SHIFT (0x00000000u)
#define CSL_USIMOCP_USIMSTAT_STATNOCARD_RESETVAL (0x00000000u)
/*----STATNOCARD Tokens----*/
#define CSL_USIMOCP_USIMSTAT_STATNOCARD_STATNOCARD_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIMSTAT_STATNOCARD_STATNOCARD_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIMSTAT_RESERVED_6_31_MASK (0xFFFFFFC0u)
#define CSL_USIMOCP_USIMSTAT_RESERVED_6_31_SHIFT (0x00000006u)
#define CSL_USIMOCP_USIMSTAT_RESERVED_6_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMSTAT_STATTXPAR_MASK (0x00000002u)
#define CSL_USIMOCP_USIMSTAT_STATTXPAR_SHIFT (0x00000001u)
#define CSL_USIMOCP_USIMSTAT_STATTXPAR_RESETVAL (0x00000000u)
/*----STATTXPAR Tokens----*/
#define CSL_USIMOCP_USIMSTAT_STATTXPAR_STATTXPAR_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIMSTAT_STATTXPAR_STATTXPAR_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIMSTAT_STATLRC_MASK (0x00000004u)
#define CSL_USIMOCP_USIMSTAT_STATLRC_SHIFT (0x00000002u)
#define CSL_USIMOCP_USIMSTAT_STATLRC_RESETVAL (0x00000000u)
/*----STATLRC Tokens----*/
#define CSL_USIMOCP_USIMSTAT_STATLRC_STATLRC_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIMSTAT_STATLRC_STATLRC_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIMSTAT_CONFCODCONV_MASK (0x00000008u)
#define CSL_USIMOCP_USIMSTAT_CONFCODCONV_SHIFT (0x00000003u)
#define CSL_USIMOCP_USIMSTAT_CONFCODCONV_RESETVAL (0x00000000u)
/*----CONFCODCONV Tokens----*/
#define CSL_USIMOCP_USIMSTAT_CONFCODCONV_CONFCODCONV_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIMSTAT_CONFCODCONV_CONFCODCONV_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIMSTAT_RESERVED_MASK (0x00000010u)
#define CSL_USIMOCP_USIMSTAT_RESERVED_SHIFT (0x00000004u)
#define CSL_USIMOCP_USIMSTAT_RESERVED_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMSTAT_FDDEACTSTATE_MASK (0x00000020u)
#define CSL_USIMOCP_USIMSTAT_FDDEACTSTATE_SHIFT (0x00000005u)
#define CSL_USIMOCP_USIMSTAT_FDDEACTSTATE_RESETVAL (0x00000000u)
/*----FDDEACTSTATE Tokens----*/
#define CSL_USIMOCP_USIMSTAT_FDDEACTSTATE_FDDEACTSTATE_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMSTAT_FDDEACTSTATE_FDDEACTSTATE_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMSTAT_RESETVAL    (0x00000000u)

/* USIMCONF1 */

#define CSL_USIMOCP_USIMCONF1_CONFSIOLOW_MASK (0x00000002u)
#define CSL_USIMOCP_USIMCONF1_CONFSIOLOW_SHIFT (0x00000001u)
#define CSL_USIMOCP_USIMCONF1_CONFSIOLOW_RESETVAL (0x00000000u)
/*----CONFSIOLOW Tokens----*/
#define CSL_USIMOCP_USIMCONF1_CONFSIOLOW_CONFSIOLOW_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF1_CONFSIOLOW_CONFSIOLOW_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF1_RESERVED_8_31_MASK (0xFFFFFF00u)
#define CSL_USIMOCP_USIMCONF1_RESERVED_8_31_SHIFT (0x00000008u)
#define CSL_USIMOCP_USIMCONF1_RESERVED_8_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF1_SCLKLEV_MASK (0x00000001u)
#define CSL_USIMOCP_USIMCONF1_SCLKLEV_SHIFT (0x00000000u)
#define CSL_USIMOCP_USIMCONF1_SCLKLEV_RESETVAL (0x00000000u)
/*----SCLKLEV Tokens----*/
#define CSL_USIMOCP_USIMCONF1_SCLKLEV_SCLKLEV_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF1_SCLKLEV_SCLKLEV_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF1_CONFBYPASS_MASK (0x00000004u)
#define CSL_USIMOCP_USIMCONF1_CONFBYPASS_SHIFT (0x00000002u)
#define CSL_USIMOCP_USIMCONF1_CONFBYPASS_RESETVAL (0x00000000u)
/*----CONFBYPASS Tokens----*/
#define CSL_USIMOCP_USIMCONF1_CONFBYPASS_CONFBYPASS_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF1_CONFBYPASS_CONFBYPASS_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF1_SVCCLEV_MASK (0x00000008u)
#define CSL_USIMOCP_USIMCONF1_SVCCLEV_SHIFT (0x00000003u)
#define CSL_USIMOCP_USIMCONF1_SVCCLEV_RESETVAL (0x00000000u)
/*----SVCCLEV Tokens----*/
#define CSL_USIMOCP_USIMCONF1_SVCCLEV_SVCCLEV_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF1_SVCCLEV_SVCCLEV_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF1_SRSTLEV_MASK (0x00000010u)
#define CSL_USIMOCP_USIMCONF1_SRSTLEV_SHIFT (0x00000004u)
#define CSL_USIMOCP_USIMCONF1_SRSTLEV_RESETVAL (0x00000000u)
/*----SRSTLEV Tokens----*/
#define CSL_USIMOCP_USIMCONF1_SRSTLEV_SRSTLEV_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF1_SRSTLEV_SRSTLEV_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF1_CONF_SCLK_EN_MASK (0x00000020u)
#define CSL_USIMOCP_USIMCONF1_CONF_SCLK_EN_SHIFT (0x00000005u)
#define CSL_USIMOCP_USIMCONF1_CONF_SCLK_EN_RESETVAL (0x00000000u)
/*----CONF_SCLK_EN Tokens----*/
#define CSL_USIMOCP_USIMCONF1_CONF_SCLK_EN_CONF_SCLK_EN_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF1_CONF_SCLK_EN_CONF_SCLK_EN_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF1_EMV_CONF_MASK (0x00000040u)
#define CSL_USIMOCP_USIMCONF1_EMV_CONF_SHIFT (0x00000006u)
#define CSL_USIMOCP_USIMCONF1_EMV_CONF_RESETVAL (0x00000000u)
/*----EMV_CONF Tokens----*/
#define CSL_USIMOCP_USIMCONF1_EMV_CONF_EMV_CONF_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF1_EMV_CONF_EMV_CONF_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF1_BYPASS_HW_AUTO_MASK (0x00000080u)
#define CSL_USIMOCP_USIMCONF1_BYPASS_HW_AUTO_SHIFT (0x00000007u)
#define CSL_USIMOCP_USIMCONF1_BYPASS_HW_AUTO_RESETVAL (0x00000000u)
/*----BYPASS_HW_AUTO Tokens----*/
#define CSL_USIMOCP_USIMCONF1_BYPASS_HW_AUTO_BYPASS_HW_AUTO_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF1_BYPASS_HW_AUTO_BYPASS_HW_AUTO_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF1_RESETVAL   (0x00000000u)

/* USIMCONF2 */

#define CSL_USIMOCP_USIMCONF2_CONFCHKPAR_MASK (0x00000001u)
#define CSL_USIMOCP_USIMCONF2_CONFCHKPAR_SHIFT (0x00000000u)
#define CSL_USIMOCP_USIMCONF2_CONFCHKPAR_RESETVAL (0x00000000u)
/*----CONFCHKPAR Tokens----*/
#define CSL_USIMOCP_USIMCONF2_CONFCHKPAR_CONFCHKPAR_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF2_CONFCHKPAR_CONFCHKPAR_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF2_RESERVED_20_31_MASK (0xFFF00000u)
#define CSL_USIMOCP_USIMCONF2_RESERVED_20_31_SHIFT (0x00000014u)
#define CSL_USIMOCP_USIMCONF2_RESERVED_20_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF2_TXNRX_MASK (0x00000002u)
#define CSL_USIMOCP_USIMCONF2_TXNRX_SHIFT (0x00000001u)
#define CSL_USIMOCP_USIMCONF2_TXNRX_RESETVAL (0x00000000u)
/*----TXNRX Tokens----*/
#define CSL_USIMOCP_USIMCONF2_TXNRX_TXNRX_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF2_TXNRX_TXNRX_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF2_CONFSCLKDIV_MASK (0x0000000Cu)
#define CSL_USIMOCP_USIMCONF2_CONFSCLKDIV_SHIFT (0x00000002u)
#define CSL_USIMOCP_USIMCONF2_CONFSCLKDIV_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF2_ATR_ASYN_BYPASS_MASK (0x00000010u)
#define CSL_USIMOCP_USIMCONF2_ATR_ASYN_BYPASS_SHIFT (0x00000004u)
#define CSL_USIMOCP_USIMCONF2_ATR_ASYN_BYPASS_RESETVAL (0x00000000u)
/*----ATR_ASYN_BYPASS Tokens----*/
#define CSL_USIMOCP_USIMCONF2_ATR_ASYN_BYPASS_ATR_ASYN_BYPASS_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF2_ATR_ASYN_BYPASS_ATR_ASYN_BYPASS_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF2_CONFPROTOCOL_MASK (0x00000020u)
#define CSL_USIMOCP_USIMCONF2_CONFPROTOCOL_SHIFT (0x00000005u)
#define CSL_USIMOCP_USIMCONF2_CONFPROTOCOL_RESETVAL (0x00000000u)
/*----CONFPROTOCOL Tokens----*/
#define CSL_USIMOCP_USIMCONF2_CONFPROTOCOL_CONFPROTOCOL_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF2_CONFPROTOCOL_CONFPROTOCOL_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF2_CONFEDC_MASK (0x00000040u)
#define CSL_USIMOCP_USIMCONF2_CONFEDC_SHIFT (0x00000006u)
#define CSL_USIMOCP_USIMCONF2_CONFEDC_RESETVAL (0x00000000u)
/*----CONFEDC Tokens----*/
#define CSL_USIMOCP_USIMCONF2_CONFEDC_CONFEDC_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF2_CONFEDC_CONFEDC_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF2_CONFLRCCHECK_MASK (0x00000080u)
#define CSL_USIMOCP_USIMCONF2_CONFLRCCHECK_SHIFT (0x00000007u)
#define CSL_USIMOCP_USIMCONF2_CONFLRCCHECK_RESETVAL (0x00000000u)
/*----CONFLRCCHECK Tokens----*/
#define CSL_USIMOCP_USIMCONF2_CONFLRCCHECK_CONFLRCCHECK_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF2_CONFLRCCHECK_CONFLRCCHECK_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF2_CONFRESENT_MASK (0x00000700u)
#define CSL_USIMOCP_USIMCONF2_CONFRESENT_SHIFT (0x00000008u)
#define CSL_USIMOCP_USIMCONF2_CONFRESENT_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF2_CARD_POLARITY_MASK (0x00000800u)
#define CSL_USIMOCP_USIMCONF2_CARD_POLARITY_SHIFT (0x0000000Bu)
#define CSL_USIMOCP_USIMCONF2_CARD_POLARITY_RESETVAL (0x00000000u)
/*----CARD_POLARITY Tokens----*/
#define CSL_USIMOCP_USIMCONF2_CARD_POLARITY_CARD_POLARITY_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF2_CARD_POLARITY_CARD_POLARITY_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF2_HW_DEACTIV_EN_MASK (0x00001000u)
#define CSL_USIMOCP_USIMCONF2_HW_DEACTIV_EN_SHIFT (0x0000000Cu)
#define CSL_USIMOCP_USIMCONF2_HW_DEACTIV_EN_RESETVAL (0x00000000u)
/*----HW_DEACTIV_EN Tokens----*/
#define CSL_USIMOCP_USIMCONF2_HW_DEACTIV_EN_HW_DEACTIV_EN_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF2_HW_DEACTIV_EN_HW_DEACTIV_EN_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF2_DEBOUNCE_EN_MASK (0x00002000u)
#define CSL_USIMOCP_USIMCONF2_DEBOUNCE_EN_SHIFT (0x0000000Du)
#define CSL_USIMOCP_USIMCONF2_DEBOUNCE_EN_RESETVAL (0x00000000u)
/*----DEBOUNCE_EN Tokens----*/
#define CSL_USIMOCP_USIMCONF2_DEBOUNCE_EN_DEBOUNCE_EN_VALUE0 (0x00000000u)
#define CSL_USIMOCP_USIMCONF2_DEBOUNCE_EN_DEBOUNCE_EN_VALUE1 (0x00000001u)

#define CSL_USIMOCP_USIMCONF2_PUT_ERR_IN_FIFO_MASK (0x00004000u)
#define CSL_USIMOCP_USIMCONF2_PUT_ERR_IN_FIFO_SHIFT (0x0000000Eu)
#define CSL_USIMOCP_USIMCONF2_PUT_ERR_IN_FIFO_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF2_NACKING_EN_MASK (0x00008000u)
#define CSL_USIMOCP_USIMCONF2_NACKING_EN_SHIFT (0x0000000Fu)
#define CSL_USIMOCP_USIMCONF2_NACKING_EN_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF2_PAR_ERR_LEVEL_MASK (0x00070000u)
#define CSL_USIMOCP_USIMCONF2_PAR_ERR_LEVEL_SHIFT (0x00000010u)
#define CSL_USIMOCP_USIMCONF2_PAR_ERR_LEVEL_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF2_CONFSCLKMODE_MASK (0x00080000u)
#define CSL_USIMOCP_USIMCONF2_CONFSCLKMODE_SHIFT (0x00000013u)
#define CSL_USIMOCP_USIMCONF2_CONFSCLKMODE_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF2_RESETVAL   (0x00000000u)

/* USIMCONF3 */

#define CSL_USIMOCP_USIMCONF3_TDUSIM_MASK (0x000000F0u)
#define CSL_USIMOCP_USIMCONF3_TDUSIM_SHIFT (0x00000004u)
#define CSL_USIMOCP_USIMCONF3_TDUSIM_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF3_TFUSIM_MASK (0x0000000Fu)
#define CSL_USIMOCP_USIMCONF3_TFUSIM_SHIFT (0x00000000u)
#define CSL_USIMOCP_USIMCONF3_TFUSIM_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF3_RESERVED_8_31_MASK (0xFFFFFF00u)
#define CSL_USIMOCP_USIMCONF3_RESERVED_8_31_SHIFT (0x00000008u)
#define CSL_USIMOCP_USIMCONF3_RESERVED_8_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIMCONF3_RESETVAL   (0x00000000u)

/* USIM_DRX */

#define CSL_USIMOCP_USIM_DRX_USIMDRX_MASK (0x000000FFu)
#define CSL_USIMOCP_USIM_DRX_USIMDRX_SHIFT (0x00000000u)
#define CSL_USIMOCP_USIM_DRX_USIMDRX_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_DRX_STATRXPAR_MASK (0x00000100u)
#define CSL_USIMOCP_USIM_DRX_STATRXPAR_SHIFT (0x00000008u)
#define CSL_USIMOCP_USIM_DRX_STATRXPAR_RESETVAL (0x00000000u)
/*----STATRXPAR Tokens----*/
#define CSL_USIMOCP_USIM_DRX_STATRXPAR_STATRXPAR_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIM_DRX_STATRXPAR_STATRXPAR_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIM_DRX_RESERVED_9_31_MASK (0xFFFFFE00u)
#define CSL_USIMOCP_USIM_DRX_RESERVED_9_31_SHIFT (0x00000009u)
#define CSL_USIMOCP_USIM_DRX_RESERVED_9_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_DRX_RESETVAL    (0x00000000u)

/* USIM_DTX */

#define CSL_USIMOCP_USIM_DTX_DTX_MASK    (0x000000FFu)
#define CSL_USIMOCP_USIM_DTX_DTX_SHIFT   (0x00000000u)
#define CSL_USIMOCP_USIM_DTX_DTX_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_DTX_RESERVED_8_31_MASK (0xFFFFFF00u)
#define CSL_USIMOCP_USIM_DTX_RESERVED_8_31_SHIFT (0x00000008u)
#define CSL_USIMOCP_USIM_DTX_RESERVED_8_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_DTX_RESETVAL    (0x00000000u)

/* USIM_FIFOS */

#define CSL_USIMOCP_USIM_FIFOS_DMA_MODE_MASK (0x00000001u)
#define CSL_USIMOCP_USIM_FIFOS_DMA_MODE_SHIFT (0x00000000u)
#define CSL_USIMOCP_USIM_FIFOS_DMA_MODE_RESETVAL (0x00000000u)
/*----DMA_MODE Tokens----*/
#define CSL_USIMOCP_USIM_FIFOS_DMA_MODE_DMA_MODE_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIM_FIFOS_DMA_MODE_DMA_MODE_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_FIFO_ENABLE_MASK (0x00000002u)
#define CSL_USIMOCP_USIM_FIFOS_FIFO_ENABLE_SHIFT (0x00000001u)
#define CSL_USIMOCP_USIM_FIFOS_FIFO_ENABLE_RESETVAL (0x00000000u)
/*----FIFO_ENABLE Tokens----*/
#define CSL_USIMOCP_USIM_FIFOS_FIFO_ENABLE_FIFO_ENABLE_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIM_FIFOS_FIFO_ENABLE_FIFO_ENABLE_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_FIFO_TX_TRIGGER_MASK (0x0000003Cu)
#define CSL_USIMOCP_USIM_FIFOS_FIFO_TX_TRIGGER_SHIFT (0x00000002u)
#define CSL_USIMOCP_USIM_FIFOS_FIFO_TX_TRIGGER_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_RESET_MASK (0x00000040u)
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_RESET_SHIFT (0x00000006u)
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_RESET_RESETVAL (0x00000000u)
/*----FIFOTX_RESET Tokens----*/
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_RESET_FIFOTX_RESET_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_RESET_FIFOTX_RESET_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_EMPTY_MASK (0x00000080u)
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_EMPTY_SHIFT (0x00000007u)
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_EMPTY_RESETVAL (0x00000000u)
/*----FIFOTX_EMPTY Tokens----*/
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_EMPTY_FIFOTX_EMPTY_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_EMPTY_FIFOTX_EMPTY_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_RESERVED_23_31_MASK (0xFF800000u)
#define CSL_USIMOCP_USIM_FIFOS_RESERVED_23_31_SHIFT (0x00000017u)
#define CSL_USIMOCP_USIM_FIFOS_RESERVED_23_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_FULL_MASK (0x00000100u)
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_FULL_SHIFT (0x00000008u)
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_FULL_RESETVAL (0x00000000u)
/*----FIFOTX_FULL Tokens----*/
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_FULL_FIFOTX_FULL_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIM_FIFOS_FIFOTX_FULL_FIFOTX_FULL_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_FIFO_RX_TRIGGER_MASK (0x0003FE00u)
#define CSL_USIMOCP_USIM_FIFOS_FIFO_RX_TRIGGER_SHIFT (0x00000009u)
#define CSL_USIMOCP_USIM_FIFOS_FIFO_RX_TRIGGER_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_FIFORX_RESET_MASK (0x00040000u)
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_RESET_SHIFT (0x00000012u)
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_RESET_RESETVAL (0x00000000u)
/*----FIFORX_RESET Tokens----*/
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_RESET_FIFORX_RESET_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_RESET_FIFORX_RESET_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_FIFORX_EMPTY_MASK (0x00080000u)
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_EMPTY_SHIFT (0x00000013u)
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_EMPTY_RESETVAL (0x00000000u)
/*----FIFORX_EMPTY Tokens----*/
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_EMPTY_FIFORX_EMPTY_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_EMPTY_FIFORX_EMPTY_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_FIFORX_FULL_MASK (0x00100000u)
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_FULL_SHIFT (0x00000014u)
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_FULL_RESETVAL (0x00000000u)
/*----FIFORX_FULL Tokens----*/
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_FULL_FIFORX_FULL_VALUE_1 (0x00000001u)
#define CSL_USIMOCP_USIM_FIFOS_FIFORX_FULL_FIFORX_FULL_VALUE_0 (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_RXDMA_TYPE_MASK (0x00600000u)
#define CSL_USIMOCP_USIM_FIFOS_RXDMA_TYPE_SHIFT (0x00000015u)
#define CSL_USIMOCP_USIM_FIFOS_RXDMA_TYPE_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_FIFOS_RESETVAL  (0x00000000u)

/* USIM_CGT */

#define CSL_USIMOCP_USIM_CGT_RESERVED_9_31_MASK (0xFFFFFE00u)
#define CSL_USIMOCP_USIM_CGT_RESERVED_9_31_SHIFT (0x00000009u)
#define CSL_USIMOCP_USIM_CGT_RESERVED_9_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_CGT_CGT_MASK    (0x000001FFu)
#define CSL_USIMOCP_USIM_CGT_CGT_SHIFT   (0x00000000u)
#define CSL_USIMOCP_USIM_CGT_CGT_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_CGT_RESETVAL    (0x00000000u)

/* USIM_CWT */

#define CSL_USIMOCP_USIM_CWT_RESERVED_16_31_MASK (0xFFFF0000u)
#define CSL_USIMOCP_USIM_CWT_RESERVED_16_31_SHIFT (0x00000010u)
#define CSL_USIMOCP_USIM_CWT_RESERVED_16_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_CWT_CWT_MASK    (0x0000FFFFu)
#define CSL_USIMOCP_USIM_CWT_CWT_SHIFT   (0x00000000u)
#define CSL_USIMOCP_USIM_CWT_CWT_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_CWT_RESETVAL    (0x00000000u)

/* USIM_BWT */

#define CSL_USIMOCP_USIM_BWT_RESERVED_23_31_MASK (0xFE000000u)
#define CSL_USIMOCP_USIM_BWT_RESERVED_23_31_SHIFT (0x00000019u)
#define CSL_USIMOCP_USIM_BWT_RESERVED_23_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_BWT_BWT_MASK    (0x01FFFFFFu)
#define CSL_USIMOCP_USIM_BWT_BWT_SHIFT   (0x00000000u)
#define CSL_USIMOCP_USIM_BWT_BWT_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_BWT_RESETVAL    (0x00000000u)

/* DEBUG_REG */

#define CSL_USIMOCP_DEBUG_REG_RESERVED_20_31_MASK (0xFFF00000u)
#define CSL_USIMOCP_DEBUG_REG_RESERVED_20_31_SHIFT (0x00000014u)
#define CSL_USIMOCP_DEBUG_REG_RESERVED_20_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_DEBUG_REG_MAIN_STATE_DEBUG_MASK (0x0000000Fu)
#define CSL_USIMOCP_DEBUG_REG_MAIN_STATE_DEBUG_SHIFT (0x00000000u)
#define CSL_USIMOCP_DEBUG_REG_MAIN_STATE_DEBUG_RESETVAL (0x00000000u)

#define CSL_USIMOCP_DEBUG_REG_TX_STATE_MACHINE_MASK (0x00000030u)
#define CSL_USIMOCP_DEBUG_REG_TX_STATE_MACHINE_SHIFT (0x00000004u)
#define CSL_USIMOCP_DEBUG_REG_TX_STATE_MACHINE_RESETVAL (0x00000000u)

#define CSL_USIMOCP_DEBUG_REG_RX_STATE_MACHINE_MASK (0x000000C0u)
#define CSL_USIMOCP_DEBUG_REG_RX_STATE_MACHINE_SHIFT (0x00000006u)
#define CSL_USIMOCP_DEBUG_REG_RX_STATE_MACHINE_RESETVAL (0x00000000u)

#define CSL_USIMOCP_DEBUG_REG_RXFIFO_PEAK_MASK (0x0003FF00u)
#define CSL_USIMOCP_DEBUG_REG_RXFIFO_PEAK_SHIFT (0x00000008u)
#define CSL_USIMOCP_DEBUG_REG_RXFIFO_PEAK_RESETVAL (0x00000000u)

#define CSL_USIMOCP_DEBUG_REG_RXDMA_MASK (0x00040000u)
#define CSL_USIMOCP_DEBUG_REG_RXDMA_SHIFT (0x00000012u)
#define CSL_USIMOCP_DEBUG_REG_RXDMA_RESETVAL (0x00000000u)

#define CSL_USIMOCP_DEBUG_REG_TXDMA_MASK (0x00080000u)
#define CSL_USIMOCP_DEBUG_REG_TXDMA_SHIFT (0x00000013u)
#define CSL_USIMOCP_DEBUG_REG_TXDMA_RESETVAL (0x00000000u)

#define CSL_USIMOCP_DEBUG_REG_RESETVAL   (0x00000000u)

/* CONF_SAM1_DIV */

#define CSL_USIMOCP_CONF_SAM1_DIV_RESERVED_12_31_MASK (0xFFFFF000u)
#define CSL_USIMOCP_CONF_SAM1_DIV_RESERVED_12_31_SHIFT (0x0000000Cu)
#define CSL_USIMOCP_CONF_SAM1_DIV_RESERVED_12_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_CONF_SAM1_DIV_SAM1_DIV_MASK (0x00000FFFu)
#define CSL_USIMOCP_CONF_SAM1_DIV_SAM1_DIV_SHIFT (0x00000000u)
#define CSL_USIMOCP_CONF_SAM1_DIV_SAM1_DIV_RESETVAL (0x00000000u)

#define CSL_USIMOCP_CONF_SAM1_DIV_RESETVAL (0x00000000u)

/* CONF4_REG */

#define CSL_USIMOCP_CONF4_REG_RESERVED_16_31_MASK (0xFFFF0000u)
#define CSL_USIMOCP_CONF4_REG_RESERVED_16_31_SHIFT (0x00000010u)
#define CSL_USIMOCP_CONF4_REG_RESERVED_16_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_CONF4_REG_CONFWAITI_MASK (0x0000FFFFu)
#define CSL_USIMOCP_CONF4_REG_CONFWAITI_SHIFT (0x00000000u)
#define CSL_USIMOCP_CONF4_REG_CONFWAITI_RESETVAL (0x00000000u)

#define CSL_USIMOCP_CONF4_REG_RESETVAL   (0x00000000u)

/* ATR_CLK_PRD_NBS */

#define CSL_USIMOCP_ATR_CLK_PRD_NBS_RESERVED_16_31_MASK (0xFFFF0000u)
#define CSL_USIMOCP_ATR_CLK_PRD_NBS_RESERVED_16_31_SHIFT (0x00000010u)
#define CSL_USIMOCP_ATR_CLK_PRD_NBS_RESERVED_16_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_ATR_CLK_PRD_NBS_CLOCK_NUMBER_BEFORE_ATR_MASK (0x0000FFFFu)
#define CSL_USIMOCP_ATR_CLK_PRD_NBS_CLOCK_NUMBER_BEFORE_ATR_SHIFT (0x00000000u)
#define CSL_USIMOCP_ATR_CLK_PRD_NBS_CLOCK_NUMBER_BEFORE_ATR_RESETVAL (0x00000000u)

#define CSL_USIMOCP_ATR_CLK_PRD_NBS_RESETVAL (0x00000000u)

/* CONF_ETU_DIV */

#define CSL_USIMOCP_CONF_ETU_DIV_RESERVED_16_31_MASK (0xFFFF0000u)
#define CSL_USIMOCP_CONF_ETU_DIV_RESERVED_16_31_SHIFT (0x00000010u)
#define CSL_USIMOCP_CONF_ETU_DIV_RESERVED_16_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_CONF_ETU_DIV_ETU_DIV_MASK (0x0000FFFFu)
#define CSL_USIMOCP_CONF_ETU_DIV_ETU_DIV_SHIFT (0x00000000u)
#define CSL_USIMOCP_CONF_ETU_DIV_ETU_DIV_RESETVAL (0x00000000u)

#define CSL_USIMOCP_CONF_ETU_DIV_RESETVAL (0x00000000u)

/* CONF5_REG */

#define CSL_USIMOCP_CONF5_REG_RESERVED_12_31_MASK (0xFFFFFE00u)
#define CSL_USIMOCP_CONF5_REG_RESERVED_12_31_SHIFT (0x00000009u)
#define CSL_USIMOCP_CONF5_REG_RESERVED_12_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_CONF5_REG_DI_MASK    (0x0000000Fu)
#define CSL_USIMOCP_CONF5_REG_DI_SHIFT   (0x00000000u)
#define CSL_USIMOCP_CONF5_REG_DI_RESETVAL (0x00000000u)

#define CSL_USIMOCP_CONF5_REG_CONFFI_MASK (0x000000F0u)
#define CSL_USIMOCP_CONF5_REG_CONFFI_SHIFT (0x00000004u)
#define CSL_USIMOCP_CONF5_REG_CONFFI_RESETVAL (0x00000000u)

#define CSL_USIMOCP_CONF5_REG_SOFT_NHARD_FIDI_PROG_MASK (0x00000100u)
#define CSL_USIMOCP_CONF5_REG_SOFT_NHARD_FIDI_PROG_SHIFT (0x00000008u)
#define CSL_USIMOCP_CONF5_REG_SOFT_NHARD_FIDI_PROG_RESETVAL (0x00000000u)
/*----SOFT_NHARD_FIDI_PROG Tokens----*/
#define CSL_USIMOCP_CONF5_REG_SOFT_NHARD_FIDI_PROG_SOFT_NHARD_FIDI_PROG_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_CONF5_REG_SOFT_NHARD_FIDI_PROG_SOFT_NHARD_FIDI_PROG_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_CONF5_REG_RESETVAL   (0x00000000u)

/* TC_GUARD_TIME_ADD */

#define CSL_USIMOCP_TC_GUARD_TIME_ADD_RESERVED_14_31_MASK (0xFFFFC000u)
#define CSL_USIMOCP_TC_GUARD_TIME_ADD_RESERVED_14_31_SHIFT (0x0000000Eu)
#define CSL_USIMOCP_TC_GUARD_TIME_ADD_RESERVED_14_31_RESETVAL (0x00000000u)

#define CSL_USIMOCP_TC_GUARD_TIME_ADD_SOFT_TC_GUARD_TIME_ADD_EN_MASK (0x00002000u)
#define CSL_USIMOCP_TC_GUARD_TIME_ADD_SOFT_TC_GUARD_TIME_ADD_EN_SHIFT (0x0000000Du)
#define CSL_USIMOCP_TC_GUARD_TIME_ADD_SOFT_TC_GUARD_TIME_ADD_EN_RESETVAL (0x00000000u)
/*----SOFT_TC_GUARD_TIME_ADD_EN Tokens----*/
#define CSL_USIMOCP_TC_GUARD_TIME_ADD_SOFT_TC_GUARD_TIME_ADD_EN_SOFT_TC_GUARD_TIME_ADD_EN_VALUE_0 (0x00000000u)
#define CSL_USIMOCP_TC_GUARD_TIME_ADD_SOFT_TC_GUARD_TIME_ADD_EN_SOFT_TC_GUARD_TIME_ADD_EN_VALUE_1 (0x00000001u)

#define CSL_USIMOCP_TC_GUARD_TIME_ADD_SOFT_TC_GUARD_TIME_ADD_MASK (0x00001FFFu)
#define CSL_USIMOCP_TC_GUARD_TIME_ADD_SOFT_TC_GUARD_TIME_ADD_SHIFT (0x00000000u)
#define CSL_USIMOCP_TC_GUARD_TIME_ADD_SOFT_TC_GUARD_TIME_ADD_RESETVAL (0x00000000u)

#define CSL_USIMOCP_TC_GUARD_TIME_ADD_RESETVAL (0x00000000u)

/* USIM_RXFIFO_LEVEL */

#define CSL_USIMOCP_USIM_RXFIFO_LEVEL_USIM_RXFIFO_LEVEL_MASK (0x000001FFu)
#define CSL_USIMOCP_USIM_RXFIFO_LEVEL_USIM_RXFIFO_LEVEL_SHIFT (0x00000000u)
#define CSL_USIMOCP_USIM_RXFIFO_LEVEL_USIM_RXFIFO_LEVEL_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_RXFIFO_LEVEL_RESERVED_MASK (0xFFFFFE00u)
#define CSL_USIMOCP_USIM_RXFIFO_LEVEL_RESERVED_SHIFT (0x00000009u)
#define CSL_USIMOCP_USIM_RXFIFO_LEVEL_RESERVED_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_RXFIFO_LEVEL_RESETVAL (0x00000000u)

/* USIM_RXFIFO_BYTECNT */

#define CSL_USIMOCP_USIM_RXFIFO_BYTECNT_USIM_RXFIFO_BYTECNT_MASK (0x000001FFu)
#define CSL_USIMOCP_USIM_RXFIFO_BYTECNT_USIM_RXFIFO_BYTECNT_SHIFT (0x00000000u)
#define CSL_USIMOCP_USIM_RXFIFO_BYTECNT_USIM_RXFIFO_BYTECNT_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_RXFIFO_BYTECNT_RESERVED_MASK (0xFFFFFE00u)
#define CSL_USIMOCP_USIM_RXFIFO_BYTECNT_RESERVED_SHIFT (0x00000009u)
#define CSL_USIMOCP_USIM_RXFIFO_BYTECNT_RESERVED_RESETVAL (0x00000000u)

#define CSL_USIMOCP_USIM_RXFIFO_BYTECNT_RESETVAL (0x00000000u)

#endif
