/****************************************************************************\
 *           (C) Copyright 2009, Texas Instruments, Inc.                    *
 *                                                                          *
 *  Redistribution and use in source and binary forms, with or without      *
 *  modification, are permitted provided that the following conditions      *
 *  are met:                                                                *
 *                                                                          *
 *    Redistributions of source code must retain the above copyright        *
 *    notice, this list of conditions and the following disclaimer.         *
 *                                                                          *
 *    Redistributions in binary form must reproduce the above copyright     *
 *    notice, this list of conditions and the following disclaimer in the   *
 *    documentation and/or other materials provided with the                *
 *    distribution.                                                         *
 *                                                                          *
 *    Neither the name of Texas Instruments Incorporated nor the names of   *
 *    its contributors may be used to endorse or promote products derived   *
 *    from this software without specific prior written permission.         *
 *                                                                          *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS     *
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT       *
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR   *
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT    *
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,   *
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT        *
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,   *
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY   *
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT     *
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE   *
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    *
 ****************************************************************************
 *                                                                          *
 * Target processors : TMS320C66xx                                          *
 *                                                                          *
\****************************************************************************/

#include <string.h>
#include <stdio.h>

#include <ti/csl/csl.h>
#include <ti/csl/csl_aif2GetHwStatusAux.h>

#include <ti/drv/aif2/AIF_defs.h>
#include <ti/drv/aif2/AIF_cfg.h>
#include <ti/drv/aif2/AIF_init.h>
#include <ti/drv/aif2/AIF_init_dat.h>
#include <ti/drv/aif2/aif2_osal.h>

#define __AIF_SHUTDOWN_C
#include <ti/drv/aif2/AIF_shutdown.h>

#pragma CODE_SECTION(AIF_resetFsync, ".text:aifInit"); 
#pragma CODE_SECTION(AIF_resetAif, ".text:aifInit"); 

static CSL_Aif2Obj                 Aif2Obj;

void AIF_cleanMMRs(AIF_ConfigHandle  hAif);

void
AIF_resetFsync(
    AIF_ConfigHandle    hAif
)
{
	CSL_Status status;
	Bool ctrlArg = TRUE;

	volatile Uint32  sampelPhyTclockCounter;

	//Int32 i;
	if (aifFsyncInitDone == 0) {
		/* Initialize CSL library, this step is required */
	    hAif->hCsl = CSL_aif2Open(&Aif2Obj, 0, NULL, &status);
    }
	//AT disable all events	
	CSL_aif2HwControl(hAif->hCsl, CSL_AIF2_CMD_AT_DISABLE_ALL_EVENTS, (void *)&ctrlArg);
	//stop aif2 AT timer
   	CSL_aif2HwControl(hAif->hCsl, CSL_AIF2_CMD_AT_HALT_TIMER, (void *)&ctrlArg);	
   	// Check AT timer is actually stopped - debug code only
   	/*sampelPhyTclockCounter = CSL_aif2GetAtPhytClkCount(hAif->hCsl);
   	{
   	    volatile Uint32 i, n;
   	    n = 0;
   	    for (i = 0; i < 10000; i++)
   	    {
   	        n = n + 1;
   	    }
   	}
   	if (sampelPhyTclockCounter != CSL_aif2GetAtPhytClkCount(hAif->hCsl)) {
   		Aif2_osalLog("Error: AIF2 AT timer didn't stop\n");
   	}*/

   	if (hAif->hCsl != NULL) {CSL_aif2Close(hAif->hCsl); hAif->hCsl = NULL;}
}


// This function is used to reset AIF to its default state.
void AIF_resetAif(
    AIF_ConfigHandle    hAif
)
{
	Int32 i;
	CSL_Status status;
	Bool ctrlArg = FALSE;
	//CSL_Cppidma_rx_channel_configRegs* pktDMARxCfg = (CSL_Cppidma_rx_channel_configRegs*)CSL_AIF2_CFG_CPPI_DMA_RX_CFG_REGS;
	//CSL_Cppidma_tx_channel_configRegs* pktDMATxCfg = (CSL_Cppidma_tx_channel_configRegs*)CSL_AIF2_CFG_CPPI_DMA_TX_CFG_REGS;

	if (aifInitDone == 0) {
		/* Initialize CSL library, this step is required */
	    hAif->hCsl = CSL_aif2Open(&Aif2Obj, 0, NULL, &status);
	}	
	

	//AT disable all events and halt timer
    ctrlArg = TRUE;
	CSL_aif2HwControl(hAif->hCsl, CSL_AIF2_CMD_AT_DISABLE_ALL_EVENTS, (void *)&ctrlArg);
    CSL_aif2HwControl(hAif->hCsl, CSL_AIF2_CMD_AT_HALT_TIMER, (void *)&ctrlArg);	
	// Stop  the DIO engines
	ctrlArg = FALSE;
	CSL_aif2HwControl(hAif->hCsl, CSL_AIF2_CMD_AD_E_ENABLE_DISABLE_DIO_GLOBAL, (void *)&ctrlArg);
    CSL_aif2HwControl(hAif->hCsl, CSL_AIF2_CMD_AD_IN_ENABLE_DISABLE_DIO_GLOBAL, (void *)&ctrlArg);
	
	for(i=0; i<AIF_MAX_NUM_LINKS; i++) 	//for 6 links
	{
		hAif->hCsl->arg_link = (CSL_Aif2LinkIndex)i;
		ctrlArg = FALSE;
     	CSL_aif2HwControl(hAif->hCsl, CSL_AIF2_CMD_ENABLE_DISABLE_TX_LINK, (void *)&ctrlArg);
        CSL_aif2HwControl(hAif->hCsl, CSL_AIF2_CMD_ENABLE_DISABLE_RX_LINK, (void *)&ctrlArg);
            
	}

	// Disable all channels
	for(i=0; i<124; i++)
	{
	    if (hAif->pktDmaConfig.txChAxC[i]) {Cppi_channelDisable (hAif->pktDmaConfig.txChAxC[i]); Cppi_channelClose (hAif->pktDmaConfig.txChAxC[i]); hAif->pktDmaConfig.txChAxC[i] = NULL;}
		if (hAif->pktDmaConfig.rxChAxC[i]) {Cppi_channelDisable (hAif->pktDmaConfig.rxChAxC[i]); Cppi_channelClose (hAif->pktDmaConfig.rxChAxC[i]); hAif->pktDmaConfig.rxChAxC[i] = NULL;}
		//CSL_FINS(pktDMATxCfg->TX_CHANNEL_GLOBAL_CONFIG[i].TX_CHANNEL_GLOBAL_CONFIG_REG_A, CPPIDMA_TX_CHANNEL_CONFIG_TX_CHANNEL_GLOBAL_CONFIG_REG_A_TX_ENABLE, (Uint32)0);	
		//CSL_FINS(pktDMARxCfg->RX_CHANNEL_GLOBAL_CONFIG[i].RX_CHANNEL_GLOBAL_CONFIG_REG, CPPIDMA_RX_CHANNEL_CONFIG_RX_CHANNEL_GLOBAL_CONFIG_REG_RX_ENABLE, (Uint32)0);
	}
	for(i=0; i<3; i++)
	{
	    if (hAif->pktDmaConfig.txChCtrl[i]) {Cppi_channelDisable (hAif->pktDmaConfig.txChCtrl[i]); Cppi_channelClose (hAif->pktDmaConfig.txChCtrl[i]); hAif->pktDmaConfig.txChCtrl[i] = NULL;}
		if (hAif->pktDmaConfig.rxChCtrl[i]) {Cppi_channelDisable (hAif->pktDmaConfig.rxChCtrl[i]); Cppi_channelClose (hAif->pktDmaConfig.rxChCtrl[i]); hAif->pktDmaConfig.rxChCtrl[i] = NULL;}
	}

    if (hAif->pktDmaConfig.dioTxChAxC) {Cppi_channelDisable (hAif->pktDmaConfig.dioTxChAxC); Cppi_channelClose (hAif->pktDmaConfig.dioTxChAxC); hAif->pktDmaConfig.dioTxChAxC = NULL;}
	if (hAif->pktDmaConfig.dioRxChAxC) {Cppi_channelDisable (hAif->pktDmaConfig.dioRxChAxC); Cppi_channelClose (hAif->pktDmaConfig.dioRxChAxC); hAif->pktDmaConfig.dioRxChAxC = NULL;}
	
	if (hAif->pktDmaConfig.hCppi) {Cppi_close (hAif->pktDmaConfig.hCppi); hAif->pktDmaConfig.hCppi = NULL;}
	
	CSL_aif2Reset(hAif->hCsl);

	if (hAif->hAif2Setup != NULL) AIF_cleanMMRs(hAif);
		
   	if (hAif->hCsl != NULL) {CSL_aif2Close(hAif->hCsl); hAif->hCsl = NULL; aifFsyncInitDone = 0;aifInitDone = 0;}

}


void AIF_cleanMMRs(
		AIF_ConfigHandle  hAif
)
{
  Int32  	i;

   //////////////////Initialize Aif2 structures to avoid unwanted configuration ////////////////////////////////////////

   if (hAif->hAif2Setup->commonSetup->pSdCommonSetup != NULL) memset(hAif->hAif2Setup->commonSetup->pSdCommonSetup, 0, sizeof(CSL_Aif2SdCommonSetup));
   memset(hAif->hAif2Setup->commonSetup->pPdCommonSetup, 0, sizeof(CSL_Aif2PdCommonSetup));
   memset(hAif->hAif2Setup->commonSetup->pPeCommonSetup, 0, sizeof(CSL_Aif2PeCommonSetup));
   memset(hAif->hAif2Setup->commonSetup->pIngrDbSetup, 0, sizeof(CSL_Aif2IngrDbSetup));
   memset(hAif->hAif2Setup->commonSetup->pEgrDbSetup, 0, sizeof(CSL_Aif2EgrDbSetup));
   memset(hAif->hAif2Setup->commonSetup->pAdCommonSetup, 0, sizeof(CSL_Aif2AdCommonSetup));
   memset(hAif->hAif2Setup->commonSetup->pAdDioSetup, 0, sizeof(CSL_Aif2AdDioSetup));
   memset(hAif->hAif2Setup->commonSetup->pAtEventSetup, 0, sizeof(CSL_Aif2AtEventSetup));
   memset(hAif->hAif2Setup->commonSetup->pAtCommonSetup->AtInit.pPhyTimerInit, 0, sizeof(CSL_Aif2AtCountObj));
   memset(hAif->hAif2Setup->commonSetup->pAtCommonSetup->AtInit.pRadTimerInit, 0, sizeof(CSL_Aif2AtCountObj));
   memset(hAif->hAif2Setup->commonSetup->pAtCommonSetup->AtInit.pUlRadTimerInit, 0, sizeof(CSL_Aif2AtCountObj));
   memset(hAif->hAif2Setup->commonSetup->pAtCommonSetup->AtTerminalCount.pPhyTimerTc, 0, sizeof(CSL_Aif2AtCountObj));
   memset(hAif->hAif2Setup->commonSetup->pAtCommonSetup->AtTerminalCount.pRadTimerTc, 0, sizeof(CSL_Aif2AtCountObj));

   for(i=0; i< AIF_MAX_NUM_LINKS; i++) {
	   memset(hAif->hAif2Setup->linkSetup[i]->pComLinkSetup, 0, sizeof(CSL_Aif2CommonLinkSetup));
	   if (hAif->hAif2Setup->linkSetup[i]->pSdLinkSetup != NULL) memset(hAif->hAif2Setup->linkSetup[i]->pSdLinkSetup,  0, sizeof(CSL_Aif2SdLinkSetup));
	   memset(hAif->hAif2Setup->linkSetup[i]->pRmLinkSetup,  0, sizeof(CSL_Aif2RmLinkSetup));
	   memset(hAif->hAif2Setup->linkSetup[i]->pTmLinkSetup,  0, sizeof(CSL_Aif2TmLinkSetup));
	   memset(hAif->hAif2Setup->linkSetup[i]->pPdLinkSetup,  0, sizeof(CSL_Aif2PdLinkSetup));
	   memset(hAif->hAif2Setup->linkSetup[i]->pPeLinkSetup,  0, sizeof(CSL_Aif2PeLinkSetup));
	   memset(hAif->hAif2Setup->linkSetup[i]->pRtLinkSetup,  0, sizeof(CSL_Aif2RtLinkSetup));
	   memset(hAif->hAif2Setup->linkSetup[i]->pAtLinkSetup,  0, sizeof(CSL_Aif2AtLinkSetup));
   }

   /* Clean all MMRs */
   CSL_aif2HwSetup(hAif->hCsl, hAif->hAif2Setup);
   hAif->hAif2Setup = 0;

}


// This function is used to disable a given PE channel.
void AIF_disablePeCh(
    AIF_ConfigHandle                hAif,
    Uint32                          peChanNum
)
{
	CSL_Status status;
      if (aifInitDone == 0) {
            /* Initialize CSL library, this step is required */
          hAif->hCsl = CSL_aif2Open(&Aif2Obj, 0, NULL, &status);
      }
      /* disable PE dma channel  */
      CSL_FINS(hAif->hCsl->regs->PE_DMACHAN_EN[peChanNum], AIF2_PE_DMACHAN_EN_CH_EN, 0);
}

// This function is used to disable a given PD channel.
void AIF_disablePdCh(
    AIF_ConfigHandle                hAif,
    Uint32                          pdChanNum
)
{
	CSL_Status status;
      if (aifInitDone == 0) {
            /* Initialize CSL library, this step is required */
          hAif->hCsl = CSL_aif2Open(&Aif2Obj, 0, NULL, &status);
      }
      /* disable PD dma channel  */
      CSL_FINS(hAif->hCsl->regs->PD_DMACHAN[pdChanNum], AIF2_PD_DMACHAN_CHAN_EN, 0);
}

// This function is used to disable a given PE channel.
void AIF_enablePeCh(
    AIF_ConfigHandle                hAif,
    Uint32                          peChanNum
)
{
	CSL_Status status;
      if (aifInitDone == 0) {
            /* Initialize CSL library, this step is required */
          hAif->hCsl = CSL_aif2Open(&Aif2Obj, 0, NULL, &status);
      }
      /* Enable PE dma channel  */
      CSL_FINS(hAif->hCsl->regs->PE_DMACHAN_EN[peChanNum], AIF2_PE_DMACHAN_EN_CH_EN, 1);
}

// This function is used to disable a given PD channel.
void AIF_enablePdCh(
    AIF_ConfigHandle                hAif,
    Uint32                          pdChanNum
)
{
	CSL_Status status;
      if (aifInitDone == 0) {
            /* Initialize CSL library, this step is required */
          hAif->hCsl = CSL_aif2Open(&Aif2Obj, 0, NULL, &status);
      }
      /* Enable PD dma channel  */
      CSL_FINS(hAif->hCsl->regs->PD_DMACHAN[pdChanNum], AIF2_PD_DMACHAN_CHAN_EN, 1);
}



////////////////////
