/****************************************************************************\
 *           (C) Copyright 2009, Texas Instruments, Inc.                    *
 *                                                                          *
 *  Redistribution and use in source and binary forms, with or without      *
 *  modification, are permitted provided that the following conditions      *
 *  are met:                                                                *
 *                                                                          *
 *    Redistributions of source code must retain the above copyright        *
 *    notice, this list of conditions and the following disclaimer.         *
 *                                                                          *
 *    Redistributions in binary form must reproduce the above copyright     *
 *    notice, this list of conditions and the following disclaimer in the   *
 *    documentation and/or other materials provided with the                *
 *    distribution.                                                         *
 *                                                                          *
 *    Neither the name of Texas Instruments Incorporated nor the names of   *
 *    its contributors may be used to endorse or promote products derived   *
 *    from this software without specific prior written permission.         *
 *                                                                          *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS     *
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT       *
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR   *
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT    *
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,   *
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT        *
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,   *
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY   *
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT     *
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE   *
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    *
 ****************************************************************************
 *                                                                          *
 * Target processors : TMS320C66xx                                          *
 *                                                                          *
\****************************************************************************/


#ifndef __CSLUTILS_H
#define __CSLUTILS_H

#include <ti/csl/csl.h>
#include <ti/csl/csl_pllc.h>
#include <ti/csl/csl_aif2.h>
#include <ti/csl/csl_edma3.h>
#include <ti/csl/csl_edma3Aux.h>
#include <ti/csl/src/intc/csl_intc.h>
#include <ti/csl/csl_cpIntc.h>
#include <ti/csl/csl_gpio.h>
#include <ti/csl/cslr_device.h>
#include <ti/drv/aif2/aif2.h>

#define DATA_TYPE_DL    CSL_AIF2_LINK_DATA_TYPE_NORMAL
#define DATA_TYPE_UL    CSL_AIF2_LINK_DATA_TYPE_RSA
#define DATA_WIDTH_16   CSL_AIF2_DATA_WIDTH_16_BIT
#define DATA_WIDTH_15   CSL_AIF2_DATA_WIDTH_15_BIT
#define DATA_WIDTH_8    CSL_AIF2_DATA_WIDTH_8_BIT
#define DATA_WIDTH_7    CSL_AIF2_DATA_WIDTH_7_BIT

#define DSP_1           1
#define DSP_2           2

////////////////////////////////////////////
// define for local pktdma transfer ////////
////////////////////////////////////////////
#define SIZE_HOST_DESC               48
#define NUM_DESC		             7
#define SIZE_PS_DATA                 4
#define DATA_SIZE                    5120
#define CPPI_COMPLETION_QUE_NUM      1000
                                                      

typedef void (*UTILS_FxnPtr)();

extern Uint8      	       DSP_procId;
extern CSL_CPINTCRegs     *CicRegs[3];
extern CSL_IntcRegs       *IntcRegs;
extern UTILS_FxnPtr        fsevt1_userIsr;
extern UTILS_FxnPtr        aif2evt6_userIsr;
extern UTILS_FxnPtr        aif2evt5_userIsr;
extern UTILS_FxnPtr        aif2evt4_userIsr;

/** Get core number */
#define UTILS_getCoreNum() ( DNUM & ((Uint32)0x000000FF) )
// DEFINES WHETHER GLOBAL ADDRESSING IS REQUIRED FOR MASTER (EDMA, Peripherals, OTHER CorePacs) ACCESSES TO L2/L1
#define UTILS_GLOBAL_MEM_MASK    1
/** Get global address */
#define UTILS_local2GlobalAddr(dspAddr)     ( ((((Uint32)dspAddr)&((Uint32)0xFF000000))==(Uint32)0x00000000) ?  \
                                                   (Uint32*)((Uint32)dspAddr|((UTILS_GLOBAL_MEM_MASK<<28)|((UTILS_getCoreNum()<<24) \
                                                   & 0x0F000000))) : (Uint32*)dspAddr )
/** Get memory region number, LL2 or MSM to region0, DDR3 to region16 */
#define UTILS_getMemRegionNum(dspAddr)      ( ((((Uint32)dspAddr)&((Uint32)0xE0000000))==(Uint32)0x00000000) ?  \
                                                   (Qmss_MemRegion)(Qmss_MemRegion_MEMORY_REGION0) : (Qmss_MemRegion)Qmss_MemRegion_MEMORY_REGION16 )


#ifndef __CSLUTILS_C
extern
#endif
void
AIF_enable(
);


#ifndef __CSLUTILS_C
extern
#endif
void
AIF_disable(
);


#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_GPIO8_setup(

);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_doCleanup(
    AIF_ConfigHandle    hAif,
    Uint32 timer
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_resetTimer(
		Uint32 timer
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_startTimer(
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_initTimer(
		Uint32 timer
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_triggerFsync(
	AIF_ConfigHandle hAif
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_triggerBoardsSync(
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_boardsSync(
		Uint32 timer,
		Uint32 timerpll
#ifdef EXT_CLOCK
		,Uint32 timer10Mhz
#endif
);

#ifndef __CSLUTILS_C
extern
#endif
Int32
UTILS_configRtwp(
);

#ifndef __CSLUTILS_C
extern
#endif
Int32
UTILS_readRtwpAnt01(
);

#ifndef __CSLUTILS_C
extern
#endif
void 
UTILS_configMasterSlave(
);


#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_printLinkConfig(
    AIF_ConfigHandle    hAif
);

#ifndef __CSLUTILS_C
extern
#endif 
void 
UTILS_aifIntcSetup(
);



#ifndef __CSLUTILS_C
extern
#endif 
void
UTILS_waitForHw(
   Uint32 delay
);

#ifndef __CSLUTILS_C
extern
#endif 
Int32
UTILS_bytecmp(
    void *x1,
    void *x2,
    Uint32 byteCount
);

#ifndef __CSLUTILS_C
extern
#endif
Uint32 
UTILS_isL2Asymmetric(
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_resetQmss(
);


#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_deinterleaveLteSuperPacket(
		Uint32* superPktAxCPtr,
		Uint32* dstPktPtr,
		Uint32  numPackedSamples,
		Uint32  numAxCs,
		Uint32  payloadSize
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_openEdmaSampleCapt(
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_triggerEdmaSampleCapt(
		Uint32  chan,
		Uint32* dstAddr,
		Uint32* srcAddr,
		Uint32  numBytes
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_aif2ExceptIntDisable(
);

#ifndef __CSLUTILS_C
extern
#endif
void
UTILS_aif2IsOnLoss(
		AIF_ConfigHandle    hAif,
		Uint32 activeLink
);

#endif//__CSLUTILS_H

/** @} */ // end of module additions

