#ifndef _PAFW_V1_H
#define _PAFW_V1_H

/******************************************************************************
 * FILE PURPOSE: PASS Firmware Image Definitions for the PA LLD 
 ******************************************************************************
 * FILE NAME:   pafw.h
 *
 * DESCRIPTION: Define PASS firmware image related constants and data structures.  
 *  The PASS contains 15 PDSPs wihich perform the command and packet processing. 
 *  There are 15 PDSP images provided by the module under the ti/drv/pa/fw/v1 directory:
 *  -Ingress0 PDSP0 image: pa15_in0_pdsp0_bin.c
 *  -Ingress0 PDSP1 image: pa15_in0_pdsp1_bin.c
 *  -Ingress1 PDSP0 image: pa15_in1_pdsp0_bin.c
 *  -Ingress1 PDSP1 image: pa15_in1_pdsp1_bin.c
 *  -Ingress2 PDSP0 image: pa15_in2_pdsp0_bin.c
 *  -Ingress3 PDSP1 image: pa15_in3_pdsp0_bin.c
 *  -Ingress4 PDSP0 image: pa15_in4_pdsp0_bin.c
 *  -Ingress4 PDSP1 image: pa15_in4_pdsp1_bin.c
 *  -Post PDSP0 image    : pa15_post_pdsp0_bin.c
 *  -Post PDSP1 image    : pa15_post_pdsp1_bin.c
 *  -Egress0 PDSP0 image : pa15_eg0_pdsp0_bin.c
 *  -Egress0 PDSP1 image : pa15_eg0_pdsp1_bin.c
 *  -Egress0 PDSP2 image : pa15_eg0_pdsp2_bin.c
 *  -Egress1 PDSP0 image : pa15_eg1_pdsp0_bin.c
 *  -Egress2 PDSP0 image : pa15_eg2_pdsp0_bin.c
 *
 * REVISION HISTORY:
 *
 *  Copyright (c) Texas Instruments Incorporated 2013
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>
/* PDSP Packet Ingress0 PDSP0 image */
extern const uint32_t in0_pdsp0[];
extern const int in0_pdsp0Size;
/* PDSP Packet Ingress0 PDSP1 image */
extern const uint32_t in0_pdsp1[];
extern const int in0_pdsp1Size;
/* PDSP Packet Ingress1 PDSP0 image */
extern const uint32_t in1_pdsp0[];
extern const int in1_pdsp0Size;
/* PDSP Packet Ingress1 PDSP1 image */
extern const uint32_t in1_pdsp1[];
extern const int in1_pdsp1Size;
/* PDSP Packet Ingress2 PDSP0 image */
extern const uint32_t in2_pdsp0[];
extern const int in2_pdsp0Size;
/* PDSP Packet Ingress3 PDSP0 image */
extern const uint32_t in3_pdsp0[];
extern const int in3_pdsp0Size;
/* PDSP Packet Ingress4 PDSP0 image */
extern const uint32_t in4_pdsp0[];
extern const int in4_pdsp0Size;
/* PDSP Packet Ingress4 PDSP1 image */
extern const uint32_t in4_pdsp1[];
extern const int in4_pdsp1Size;
/* PDSP Packet Post PDSP0 image */
extern const uint32_t post_pdsp0[];
extern const int post_pdsp0Size;
/* PDSP Packet Post PDSP1 image */
extern const uint32_t post_pdsp1[];
extern const int post_pdsp1Size;
/* PDSP Packet Egress0 PDSP0 image */
extern const uint32_t eg0_pdsp0[];
extern const int eg0_pdsp0Size;
/* PDSP Packet Egress0 PDSP1 image */
extern const uint32_t eg0_pdsp1[];
extern const int eg0_pdsp1Size;
/* PDSP Packet Egress0 PDSP2 image */
extern const uint32_t eg0_pdsp2[];
extern const int eg0_pdsp2Size;
/* PDSP Packet Egress1 PDSP0 image */
extern const uint32_t eg1_pdsp0[];
extern const int eg1_pdsp0Size;
/* PDSP Packet Egress2 PDSP0 image */
extern const uint32_t eg2_pdsp0[];
extern const int eg2_pdsp0Size;

#ifdef __cplusplus
}
#endif
  

#endif  /* _PAFW_V1_H */
