/********************************************************************
 * Copyright (C) 2003-2014 Texas Instruments Incorporated.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
#ifndef _CSLR_SGCP_CFG_V1_H_
#define _CSLR_SGCP_CFG_V1_H_

/* CSL Modification:
 *  The file has been modified from the AUTOGEN file for the following
 *  reasons:-
 *      a) Modified the header file includes to be RTSC compliant
 */

#include <ti/csl/cslr.h>
#include <ti/csl/tistdtypes.h>


/* Minimum unit = 4 bytes */

/**************************************************************************\
* Register Overlay Structure for SPM
\**************************************************************************/
typedef struct  {
    volatile Uint32 SPM_DPCH_W0;
    volatile Uint32 SPM_DPCH_W1;
    volatile Uint32 SPM_DPCH_W2;
    volatile Uint32 SPM_DPCH_W3;
    volatile Uint32 SPM_DPCH_W4;
    volatile Uint32 SPM_DPCH_W5;
    volatile Uint32 SPM_DPCH_W6;
    volatile Uint32 SPM_DPCH_W7;
} CSL_Sgcp_cfgSpmRegs;

/**************************************************************************\
* Register Overlay Structure for DL_TPC_CTL
\**************************************************************************/
typedef struct  {
    volatile Uint32 DL_TPC_W00;
    volatile Uint32 DL_TPC_W01;
    volatile Uint32 DL_TPC_W02;
    volatile Uint32 DL_TPC_W03;
    volatile Uint32 DL_TPC_W04;
    volatile Uint32 DL_TPC_W05;
    volatile Uint32 DL_TPC_W06;
    volatile Uint32 DL_TPC_W07;
    volatile Uint32 DL_TPC_W08;
    volatile Uint32 DL_TPC_W09;
    volatile Uint32 DL_TPC_W10;
    volatile Uint32 DL_TPC_W11;
    volatile Uint32 DL_TPC_W12;
    volatile Uint32 DL_TPC_W13;
    volatile Uint32 DL_TPC_W14;
    volatile Uint32 DL_TPC_W15;
    volatile Uint32 DL_TPC_W16;
    volatile Uint32 DL_TPC_W17;
    volatile Uint32 DL_TPC_W18;
    volatile Uint32 DL_TPC_W19;
    volatile Uint32 DL_TPC_W20;
    volatile Uint32 DL_TPC_W21;
    volatile Uint32 DL_TPC_W22;
    volatile Uint32 DL_TPC_W23;
    volatile Uint32 DL_TPC_W24;
    volatile Uint32 DL_TPC_W25;
    volatile Uint32 DL_TPC_W26;
    volatile Uint32 DL_TPC_W27;
    volatile Uint32 DL_TPC_W28;
    volatile Uint32 DL_TPC_W29;
    volatile Uint32 DL_TPC_W30;
    volatile Uint32 DL_TPC_W31;
} CSL_Sgcp_cfgDl_tpc_ctlRegs;

/**************************************************************************\
* Register Overlay Structure for BF_CTL
\**************************************************************************/
typedef struct  {
    volatile Uint32 BF_W00;
    volatile Uint32 BF_W01;
    volatile Uint32 BF_W02;
    volatile Uint32 BF_W03;
    volatile Uint32 BF_W04;
    volatile Uint32 RSVD0[3];
    volatile Uint32 BF_W08;
    volatile Uint32 BF_W09;
    volatile Uint32 BF_W10;
    volatile Uint32 BF_W11;
    volatile Uint32 RSVD10[4];
} CSL_Sgcp_cfgBf_ctlRegs;

/**************************************************************************\
* Register Overlay Structure for UL_TPC_CTL
\**************************************************************************/
typedef struct  {
    volatile Uint32 UL_TPC_W0;
    volatile Uint32 UL_TPC_W1;
    volatile Uint32 UL_TPC_W2;
    volatile Uint32 UL_TPC_W3;
    volatile Uint32 UL_TPC_W4;
    volatile Uint32 RSVD0[2];
    volatile Uint32 UL_TPC_W7;
} CSL_Sgcp_cfgUl_tpc_ctlRegs;

/**************************************************************************\
* Register Overlay Structure for DIV_CTL
\**************************************************************************/
typedef struct  {
    volatile Uint32 DIV_W0;
    volatile Uint32 DIV_W1;
    volatile Uint32 DIV_W2;
    volatile Uint32 DIV_W3;
    volatile Uint32 DIV_W4;
    volatile Uint32 DIV_W5;
    volatile Uint32 RSVD0;
    volatile Uint32 DIV_W7;
} CSL_Sgcp_cfgDiv_ctlRegs;

/**************************************************************************\
* Register Overlay Structure for SLT
\**************************************************************************/
typedef struct  {
    volatile Uint32 SLT_W0;
    volatile Uint32 SLT_W1;
} CSL_Sgcp_cfgSltRegs;

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    CSL_Sgcp_cfgSpmRegs SPM[512];
    CSL_Sgcp_cfgDl_tpc_ctlRegs DL_TPC_CTL[128];
    CSL_Sgcp_cfgBf_ctlRegs BF_CTL[128];
    CSL_Sgcp_cfgUl_tpc_ctlRegs UL_TPC_CTL[128];
    CSL_Sgcp_cfgDiv_ctlRegs DIV_CTL[128];
    volatile Uint32 SRM[512];
    volatile Uint32 SIG_SETUP[384];
    volatile Uint32 RSVD11[128];
    volatile Uint32 PBT[300];
    volatile Uint32 RSVD12[212];
    CSL_Sgcp_cfgSltRegs SLT[128];
    volatile Uint32 SSM[64];
    volatile Uint32 RSVD13[1216];
    volatile Uint32 SGCP_SEQ_ENA;
    volatile Uint32 SGCP_SEQ_ACT;
    volatile Uint32 SGCP_SEQ_CYC;
    volatile Uint32 SGCP_CYC_OVER;
    volatile Uint32 SGCP_FIFO_OVER;
    volatile Uint32 SGCP_FIFO_RESET;
    volatile Uint32 SGCP_RD_SYS_TIME;
    volatile Uint32 SGCP_IB_MISS;
    volatile Uint32 TRA_CTL;
    volatile Uint32 TRA_STAT;
    volatile Uint32 TRA_INA[2];
    volatile Uint32 TRA_INB;
    volatile Uint32 TRA_GAINA;
    volatile Uint32 TRA_GAINB;
    volatile Uint32 TRA_GAINCD[2];
    volatile Uint32 TRA_DIVA;
    volatile Uint32 TRA_DIVB;
    volatile Uint32 TRA_DIVCD[2];
    volatile Uint32 TRA_BFNA;
    volatile Uint32 TRA_BFNB;
    volatile Uint32 TRA_BFNCD[2];
    volatile Uint32 TRA_CHCDA;
    volatile Uint32 TRA_CHCDBC[2];
    volatile Uint32 TRA_SCCDA;
    volatile Uint32 TRA_SCCDBC[2];
    volatile Uint32 TRA_AGGRA;
    volatile Uint32 TRA_AGGRBC[2];
    volatile Uint32 TRA_SIGA;
    volatile Uint32 TRA_SIGBC[2];
    volatile Uint32 TRA_SPM[9];
    volatile Uint32 RSVD14[17];
    volatile Uint32 SPM_WORD_9;
    volatile Uint32 PAT;
    volatile Uint32 SIG_PAGE_EN;
    volatile Uint32 HEAD_FETCH;
    volatile Uint32 DATA_FETCH;
    volatile Uint32 RSVD15[60];
    volatile Uint32 SS2M[16];
    volatile Uint32 RSVD16[368];
    volatile Uint32 FTQ_CURR_LVL;
    volatile Uint32 FTQ_WTMK_LVL;
    volatile Uint32 CTQ_CURR_LVL;
    volatile Uint32 CTQ_WTMK_LVL;
    volatile Uint32 WTQ_CURR_LVL;
    volatile Uint32 WTQ_WTMK_LVL;
    volatile Uint32 RSVD17[506];
} CSL_Sgcp_cfgRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* SPM_DPCH_W0 */

#define CSL_SGCP_CFG_SPM_DPCH_W0_INIT_CM_TYPE_BIT0_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_INIT_CM_TYPE_BIT0_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_DPCH_W0_INIT_CM_TYPE_BIT0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W0_SL_FOR_ID_MASK (0x7C000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_SL_FOR_ID_SHIFT (0x0000001Au)
#define CSL_SGCP_CFG_SPM_DPCH_W0_SL_FOR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W0_INITFR_LASTSLOT_BIT_MASK (0x02000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_INITFR_LASTSLOT_BIT_SHIFT (0x00000019u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_INITFR_LASTSLOT_BIT_RESETVAL (0x00000000u)
/*----INITFR_LASTSLOT_BIT Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W0_INITFR_LASTSLOT_BIT_TRANSMISSION (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_INITFR_LASTSLOT_BIT_GAP (0x00000001u)

#define CSL_SGCP_CFG_SPM_DPCH_W0_MOD_SCHEME_MASK (0x01800000u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_MOD_SCHEME_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_MOD_SCHEME_RESETVAL (0x00000000u)
/*----MOD_SCHEME Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W0_MOD_SCHEME_QPSK (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_MOD_SCHEME_QPSK_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_DPCH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_DPCH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_DPCH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W0_CHANNEL_KIND_DPCH (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W0_RESETVAL (0x00000000u)

/* SPM_DPCH_W1 */

#define CSL_SGCP_CFG_SPM_DPCH_W1_INIT_CM_TYPE_BIT1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W1_INIT_CM_TYPE_BIT1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_DPCH_W1_INIT_CM_TYPE_BIT1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W1_DIV_MODE_MASK (0x60000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W1_DIV_MODE_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_DPCH_W1_DIV_MODE_RESETVAL (0x00000000u)
/*----DIV_MODE Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W1_DIV_MODE_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W1_DIV_MODE_STTD (0x00000001u)
#define CSL_SGCP_CFG_SPM_DPCH_W1_DIV_MODE_CLD1 (0x00000002u)

#define CSL_SGCP_CFG_SPM_DPCH_W1_ALT_SCR_CODE_FLG_MASK (0x10000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W1_ALT_SCR_CODE_FLG_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SPM_DPCH_W1_ALT_SCR_CODE_FLG_RESETVAL (0x00000000u)
/*----ALT_SCR_CODE_FLG Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W1_ALT_SCR_CODE_FLG_NO_ALT (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W1_ALT_SCR_CODE_FLG_ALTERNATE (0x00000001u)

#define CSL_SGCP_CFG_SPM_DPCH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_DPCH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_DPCH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_DPCH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_DPCH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_DPCH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W1_RESETVAL (0x00000000u)

/* SPM_DPCH_W2 */

#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_MASTER_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_MASTER_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_MASTER_RESETVAL (0x00000000u)
/*----MSG_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_MASTER_MSG_SLAVE (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_MASTER_MSG_MASTER (0x00000001u)

#define CSL_SGCP_CFG_SPM_DPCH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_DPCH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)

#define CSL_SGCP_CFG_SPM_DPCH_W2_SYM_IB_ID_MASK (0x3FE00000u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_SYM_IB_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_SYM_IB_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_DPCH_W2_BF_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_RL_ID_MASK (0x00000380u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_RL_ID_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_RLS_ID_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_RLS_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W2_MSG_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W2_RESETVAL (0x00000000u)

/* SPM_DPCH_W3 */

#define CSL_SGCP_CFG_SPM_DPCH_W3_EVEN_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_DPCH_W3_EVEN_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W3_EVEN_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W3_RESETVAL (0x00000000u)

/* SPM_DPCH_W4 */

#define CSL_SGCP_CFG_SPM_DPCH_W4_ODD_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_DPCH_W4_ODD_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W4_ODD_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W4_RESETVAL (0x00000000u)

/* SPM_DPCH_W5 */

#define CSL_SGCP_CFG_SPM_DPCH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_DPCH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W5_DTX_FLAG1_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_DPCH_W5_SLOT_MASK1_MASK (0x7FFF0000u)
#define CSL_SGCP_CFG_SPM_DPCH_W5_SLOT_MASK1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SPM_DPCH_W5_SLOT_MASK1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_DPCH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_DPCH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W5_DTX_FLAG0_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_DPCH_W5_SLOT_MASK0_MASK (0x00007FFFu)
#define CSL_SGCP_CFG_SPM_DPCH_W5_SLOT_MASK0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W5_SLOT_MASK0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_DPCH_W5_RESETVAL (0x00000000u)

/* SPM_DPCH_W6 */

#define CSL_SGCP_CFG_SPM_DPCH_W6_NEXT_BLK_PTR0_MASK (0xFFFFFFF8u)
#define CSL_SGCP_CFG_SPM_DPCH_W6_NEXT_BLK_PTR0_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_SPM_DPCH_W6_NEXT_BLK_PTR0_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_DPCH_W6_CM_TYPE0_MASK (0x00000003u)
#define CSL_SGCP_CFG_SPM_DPCH_W6_CM_TYPE0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W6_CM_TYPE0_RESETVAL (0x00000000u)
/*----CM_TYPE0 Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W6_CM_TYPE0_NO_CM (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W6_CM_TYPE0_CM_TYPEA (0x00000001u)
#define CSL_SGCP_CFG_SPM_DPCH_W6_CM_TYPE0_CM_TYPEB (0x00000002u)

#define CSL_SGCP_CFG_SPM_DPCH_W6_RESETVAL (0x00000000u)

/* SPM_DPCH_W7 */

#define CSL_SGCP_CFG_SPM_DPCH_W7_NEXT_BLK_PTR1_MASK (0xFFFFFFF8u)
#define CSL_SGCP_CFG_SPM_DPCH_W7_NEXT_BLK_PTR1_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_SPM_DPCH_W7_NEXT_BLK_PTR1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_DPCH_W7_CM_TYPE1_MASK (0x00000003u)
#define CSL_SGCP_CFG_SPM_DPCH_W7_CM_TYPE1_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W7_CM_TYPE1_RESETVAL (0x00000000u)
/*----CM_TYPE1 Tokens----*/
#define CSL_SGCP_CFG_SPM_DPCH_W7_CM_TYPE1_NO_CM (0x00000000u)
#define CSL_SGCP_CFG_SPM_DPCH_W7_CM_TYPE1_CM_TYPEA (0x00000001u)
#define CSL_SGCP_CFG_SPM_DPCH_W7_CM_TYPE1_CM_TYPEB (0x00000002u)

#define CSL_SGCP_CFG_SPM_DPCH_W7_RESETVAL (0x00000000u)

/* SPM_SCH_W0 */


#define CSL_SGCP_CFG_SPM_SCH_W0_A_VALUE_MASK (0x04000000u)
#define CSL_SGCP_CFG_SPM_SCH_W0_A_VALUE_SHIFT (0x0000001Au)
#define CSL_SGCP_CFG_SPM_SCH_W0_A_VALUE_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_SCH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_SCH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_SCH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_SCH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_SCH_W0_CHANNEL_KIND_PSCH (0x00000001u)
#define CSL_SGCP_CFG_SPM_SCH_W0_CHANNEL_KIND_SSCH (0x00000002u)

#define CSL_SGCP_CFG_SPM_SCH_W0_RESETVAL (0x00000000u)

/* SPM_SCH_W1 */


#define CSL_SGCP_CFG_SPM_SCH_W1_DIV_MODE_MASK (0x60000000u)
#define CSL_SGCP_CFG_SPM_SCH_W1_DIV_MODE_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_SCH_W1_DIV_MODE_RESETVAL (0x00000000u)
/*----DIV_MODE Tokens----*/
#define CSL_SGCP_CFG_SPM_SCH_W1_DIV_MODE_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCH_W1_DIV_MODE_TSTD (0x00000001u)


#define CSL_SGCP_CFG_SPM_SCH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_SCH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_SCH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_SCH_W1_SCR_CODE_GRP_MASK (0x0000003Fu)
#define CSL_SGCP_CFG_SPM_SCH_W1_SCR_CODE_GRP_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCH_W1_SCR_CODE_GRP_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCH_W1_RESETVAL (0x00000000u)

/* SPM_SCH_W2 */


#define CSL_SGCP_CFG_SPM_SCH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_SCH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_SCH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_SCH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_SCH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_SCH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_SCH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_SCH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_SCH_W2_BF_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCH_W2_CHAN_GAIN_MASK (0x000003FFu)
#define CSL_SGCP_CFG_SPM_SCH_W2_CHAN_GAIN_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCH_W2_CHAN_GAIN_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCH_W2_RESETVAL (0x00000000u)

/* SPM_CPICH_W0 */


#define CSL_SGCP_CFG_SPM_CPICH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_CPICH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_CPICH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_CPICH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_CPICH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_CPICH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_CPICH_W0_CHANNEL_KIND_PCPICH (0x00000003u)
#define CSL_SGCP_CFG_SPM_CPICH_W0_CHANNEL_KIND_SCPICH (0x00000004u)

#define CSL_SGCP_CFG_SPM_CPICH_W0_RESETVAL (0x00000000u)

/* SPM_CPICH_W1 */


#define CSL_SGCP_CFG_SPM_CPICH_W1_DIV_MODE_MASK (0x60000000u)
#define CSL_SGCP_CFG_SPM_CPICH_W1_DIV_MODE_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_CPICH_W1_DIV_MODE_RESETVAL (0x00000000u)
/*----DIV_MODE Tokens----*/
#define CSL_SGCP_CFG_SPM_CPICH_W1_DIV_MODE_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_CPICH_W1_DIV_MODE_DIV (0x00000001u)

#define CSL_SGCP_CFG_SPM_CPICH_W1_VAM_GAIN_FLAG_MASK (0x10000000u)
#define CSL_SGCP_CFG_SPM_CPICH_W1_VAM_GAIN_FLAG_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SPM_CPICH_W1_VAM_GAIN_FLAG_RESETVAL (0x00000000u)
/*----VAM_GAIN_FLAG Tokens----*/
#define CSL_SGCP_CFG_SPM_CPICH_W1_VAM_GAIN_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_CPICH_W1_VAM_GAIN_FLAG_ENABLE (0x00000001u)


#define CSL_SGCP_CFG_SPM_CPICH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_CPICH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_CPICH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_CPICH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_CPICH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_CPICH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_CPICH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_CPICH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_CPICH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_CPICH_W1_RESETVAL (0x00000000u)

/* SPM_CPICH_W2 */


#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_CPICH_W2_BF_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_CPICH_W2_CHAN_GAIN_MASK (0x000003FFu)
#define CSL_SGCP_CFG_SPM_CPICH_W2_CHAN_GAIN_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_CPICH_W2_CHAN_GAIN_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_CPICH_W2_RESETVAL (0x00000000u)

/* SPM_PICH_W0 */


#define CSL_SGCP_CFG_SPM_PICH_W0_MOD_SCHEME_MASK (0x03800000u)
#define CSL_SGCP_CFG_SPM_PICH_W0_MOD_SCHEME_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_PICH_W0_MOD_SCHEME_RESETVAL (0x00000000u)
/*----MOD_SCHEME Tokens----*/
#define CSL_SGCP_CFG_SPM_PICH_W0_MOD_SCHEME_QPSK (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W0_MOD_SCHEME_QPSK_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_PICH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_PICH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_PICH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_PICH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_PICH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_PICH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_PICH_W0_CHANNEL_KIND_PICH (0x00000005u)

#define CSL_SGCP_CFG_SPM_PICH_W0_RESETVAL (0x00000000u)

/* SPM_PICH_W1 */


#define CSL_SGCP_CFG_SPM_PICH_W1_DIV_MODE_MASK (0x60000000u)
#define CSL_SGCP_CFG_SPM_PICH_W1_DIV_MODE_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_PICH_W1_DIV_MODE_RESETVAL (0x00000000u)
/*----DIV_MODE Tokens----*/
#define CSL_SGCP_CFG_SPM_PICH_W1_DIV_MODE_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W1_DIV_MODE_STTD (0x00000001u)

#define CSL_SGCP_CFG_SPM_PICH_W1_VAM_GAIN_FLAG_MASK (0x10000000u)
#define CSL_SGCP_CFG_SPM_PICH_W1_VAM_GAIN_FLAG_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SPM_PICH_W1_VAM_GAIN_FLAG_RESETVAL (0x00000000u)
/*----VAM_GAIN_FLAG Tokens----*/
#define CSL_SGCP_CFG_SPM_PICH_W1_VAM_GAIN_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W1_VAM_GAIN_FLAG_ENABLE (0x00000001u)


#define CSL_SGCP_CFG_SPM_PICH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_PICH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_PICH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_PICH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_PICH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_PICH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W1_RESETVAL (0x00000000u)

/* SPM_PICH_W2 */


#define CSL_SGCP_CFG_SPM_PICH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_PICH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_PICH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_PICH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)

#define CSL_SGCP_CFG_SPM_PICH_W2_SYM_IB_ID_MASK (0x3FE00000u)
#define CSL_SGCP_CFG_SPM_PICH_W2_SYM_IB_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_PICH_W2_SYM_IB_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_PICH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_PICH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_PICH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_PICH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_PICH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_PICH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_PICH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_PICH_W2_BF_RLS_ID_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_PICH_W2_RESETVAL (0x00000000u)

/* SPM_PICH_W3 */

#define CSL_SGCP_CFG_SPM_PICH_W3_EVEN_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_PICH_W3_EVEN_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W3_EVEN_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W3_RESETVAL (0x00000000u)

/* SPM_PICH_W4 */

#define CSL_SGCP_CFG_SPM_PICH_W4_ODD_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_PICH_W4_ODD_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W4_ODD_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W4_RESETVAL (0x00000000u)

/* SPM_PICH_W5 */

#define CSL_SGCP_CFG_SPM_PICH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_PICH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_PICH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_PICH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W5_DTX_FLAG1_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_PICH_W5_CHANNEL_GAIN1_MASK (0x03FF0000u)
#define CSL_SGCP_CFG_SPM_PICH_W5_CHANNEL_GAIN1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SPM_PICH_W5_CHANNEL_GAIN1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_PICH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_PICH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_PICH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W5_DTX_FLAG0_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_PICH_W5_CHANNEL_GAIN0_MASK (0x000003FFu)
#define CSL_SGCP_CFG_SPM_PICH_W5_CHANNEL_GAIN0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_PICH_W5_CHANNEL_GAIN0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PICH_W5_RESETVAL (0x00000000u)

/* SPM_MICH_W0 */


#define CSL_SGCP_CFG_SPM_MICH_W0_MOD_SCHEME_MASK (0x03800000u)
#define CSL_SGCP_CFG_SPM_MICH_W0_MOD_SCHEME_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_MICH_W0_MOD_SCHEME_RESETVAL (0x00000000u)
/*----MOD_SCHEME Tokens----*/
#define CSL_SGCP_CFG_SPM_MICH_W0_MOD_SCHEME_QPSK (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W0_MOD_SCHEME_QPSK_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_MICH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_MICH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_MICH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_MICH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_MICH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_MICH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_MICH_W0_CHANNEL_KIND_MICH (0x0000000Du)

#define CSL_SGCP_CFG_SPM_MICH_W0_RESETVAL (0x00000000u)

/* SPM_MICH_W1 */


#define CSL_SGCP_CFG_SPM_MICH_W1_DIV_MODE_MASK (0x60000000u)
#define CSL_SGCP_CFG_SPM_MICH_W1_DIV_MODE_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_MICH_W1_DIV_MODE_RESETVAL (0x00000000u)
/*----DIV_MODE Tokens----*/
#define CSL_SGCP_CFG_SPM_MICH_W1_DIV_MODE_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W1_DIV_MODE_STTD (0x00000001u)

#define CSL_SGCP_CFG_SPM_MICH_W1_VAM_GAIN_FLAG_MASK (0x10000000u)
#define CSL_SGCP_CFG_SPM_MICH_W1_VAM_GAIN_FLAG_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SPM_MICH_W1_VAM_GAIN_FLAG_RESETVAL (0x00000000u)
/*----VAM_GAIN_FLAG Tokens----*/
#define CSL_SGCP_CFG_SPM_MICH_W1_VAM_GAIN_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W1_VAM_GAIN_FLAG_ENABLE (0x00000001u)


#define CSL_SGCP_CFG_SPM_MICH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_MICH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_MICH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_MICH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_MICH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_MICH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W1_RESETVAL (0x00000000u)

/* SPM_MICH_W2 */


#define CSL_SGCP_CFG_SPM_MICH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_MICH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_MICH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_MICH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)

#define CSL_SGCP_CFG_SPM_MICH_W2_SYM_IB_ID_MASK (0x3FE00000u)
#define CSL_SGCP_CFG_SPM_MICH_W2_SYM_IB_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_MICH_W2_SYM_IB_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_MICH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_MICH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_MICH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_MICH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_MICH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_MICH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_MICH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_MICH_W2_BF_RLS_ID_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_MICH_W2_RESETVAL (0x00000000u)

/* SPM_MICH_W3 */

#define CSL_SGCP_CFG_SPM_MICH_W3_EVEN_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_MICH_W3_EVEN_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W3_EVEN_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W3_RESETVAL (0x00000000u)

/* SPM_MICH_W4 */

#define CSL_SGCP_CFG_SPM_MICH_W4_ODD_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_MICH_W4_ODD_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W4_ODD_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W4_RESETVAL (0x00000000u)

/* SPM_MICH_W5 */

#define CSL_SGCP_CFG_SPM_MICH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_MICH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_MICH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_MICH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W5_DTX_FLAG1_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_MICH_W5_CHANNEL_GAIN1_MASK (0x03FF0000u)
#define CSL_SGCP_CFG_SPM_MICH_W5_CHANNEL_GAIN1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SPM_MICH_W5_CHANNEL_GAIN1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_MICH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_MICH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_MICH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W5_DTX_FLAG0_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_MICH_W5_CHANNEL_GAIN0_MASK (0x000003FFu)
#define CSL_SGCP_CFG_SPM_MICH_W5_CHANNEL_GAIN0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_MICH_W5_CHANNEL_GAIN0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_MICH_W5_RESETVAL (0x00000000u)

/* SPM_PCCPCH_W0 */


#define CSL_SGCP_CFG_SPM_PCCPCH_W0_MOD_SCHEME_MASK (0x03800000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_MOD_SCHEME_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_MOD_SCHEME_RESETVAL (0x00000000u)
/*----MOD_SCHEME Tokens----*/
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_MOD_SCHEME_QPSK (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_MOD_SCHEME_QPSK_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_PCCPCH_W0_CHANNEL_KIND_PCCPCH (0x00000006u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W0_RESETVAL (0x00000000u)

/* SPM_PCCPCH_W1 */


#define CSL_SGCP_CFG_SPM_PCCPCH_W1_DIV_MODE_MASK (0x60000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_DIV_MODE_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_DIV_MODE_RESETVAL (0x00000000u)
/*----DIV_MODE Tokens----*/
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_DIV_MODE_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_DIV_MODE_STTD (0x00000001u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W1_VAM_GAIN_FLAG_MASK (0x10000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_VAM_GAIN_FLAG_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_VAM_GAIN_FLAG_RESETVAL (0x00000000u)
/*----VAM_GAIN_FLAG Tokens----*/
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_VAM_GAIN_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_VAM_GAIN_FLAG_ENABLE (0x00000001u)


#define CSL_SGCP_CFG_SPM_PCCPCH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W1_RESETVAL (0x00000000u)

/* SPM_PCCPCH_W2 */


#define CSL_SGCP_CFG_SPM_PCCPCH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W2_SYM_IB_ID_MASK (0x3FE00000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_SYM_IB_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_SYM_IB_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_PCCPCH_W2_BF_RLS_ID_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_PCCPCH_W2_RESETVAL (0x00000000u)

/* SPM_PCCPCH_W3 */

#define CSL_SGCP_CFG_SPM_PCCPCH_W3_EVEN_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_PCCPCH_W3_EVEN_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W3_EVEN_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W3_RESETVAL (0x00000000u)

/* SPM_PCCPCH_W4 */

#define CSL_SGCP_CFG_SPM_PCCPCH_W4_ODD_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_PCCPCH_W4_ODD_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W4_ODD_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W4_RESETVAL (0x00000000u)

/* SPM_PCCPCH_W5 */

#define CSL_SGCP_CFG_SPM_PCCPCH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_DTX_FLAG1_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_PCCPCH_W5_CHANNEL_GAIN1_MASK (0x03FF0000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_CHANNEL_GAIN1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_CHANNEL_GAIN1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_DTX_FLAG0_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_PCCPCH_W5_CHANNEL_GAIN0_MASK (0x000003FFu)
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_CHANNEL_GAIN0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_PCCPCH_W5_CHANNEL_GAIN0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_PCCPCH_W5_RESETVAL (0x00000000u)

/* SPM_SCCPCH_W0 */


#define CSL_SGCP_CFG_SPM_SCCPCH_W0_SL_FOR_ID_MASK (0x7C000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_SL_FOR_ID_SHIFT (0x0000001Au)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_SL_FOR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W0_MOD_SCHEME_MASK (0x03800000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_MOD_SCHEME_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_MOD_SCHEME_RESETVAL (0x00000000u)
/*----MOD_SCHEME Tokens----*/
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_MOD_SCHEME_QPSK (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_MOD_SCHEME_QPSK_DTX (0x00000001u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_MOD_SCHEME_16QAM (0x00000002u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_MOD_SCHEME_16QAM_DTX (0x00000003u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_SCCPCH_W0_CHANNEL_KIND_SCCPCH (0x00000007u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W0_RESETVAL (0x00000000u)

/* SPM_SCCPCH_W1 */


#define CSL_SGCP_CFG_SPM_SCCPCH_W1_DIV_MODE_MASK (0x60000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_DIV_MODE_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_DIV_MODE_RESETVAL (0x00000000u)
/*----DIV_MODE Tokens----*/
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_DIV_MODE_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_DIV_MODE_STTD (0x00000001u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W1_VAM_GAIN_FLAG_MASK (0x10000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_VAM_GAIN_FLAG_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_VAM_GAIN_FLAG_RESETVAL (0x00000000u)
/*----VAM_GAIN_FLAG Tokens----*/
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_VAM_GAIN_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_VAM_GAIN_FLAG_ENABLE (0x00000001u)


#define CSL_SGCP_CFG_SPM_SCCPCH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W1_RESETVAL (0x00000000u)

/* SPM_SCCPCH_W2 */


#define CSL_SGCP_CFG_SPM_SCCPCH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W2_SYM_IB_ID_MASK (0x3FE00000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_SYM_IB_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_SYM_IB_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_BF_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W2_PO3_PILOT_MASK (0x000003E0u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_PO3_PILOT_SHIFT (0x00000005u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_PO3_PILOT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W2_PO1_TFCI_MASK (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_PO1_TFCI_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W2_PO1_TFCI_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W2_RESETVAL (0x00000000u)

/* SPM_SCCPCH_W3 */

#define CSL_SGCP_CFG_SPM_SCCPCH_W3_EVEN_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W3_EVEN_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W3_EVEN_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W3_RESETVAL (0x00000000u)

/* SPM_SCCPCH_W4 */

#define CSL_SGCP_CFG_SPM_SCCPCH_W4_ODD_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W4_ODD_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W4_ODD_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W4_RESETVAL (0x00000000u)

/* SPM_SCCPCH_W5 */

#define CSL_SGCP_CFG_SPM_SCCPCH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_DTX_FLAG1_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_SCCPCH_W5_CHANNEL_GAIN1_MASK (0x03FF0000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_CHANNEL_GAIN1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_CHANNEL_GAIN1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_DTX_FLAG0_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_SCCPCH_W5_CHANNEL_GAIN0_MASK (0x000003FFu)
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_CHANNEL_GAIN0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W5_CHANNEL_GAIN0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_SCCPCH_W5_RESETVAL (0x00000000u)

/* SPM_SCCPCH_W6 */

#define CSL_SGCP_CFG_SPM_SCCPCH_W6_NEXT_BLK_PTR0_MASK (0xFFFFFFF8u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W6_NEXT_BLK_PTR0_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W6_NEXT_BLK_PTR0_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_SCCPCH_W6_RESETVAL (0x00000000u)

/* SPM_SCCPCH_W7 */

#define CSL_SGCP_CFG_SPM_SCCPCH_W7_NEXT_BLK_PTR1_MASK (0xFFFFFFF8u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W7_NEXT_BLK_PTR1_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_SPM_SCCPCH_W7_NEXT_BLK_PTR1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_SCCPCH_W7_RESETVAL (0x00000000u)

/* SPM_AICH_W0 */


#define CSL_SGCP_CFG_SPM_AICH_W0_MOD_SCHEME_MASK (0x03800000u)
#define CSL_SGCP_CFG_SPM_AICH_W0_MOD_SCHEME_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_AICH_W0_MOD_SCHEME_RESETVAL (0x00000000u)
/*----MOD_SCHEME Tokens----*/
#define CSL_SGCP_CFG_SPM_AICH_W0_MOD_SCHEME_QPSK (0x00000000u)

#define CSL_SGCP_CFG_SPM_AICH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_AICH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_AICH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_AICH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_AICH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_AICH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_AICH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_AICH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_AICH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_AICH_W0_CHANNEL_KIND_AICH (0x00000008u)

#define CSL_SGCP_CFG_SPM_AICH_W0_RESETVAL (0x00000000u)

/* SPM_AICH_W1 */


#define CSL_SGCP_CFG_SPM_AICH_W1_DIV_MODE_MASK (0x60000000u)
#define CSL_SGCP_CFG_SPM_AICH_W1_DIV_MODE_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_AICH_W1_DIV_MODE_RESETVAL (0x00000000u)
/*----DIV_MODE Tokens----*/
#define CSL_SGCP_CFG_SPM_AICH_W1_DIV_MODE_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_AICH_W1_DIV_MODE_STTD (0x00000001u)

#define CSL_SGCP_CFG_SPM_AICH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_AICH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_AICH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_AICH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_AICH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_AICH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_AICH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_AICH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_AICH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_AICH_W1_RESETVAL (0x00000000u)

/* SPM_AICH_W2 */


#define CSL_SGCP_CFG_SPM_AICH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_AICH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_AICH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_AICH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_AICH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)


#define CSL_SGCP_CFG_SPM_AICH_W2_SIG_AGGR_ID_MASK (0x07E00000u)
#define CSL_SGCP_CFG_SPM_AICH_W2_SIG_AGGR_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_AICH_W2_SIG_AGGR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_AICH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_AICH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_AICH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_AICH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_AICH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_AICH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_AICH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_AICH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_AICH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_AICH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_AICH_W2_BF_RLS_ID_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_AICH_W2_SIG_TASK_ID_MASK (0x000001FFu)
#define CSL_SGCP_CFG_SPM_AICH_W2_SIG_TASK_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_AICH_W2_SIG_TASK_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_AICH_W2_RESETVAL (0x00000000u)

/* SPM_AICH_W3 */

#define CSL_SGCP_CFG_SPM_AICH_W3_ACCESS_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_AICH_W3_ACCESS_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_AICH_W3_ACCESS_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_AICH_W3_RESETVAL (0x00000000u)

/* SPM_AICH_W5 */

#define CSL_SGCP_CFG_SPM_AICH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_AICH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_AICH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_AICH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_AICH_W5_DTX_FLAG1_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_AICH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_AICH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_AICH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_AICH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_AICH_W5_DTX_FLAG0_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_AICH_W5_RESETVAL (0x00000000u)

/* SPM_HSPDSCH_W0 */


#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_BF_2ND_CYC_DTX_MASK (0x20000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_BF_2ND_CYC_DTX_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_BF_2ND_CYC_DTX_RESETVAL (0x00000000u)
/*----BF_2ND_CYC_DTX Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_BF_2ND_CYC_DTX_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_BF_2ND_CYC_DTX_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_PRIM_STR_SWAP_MASK (0x10000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_PRIM_STR_SWAP_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_PRIM_STR_SWAP_RESETVAL (0x00000000u)
/*----PRIM_STR_SWAP Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_PRIM_STR_SWAP_NO_SWAP (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_PRIM_STR_SWAP_SWAP (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_DUMMY_SPR_MASK (0x08000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_DUMMY_SPR_SHIFT (0x0000001Bu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_DUMMY_SPR_RESETVAL (0x00000000u)
/*----DUMMY_SPR Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_DUMMY_SPR_REAL (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_DUMMY_SPR_DUMMY (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_MIMO_INV_MASK (0x04000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_MIMO_INV_SHIFT (0x0000001Au)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_MIMO_INV_RESETVAL (0x00000000u)
/*----MIMO_INV Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_MIMO_INV_NO_INV (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_MIMO_INV_INV (0x00000001u)


#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_CHANNEL_KIND_HSPDSCH (0x00000009u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W0_RESETVAL (0x00000000u)

/* SPM_HSPDSCH_W1 */


#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_VAM_GAIN_FLAG_MASK (0x10000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_VAM_GAIN_FLAG_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_VAM_GAIN_FLAG_RESETVAL (0x00000000u)
/*----VAM_GAIN_FLAG Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_VAM_GAIN_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_VAM_GAIN_FLAG_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W1_RESETVAL (0x00000000u)

/* SPM_HSPDSCH_W2 */

#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_MSG_MASTER_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_MSG_MASTER_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_MSG_MASTER_RESETVAL (0x00000000u)
/*----MSG_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_MSG_MASTER_MSG_SLAVE (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_MSG_MASTER_MSG_MASTER (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_SYM_IB_ID_MASK (0x3FE00000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_SYM_IB_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_SYM_IB_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_DUM_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_DUM_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_DUM_BF_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_MSG_RL_ID_MASK (0x00000380u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_MSG_RL_ID_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_MSG_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_DUM_MSG_RLS_ID_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_DUM_MSG_RLS_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_DUM_MSG_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W2_RESETVAL (0x00000000u)

/* SPM_HSPDSCH_W3 */

#define CSL_SGCP_CFG_SPM_HSPDSCH_W3_EVEN_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W3_EVEN_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W3_EVEN_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W3_RESETVAL (0x00000000u)

/* SPM_HSPDSCH_W4 */

#define CSL_SGCP_CFG_SPM_HSPDSCH_W4_ODD_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W4_ODD_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W4_ODD_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W4_RESETVAL (0x00000000u)

/* SPM_HSPDSCH_W5 */


#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_DTX_FLAG1_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_DTX_FLAG0_DTX (0x00000001u)



#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME1_MASK (0x38000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME1_SHIFT (0x0000001Bu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME1_RESETVAL (0x00000000u)
/*----MOD_SCHEME1 Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME1_QPSK (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME1_QPSK_DTX (0x00000001u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME1_16QAM (0x00000002u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME1_16QAM_DTX (0x00000003u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME1_64QAM (0x00000004u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME1_64QAM_DTX (0x00000005u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME0_MASK (0x00003800u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME0_SHIFT (0x0000000Bu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME0_RESETVAL (0x00000000u)
/*----MOD_SCHEME0 Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME0_QPSK (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME0_QPSK_DTX (0x00000001u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME0_16QAM (0x00000002u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME0_16QAM_DTX (0x00000003u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME0_64QAM (0x00000004u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MOD_SCHEME0_64QAM_DTX (0x00000005u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_CHANNEL_CODE_ID1_MASK (0x07800000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_CHANNEL_CODE_ID1_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_CHANNEL_CODE_ID1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_CHANNEL_CODE_ID0_MASK (0x00000780u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_CHANNEL_CODE_ID0_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_CHANNEL_CODE_ID0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MSG_RL_ID1_MASK (0x007F0000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MSG_RL_ID1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MSG_RL_ID1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MSG_RL_ID0_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MSG_RL_ID0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_MSG_RL_ID0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W5_RESETVAL (0x00000000u)

/* SPM_HSPDSCH_W6 */

#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_NEXT_BLK_PTR0_MASK (0xFFFFFFF8u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_NEXT_BLK_PTR0_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_NEXT_BLK_PTR0_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_DIV_MODE0_MASK (0x00000003u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_DIV_MODE0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_DIV_MODE0_RESETVAL (0x00000000u)
/*----DIV_MODE0 Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_DIV_MODE0_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_DIV_MODE0_STTD (0x00000001u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_DIV_MODE0_CLD1 (0x00000002u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_DIV_MODE0_MIMO (0x00000003u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W6_RESETVAL (0x00000000u)

/* SPM_HSPDSCH_W7 */

#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_NEXT_BLK_PTR1_MASK (0xFFFFFFF8u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_NEXT_BLK_PTR1_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_NEXT_BLK_PTR1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_DIV_MODE1_MASK (0x00000003u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_DIV_MODE1_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_DIV_MODE1_RESETVAL (0x00000000u)
/*----DIV_MODE1 Tokens----*/
#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_DIV_MODE1_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_DIV_MODE1_STTD (0x00000001u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_DIV_MODE1_CLD1 (0x00000002u)
#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_DIV_MODE1_MIMO (0x00000003u)

#define CSL_SGCP_CFG_SPM_HSPDSCH_W7_RESETVAL (0x00000000u)

/* SPM_HSSCCH_W0 */


#define CSL_SGCP_CFG_SPM_HSSCCH_W0_BF_2ND_CYC_DTX_MASK (0x20000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_BF_2ND_CYC_DTX_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_BF_2ND_CYC_DTX_RESETVAL (0x00000000u)
/*----BF_2ND_CYC_DTX Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_BF_2ND_CYC_DTX_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_BF_2ND_CYC_DTX_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_HSSCCH_W0_MOD_SCHEME_MASK (0x03800000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_MOD_SCHEME_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_MOD_SCHEME_RESETVAL (0x00000000u)
/*----MOD_SCHEME Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_MOD_SCHEME_QPSK (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_MOD_SCHEME_QPSK_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W0_CHANNEL_KIND_HSSCCH (0x0000000Au)

#define CSL_SGCP_CFG_SPM_HSSCCH_W0_RESETVAL (0x00000000u)

/* SPM_HSSCCH_W1 */


#define CSL_SGCP_CFG_SPM_HSSCCH_W1_VAM_GAIN_FLAG_MASK (0x10000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W1_VAM_GAIN_FLAG_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W1_VAM_GAIN_FLAG_RESETVAL (0x00000000u)
/*----VAM_GAIN_FLAG Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W1_VAM_GAIN_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W1_VAM_GAIN_FLAG_ENABLE (0x00000001u)


#define CSL_SGCP_CFG_SPM_HSSCCH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_HSSCCH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W1_RESETVAL (0x00000000u)

/* SPM_HSSCCH_W2 */

#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_MASTER_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_MASTER_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_MASTER_RESETVAL (0x00000000u)
/*----MSG_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_MASTER_MSG_SLAVE (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_MASTER_MSG_MASTER (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W2_SYM_IB_ID_MASK (0x3FE00000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_SYM_IB_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_SYM_IB_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_BF_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_RL_ID_MASK (0x00000380u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_RL_ID_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_RLS_ID_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_RLS_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W2_MSG_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W2_RESETVAL (0x00000000u)

/* SPM_HSSCCH_W3 */

#define CSL_SGCP_CFG_SPM_HSSCCH_W3_EVEN_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W3_EVEN_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W3_EVEN_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W3_RESETVAL (0x00000000u)

/* SPM_HSSCCH_W4 */

#define CSL_SGCP_CFG_SPM_HSSCCH_W4_ODD_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W4_ODD_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W4_ODD_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W4_RESETVAL (0x00000000u)

/* SPM_HSSCCH_W5 */

#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DTX_FLAG1_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DIV_MODE1_MASK (0x00030000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DIV_MODE1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DIV_MODE1_RESETVAL (0x00000000u)
/*----DIV_MODE1 Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DIV_MODE1_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DIV_MODE1_STTD (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DTX_FLAG0_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DIV_MODE0_MASK (0x00000003u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DIV_MODE0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DIV_MODE0_RESETVAL (0x00000000u)
/*----DIV_MODE0 Tokens----*/
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DIV_MODE0_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_HSSCCH_W5_DIV_MODE0_STTD (0x00000001u)

#define CSL_SGCP_CFG_SPM_HSSCCH_W5_RESETVAL (0x00000000u)

/* SPM_ERGCH_W0 */


#define CSL_SGCP_CFG_SPM_ERGCH_W0_NB_SIG_MASK (0x1F800000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W0_NB_SIG_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_ERGCH_W0_NB_SIG_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_ERGCH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_ERGCH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_ERGCH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_ERGCH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_ERGCH_W0_CHANNEL_KIND_ERGCH (0x0000000Bu)

#define CSL_SGCP_CFG_SPM_ERGCH_W0_RESETVAL (0x00000000u)

/* SPM_ERGCH_W1 */


#define CSL_SGCP_CFG_SPM_ERGCH_W1_DIV_MODE_MASK (0x60000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W1_DIV_MODE_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_ERGCH_W1_DIV_MODE_RESETVAL (0x00000000u)
/*----DIV_MODE Tokens----*/
#define CSL_SGCP_CFG_SPM_ERGCH_W1_DIV_MODE_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W1_DIV_MODE_STTD (0x00000001u)


#define CSL_SGCP_CFG_SPM_ERGCH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_ERGCH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_ERGCH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_ERGCH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W1_RESETVAL (0x00000000u)

/* SPM_ERGCH_W2 */


#define CSL_SGCP_CFG_SPM_ERGCH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_ERGCH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)


#define CSL_SGCP_CFG_SPM_ERGCH_W2_SIG_AGGR_ID_MASK (0x1FE00000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_SIG_AGGR_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_SIG_AGGR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_BF_RLS_ID_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SPM_ERGCH_W2_SIG_TASK_ID_MASK (0x000001FFu)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_SIG_TASK_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W2_SIG_TASK_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W2_RESETVAL (0x00000000u)

/* SPM_ERGCH_W3 */

#define CSL_SGCP_CFG_SPM_ERGCH_W3_EVEN_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_ERGCH_W3_EVEN_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W3_EVEN_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W3_RESETVAL (0x00000000u)

/* SPM_ERGCH_W4 */

#define CSL_SGCP_CFG_SPM_ERGCH_W4_ODD_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_ERGCH_W4_ODD_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W4_ODD_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_ERGCH_W4_RESETVAL (0x00000000u)

/* SPM_ERGCH_W5 */

#define CSL_SGCP_CFG_SPM_ERGCH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_ERGCH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_ERGCH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W5_DTX_FLAG1_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_ERGCH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_ERGCH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_ERGCH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_ERGCH_W5_DTX_FLAG0_DTX (0x00000001u)


#define CSL_SGCP_CFG_SPM_ERGCH_W5_RESETVAL (0x00000000u)

/* SPM_EAGCH_W0 */


#define CSL_SGCP_CFG_SPM_EAGCH_W0_BF_2ND_CYC_DTX_FLAG_MASK (0x20000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_BF_2ND_CYC_DTX_FLAG_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_BF_2ND_CYC_DTX_FLAG_RESETVAL (0x00000000u)
/*----BF_2ND_CYC_DTX_FLAG Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W0_BF_2ND_CYC_DTX_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_BF_2ND_CYC_DTX_FLAG_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_EAGCH_W0_MOD_SCHEME_MASK (0x03800000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_MOD_SCHEME_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_MOD_SCHEME_RESETVAL (0x00000000u)
/*----MOD_SCHEME Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W0_MOD_SCHEME_QPSK (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_MOD_SCHEME_QPSK_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_EAGCH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W0_CHANNEL_KIND_EAGCH (0x0000000Cu)

#define CSL_SGCP_CFG_SPM_EAGCH_W0_RESETVAL (0x00000000u)

/* SPM_EAGCH_W1 */


#define CSL_SGCP_CFG_SPM_EAGCH_W1_VAM_GAIN_FLAG_MASK (0x10000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W1_VAM_GAIN_FLAG_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SPM_EAGCH_W1_VAM_GAIN_FLAG_RESETVAL (0x00000000u)
/*----VAM_GAIN_FLAG Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W1_VAM_GAIN_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W1_VAM_GAIN_FLAG_ENABLE (0x00000001u)


#define CSL_SGCP_CFG_SPM_EAGCH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_EAGCH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_EAGCH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_EAGCH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W1_RESETVAL (0x00000000u)

/* SPM_EAGCH_W2 */

#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_MASTER_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_MASTER_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_MASTER_RESETVAL (0x00000000u)
/*----MSG_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_MASTER_MSG_SLAVE (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_MASTER_MSG_MASTER (0x00000001u)

#define CSL_SGCP_CFG_SPM_EAGCH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)

#define CSL_SGCP_CFG_SPM_EAGCH_W2_SYM_IB_ID_MASK (0x3FE00000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_SYM_IB_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_SYM_IB_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_BF_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_RL_ID_MASK (0x00000380u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_RL_ID_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_RLS_ID_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_RLS_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W2_MSG_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W2_RESETVAL (0x00000000u)

/* SPM_EAGCH_W3 */

#define CSL_SGCP_CFG_SPM_EAGCH_W3_EVEN_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_EAGCH_W3_EVEN_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W3_EVEN_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W3_RESETVAL (0x00000000u)

/* SPM_EAGCH_W4 */

#define CSL_SGCP_CFG_SPM_EAGCH_W4_ODD_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_EAGCH_W4_ODD_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W4_ODD_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_EAGCH_W4_RESETVAL (0x00000000u)

/* SPM_EAGCH_W5 */

#define CSL_SGCP_CFG_SPM_EAGCH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DTX_FLAG1_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_EAGCH_W5_DIV_MODE1_MASK (0x00030000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DIV_MODE1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DIV_MODE1_RESETVAL (0x00000000u)
/*----DIV_MODE1 Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DIV_MODE1_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DIV_MODE1_STTD (0x00000001u)


#define CSL_SGCP_CFG_SPM_EAGCH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DTX_FLAG0_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_EAGCH_W5_DIV_MODE0_MASK (0x00000003u)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DIV_MODE0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DIV_MODE0_RESETVAL (0x00000000u)
/*----DIV_MODE0 Tokens----*/
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DIV_MODE0_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_EAGCH_W5_DIV_MODE0_STTD (0x00000001u)


#define CSL_SGCP_CFG_SPM_EAGCH_W5_RESETVAL (0x00000000u)

/* SPM_FDPCH_W0 */


#define CSL_SGCP_CFG_SPM_FDPCH_W0_SL_FOR_ID_MASK (0x7C000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_SL_FOR_ID_SHIFT (0x0000001Au)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_SL_FOR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W0_INITFR_LASTSLOT_BIT_MASK (0x02000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_INITFR_LASTSLOT_BIT_SHIFT (0x00000019u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_INITFR_LASTSLOT_BIT_RESETVAL (0x00000000u)
/*----INITFR_LASTSLOT_BIT Tokens----*/
#define CSL_SGCP_CFG_SPM_FDPCH_W0_INITFR_LASTSLOT_BIT_TRANSMISSION (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_INITFR_LASTSLOT_BIT_GAP (0x00000001u)

#define CSL_SGCP_CFG_SPM_FDPCH_W0_MOD_SCHEME_MASK (0x01800000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_MOD_SCHEME_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_MOD_SCHEME_RESETVAL (0x00000000u)
/*----MOD_SCHEME Tokens----*/
#define CSL_SGCP_CFG_SPM_FDPCH_W0_MOD_SCHEME_QPSK (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_MOD_SCHEME_QPSK_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_FDPCH_W0_TXOFFSET_MASK (0x007F8000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_TXOFFSET_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_TXOFFSET_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W0_TCELL_MASK (0x00007FF0u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_TCELL_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_TCELL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W0_CHANNEL_KIND_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_CHANNEL_KIND_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W0_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SPM_FDPCH_W0_CHANNEL_KIND_FDPCH (0x0000000Eu)

#define CSL_SGCP_CFG_SPM_FDPCH_W0_RESETVAL (0x00000000u)

/* SPM_FDPCH_W1 */


#define CSL_SGCP_CFG_SPM_FDPCH_W1_DIV_MODE_MASK (0x60000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W1_DIV_MODE_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SPM_FDPCH_W1_DIV_MODE_RESETVAL (0x00000000u)
/*----DIV_MODE Tokens----*/
#define CSL_SGCP_CFG_SPM_FDPCH_W1_DIV_MODE_NO_DIV (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W1_DIV_MODE_STTD (0x00000001u)


#define CSL_SGCP_CFG_SPM_FDPCH_W1_STREAM_PAIR_ID_MASK (0x0FC00000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W1_STREAM_PAIR_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SPM_FDPCH_W1_STREAM_PAIR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W1_CHANNEL_CODE_ID_MASK (0x003FE000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W1_CHANNEL_CODE_ID_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SPM_FDPCH_W1_CHANNEL_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W1_SCR_CODE_ID_MASK (0x00001FFFu)
#define CSL_SGCP_CFG_SPM_FDPCH_W1_SCR_CODE_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W1_SCR_CODE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W1_RESETVAL (0x00000000u)

/* SPM_FDPCH_W2 */

#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_MASTER_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_MASTER_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_MASTER_RESETVAL (0x00000000u)
/*----MSG_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_MASTER_MSG_SLAVE (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_MASTER_MSG_MASTER (0x00000001u)

#define CSL_SGCP_CFG_SPM_FDPCH_W2_FETCH_MASTER_MASK (0x40000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_FETCH_MASTER_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_FETCH_MASTER_RESETVAL (0x00000000u)
/*----FETCH_MASTER Tokens----*/
#define CSL_SGCP_CFG_SPM_FDPCH_W2_FETCH_MASTER_NO_DATA_FETCH (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_FETCH_MASTER_DATA_FETCH (0x00000001u)

#define CSL_SGCP_CFG_SPM_FDPCH_W2_SYM_IB_ID_MASK (0x3FE00000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_SYM_IB_ID_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_SYM_IB_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_ENA_MASK (0x00100000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_ENA_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_ENA_RESETVAL (0x00000000u)
/*----BF_ENA Tokens----*/
#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_RL_ID_MASK (0x000E0000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_RL_ID_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_RLS_ID_MASK (0x0001FC00u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_RLS_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_BF_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_RL_ID_MASK (0x00000380u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_RL_ID_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_RLS_ID_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_RLS_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W2_MSG_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W2_RESETVAL (0x00000000u)

/* SPM_FDPCH_W3 */

#define CSL_SGCP_CFG_SPM_FDPCH_W3_EVEN_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_FDPCH_W3_EVEN_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W3_EVEN_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W3_RESETVAL (0x00000000u)

/* SPM_FDPCH_W4 */

#define CSL_SGCP_CFG_SPM_FDPCH_W4_ODD_FRAME_PTR_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_SPM_FDPCH_W4_ODD_FRAME_PTR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W4_ODD_FRAME_PTR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W4_RESETVAL (0x00000000u)

/* SPM_FDPCH_W5 */

#define CSL_SGCP_CFG_SPM_FDPCH_W5_DTX_FLAG1_MASK (0x80000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W5_DTX_FLAG1_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SPM_FDPCH_W5_DTX_FLAG1_RESETVAL (0x00000000u)
/*----DTX_FLAG1 Tokens----*/
#define CSL_SGCP_CFG_SPM_FDPCH_W5_DTX_FLAG1_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W5_DTX_FLAG1_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_FDPCH_W5_SLOT_MASK1_MASK (0x7FFF0000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W5_SLOT_MASK1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SPM_FDPCH_W5_SLOT_MASK1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W5_DTX_FLAG0_MASK (0x00008000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W5_DTX_FLAG0_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SPM_FDPCH_W5_DTX_FLAG0_RESETVAL (0x00000000u)
/*----DTX_FLAG0 Tokens----*/
#define CSL_SGCP_CFG_SPM_FDPCH_W5_DTX_FLAG0_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W5_DTX_FLAG0_DTX (0x00000001u)

#define CSL_SGCP_CFG_SPM_FDPCH_W5_SLOT_MASK0_MASK (0x00007FFFu)
#define CSL_SGCP_CFG_SPM_FDPCH_W5_SLOT_MASK0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_FDPCH_W5_SLOT_MASK0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_FDPCH_W5_RESETVAL (0x00000000u)

/* DL_TPC_W00 */


#define CSL_SGCP_CFG_DL_TPC_W00_MSG_FLG_MASK (0x00000100u)
#define CSL_SGCP_CFG_DL_TPC_W00_MSG_FLG_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_DL_TPC_W00_MSG_FLG_RESETVAL (0x00000000u)
/*----MSG_FLG Tokens----*/
#define CSL_SGCP_CFG_DL_TPC_W00_MSG_FLG_NO_MSG (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W00_MSG_FLG_MSG_PENDING (0x00000001u)

#define CSL_SGCP_CFG_DL_TPC_W00_DELTA_GAIN_MASK (0x000000FFu)
#define CSL_SGCP_CFG_DL_TPC_W00_DELTA_GAIN_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W00_DELTA_GAIN_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W00_RESETVAL (0x00000000u)

/* DL_TPC_W01 */


#define CSL_SGCP_CFG_DL_TPC_W01_MSG2_FLG_MASK (0x01000000u)
#define CSL_SGCP_CFG_DL_TPC_W01_MSG2_FLG_SHIFT (0x00000018u)
#define CSL_SGCP_CFG_DL_TPC_W01_MSG2_FLG_RESETVAL (0x00000000u)
/*----MSG2_FLG Tokens----*/
#define CSL_SGCP_CFG_DL_TPC_W01_MSG2_FLG_NO_MSG (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W01_MSG2_FLG_MSG_PENDING (0x00000001u)

#define CSL_SGCP_CFG_DL_TPC_W01_PCURR_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_DL_TPC_W01_PCURR_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W01_PCURR_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DL_TPC_W01_PSIR_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W01_PSIR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W01_PSIR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W01_RESETVAL (0x00000000u)

/* DL_TPC_W02 */


#define CSL_SGCP_CFG_DL_TPC_W02_RL_ID_MASK (0x00700000u)
#define CSL_SGCP_CFG_DL_TPC_W02_RL_ID_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_DL_TPC_W02_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W02_CPM_GEN_FLAG_MASK (0x00080000u)
#define CSL_SGCP_CFG_DL_TPC_W02_CPM_GEN_FLAG_SHIFT (0x00000013u)
#define CSL_SGCP_CFG_DL_TPC_W02_CPM_GEN_FLAG_RESETVAL (0x00000000u)
/*----CPM_GEN_FLAG Tokens----*/
#define CSL_SGCP_CFG_DL_TPC_W02_CPM_GEN_FLAG_NO_CPM (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W02_CPM_GEN_FLAG_CPM_GENERATED (0x00000001u)

#define CSL_SGCP_CFG_DL_TPC_W02_ACC_CLR_ONLY_MASK (0x00040000u)
#define CSL_SGCP_CFG_DL_TPC_W02_ACC_CLR_ONLY_SHIFT (0x00000012u)
#define CSL_SGCP_CFG_DL_TPC_W02_ACC_CLR_ONLY_RESETVAL (0x00000000u)
/*----ACC_CLR_ONLY Tokens----*/
#define CSL_SGCP_CFG_DL_TPC_W02_ACC_CLR_ONLY_FULL_UPDATE (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W02_ACC_CLR_ONLY_ACC_CLR_ONLY (0x00000001u)

#define CSL_SGCP_CFG_DL_TPC_W02_ACC_CLR_MASK (0x00020000u)
#define CSL_SGCP_CFG_DL_TPC_W02_ACC_CLR_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_DL_TPC_W02_ACC_CLR_RESETVAL (0x00000000u)
/*----ACC_CLR Tokens----*/
#define CSL_SGCP_CFG_DL_TPC_W02_ACC_CLR_NO_CLEAR (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W02_ACC_CLR_CLEAR (0x00000001u)

#define CSL_SGCP_CFG_DL_TPC_W02_REQ_FLAG_MASK (0x00010000u)
#define CSL_SGCP_CFG_DL_TPC_W02_REQ_FLAG_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W02_REQ_FLAG_RESETVAL (0x00000000u)
/*----REQ_FLAG Tokens----*/
#define CSL_SGCP_CFG_DL_TPC_W02_REQ_FLAG_NO_REQ (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W02_REQ_FLAG_REQ_PENDING (0x00000001u)

#define CSL_SGCP_CFG_DL_TPC_W02_CHANNEL_SLOT_MASK (0x0000F000u)
#define CSL_SGCP_CFG_DL_TPC_W02_CHANNEL_SLOT_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_DL_TPC_W02_CHANNEL_SLOT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W02_CHANNEL_FRAME_MASK (0x00000FFFu)
#define CSL_SGCP_CFG_DL_TPC_W02_CHANNEL_FRAME_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W02_CHANNEL_FRAME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W02_RESETVAL (0x00000000u)

/* DL_TPC_W03 */


#define CSL_SGCP_CFG_DL_TPC_W03_NEW_MAX_MASK (0x000FFC00u)
#define CSL_SGCP_CFG_DL_TPC_W03_NEW_MAX_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_DL_TPC_W03_NEW_MAX_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W03_NEW_MIN_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W03_NEW_MIN_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W03_NEW_MIN_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W03_RESETVAL (0x00000000u)

/* DL_TPC_W04 */


#define CSL_SGCP_CFG_DL_TPC_W04_NEW_PO3_MASK (0x00007C00u)
#define CSL_SGCP_CFG_DL_TPC_W04_NEW_PO3_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_DL_TPC_W04_NEW_PO3_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W04_NEW_PO2_MASK (0x000003E0u)
#define CSL_SGCP_CFG_DL_TPC_W04_NEW_PO2_SHIFT (0x00000005u)
#define CSL_SGCP_CFG_DL_TPC_W04_NEW_PO2_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W04_NEW_PO1_MASK (0x0000001Fu)
#define CSL_SGCP_CFG_DL_TPC_W04_NEW_PO1_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W04_NEW_PO1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W04_RESETVAL (0x00000000u)

/* DL_TPC_W05 */

#define CSL_SGCP_CFG_DL_TPC_W05_NEW_EARLY_MASK (0xF0000000u)
#define CSL_SGCP_CFG_DL_TPC_W05_NEW_EARLY_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_DL_TPC_W05_NEW_EARLY_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W05_NEW_RD_MASK (0x0FF00000u)
#define CSL_SGCP_CFG_DL_TPC_W05_NEW_RD_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_DL_TPC_W05_NEW_RD_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W05_NEW_WR_MASK (0x00080000u)
#define CSL_SGCP_CFG_DL_TPC_W05_NEW_WR_SHIFT (0x00000013u)
#define CSL_SGCP_CFG_DL_TPC_W05_NEW_WR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W05_RL_ID_MASK (0x00070000u)
#define CSL_SGCP_CFG_DL_TPC_W05_RL_ID_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W05_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W05_CHANNEL_SLOT_MASK (0x0000F000u)
#define CSL_SGCP_CFG_DL_TPC_W05_CHANNEL_SLOT_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_DL_TPC_W05_CHANNEL_SLOT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W05_CHANNEL_FRAME_MASK (0x00000FFFu)
#define CSL_SGCP_CFG_DL_TPC_W05_CHANNEL_FRAME_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W05_CHANNEL_FRAME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W05_RESETVAL (0x00000000u)

/* DL_TPC_W06 */


#define CSL_SGCP_CFG_DL_TPC_W06_RL_MASK_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_DL_TPC_W06_RL_MASK_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W06_RL_MASK_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DL_TPC_W06_REQ_FLAG_MASK (0x00001000u)
#define CSL_SGCP_CFG_DL_TPC_W06_REQ_FLAG_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_DL_TPC_W06_REQ_FLAG_RESETVAL (0x00000000u)
/*----REQ_FLAG Tokens----*/
#define CSL_SGCP_CFG_DL_TPC_W06_REQ_FLAG_NO_REQ (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W06_REQ_FLAG_REQ_PENDING (0x00000001u)

#define CSL_SGCP_CFG_DL_TPC_W06_CHANNEL_FRAME_MASK (0x00000FFFu)
#define CSL_SGCP_CFG_DL_TPC_W06_CHANNEL_FRAME_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W06_CHANNEL_FRAME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W06_RESETVAL (0x00000000u)

/* DL_TPC_W07 */


#define CSL_SGCP_CFG_DL_TPC_W07_MISS_COUNTER_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_DL_TPC_W07_MISS_COUNTER_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W07_MISS_COUNTER_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W07_MISS_SLOT_MASK (0x0000F000u)
#define CSL_SGCP_CFG_DL_TPC_W07_MISS_SLOT_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_DL_TPC_W07_MISS_SLOT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W07_MISS_FRAME_MASK (0x00000FFFu)
#define CSL_SGCP_CFG_DL_TPC_W07_MISS_FRAME_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W07_MISS_FRAME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W07_RESETVAL (0x00000000u)

/* DL_TPC_W08 */


#define CSL_SGCP_CFG_DL_TPC_W08_NEW_INIT0_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W08_NEW_INIT0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W08_NEW_INIT0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W08_RESETVAL (0x00000000u)

/* DL_TPC_W09 */


#define CSL_SGCP_CFG_DL_TPC_W09_NEW_INIT1_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W09_NEW_INIT1_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W09_NEW_INIT1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W09_RESETVAL (0x00000000u)

/* DL_TPC_W10 */


#define CSL_SGCP_CFG_DL_TPC_W10_NEW_INIT2_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W10_NEW_INIT2_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W10_NEW_INIT2_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W10_RESETVAL (0x00000000u)

/* DL_TPC_W11 */


#define CSL_SGCP_CFG_DL_TPC_W11_NEW_INIT3_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W11_NEW_INIT3_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W11_NEW_INIT3_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W11_RESETVAL (0x00000000u)

/* DL_TPC_W12 */


#define CSL_SGCP_CFG_DL_TPC_W12_NEW_INIT4_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W12_NEW_INIT4_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W12_NEW_INIT4_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W12_RESETVAL (0x00000000u)

/* DL_TPC_W13 */


#define CSL_SGCP_CFG_DL_TPC_W13_NEW_INIT5_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W13_NEW_INIT5_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W13_NEW_INIT5_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W13_RESETVAL (0x00000000u)

/* DL_TPC_W14 */


#define CSL_SGCP_CFG_DL_TPC_W14_NEW_INIT6_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W14_NEW_INIT6_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W14_NEW_INIT6_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W14_RESETVAL (0x00000000u)

/* DL_TPC_W15 */


#define CSL_SGCP_CFG_DL_TPC_W15_NEW_INIT7_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W15_NEW_INIT7_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W15_NEW_INIT7_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W15_RESETVAL (0x00000000u)

/* DL_TPC_W16 */


#define CSL_SGCP_CFG_DL_TPC_W16_INIT0_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W16_INIT0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W16_INIT0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W16_RESETVAL (0x00000000u)

/* DL_TPC_W17 */


#define CSL_SGCP_CFG_DL_TPC_W17_INIT1_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W17_INIT1_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W17_INIT1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W17_RESETVAL (0x00000000u)

/* DL_TPC_W18 */


#define CSL_SGCP_CFG_DL_TPC_W18_INIT2_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W18_INIT2_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W18_INIT2_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W18_RESETVAL (0x00000000u)

/* DL_TPC_W19 */


#define CSL_SGCP_CFG_DL_TPC_W19_INIT3_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W19_INIT3_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W19_INIT3_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W19_RESETVAL (0x00000000u)

/* DL_TPC_W20 */


#define CSL_SGCP_CFG_DL_TPC_W20_INIT4_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W20_INIT4_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W20_INIT4_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W20_RESETVAL (0x00000000u)

/* DL_TPC_W21 */


#define CSL_SGCP_CFG_DL_TPC_W21_INIT5_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W21_INIT5_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W21_INIT5_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W21_RESETVAL (0x00000000u)

/* DL_TPC_W22 */


#define CSL_SGCP_CFG_DL_TPC_W22_INIT6_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W22_INIT6_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W22_INIT6_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W22_RESETVAL (0x00000000u)

/* DL_TPC_W23 */


#define CSL_SGCP_CFG_DL_TPC_W23_INIT7_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W23_INIT7_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W23_INIT7_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W23_RESETVAL (0x00000000u)

/* DL_TPC_W24 */


#define CSL_SGCP_CFG_DL_TPC_W24_ACC_GAIN1_MASK (0x03FF0000u)
#define CSL_SGCP_CFG_DL_TPC_W24_ACC_GAIN1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W24_ACC_GAIN1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DL_TPC_W24_ACC_GAIN0_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W24_ACC_GAIN0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W24_ACC_GAIN0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W24_RESETVAL (0x00000000u)

/* DL_TPC_W25 */


#define CSL_SGCP_CFG_DL_TPC_W25_EARLY_MASK (0x000F0000u)
#define CSL_SGCP_CFG_DL_TPC_W25_EARLY_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W25_EARLY_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W25_RD_MASK  (0x0000FF00u)
#define CSL_SGCP_CFG_DL_TPC_W25_RD_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_DL_TPC_W25_RD_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DL_TPC_W25_WR_MASK  (0x00000001u)
#define CSL_SGCP_CFG_DL_TPC_W25_WR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W25_WR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W25_RESETVAL (0x00000000u)

/* DL_TPC_W26 */


#define CSL_SGCP_CFG_DL_TPC_W26_ST_MIN1_MASK (0x03FF0000u)
#define CSL_SGCP_CFG_DL_TPC_W26_ST_MIN1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W26_ST_MIN1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DL_TPC_W26_ST_MIN0_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W26_ST_MIN0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W26_ST_MIN0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W26_RESETVAL (0x00000000u)

/* DL_TPC_W27 */


#define CSL_SGCP_CFG_DL_TPC_W27_ST_MAX1_MASK (0x03FF0000u)
#define CSL_SGCP_CFG_DL_TPC_W27_ST_MAX1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W27_ST_MAX1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DL_TPC_W27_ST_MAX0_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W27_ST_MAX0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W27_ST_MAX0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W27_RESETVAL (0x00000000u)

/* DL_TPC_W28 */


#define CSL_SGCP_CFG_DL_TPC_W28_ST_PSIR1_MASK (0x03FF0000u)
#define CSL_SGCP_CFG_DL_TPC_W28_ST_PSIR1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W28_ST_PSIR1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DL_TPC_W28_ST_PSIR0_MASK (0x000003FFu)
#define CSL_SGCP_CFG_DL_TPC_W28_ST_PSIR0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W28_ST_PSIR0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W28_RESETVAL (0x00000000u)

/* DL_TPC_W29 */


#define CSL_SGCP_CFG_DL_TPC_W29_ST_PCURR1_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_DL_TPC_W29_ST_PCURR1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DL_TPC_W29_ST_PCURR1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DL_TPC_W29_ST_PCURR0_MASK (0x000000FFu)
#define CSL_SGCP_CFG_DL_TPC_W29_ST_PCURR0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W29_ST_PCURR0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W29_RESETVAL (0x00000000u)

/* DL_TPC_W30 */


#define CSL_SGCP_CFG_DL_TPC_W30_ST_PO3_0_MASK (0x00007C00u)
#define CSL_SGCP_CFG_DL_TPC_W30_ST_PO3_0_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_DL_TPC_W30_ST_PO3_0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W30_ST_PO2_0_MASK (0x000003E0u)
#define CSL_SGCP_CFG_DL_TPC_W30_ST_PO2_0_SHIFT (0x00000005u)
#define CSL_SGCP_CFG_DL_TPC_W30_ST_PO2_0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W30_ST_PO1_0_MASK (0x0000001Fu)
#define CSL_SGCP_CFG_DL_TPC_W30_ST_PO1_0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W30_ST_PO1_0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W30_RESETVAL (0x00000000u)

/* DL_TPC_W31 */


#define CSL_SGCP_CFG_DL_TPC_W31_ST_PO3_1_MASK (0x00007C00u)
#define CSL_SGCP_CFG_DL_TPC_W31_ST_PO3_1_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_DL_TPC_W31_ST_PO3_1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W31_ST_PO2_1_MASK (0x000003E0u)
#define CSL_SGCP_CFG_DL_TPC_W31_ST_PO2_1_SHIFT (0x00000005u)
#define CSL_SGCP_CFG_DL_TPC_W31_ST_PO2_1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W31_ST_PO1_1_MASK (0x0000001Fu)
#define CSL_SGCP_CFG_DL_TPC_W31_ST_PO1_1_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DL_TPC_W31_ST_PO1_1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DL_TPC_W31_RESETVAL (0x00000000u)

/* BF_W00 */

#define CSL_SGCP_CFG_BF_W00_WEIGHT_MASK_MASK (0xFF000000u)
#define CSL_SGCP_CFG_BF_W00_WEIGHT_MASK_SHIFT (0x00000018u)
#define CSL_SGCP_CFG_BF_W00_WEIGHT_MASK_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_BF_W00_SINGLE_CYC_UPDATE_MASK (0x00020000u)
#define CSL_SGCP_CFG_BF_W00_SINGLE_CYC_UPDATE_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_BF_W00_SINGLE_CYC_UPDATE_RESETVAL (0x00000000u)
/*----SINGLE_CYC_UPDATE Tokens----*/
#define CSL_SGCP_CFG_BF_W00_SINGLE_CYC_UPDATE_ONE_PER_CYCLE (0x00000000u)
#define CSL_SGCP_CFG_BF_W00_SINGLE_CYC_UPDATE_ALL_IN_ONE_CYCLE (0x00000001u)

#define CSL_SGCP_CFG_BF_W00_REQ_FLAG_MASK (0x00010000u)
#define CSL_SGCP_CFG_BF_W00_REQ_FLAG_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_BF_W00_REQ_FLAG_RESETVAL (0x00000000u)
/*----REQ_FLAG Tokens----*/
#define CSL_SGCP_CFG_BF_W00_REQ_FLAG_NO_REQ (0x00000000u)
#define CSL_SGCP_CFG_BF_W00_REQ_FLAG_REQ_PENDING (0x00000001u)

#define CSL_SGCP_CFG_BF_W00_CHANNEL_SLOT_MASK (0x0000F000u)
#define CSL_SGCP_CFG_BF_W00_CHANNEL_SLOT_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_BF_W00_CHANNEL_SLOT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W00_CHANNEL_FRAME_MASK (0x00000FFFu)
#define CSL_SGCP_CFG_BF_W00_CHANNEL_FRAME_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_BF_W00_CHANNEL_FRAME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W00_RESETVAL     (0x00000000u)

/* BF_W01 */

#define CSL_SGCP_CFG_BF_W01_NEW_W1_I_MASK (0xFF000000u)
#define CSL_SGCP_CFG_BF_W01_NEW_W1_I_SHIFT (0x00000018u)
#define CSL_SGCP_CFG_BF_W01_NEW_W1_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W01_NEW_W1_Q_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_BF_W01_NEW_W1_Q_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_BF_W01_NEW_W1_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W01_NEW_W0_I_MASK (0x0000FF00u)
#define CSL_SGCP_CFG_BF_W01_NEW_W0_I_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_BF_W01_NEW_W0_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W01_NEW_W0_Q_MASK (0x000000FFu)
#define CSL_SGCP_CFG_BF_W01_NEW_W0_Q_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_BF_W01_NEW_W0_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W01_RESETVAL     (0x00000000u)

/* BF_W02 */

#define CSL_SGCP_CFG_BF_W02_NEW_W3_I_MASK (0xFF000000u)
#define CSL_SGCP_CFG_BF_W02_NEW_W3_I_SHIFT (0x00000018u)
#define CSL_SGCP_CFG_BF_W02_NEW_W3_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W02_NEW_W3_Q_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_BF_W02_NEW_W3_Q_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_BF_W02_NEW_W3_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W02_NEW_W2_I_MASK (0x0000FF00u)
#define CSL_SGCP_CFG_BF_W02_NEW_W2_I_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_BF_W02_NEW_W2_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W02_NEW_W2_Q_MASK (0x000000FFu)
#define CSL_SGCP_CFG_BF_W02_NEW_W2_Q_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_BF_W02_NEW_W2_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W02_RESETVAL     (0x00000000u)

/* BF_W03 */

#define CSL_SGCP_CFG_BF_W03_NEW_W5_I_MASK (0xFF000000u)
#define CSL_SGCP_CFG_BF_W03_NEW_W5_I_SHIFT (0x00000018u)
#define CSL_SGCP_CFG_BF_W03_NEW_W5_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W03_NEW_W5_Q_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_BF_W03_NEW_W5_Q_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_BF_W03_NEW_W5_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W03_NEW_W4_I_MASK (0x0000FF00u)
#define CSL_SGCP_CFG_BF_W03_NEW_W4_I_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_BF_W03_NEW_W4_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W03_NEW_W4_Q_MASK (0x000000FFu)
#define CSL_SGCP_CFG_BF_W03_NEW_W4_Q_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_BF_W03_NEW_W4_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W03_RESETVAL     (0x00000000u)

/* BF_W04 */

#define CSL_SGCP_CFG_BF_W04_NEW_W7_I_MASK (0xFF000000u)
#define CSL_SGCP_CFG_BF_W04_NEW_W7_I_SHIFT (0x00000018u)
#define CSL_SGCP_CFG_BF_W04_NEW_W7_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W04_NEW_W7_Q_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_BF_W04_NEW_W7_Q_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_BF_W04_NEW_W7_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W04_NEW_W6_I_MASK (0x0000FF00u)
#define CSL_SGCP_CFG_BF_W04_NEW_W6_I_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_BF_W04_NEW_W6_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W04_NEW_W6_Q_MASK (0x000000FFu)
#define CSL_SGCP_CFG_BF_W04_NEW_W6_Q_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_BF_W04_NEW_W6_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W04_RESETVAL     (0x00000000u)

/* BF_W08 */

#define CSL_SGCP_CFG_BF_W08_W1_I_MASK    (0xFF000000u)
#define CSL_SGCP_CFG_BF_W08_W1_I_SHIFT   (0x00000018u)
#define CSL_SGCP_CFG_BF_W08_W1_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W08_W1_Q_MASK    (0x00FF0000u)
#define CSL_SGCP_CFG_BF_W08_W1_Q_SHIFT   (0x00000010u)
#define CSL_SGCP_CFG_BF_W08_W1_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W08_W0_I_MASK    (0x0000FF00u)
#define CSL_SGCP_CFG_BF_W08_W0_I_SHIFT   (0x00000008u)
#define CSL_SGCP_CFG_BF_W08_W0_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W08_W0_Q_MASK    (0x000000FFu)
#define CSL_SGCP_CFG_BF_W08_W0_Q_SHIFT   (0x00000000u)
#define CSL_SGCP_CFG_BF_W08_W0_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W08_RESETVAL     (0x00000000u)

/* BF_W09 */

#define CSL_SGCP_CFG_BF_W09_W3_I_MASK    (0xFF000000u)
#define CSL_SGCP_CFG_BF_W09_W3_I_SHIFT   (0x00000018u)
#define CSL_SGCP_CFG_BF_W09_W3_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W09_W3_Q_MASK    (0x00FF0000u)
#define CSL_SGCP_CFG_BF_W09_W3_Q_SHIFT   (0x00000010u)
#define CSL_SGCP_CFG_BF_W09_W3_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W09_W2_I_MASK    (0x0000FF00u)
#define CSL_SGCP_CFG_BF_W09_W2_I_SHIFT   (0x00000008u)
#define CSL_SGCP_CFG_BF_W09_W2_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W09_W2_Q_MASK    (0x000000FFu)
#define CSL_SGCP_CFG_BF_W09_W2_Q_SHIFT   (0x00000000u)
#define CSL_SGCP_CFG_BF_W09_W2_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W09_RESETVAL     (0x00000000u)

/* BF_W10 */

#define CSL_SGCP_CFG_BF_W10_W5_I_MASK    (0xFF000000u)
#define CSL_SGCP_CFG_BF_W10_W5_I_SHIFT   (0x00000018u)
#define CSL_SGCP_CFG_BF_W10_W5_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W10_W5_Q_MASK    (0x00FF0000u)
#define CSL_SGCP_CFG_BF_W10_W5_Q_SHIFT   (0x00000010u)
#define CSL_SGCP_CFG_BF_W10_W5_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W10_W4_I_MASK    (0x0000FF00u)
#define CSL_SGCP_CFG_BF_W10_W4_I_SHIFT   (0x00000008u)
#define CSL_SGCP_CFG_BF_W10_W4_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W10_W4_Q_MASK    (0x000000FFu)
#define CSL_SGCP_CFG_BF_W10_W4_Q_SHIFT   (0x00000000u)
#define CSL_SGCP_CFG_BF_W10_W4_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W10_RESETVAL     (0x00000000u)

/* BF_W11 */

#define CSL_SGCP_CFG_BF_W11_W7_I_MASK    (0xFF000000u)
#define CSL_SGCP_CFG_BF_W11_W7_I_SHIFT   (0x00000018u)
#define CSL_SGCP_CFG_BF_W11_W7_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W11_W7_Q_MASK    (0x00FF0000u)
#define CSL_SGCP_CFG_BF_W11_W7_Q_SHIFT   (0x00000010u)
#define CSL_SGCP_CFG_BF_W11_W7_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W11_W6_I_MASK    (0x0000FF00u)
#define CSL_SGCP_CFG_BF_W11_W6_I_SHIFT   (0x00000008u)
#define CSL_SGCP_CFG_BF_W11_W6_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W11_W6_Q_MASK    (0x000000FFu)
#define CSL_SGCP_CFG_BF_W11_W6_Q_SHIFT   (0x00000000u)
#define CSL_SGCP_CFG_BF_W11_W6_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_BF_W11_RESETVAL     (0x00000000u)

/* UL_TPC_W0 */


#define CSL_SGCP_CFG_UL_TPC_W0_MSG_FLG_MASK (0x00000008u)
#define CSL_SGCP_CFG_UL_TPC_W0_MSG_FLG_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_UL_TPC_W0_MSG_FLG_RESETVAL (0x00000000u)
/*----MSG_FLG Tokens----*/
#define CSL_SGCP_CFG_UL_TPC_W0_MSG_FLG_NO_MSG (0x00000000u)
#define CSL_SGCP_CFG_UL_TPC_W0_MSG_FLG_MSG_PENDING (0x00000001u)

#define CSL_SGCP_CFG_UL_TPC_W0_INV_CMD_MASK (0x00000004u)
#define CSL_SGCP_CFG_UL_TPC_W0_INV_CMD_SHIFT (0x00000002u)
#define CSL_SGCP_CFG_UL_TPC_W0_INV_CMD_RESETVAL (0x00000000u)
/*----INV_CMD Tokens----*/
#define CSL_SGCP_CFG_UL_TPC_W0_INV_CMD_TOGGLE (0x00000000u)
#define CSL_SGCP_CFG_UL_TPC_W0_INV_CMD_DTX (0x00000001u)

#define CSL_SGCP_CFG_UL_TPC_W0_DTX_BIT_MASK (0x00000002u)
#define CSL_SGCP_CFG_UL_TPC_W0_DTX_BIT_SHIFT (0x00000001u)
#define CSL_SGCP_CFG_UL_TPC_W0_DTX_BIT_RESETVAL (0x00000000u)
/*----DTX_BIT Tokens----*/
#define CSL_SGCP_CFG_UL_TPC_W0_DTX_BIT_NO_DTX (0x00000000u)
#define CSL_SGCP_CFG_UL_TPC_W0_DTX_BIT_DTX (0x00000001u)

#define CSL_SGCP_CFG_UL_TPC_W0_TPC_BIT_MASK (0x00000001u)
#define CSL_SGCP_CFG_UL_TPC_W0_TPC_BIT_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_UL_TPC_W0_TPC_BIT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W0_RESETVAL  (0x00000000u)

/* UL_TPC_W1 */


#define CSL_SGCP_CFG_UL_TPC_W1_RL_ID_MASK (0x00700000u)
#define CSL_SGCP_CFG_UL_TPC_W1_RL_ID_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_UL_TPC_W1_RL_ID_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_UL_TPC_W1_REQ_FLAG_MASK (0x00010000u)
#define CSL_SGCP_CFG_UL_TPC_W1_REQ_FLAG_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_UL_TPC_W1_REQ_FLAG_RESETVAL (0x00000000u)
/*----REQ_FLAG Tokens----*/
#define CSL_SGCP_CFG_UL_TPC_W1_REQ_FLAG_NO_REQ (0x00000000u)
#define CSL_SGCP_CFG_UL_TPC_W1_REQ_FLAG_REQ_PENDING (0x00000001u)

#define CSL_SGCP_CFG_UL_TPC_W1_CHANNEL_SLOT_MASK (0x0000F000u)
#define CSL_SGCP_CFG_UL_TPC_W1_CHANNEL_SLOT_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_UL_TPC_W1_CHANNEL_SLOT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W1_CHANNEL_FRAME_MASK (0x00000FFFu)
#define CSL_SGCP_CFG_UL_TPC_W1_CHANNEL_FRAME_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_UL_TPC_W1_CHANNEL_FRAME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W1_RESETVAL  (0x00000000u)

/* UL_TPC_W2 */


#define CSL_SGCP_CFG_UL_TPC_W2_NEW_EARLY_MASK (0x000F0000u)
#define CSL_SGCP_CFG_UL_TPC_W2_NEW_EARLY_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_UL_TPC_W2_NEW_EARLY_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W2_NEW_RD_MASK (0x0000FF00u)
#define CSL_SGCP_CFG_UL_TPC_W2_NEW_RD_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_UL_TPC_W2_NEW_RD_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_UL_TPC_W2_NEW_WR_MASK (0x00000001u)
#define CSL_SGCP_CFG_UL_TPC_W2_NEW_WR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_UL_TPC_W2_NEW_WR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W2_RESETVAL  (0x00000000u)

/* UL_TPC_W3 */


#define CSL_SGCP_CFG_UL_TPC_W3_ST_CNT1_MASK (0x00080000u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_CNT1_SHIFT (0x00000013u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_CNT1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W3_ST_INV1_MASK (0x00040000u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_INV1_SHIFT (0x00000012u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_INV1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W3_ST_DTX1_MASK (0x00020000u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_DTX1_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_DTX1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W3_ST_TPC1_MASK (0x00010000u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_TPC1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_TPC1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_UL_TPC_W3_ST_CNT0_MASK (0x00000008u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_CNT0_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_CNT0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W3_ST_INV0_MASK (0x00000004u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_INV0_SHIFT (0x00000002u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_INV0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W3_ST_DTX0_MASK (0x00000002u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_DTX0_SHIFT (0x00000001u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_DTX0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W3_ST_TPC0_MASK (0x00000001u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_TPC0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_UL_TPC_W3_ST_TPC0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W3_RESETVAL  (0x00000000u)

/* UL_TPC_W4 */


#define CSL_SGCP_CFG_UL_TPC_W4_EARLY_MASK (0x000F0000u)
#define CSL_SGCP_CFG_UL_TPC_W4_EARLY_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_UL_TPC_W4_EARLY_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W4_RD_MASK   (0x0000FF00u)
#define CSL_SGCP_CFG_UL_TPC_W4_RD_SHIFT  (0x00000008u)
#define CSL_SGCP_CFG_UL_TPC_W4_RD_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_UL_TPC_W4_WR_MASK   (0x00000001u)
#define CSL_SGCP_CFG_UL_TPC_W4_WR_SHIFT  (0x00000000u)
#define CSL_SGCP_CFG_UL_TPC_W4_WR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W4_RESETVAL  (0x00000000u)

/* UL_TPC_W7 */


#define CSL_SGCP_CFG_UL_TPC_W7_MISS_COUNTER_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_UL_TPC_W7_MISS_COUNTER_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_UL_TPC_W7_MISS_COUNTER_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W7_MISS_SLOT_MASK (0x0000F000u)
#define CSL_SGCP_CFG_UL_TPC_W7_MISS_SLOT_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_UL_TPC_W7_MISS_SLOT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W7_MISS_FRAME_MASK (0x00000FFFu)
#define CSL_SGCP_CFG_UL_TPC_W7_MISS_FRAME_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_UL_TPC_W7_MISS_FRAME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_UL_TPC_W7_RESETVAL  (0x00000000u)

/* DIV_W0 */

#define CSL_SGCP_CFG_DIV_W0_MSG_FLG_MASK (0x80000000u)
#define CSL_SGCP_CFG_DIV_W0_MSG_FLG_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_DIV_W0_MSG_FLG_RESETVAL (0x00000000u)
/*----MSG_FLG Tokens----*/
#define CSL_SGCP_CFG_DIV_W0_MSG_FLG_NO_MSG (0x00000000u)
#define CSL_SGCP_CFG_DIV_W0_MSG_FLG_MSG_PENDING (0x00000001u)

#define CSL_SGCP_CFG_DIV_W0_W2PHASE_I_MASK (0x7FFF0000u)
#define CSL_SGCP_CFG_DIV_W0_W2PHASE_I_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DIV_W0_W2PHASE_I_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DIV_W0_W2PHASE_Q_MASK (0x00007FFFu)
#define CSL_SGCP_CFG_DIV_W0_W2PHASE_Q_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DIV_W0_W2PHASE_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W0_RESETVAL     (0x00000000u)

/* DIV_W1 */


#define CSL_SGCP_CFG_DIV_W1_RL_ID_MASK   (0x00700000u)
#define CSL_SGCP_CFG_DIV_W1_RL_ID_SHIFT  (0x00000014u)
#define CSL_SGCP_CFG_DIV_W1_RL_ID_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DIV_W1_REQ_FLAG_MASK (0x00010000u)
#define CSL_SGCP_CFG_DIV_W1_REQ_FLAG_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DIV_W1_REQ_FLAG_RESETVAL (0x00000000u)
/*----REQ_FLAG Tokens----*/
#define CSL_SGCP_CFG_DIV_W1_REQ_FLAG_NO_REQ (0x00000000u)
#define CSL_SGCP_CFG_DIV_W1_REQ_FLAG_REQ_PENDING (0x00000001u)

#define CSL_SGCP_CFG_DIV_W1_CHANNEL_SLOT_MASK (0x0000F000u)
#define CSL_SGCP_CFG_DIV_W1_CHANNEL_SLOT_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_DIV_W1_CHANNEL_SLOT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W1_CHANNEL_FRAME_MASK (0x00000FFFu)
#define CSL_SGCP_CFG_DIV_W1_CHANNEL_FRAME_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DIV_W1_CHANNEL_FRAME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W1_RESETVAL     (0x00000000u)

/* DIV_W2 */


#define CSL_SGCP_CFG_DIV_W2_NEW_EARLY_MASK (0x000F0000u)
#define CSL_SGCP_CFG_DIV_W2_NEW_EARLY_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DIV_W2_NEW_EARLY_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W2_NEW_RD_MASK  (0x0000FF00u)
#define CSL_SGCP_CFG_DIV_W2_NEW_RD_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_DIV_W2_NEW_RD_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DIV_W2_NEW_WR_MASK  (0x00000001u)
#define CSL_SGCP_CFG_DIV_W2_NEW_WR_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DIV_W2_NEW_WR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W2_RESETVAL     (0x00000000u)

/* DIV_W3 */


#define CSL_SGCP_CFG_DIV_W3_EARLY_MASK   (0x000F0000u)
#define CSL_SGCP_CFG_DIV_W3_EARLY_SHIFT  (0x00000010u)
#define CSL_SGCP_CFG_DIV_W3_EARLY_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W3_RD_MASK      (0x0000FF00u)
#define CSL_SGCP_CFG_DIV_W3_RD_SHIFT     (0x00000008u)
#define CSL_SGCP_CFG_DIV_W3_RD_RESETVAL  (0x00000000u)


#define CSL_SGCP_CFG_DIV_W3_WR_MASK      (0x00000001u)
#define CSL_SGCP_CFG_DIV_W3_WR_SHIFT     (0x00000000u)
#define CSL_SGCP_CFG_DIV_W3_WR_RESETVAL  (0x00000000u)

#define CSL_SGCP_CFG_DIV_W3_RESETVAL     (0x00000000u)

/* DIV_W4 */


#define CSL_SGCP_CFG_DIV_W4_ST_W2PHASE_I0_MASK (0x7FFF0000u)
#define CSL_SGCP_CFG_DIV_W4_ST_W2PHASE_I0_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DIV_W4_ST_W2PHASE_I0_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DIV_W4_ST_W2PHASE_Q0_MASK (0x00007FFFu)
#define CSL_SGCP_CFG_DIV_W4_ST_W2PHASE_Q0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DIV_W4_ST_W2PHASE_Q0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W4_RESETVAL     (0x00000000u)

/* DIV_W5 */


#define CSL_SGCP_CFG_DIV_W5_ST_W2PHASE_I1_MASK (0x7FFF0000u)
#define CSL_SGCP_CFG_DIV_W5_ST_W2PHASE_I1_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DIV_W5_ST_W2PHASE_I1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_DIV_W5_ST_W2PHASE_Q1_MASK (0x00007FFFu)
#define CSL_SGCP_CFG_DIV_W5_ST_W2PHASE_Q1_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DIV_W5_ST_W2PHASE_Q1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W5_RESETVAL     (0x00000000u)

/* DIV_W7 */


#define CSL_SGCP_CFG_DIV_W7_MISS_COUNTER_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_DIV_W7_MISS_COUNTER_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_DIV_W7_MISS_COUNTER_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W7_MISS_SLOT_MASK (0x0000F000u)
#define CSL_SGCP_CFG_DIV_W7_MISS_SLOT_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_DIV_W7_MISS_SLOT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W7_MISS_FRAME_MASK (0x00000FFFu)
#define CSL_SGCP_CFG_DIV_W7_MISS_FRAME_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DIV_W7_MISS_FRAME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_DIV_W7_RESETVAL     (0x00000000u)

/* SLT_W0 */


#define CSL_SGCP_CFG_SLT_W0_NB_ITE_TPC_MASK (0x0FFC0000u)
#define CSL_SGCP_CFG_SLT_W0_NB_ITE_TPC_SHIFT (0x00000012u)
#define CSL_SGCP_CFG_SLT_W0_NB_ITE_TPC_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SLT_W0_NB_ITE_DATA1_MASK (0x0003FF00u)
#define CSL_SGCP_CFG_SLT_W0_NB_ITE_DATA1_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_SLT_W0_NB_ITE_DATA1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SLT_W0_PBT_INDEX_MASK (0x000000F0u)
#define CSL_SGCP_CFG_SLT_W0_PBT_INDEX_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SLT_W0_PBT_INDEX_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SLT_W0_SF_MASK      (0x0000000Fu)
#define CSL_SGCP_CFG_SLT_W0_SF_SHIFT     (0x00000000u)
#define CSL_SGCP_CFG_SLT_W0_SF_RESETVAL  (0x00000000u)

#define CSL_SGCP_CFG_SLT_W0_RESETVAL     (0x00000000u)

/* SLT_W1 */


#define CSL_SGCP_CFG_SLT_W1_NB_ITE_PILOT_MASK (0x3FF00000u)
#define CSL_SGCP_CFG_SLT_W1_NB_ITE_PILOT_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SLT_W1_NB_ITE_PILOT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SLT_W1_NB_ITE_DATA2_MASK (0x000FFC00u)
#define CSL_SGCP_CFG_SLT_W1_NB_ITE_DATA2_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SLT_W1_NB_ITE_DATA2_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SLT_W1_NB_ITE_TFCI_MASK (0x000003FFu)
#define CSL_SGCP_CFG_SLT_W1_NB_ITE_TFCI_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SLT_W1_NB_ITE_TFCI_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SLT_W1_RESETVAL     (0x00000000u)

/* TRA_INA */

#define CSL_SGCP_CFG_TRA_INA_WORD_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_TRA_INA_WORD_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_INA_WORD_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_INA_RESETVAL (0x00000000u)

/* TRA_GAINCD */

#define CSL_SGCP_CFG_TRA_GAINCD_GAIN_OUT_MASK (0x007FFFFFu)
#define CSL_SGCP_CFG_TRA_GAINCD_GAIN_OUT_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_GAINCD_GAIN_OUT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_GAINCD_RESETVAL (0x00000000u)

/* TRA_DIVCD */

#define CSL_SGCP_CFG_TRA_DIVCD_DIV_OUT_MASK (0x007FFFFFu)
#define CSL_SGCP_CFG_TRA_DIVCD_DIV_OUT_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_DIVCD_DIV_OUT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_DIVCD_RESETVAL (0x00000000u)

/* TRA_BFNCD */

#define CSL_SGCP_CFG_TRA_BFNCD_BFN_OUT_MASK (0x007FFFFFu)
#define CSL_SGCP_CFG_TRA_BFNCD_BFN_OUT_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_BFNCD_BFN_OUT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_BFNCD_RESETVAL (0x00000000u)

/* TRA_CHCDBC */

#define CSL_SGCP_CFG_TRA_CHCDBC_CHCD_OUT_MASK (0xFu)
#define CSL_SGCP_CFG_TRA_CHCDBC_CHCD_OUT_SHIFT (0x0u)
#define CSL_SGCP_CFG_TRA_CHCDBC_CHCD_OUT_RESETVAL (0x0u)

#define CSL_SGCP_CFG_TRA_CHCDBC_RESETVAL (0x0u)

/* TRA_SCCDBC */

#define CSL_SGCP_CFG_TRA_SCCDBC_SCCD_OUT_MASK (0xFu)
#define CSL_SGCP_CFG_TRA_SCCDBC_SCCD_OUT_SHIFT (0x0u)
#define CSL_SGCP_CFG_TRA_SCCDBC_SCCD_OUT_RESETVAL (0x0u)

#define CSL_SGCP_CFG_TRA_SCCDBC_RESETVAL (0x0u)

/* TRA_AGGRBC */

#define CSL_SGCP_CFG_TRA_AGGRBC_AGGR_OUT_MASK (0xFu)
#define CSL_SGCP_CFG_TRA_AGGRBC_AGGR_OUT_SHIFT (0x0u)
#define CSL_SGCP_CFG_TRA_AGGRBC_AGGR_OUT_RESETVAL (0x0u)

#define CSL_SGCP_CFG_TRA_AGGRBC_RESETVAL (0x0u)

/* TRA_SIGBC */

#define CSL_SGCP_CFG_TRA_SIGBC_SIG_OUT_MASK (0xFu)
#define CSL_SGCP_CFG_TRA_SIGBC_SIG_OUT_SHIFT (0x0u)
#define CSL_SGCP_CFG_TRA_SIGBC_SIG_OUT_RESETVAL (0x0u)

#define CSL_SGCP_CFG_TRA_SIGBC_RESETVAL (0x0u)

/* TRA_SPM */

#define CSL_SGCP_CFG_TRA_SPM_TRA_SPM_MASK (0xFFFFFFFFu)
#define CSL_SGCP_CFG_TRA_SPM_TRA_SPM_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_SPM_TRA_SPM_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_SPM_RESETVAL (0x00000000u)

/* SS2M */

#define CSL_SGCP_CFG_SS2M_STATE31_MASK (0x80000000u)
#define CSL_SGCP_CFG_SS2M_STATE31_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SS2M_STATE31_RESETVAL (0x00000000u)
/*----STATE31 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE31_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE31_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE30_MASK (0x40000000u)
#define CSL_SGCP_CFG_SS2M_STATE30_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_SS2M_STATE30_RESETVAL (0x00000000u)
/*----STATE30 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE30_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE30_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE29_MASK (0x20000000u)
#define CSL_SGCP_CFG_SS2M_STATE29_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_SS2M_STATE29_RESETVAL (0x00000000u)
/*----STATE29 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE29_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE29_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE28_MASK (0x10000000u)
#define CSL_SGCP_CFG_SS2M_STATE28_SHIFT (0x0000001Cu)
#define CSL_SGCP_CFG_SS2M_STATE28_RESETVAL (0x00000000u)
/*----STATE28 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE28_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE28_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE27_MASK (0x08000000u)
#define CSL_SGCP_CFG_SS2M_STATE27_SHIFT (0x0000001Bu)
#define CSL_SGCP_CFG_SS2M_STATE27_RESETVAL (0x00000000u)
/*----STATE27 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE27_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE27_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE26_MASK (0x04000000u)
#define CSL_SGCP_CFG_SS2M_STATE26_SHIFT (0x0000001Au)
#define CSL_SGCP_CFG_SS2M_STATE26_RESETVAL (0x00000000u)
/*----STATE26 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE26_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE26_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE25_MASK (0x02000000u)
#define CSL_SGCP_CFG_SS2M_STATE25_SHIFT (0x00000019u)
#define CSL_SGCP_CFG_SS2M_STATE25_RESETVAL (0x00000000u)
/*----STATE25 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE25_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE25_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE24_MASK (0x01000000u)
#define CSL_SGCP_CFG_SS2M_STATE24_SHIFT (0x00000018u)
#define CSL_SGCP_CFG_SS2M_STATE24_RESETVAL (0x00000000u)
/*----STATE24 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE24_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE24_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE23_MASK (0x00800000u)
#define CSL_SGCP_CFG_SS2M_STATE23_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SS2M_STATE23_RESETVAL (0x00000000u)
/*----STATE23 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE23_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE23_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE22_MASK (0x00400000u)
#define CSL_SGCP_CFG_SS2M_STATE22_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SS2M_STATE22_RESETVAL (0x00000000u)
/*----STATE22 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE22_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE22_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE21_MASK (0x00200000u)
#define CSL_SGCP_CFG_SS2M_STATE21_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SS2M_STATE21_RESETVAL (0x00000000u)
/*----STATE21 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE21_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE21_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE20_MASK (0x00100000u)
#define CSL_SGCP_CFG_SS2M_STATE20_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SS2M_STATE20_RESETVAL (0x00000000u)
/*----STATE20 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE20_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE20_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE19_MASK (0x00080000u)
#define CSL_SGCP_CFG_SS2M_STATE19_SHIFT (0x00000013u)
#define CSL_SGCP_CFG_SS2M_STATE19_RESETVAL (0x00000000u)
/*----STATE19 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE19_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE19_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE18_MASK (0x00040000u)
#define CSL_SGCP_CFG_SS2M_STATE18_SHIFT (0x00000012u)
#define CSL_SGCP_CFG_SS2M_STATE18_RESETVAL (0x00000000u)
/*----STATE18 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE18_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE18_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE17_MASK (0x00020000u)
#define CSL_SGCP_CFG_SS2M_STATE17_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SS2M_STATE17_RESETVAL (0x00000000u)
/*----STATE17 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE17_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE17_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE16_MASK (0x00010000u)
#define CSL_SGCP_CFG_SS2M_STATE16_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SS2M_STATE16_RESETVAL (0x00000000u)
/*----STATE16 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE16_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE16_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE15_MASK (0x00008000u)
#define CSL_SGCP_CFG_SS2M_STATE15_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SS2M_STATE15_RESETVAL (0x00000000u)
/*----STATE15 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE15_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE15_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE14_MASK (0x00004000u)
#define CSL_SGCP_CFG_SS2M_STATE14_SHIFT (0x0000000Eu)
#define CSL_SGCP_CFG_SS2M_STATE14_RESETVAL (0x00000000u)
/*----STATE14 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE14_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE14_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE13_MASK (0x00002000u)
#define CSL_SGCP_CFG_SS2M_STATE13_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SS2M_STATE13_RESETVAL (0x00000000u)
/*----STATE13 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE13_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE13_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE12_MASK (0x00001000u)
#define CSL_SGCP_CFG_SS2M_STATE12_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_SS2M_STATE12_RESETVAL (0x00000000u)
/*----STATE12 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE12_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE12_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE11_MASK (0x00000800u)
#define CSL_SGCP_CFG_SS2M_STATE11_SHIFT (0x0000000Bu)
#define CSL_SGCP_CFG_SS2M_STATE11_RESETVAL (0x00000000u)
/*----STATE11 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE11_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE11_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE10_MASK (0x00000400u)
#define CSL_SGCP_CFG_SS2M_STATE10_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SS2M_STATE10_RESETVAL (0x00000000u)
/*----STATE10 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE10_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE10_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE9_MASK (0x00000200u)
#define CSL_SGCP_CFG_SS2M_STATE9_SHIFT (0x00000009u)
#define CSL_SGCP_CFG_SS2M_STATE9_RESETVAL (0x00000000u)
/*----STATE9 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE9_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE9_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE8_MASK (0x00000100u)
#define CSL_SGCP_CFG_SS2M_STATE8_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_SS2M_STATE8_RESETVAL (0x00000000u)
/*----STATE8 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE8_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE8_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE7_MASK (0x00000080u)
#define CSL_SGCP_CFG_SS2M_STATE7_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_SS2M_STATE7_RESETVAL (0x00000000u)
/*----STATE7 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE7_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE7_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE6_MASK (0x00000040u)
#define CSL_SGCP_CFG_SS2M_STATE6_SHIFT (0x00000006u)
#define CSL_SGCP_CFG_SS2M_STATE6_RESETVAL (0x00000000u)
/*----STATE6 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE6_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE6_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE5_MASK (0x00000020u)
#define CSL_SGCP_CFG_SS2M_STATE5_SHIFT (0x00000005u)
#define CSL_SGCP_CFG_SS2M_STATE5_RESETVAL (0x00000000u)
/*----STATE5 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE5_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE5_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE4_MASK (0x00000010u)
#define CSL_SGCP_CFG_SS2M_STATE4_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SS2M_STATE4_RESETVAL (0x00000000u)
/*----STATE4 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE4_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE4_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE3_MASK (0x00000008u)
#define CSL_SGCP_CFG_SS2M_STATE3_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_SS2M_STATE3_RESETVAL (0x00000000u)
/*----STATE3 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE3_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE3_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE2_MASK (0x00000004u)
#define CSL_SGCP_CFG_SS2M_STATE2_SHIFT (0x00000002u)
#define CSL_SGCP_CFG_SS2M_STATE2_RESETVAL (0x00000000u)
/*----STATE2 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE2_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE2_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE1_MASK (0x00000002u)
#define CSL_SGCP_CFG_SS2M_STATE1_SHIFT (0x00000001u)
#define CSL_SGCP_CFG_SS2M_STATE1_RESETVAL (0x00000000u)
/*----STATE1 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE1_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE1_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_STATE0_MASK (0x00000001u)
#define CSL_SGCP_CFG_SS2M_STATE0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE0_RESETVAL (0x00000000u)
/*----STATE0 Tokens----*/
#define CSL_SGCP_CFG_SS2M_STATE0_IDLE (0x00000000u)
#define CSL_SGCP_CFG_SS2M_STATE0_NOT_IDLE (0x00000001u)

#define CSL_SGCP_CFG_SS2M_RESETVAL (0x00000000u)

/* SRM */

#define CSL_SGCP_CFG_SRM_CYCLE_CNT_MASK  (0x80000000u)
#define CSL_SGCP_CFG_SRM_CYCLE_CNT_SHIFT (0x0000001Fu)
#define CSL_SGCP_CFG_SRM_CYCLE_CNT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SRM_REQ_ID_MASK     (0x70000000u)
#define CSL_SGCP_CFG_SRM_REQ_ID_SHIFT    (0x0000001Cu)
#define CSL_SGCP_CFG_SRM_REQ_ID_RESETVAL (0x00000000u)
/*----REQ_ID Tokens----*/
#define CSL_SGCP_CFG_SRM_REQ_ID_GO_IDLE  (0x00000000u)
#define CSL_SGCP_CFG_SRM_REQ_ID_GO_COMMIT (0x00000001u)
#define CSL_SGCP_CFG_SRM_REQ_ID_GO_DECOMMIT (0x00000002u)
#define CSL_SGCP_CFG_SRM_REQ_ID_GO_ACTIVATED (0x00000003u)
#define CSL_SGCP_CFG_SRM_REQ_ID_GO_IDLE2 (0x00000004u)
#define CSL_SGCP_CFG_SRM_REQ_ID_GO_COMMITD (0x00000005u)
#define CSL_SGCP_CFG_SRM_REQ_ID_GO_DECOMMITD (0x00000006u)
#define CSL_SGCP_CFG_SRM_REQ_ID_GO_DEACTIVATED (0x00000007u)

#define CSL_SGCP_CFG_SRM_FRAME_ID_MASK   (0x0FFF0000u)
#define CSL_SGCP_CFG_SRM_FRAME_ID_SHIFT  (0x00000010u)
#define CSL_SGCP_CFG_SRM_FRAME_ID_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SRM_ITE_ID_MASK     (0x00003FFFu)
#define CSL_SGCP_CFG_SRM_ITE_ID_SHIFT    (0x00000000u)
#define CSL_SGCP_CFG_SRM_ITE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SRM_RESETVAL        (0x00000000u)

/* SIG_SETUP */


#define CSL_SGCP_CFG_SIG_SETUP_OFFSET_MASK (0x3FFF0000u)
#define CSL_SGCP_CFG_SIG_SETUP_OFFSET_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SIG_SETUP_OFFSET_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SIG_SETUP_VAM_GAIN_FLAG_MASK (0x00002000u)
#define CSL_SGCP_CFG_SIG_SETUP_VAM_GAIN_FLAG_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SIG_SETUP_VAM_GAIN_FLAG_RESETVAL (0x00000000u)
/*----VAM_GAIN_FLAG Tokens----*/
#define CSL_SGCP_CFG_SIG_SETUP_VAM_GAIN_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SIG_SETUP_VAM_GAIN_FLAG_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SIG_SETUP_E_AICH_FLAG_MASK (0x00001000u)
#define CSL_SGCP_CFG_SIG_SETUP_E_AICH_FLAG_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_SIG_SETUP_E_AICH_FLAG_RESETVAL (0x00000000u)
/*----E_AICH_FLAG Tokens----*/
#define CSL_SGCP_CFG_SIG_SETUP_E_AICH_FLAG_NORMAL_AICH (0x00000000u)
#define CSL_SGCP_CFG_SIG_SETUP_E_AICH_FLAG_EXT_AICH (0x00000001u)

#define CSL_SGCP_CFG_SIG_SETUP_AGGR_CMD_MASK (0x00000C00u)
#define CSL_SGCP_CFG_SIG_SETUP_AGGR_CMD_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SIG_SETUP_AGGR_CMD_RESETVAL (0x00000000u)
/*----AGGR_CMD Tokens----*/
#define CSL_SGCP_CFG_SIG_SETUP_AGGR_CMD_NOP (0x00000000u)
#define CSL_SGCP_CFG_SIG_SETUP_AGGR_CMD_RES (0x00000001u)
#define CSL_SGCP_CFG_SIG_SETUP_AGGR_CMD_ACC (0x00000002u)

#define CSL_SGCP_CFG_SIG_SETUP_DIV_GAIN_FLAG_MASK (0x00000200u)
#define CSL_SGCP_CFG_SIG_SETUP_DIV_GAIN_FLAG_SHIFT (0x00000009u)
#define CSL_SGCP_CFG_SIG_SETUP_DIV_GAIN_FLAG_RESETVAL (0x00000000u)
/*----DIV_GAIN_FLAG Tokens----*/
#define CSL_SGCP_CFG_SIG_SETUP_DIV_GAIN_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SIG_SETUP_DIV_GAIN_FLAG_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SIG_SETUP_CHANNEL_KIND_MASK (0x00000100u)
#define CSL_SGCP_CFG_SIG_SETUP_CHANNEL_KIND_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_SIG_SETUP_CHANNEL_KIND_RESETVAL (0x00000000u)
/*----CHANNEL_KIND Tokens----*/
#define CSL_SGCP_CFG_SIG_SETUP_CHANNEL_KIND_HSUPA (0x00000000u)
#define CSL_SGCP_CFG_SIG_SETUP_CHANNEL_KIND_AICH (0x00000001u)

#define CSL_SGCP_CFG_SIG_SETUP_AGGR_ID_MASK (0x000000FFu)
#define CSL_SGCP_CFG_SIG_SETUP_AGGR_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SIG_SETUP_AGGR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_SETUP_RESETVAL  (0x00000000u)

/* PBT */

#define CSL_SGCP_CFG_PBT_PILOT00_MASK    (0xC0000000u)
#define CSL_SGCP_CFG_PBT_PILOT00_SHIFT   (0x0000001Eu)
#define CSL_SGCP_CFG_PBT_PILOT00_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT01_MASK    (0x30000000u)
#define CSL_SGCP_CFG_PBT_PILOT01_SHIFT   (0x0000001Cu)
#define CSL_SGCP_CFG_PBT_PILOT01_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT02_MASK    (0x0C000000u)
#define CSL_SGCP_CFG_PBT_PILOT02_SHIFT   (0x0000001Au)
#define CSL_SGCP_CFG_PBT_PILOT02_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT03_MASK    (0x03000000u)
#define CSL_SGCP_CFG_PBT_PILOT03_SHIFT   (0x00000018u)
#define CSL_SGCP_CFG_PBT_PILOT03_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT04_MASK    (0x00C00000u)
#define CSL_SGCP_CFG_PBT_PILOT04_SHIFT   (0x00000016u)
#define CSL_SGCP_CFG_PBT_PILOT04_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT05_MASK    (0x00300000u)
#define CSL_SGCP_CFG_PBT_PILOT05_SHIFT   (0x00000014u)
#define CSL_SGCP_CFG_PBT_PILOT05_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT06_MASK    (0x000C0000u)
#define CSL_SGCP_CFG_PBT_PILOT06_SHIFT   (0x00000012u)
#define CSL_SGCP_CFG_PBT_PILOT06_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT07_MASK    (0x00030000u)
#define CSL_SGCP_CFG_PBT_PILOT07_SHIFT   (0x00000010u)
#define CSL_SGCP_CFG_PBT_PILOT07_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT08_MASK    (0x0000C000u)
#define CSL_SGCP_CFG_PBT_PILOT08_SHIFT   (0x0000000Eu)
#define CSL_SGCP_CFG_PBT_PILOT08_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT09_MASK    (0x00003000u)
#define CSL_SGCP_CFG_PBT_PILOT09_SHIFT   (0x0000000Cu)
#define CSL_SGCP_CFG_PBT_PILOT09_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT10_MASK    (0x00000C00u)
#define CSL_SGCP_CFG_PBT_PILOT10_SHIFT   (0x0000000Au)
#define CSL_SGCP_CFG_PBT_PILOT10_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT11_MASK    (0x00000300u)
#define CSL_SGCP_CFG_PBT_PILOT11_SHIFT   (0x00000008u)
#define CSL_SGCP_CFG_PBT_PILOT11_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT12_MASK    (0x000000C0u)
#define CSL_SGCP_CFG_PBT_PILOT12_SHIFT   (0x00000006u)
#define CSL_SGCP_CFG_PBT_PILOT12_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT13_MASK    (0x00000030u)
#define CSL_SGCP_CFG_PBT_PILOT13_SHIFT   (0x00000004u)
#define CSL_SGCP_CFG_PBT_PILOT13_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PBT_PILOT14_MASK    (0x0000000Cu)
#define CSL_SGCP_CFG_PBT_PILOT14_SHIFT   (0x00000002u)
#define CSL_SGCP_CFG_PBT_PILOT14_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_PBT_RESETVAL        (0x00000000u)

/* SSM */


#define CSL_SGCP_CFG_SSM_STATE7_MASK     (0x70000000u)
#define CSL_SGCP_CFG_SSM_STATE7_SHIFT    (0x0000001Cu)
#define CSL_SGCP_CFG_SSM_STATE7_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SSM_STATE6_MASK     (0x07000000u)
#define CSL_SGCP_CFG_SSM_STATE6_SHIFT    (0x00000018u)
#define CSL_SGCP_CFG_SSM_STATE6_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SSM_STATE5_MASK     (0x00700000u)
#define CSL_SGCP_CFG_SSM_STATE5_SHIFT    (0x00000014u)
#define CSL_SGCP_CFG_SSM_STATE5_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SSM_STATE4_MASK     (0x00070000u)
#define CSL_SGCP_CFG_SSM_STATE4_SHIFT    (0x00000010u)
#define CSL_SGCP_CFG_SSM_STATE4_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SSM_STATE3_MASK     (0x00007000u)
#define CSL_SGCP_CFG_SSM_STATE3_SHIFT    (0x0000000Cu)
#define CSL_SGCP_CFG_SSM_STATE3_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SSM_STATE2_MASK     (0x00000700u)
#define CSL_SGCP_CFG_SSM_STATE2_SHIFT    (0x00000008u)
#define CSL_SGCP_CFG_SSM_STATE2_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SSM_STATE1_MASK     (0x00000070u)
#define CSL_SGCP_CFG_SSM_STATE1_SHIFT    (0x00000004u)
#define CSL_SGCP_CFG_SSM_STATE1_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_SSM_STATE0_MASK     (0x00000007u)
#define CSL_SGCP_CFG_SSM_STATE0_SHIFT    (0x00000000u)
#define CSL_SGCP_CFG_SSM_STATE0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SSM_RESETVAL        (0x00000000u)

/* SGCP_SEQ_ENA */


#define CSL_SGCP_CFG_SGCP_SEQ_ENA_ENABLE_MASK (0x00000001u)
#define CSL_SGCP_CFG_SGCP_SEQ_ENA_ENABLE_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SGCP_SEQ_ENA_ENABLE_RESETVAL (0x00000000u)
/*----ENABLE Tokens----*/
#define CSL_SGCP_CFG_SGCP_SEQ_ENA_ENABLE_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_SGCP_SEQ_ENA_ENABLE_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_SGCP_SEQ_ENA_RESETVAL (0x00000000u)

/* SGCP_SEQ_ACT */


#define CSL_SGCP_CFG_SGCP_SEQ_ACT_ACT_COUNT_MASK (0x000001FFu)
#define CSL_SGCP_CFG_SGCP_SEQ_ACT_ACT_COUNT_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SGCP_SEQ_ACT_ACT_COUNT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_SEQ_ACT_RESETVAL (0x00000000u)

/* SGCP_SEQ_CYC */


#define CSL_SGCP_CFG_SGCP_SEQ_CYC_SEQ_COUNT_MASK (0x000001FFu)
#define CSL_SGCP_CFG_SGCP_SEQ_CYC_SEQ_COUNT_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SGCP_SEQ_CYC_SEQ_COUNT_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_SEQ_CYC_RESETVAL (0x00000000u)

/* SGCP_CYC_OVER */


#define CSL_SGCP_CFG_SGCP_CYC_OVER_ITE_NB_MASK (0x00FFFC00u)
#define CSL_SGCP_CFG_SGCP_CYC_OVER_ITE_NB_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SGCP_CYC_OVER_ITE_NB_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_CYC_OVER_CYC_OVER_FLG_MASK (0x00000200u)
#define CSL_SGCP_CFG_SGCP_CYC_OVER_CYC_OVER_FLG_SHIFT (0x00000009u)
#define CSL_SGCP_CFG_SGCP_CYC_OVER_CYC_OVER_FLG_RESETVAL (0x00000000u)
/*----CYC_OVER_FLG Tokens----*/
#define CSL_SGCP_CFG_SGCP_CYC_OVER_CYC_OVER_FLG_NO_ERROR (0x00000000u)
#define CSL_SGCP_CFG_SGCP_CYC_OVER_CYC_OVER_FLG_ERROR_OCCURED (0x00000001u)

#define CSL_SGCP_CFG_SGCP_CYC_OVER_PAGE_IDX_MASK (0x000001F0u)
#define CSL_SGCP_CFG_SGCP_CYC_OVER_PAGE_IDX_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SGCP_CYC_OVER_PAGE_IDX_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_CYC_OVER_TASK_IDX_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SGCP_CYC_OVER_TASK_IDX_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SGCP_CYC_OVER_TASK_IDX_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_CYC_OVER_RESETVAL (0x00000000u)

/* SGCP_FIFO_OVER */


#define CSL_SGCP_CFG_SGCP_FIFO_OVER_ITE_NB_MASK (0x03FFF000u)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_ITE_NB_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_ITE_NB_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_FIFO_OVER_FIFO_ID_MASK (0x00000C00u)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_FIFO_ID_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_FIFO_ID_RESETVAL (0x00000000u)
/*----FIFO_ID Tokens----*/
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_FIFO_ID_FETCH_QUEUE (0x00000000u)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_FIFO_ID_CPM_QUEUE (0x00000001u)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_FIFO_ID_WARN_QUEUE (0x00000002u)

#define CSL_SGCP_CFG_SGCP_FIFO_OVER_CYC_OVER_FLG_MASK (0x00000200u)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_CYC_OVER_FLG_SHIFT (0x00000009u)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_CYC_OVER_FLG_RESETVAL (0x00000000u)
/*----CYC_OVER_FLG Tokens----*/
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_CYC_OVER_FLG_NO_ERROR (0x00000000u)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_CYC_OVER_FLG_ERROR_OCCURED (0x00000001u)

#define CSL_SGCP_CFG_SGCP_FIFO_OVER_PAGE_IDX_MASK (0x000001F0u)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_PAGE_IDX_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_PAGE_IDX_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_FIFO_OVER_TASK_IDX_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_TASK_IDX_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SGCP_FIFO_OVER_TASK_IDX_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_FIFO_OVER_RESETVAL (0x00000000u)

/* SGCP_FIFO_RESET */


#define CSL_SGCP_CFG_SGCP_FIFO_RESET_WARN_RESET_MASK (0x00000004u)
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_WARN_RESET_SHIFT (0x00000002u)
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_WARN_RESET_RESETVAL (0x00000000u)
/*----WARN_RESET Tokens----*/
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_WARN_RESET_NO_RESET (0x00000000u)
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_WARN_RESET_RESET (0x00000001u)

#define CSL_SGCP_CFG_SGCP_FIFO_RESET_CPM_RESET_MASK (0x00000002u)
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_CPM_RESET_SHIFT (0x00000001u)
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_CPM_RESET_RESETVAL (0x00000000u)
/*----CPM_RESET Tokens----*/
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_CPM_RESET_NO_RESET (0x00000000u)
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_CPM_RESET_RESET (0x00000001u)

#define CSL_SGCP_CFG_SGCP_FIFO_RESET_FETCH_RESET_MASK (0x00000001u)
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_FETCH_RESET_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_FETCH_RESET_RESETVAL (0x00000000u)
/*----FETCH_RESET Tokens----*/
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_FETCH_RESET_NO_RESET (0x00000000u)
#define CSL_SGCP_CFG_SGCP_FIFO_RESET_FETCH_RESET_RESET (0x00000001u)

#define CSL_SGCP_CFG_SGCP_FIFO_RESET_RESETVAL (0x00000000u)

/* SGCP_RD_SYS_TIME */


#define CSL_SGCP_CFG_SGCP_RD_SYS_TIME_FRAME_NB_MASK (0x0FFF0000u)
#define CSL_SGCP_CFG_SGCP_RD_SYS_TIME_FRAME_NB_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SGCP_RD_SYS_TIME_FRAME_NB_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_RD_SYS_TIME_SLOT_NB_MASK (0x0000F000u)
#define CSL_SGCP_CFG_SGCP_RD_SYS_TIME_SLOT_NB_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_SGCP_RD_SYS_TIME_SLOT_NB_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_RD_SYS_TIME_CHIP_NB_MASK (0x00000FFFu)
#define CSL_SGCP_CFG_SGCP_RD_SYS_TIME_CHIP_NB_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SGCP_RD_SYS_TIME_CHIP_NB_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_RD_SYS_TIME_RESETVAL (0x00000000u)

/* SGCP_IB_MISS */


#define CSL_SGCP_CFG_SGCP_IB_MISS_ITE_NB_MASK (0x00FFFC00u)
#define CSL_SGCP_CFG_SGCP_IB_MISS_ITE_NB_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SGCP_IB_MISS_ITE_NB_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_IB_MISS_WR_MISS_MASK (0x00000200u)
#define CSL_SGCP_CFG_SGCP_IB_MISS_WR_MISS_SHIFT (0x00000009u)
#define CSL_SGCP_CFG_SGCP_IB_MISS_WR_MISS_RESETVAL (0x00000000u)
/*----WR_MISS Tokens----*/
#define CSL_SGCP_CFG_SGCP_IB_MISS_WR_MISS_NO_ERROR (0x00000000u)
#define CSL_SGCP_CFG_SGCP_IB_MISS_WR_MISS_ERROR_OCCURED (0x00000001u)

#define CSL_SGCP_CFG_SGCP_IB_MISS_PAGE_IDX_MASK (0x000001F0u)
#define CSL_SGCP_CFG_SGCP_IB_MISS_PAGE_IDX_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SGCP_IB_MISS_PAGE_IDX_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_IB_MISS_TASK_IDX_MASK (0x0000000Fu)
#define CSL_SGCP_CFG_SGCP_IB_MISS_TASK_IDX_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SGCP_IB_MISS_TASK_IDX_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SGCP_IB_MISS_RESETVAL (0x00000000u)

/* TRA_CTL */

#define CSL_SGCP_CFG_TRA_CTL_SW_TEVENT_EN_MASK (0x08000000u)
#define CSL_SGCP_CFG_TRA_CTL_SW_TEVENT_EN_SHIFT (0x0000001Bu)
#define CSL_SGCP_CFG_TRA_CTL_SW_TEVENT_EN_RESETVAL (0x00000000u)
/*----SW_TEVENT_EN Tokens----*/
#define CSL_SGCP_CFG_TRA_CTL_SW_TEVENT_EN_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_TRA_CTL_SW_TEVENT_EN_ENABLE (0x00000001u)


#define CSL_SGCP_CFG_TRA_CTL_DEVENT_FLAG_MASK (0x04000000u)
#define CSL_SGCP_CFG_TRA_CTL_DEVENT_FLAG_SHIFT (0x0000001Au)
#define CSL_SGCP_CFG_TRA_CTL_DEVENT_FLAG_RESETVAL (0x00000000u)
/*----DEVENT_FLAG Tokens----*/
#define CSL_SGCP_CFG_TRA_CTL_DEVENT_FLAG_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_TRA_CTL_DEVENT_FLAG_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_TRA_CTL_CYCLE_ID_MASK (0x02000000u)
#define CSL_SGCP_CFG_TRA_CTL_CYCLE_ID_SHIFT (0x00000019u)
#define CSL_SGCP_CFG_TRA_CTL_CYCLE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_CTL_REQ_ID_MASK (0x01FF0000u)
#define CSL_SGCP_CFG_TRA_CTL_REQ_ID_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_TRA_CTL_REQ_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_CTL_ITE_ID_MASK (0x0000FFFCu)
#define CSL_SGCP_CFG_TRA_CTL_ITE_ID_SHIFT (0x00000002u)
#define CSL_SGCP_CFG_TRA_CTL_ITE_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_CTL_TRA_MODE_MASK (0x00000002u)
#define CSL_SGCP_CFG_TRA_CTL_TRA_MODE_SHIFT (0x00000001u)
#define CSL_SGCP_CFG_TRA_CTL_TRA_MODE_RESETVAL (0x00000000u)
/*----TRA_MODE Tokens----*/
#define CSL_SGCP_CFG_TRA_CTL_TRA_MODE_CONTINUOUS (0x00000000u)
#define CSL_SGCP_CFG_TRA_CTL_TRA_MODE_DATED (0x00000001u)

#define CSL_SGCP_CFG_TRA_CTL_TRA_ENA_MASK (0x00000001u)
#define CSL_SGCP_CFG_TRA_CTL_TRA_ENA_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_CTL_TRA_ENA_RESETVAL (0x00000000u)
/*----TRA_ENA Tokens----*/
#define CSL_SGCP_CFG_TRA_CTL_TRA_ENA_DISABLE (0x00000000u)
#define CSL_SGCP_CFG_TRA_CTL_TRA_ENA_ENABLE (0x00000001u)

#define CSL_SGCP_CFG_TRA_CTL_RESETVAL    (0x00000000u)

/* TRA_STAT */


#define CSL_SGCP_CFG_TRA_STAT_LOCAL_TIME_MASK (0x1FFF8000u)
#define CSL_SGCP_CFG_TRA_STAT_LOCAL_TIME_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_TRA_STAT_LOCAL_TIME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_STAT_SYS_TIME_MASK (0x00007FFEu)
#define CSL_SGCP_CFG_TRA_STAT_SYS_TIME_SHIFT (0x00000001u)
#define CSL_SGCP_CFG_TRA_STAT_SYS_TIME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_STAT_TASK_STATUS_MASK (0x00000001u)
#define CSL_SGCP_CFG_TRA_STAT_TASK_STATUS_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_STAT_TASK_STATUS_RESETVAL (0x00000000u)
/*----TASK_STATUS Tokens----*/
#define CSL_SGCP_CFG_TRA_STAT_TASK_STATUS_INACTIVE (0x00000000u)
#define CSL_SGCP_CFG_TRA_STAT_TASK_STATUS_ACTIVE (0x00000001u)

#define CSL_SGCP_CFG_TRA_STAT_RESETVAL   (0x00000000u)

/* TRA_INB */

#define CSL_SGCP_CFG_TRA_INB_UL_TPC_RL_ID_MASK (0xE0000000u)
#define CSL_SGCP_CFG_TRA_INB_UL_TPC_RL_ID_SHIFT (0x0000001Du)
#define CSL_SGCP_CFG_TRA_INB_UL_TPC_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_INB_UL_TPC_RLS_ID_MASK (0x1FC00000u)
#define CSL_SGCP_CFG_TRA_INB_UL_TPC_RLS_ID_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_TRA_INB_UL_TPC_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_INB_UL_TPC_CMD_MASK (0x00300000u)
#define CSL_SGCP_CFG_TRA_INB_UL_TPC_CMD_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_TRA_INB_UL_TPC_CMD_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_INB_OUT_I_MASK  (0x000F0000u)
#define CSL_SGCP_CFG_TRA_INB_OUT_I_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_TRA_INB_OUT_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_INB_OUT_Q_MASK  (0x0000F000u)
#define CSL_SGCP_CFG_TRA_INB_OUT_Q_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_TRA_INB_OUT_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_INB_SL_FO_ID_MASK (0x00000F80u)
#define CSL_SGCP_CFG_TRA_INB_SL_FO_ID_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_TRA_INB_SL_FO_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_INB_CH_KIND_MASK (0x00000078u)
#define CSL_SGCP_CFG_TRA_INB_CH_KIND_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_TRA_INB_CH_KIND_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_INB_MOD_SCHEME_MASK (0x00000007u)
#define CSL_SGCP_CFG_TRA_INB_MOD_SCHEME_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_INB_MOD_SCHEME_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_INB_RESETVAL    (0x00000000u)

/* TRA_GAINA */


#define CSL_SGCP_CFG_TRA_GAINA_GAIN_IN_FLAG_MASK (0x40000000u)
#define CSL_SGCP_CFG_TRA_GAINA_GAIN_IN_FLAG_SHIFT (0x0000001Eu)
#define CSL_SGCP_CFG_TRA_GAINA_GAIN_IN_FLAG_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_GAINA_LOG_GAIN_MASK (0x3FF00000u)
#define CSL_SGCP_CFG_TRA_GAINA_LOG_GAIN_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_TRA_GAINA_LOG_GAIN_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_TRA_GAINA_LINEAR_GAIN_MASK (0x0003FFFFu)
#define CSL_SGCP_CFG_TRA_GAINA_LINEAR_GAIN_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_GAINA_LINEAR_GAIN_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_GAINA_RESETVAL  (0x00000000u)

/* TRA_GAINB */


#define CSL_SGCP_CFG_TRA_GAINB_MOD_CORR_MASK (0x0000E000u)
#define CSL_SGCP_CFG_TRA_GAINB_MOD_CORR_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_TRA_GAINB_MOD_CORR_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_GAINB_TRANS_GAP_MASK (0x00001000u)
#define CSL_SGCP_CFG_TRA_GAINB_TRANS_GAP_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_TRA_GAINB_TRANS_GAP_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_GAINB_POW_OFF_MASK (0x00000C00u)
#define CSL_SGCP_CFG_TRA_GAINB_POW_OFF_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_TRA_GAINB_POW_OFF_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_GAINB_DL_TPC_RL_ID_MASK (0x00000380u)
#define CSL_SGCP_CFG_TRA_GAINB_DL_TPC_RL_ID_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_TRA_GAINB_DL_TPC_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_GAINB_DL_TPC_RLS_ID_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_TRA_GAINB_DL_TPC_RLS_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_GAINB_DL_TPC_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_GAINB_RESETVAL  (0x00000000u)

/* TRA_DIVA */


#define CSL_SGCP_CFG_TRA_DIVA_DIV_PHASOR_Q_MASK (0x7FFF0000u)
#define CSL_SGCP_CFG_TRA_DIVA_DIV_PHASOR_Q_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_TRA_DIVA_DIV_PHASOR_Q_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_TRA_DIVA_DIV_PHASOR_I_MASK (0x00007FFFu)
#define CSL_SGCP_CFG_TRA_DIVA_DIV_PHASOR_I_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_DIVA_DIV_PHASOR_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_DIVA_RESETVAL   (0x00000000u)

/* TRA_DIVB */


#define CSL_SGCP_CFG_TRA_DIVB_DIV_BYPASS_MASK (0x00000400u)
#define CSL_SGCP_CFG_TRA_DIVB_DIV_BYPASS_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_TRA_DIVB_DIV_BYPASS_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_DIVB_DIV_RL_ID_MASK (0x00000380u)
#define CSL_SGCP_CFG_TRA_DIVB_DIV_RL_ID_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_TRA_DIVB_DIV_RL_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_DIVB_DIV_RLS_ID_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_TRA_DIVB_DIV_RLS_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_DIVB_DIV_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_DIVB_RESETVAL   (0x00000000u)

/* TRA_BFNA */

#define CSL_SGCP_CFG_TRA_BFNA_EXTENDED_Q_MASK (0xFF000000u)
#define CSL_SGCP_CFG_TRA_BFNA_EXTENDED_Q_SHIFT (0x00000018u)
#define CSL_SGCP_CFG_TRA_BFNA_EXTENDED_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_BFNA_WEIGHT_Q_MASK (0x00FF0000u)
#define CSL_SGCP_CFG_TRA_BFNA_WEIGHT_Q_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_TRA_BFNA_WEIGHT_Q_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_BFNA_EXTENDED_I_MASK (0x0000FF00u)
#define CSL_SGCP_CFG_TRA_BFNA_EXTENDED_I_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_TRA_BFNA_EXTENDED_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_BFNA_WEIGHT_I_MASK (0x000000FFu)
#define CSL_SGCP_CFG_TRA_BFNA_WEIGHT_I_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_BFNA_WEIGHT_I_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_BFNA_RESETVAL   (0x00000000u)

/* TRA_BFNB */


#define CSL_SGCP_CFG_TRA_BFNB_BFN_BYPASS_MASK (0x00000400u)
#define CSL_SGCP_CFG_TRA_BFNB_BFN_BYPASS_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_TRA_BFNB_BFN_BYPASS_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_BFNB_BFN_WEIGHT_ID_MASK (0x00000380u)
#define CSL_SGCP_CFG_TRA_BFNB_BFN_WEIGHT_ID_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_TRA_BFNB_BFN_WEIGHT_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_BFNB_BFN_RLS_ID_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_TRA_BFNB_BFN_RLS_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_BFNB_BFN_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_BFNB_RESETVAL   (0x00000000u)

/* TRA_CHCDA */


#define CSL_SGCP_CFG_TRA_CHCDA_CHCD_BYPASS_MASK (0x00000010u)
#define CSL_SGCP_CFG_TRA_CHCDA_CHCD_BYPASS_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_TRA_CHCDA_CHCD_BYPASS_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_CHCDA_CHCD3_MASK (0x00000008u)
#define CSL_SGCP_CFG_TRA_CHCDA_CHCD3_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_TRA_CHCDA_CHCD3_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_CHCDA_CHCD2_MASK (0x00000004u)
#define CSL_SGCP_CFG_TRA_CHCDA_CHCD2_SHIFT (0x00000002u)
#define CSL_SGCP_CFG_TRA_CHCDA_CHCD2_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_CHCDA_CHCD1_MASK (0x00000002u)
#define CSL_SGCP_CFG_TRA_CHCDA_CHCD1_SHIFT (0x00000001u)
#define CSL_SGCP_CFG_TRA_CHCDA_CHCD1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_CHCDA_CHCD0_MASK (0x00000001u)
#define CSL_SGCP_CFG_TRA_CHCDA_CHCD0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_CHCDA_CHCD0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_CHCDA_RESETVAL  (0x00000000u)

/* TRA_SCCDA */


#define CSL_SGCP_CFG_TRA_SCCDA_CHCD_BYPASS_MASK (0x00000100u)
#define CSL_SGCP_CFG_TRA_SCCDA_CHCD_BYPASS_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_TRA_SCCDA_CHCD_BYPASS_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_SCCDA_CHCD3_MASK (0x000000C0u)
#define CSL_SGCP_CFG_TRA_SCCDA_CHCD3_SHIFT (0x00000006u)
#define CSL_SGCP_CFG_TRA_SCCDA_CHCD3_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_SCCDA_CHCD2_MASK (0x00000030u)
#define CSL_SGCP_CFG_TRA_SCCDA_CHCD2_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_TRA_SCCDA_CHCD2_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_SCCDA_CHCD1_MASK (0x0000000Cu)
#define CSL_SGCP_CFG_TRA_SCCDA_CHCD1_SHIFT (0x00000002u)
#define CSL_SGCP_CFG_TRA_SCCDA_CHCD1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_SCCDA_CHCD0_MASK (0x00000003u)
#define CSL_SGCP_CFG_TRA_SCCDA_CHCD0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_SCCDA_CHCD0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_SCCDA_RESETVAL  (0x00000000u)

/* TRA_AGGRA */


#define CSL_SGCP_CFG_TRA_AGGRA_AGGR_CMD_MASK (0x00000100u)
#define CSL_SGCP_CFG_TRA_AGGRA_AGGR_CMD_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_TRA_AGGRA_AGGR_CMD_RESETVAL (0x00000000u)


#define CSL_SGCP_CFG_TRA_AGGRA_STR_ID_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_TRA_AGGRA_STR_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_AGGRA_STR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_AGGRA_RESETVAL  (0x00000000u)

/* TRA_SIGA */


#define CSL_SGCP_CFG_TRA_SIGA_SIG_DIV_MASK (0x00000200u)
#define CSL_SGCP_CFG_TRA_SIGA_SIG_DIV_SHIFT (0x00000009u)
#define CSL_SGCP_CFG_TRA_SIGA_SIG_DIV_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_SIGA_SIG_AGGR_ID_MASK (0x000001FEu)
#define CSL_SGCP_CFG_TRA_SIGA_SIG_AGGR_ID_SHIFT (0x00000001u)
#define CSL_SGCP_CFG_TRA_SIGA_SIG_AGGR_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_SIGA_SIG_REQ_MASK (0x00000001u)
#define CSL_SGCP_CFG_TRA_SIGA_SIG_REQ_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_TRA_SIGA_SIG_REQ_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_TRA_SIGA_RESETVAL   (0x00000000u)

/* SPM_WORD_9 */

#define CSL_SGCP_CFG_SPM_WORD_9_PONG_BFN_RLS_ID_MASK (0x007F0000u)
#define CSL_SGCP_CFG_SPM_WORD_9_PONG_BFN_RLS_ID_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SPM_WORD_9_PONG_BFN_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_WORD_9_PING_BFN_RLS_ID_MASK (0x0000007Fu)
#define CSL_SGCP_CFG_SPM_WORD_9_PING_BFN_RLS_ID_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SPM_WORD_9_PING_BFN_RLS_ID_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SPM_WORD_9_RESETVAL    (0x00000000u)

/* PAT */

#define CSL_SGCP_CFG_PAT_PAGE_31_MASK    (0x80000000u)
#define CSL_SGCP_CFG_PAT_PAGE_31_SHIFT   (0x0000001Fu)
#define CSL_SGCP_CFG_PAT_PAGE_31_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_30_MASK    (0x40000000u)
#define CSL_SGCP_CFG_PAT_PAGE_30_SHIFT   (0x0000001Eu)
#define CSL_SGCP_CFG_PAT_PAGE_30_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_29_MASK    (0x20000000u)
#define CSL_SGCP_CFG_PAT_PAGE_29_SHIFT   (0x0000001Du)
#define CSL_SGCP_CFG_PAT_PAGE_29_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_28_MASK    (0x10000000u)
#define CSL_SGCP_CFG_PAT_PAGE_28_SHIFT   (0x0000001Cu)
#define CSL_SGCP_CFG_PAT_PAGE_28_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_27_MASK    (0x08000000u)
#define CSL_SGCP_CFG_PAT_PAGE_27_SHIFT   (0x0000001Bu)
#define CSL_SGCP_CFG_PAT_PAGE_27_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_26_MASK    (0x04000000u)
#define CSL_SGCP_CFG_PAT_PAGE_26_SHIFT   (0x0000001Au)
#define CSL_SGCP_CFG_PAT_PAGE_26_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_25_MASK    (0x02000000u)
#define CSL_SGCP_CFG_PAT_PAGE_25_SHIFT   (0x00000019u)
#define CSL_SGCP_CFG_PAT_PAGE_25_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_24_MASK    (0x01000000u)
#define CSL_SGCP_CFG_PAT_PAGE_24_SHIFT   (0x00000018u)
#define CSL_SGCP_CFG_PAT_PAGE_24_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_23_MASK    (0x00800000u)
#define CSL_SGCP_CFG_PAT_PAGE_23_SHIFT   (0x00000017u)
#define CSL_SGCP_CFG_PAT_PAGE_23_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_22_MASK    (0x00400000u)
#define CSL_SGCP_CFG_PAT_PAGE_22_SHIFT   (0x00000016u)
#define CSL_SGCP_CFG_PAT_PAGE_22_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_21_MASK    (0x00200000u)
#define CSL_SGCP_CFG_PAT_PAGE_21_SHIFT   (0x00000015u)
#define CSL_SGCP_CFG_PAT_PAGE_21_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_20_MASK    (0x00100000u)
#define CSL_SGCP_CFG_PAT_PAGE_20_SHIFT   (0x00000014u)
#define CSL_SGCP_CFG_PAT_PAGE_20_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_19_MASK    (0x00080000u)
#define CSL_SGCP_CFG_PAT_PAGE_19_SHIFT   (0x00000013u)
#define CSL_SGCP_CFG_PAT_PAGE_19_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_18_MASK    (0x00040000u)
#define CSL_SGCP_CFG_PAT_PAGE_18_SHIFT   (0x00000012u)
#define CSL_SGCP_CFG_PAT_PAGE_18_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_17_MASK    (0x00020000u)
#define CSL_SGCP_CFG_PAT_PAGE_17_SHIFT   (0x00000011u)
#define CSL_SGCP_CFG_PAT_PAGE_17_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_16_MASK    (0x00010000u)
#define CSL_SGCP_CFG_PAT_PAGE_16_SHIFT   (0x00000010u)
#define CSL_SGCP_CFG_PAT_PAGE_16_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_15_MASK    (0x00008000u)
#define CSL_SGCP_CFG_PAT_PAGE_15_SHIFT   (0x0000000Fu)
#define CSL_SGCP_CFG_PAT_PAGE_15_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_14_MASK    (0x00004000u)
#define CSL_SGCP_CFG_PAT_PAGE_14_SHIFT   (0x0000000Eu)
#define CSL_SGCP_CFG_PAT_PAGE_14_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_13_MASK    (0x00002000u)
#define CSL_SGCP_CFG_PAT_PAGE_13_SHIFT   (0x0000000Du)
#define CSL_SGCP_CFG_PAT_PAGE_13_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_12_MASK    (0x00001000u)
#define CSL_SGCP_CFG_PAT_PAGE_12_SHIFT   (0x0000000Cu)
#define CSL_SGCP_CFG_PAT_PAGE_12_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_11_MASK    (0x00000800u)
#define CSL_SGCP_CFG_PAT_PAGE_11_SHIFT   (0x0000000Bu)
#define CSL_SGCP_CFG_PAT_PAGE_11_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_10_MASK    (0x00000400u)
#define CSL_SGCP_CFG_PAT_PAGE_10_SHIFT   (0x0000000Au)
#define CSL_SGCP_CFG_PAT_PAGE_10_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_9_MASK     (0x00000200u)
#define CSL_SGCP_CFG_PAT_PAGE_9_SHIFT    (0x00000009u)
#define CSL_SGCP_CFG_PAT_PAGE_9_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_8_MASK     (0x00000100u)
#define CSL_SGCP_CFG_PAT_PAGE_8_SHIFT    (0x00000008u)
#define CSL_SGCP_CFG_PAT_PAGE_8_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_7_MASK     (0x00000080u)
#define CSL_SGCP_CFG_PAT_PAGE_7_SHIFT    (0x00000007u)
#define CSL_SGCP_CFG_PAT_PAGE_7_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_6_MASK     (0x00000040u)
#define CSL_SGCP_CFG_PAT_PAGE_6_SHIFT    (0x00000006u)
#define CSL_SGCP_CFG_PAT_PAGE_6_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_5_MASK     (0x00000020u)
#define CSL_SGCP_CFG_PAT_PAGE_5_SHIFT    (0x00000005u)
#define CSL_SGCP_CFG_PAT_PAGE_5_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_4_MASK     (0x00000010u)
#define CSL_SGCP_CFG_PAT_PAGE_4_SHIFT    (0x00000004u)
#define CSL_SGCP_CFG_PAT_PAGE_4_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_3_MASK     (0x00000008u)
#define CSL_SGCP_CFG_PAT_PAGE_3_SHIFT    (0x00000003u)
#define CSL_SGCP_CFG_PAT_PAGE_3_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_2_MASK     (0x00000004u)
#define CSL_SGCP_CFG_PAT_PAGE_2_SHIFT    (0x00000002u)
#define CSL_SGCP_CFG_PAT_PAGE_2_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_1_MASK     (0x00000002u)
#define CSL_SGCP_CFG_PAT_PAGE_1_SHIFT    (0x00000001u)
#define CSL_SGCP_CFG_PAT_PAGE_1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_PAGE_0_MASK     (0x00000001u)
#define CSL_SGCP_CFG_PAT_PAGE_0_SHIFT    (0x00000000u)
#define CSL_SGCP_CFG_PAT_PAGE_0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_PAT_RESETVAL        (0x00000000u)

/* SIG_PAGE_EN */


#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_23_MASK (0x00800000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_23_SHIFT (0x00000017u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_23_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_22_MASK (0x00400000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_22_SHIFT (0x00000016u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_22_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_21_MASK (0x00200000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_21_SHIFT (0x00000015u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_21_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_20_MASK (0x00100000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_20_SHIFT (0x00000014u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_20_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_19_MASK (0x00080000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_19_SHIFT (0x00000013u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_19_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_18_MASK (0x00040000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_18_SHIFT (0x00000012u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_18_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_17_MASK (0x00020000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_17_SHIFT (0x00000011u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_17_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_16_MASK (0x00010000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_16_SHIFT (0x00000010u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_16_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_15_MASK (0x00008000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_15_SHIFT (0x0000000Fu)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_15_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_14_MASK (0x00004000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_14_SHIFT (0x0000000Eu)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_14_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_13_MASK (0x00002000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_13_SHIFT (0x0000000Du)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_13_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_12_MASK (0x00001000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_12_SHIFT (0x0000000Cu)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_12_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_11_MASK (0x00000800u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_11_SHIFT (0x0000000Bu)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_11_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_10_MASK (0x00000400u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_10_SHIFT (0x0000000Au)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_10_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_9_MASK (0x00000200u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_9_SHIFT (0x00000009u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_9_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_8_MASK (0x00000100u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_8_SHIFT (0x00000008u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_8_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_7_MASK (0x00000080u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_7_SHIFT (0x00000007u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_7_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_6_MASK (0x00000040u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_6_SHIFT (0x00000006u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_6_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_5_MASK (0x00000020u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_5_SHIFT (0x00000005u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_5_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_4_MASK (0x00000010u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_4_SHIFT (0x00000004u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_4_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_3_MASK (0x00000008u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_3_SHIFT (0x00000003u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_3_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_2_MASK (0x00000004u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_2_SHIFT (0x00000002u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_2_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_1_MASK (0x00000002u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_1_SHIFT (0x00000001u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_1_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_0_MASK (0x00000001u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_0_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_SIG_PAGE_EN_PAGE_0_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_SIG_PAGE_EN_RESETVAL (0x00000000u)

/* HEAD_FETCH */


#define CSL_SGCP_CFG_HEAD_FETCH_HEAD_LATENCY_MASK (0x0000001Fu)
#define CSL_SGCP_CFG_HEAD_FETCH_HEAD_LATENCY_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_HEAD_FETCH_HEAD_LATENCY_RESETVAL (0x00000002u)

#define CSL_SGCP_CFG_HEAD_FETCH_RESETVAL (0x00000002u)

/* DATA_FETCH */


#define CSL_SGCP_CFG_DATA_FETCH_DATA_LATENCY_MASK (0x0000001Fu)
#define CSL_SGCP_CFG_DATA_FETCH_DATA_LATENCY_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_DATA_FETCH_DATA_LATENCY_RESETVAL (0x00000001u)

#define CSL_SGCP_CFG_DATA_FETCH_RESETVAL (0x00000001u)


/* FTQ_CURR_LVL */


#define CSL_SGCP_CFG_FTQ_CURR_LVL_CURR_LVL_MASK (0x000003FFu)
#define CSL_SGCP_CFG_FTQ_CURR_LVL_CURR_LVL_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_FTQ_CURR_LVL_CURR_LVL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_FTQ_CURR_LVL_RESETVAL (0x00000000u)

/* FTQ_WTMK_LVL */


#define CSL_SGCP_CFG_FTQ_WTMK_LVL_WATERMARK_MASK (0x000003FFu)
#define CSL_SGCP_CFG_FTQ_WTMK_LVL_WATERMARK_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_FTQ_WTMK_LVL_WATERMARK_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_FTQ_WTMK_LVL_RESETVAL (0x00000000u)

/* CTQ_CURR_LVL */


#define CSL_SGCP_CFG_CTQ_CURR_LVL_CURR_LVL_MASK (0x000000FFu)
#define CSL_SGCP_CFG_CTQ_CURR_LVL_CURR_LVL_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_CTQ_CURR_LVL_CURR_LVL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_CTQ_CURR_LVL_RESETVAL (0x00000000u)

/* CTQ_WTMK_LVL */


#define CSL_SGCP_CFG_CTQ_WTMK_LVL_WATERMARK_MASK (0x000000FFu)
#define CSL_SGCP_CFG_CTQ_WTMK_LVL_WATERMARK_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_CTQ_WTMK_LVL_WATERMARK_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_CTQ_WTMK_LVL_RESETVAL (0x00000000u)

/* WTQ_CURR_LVL */


#define CSL_SGCP_CFG_WTQ_CURR_LVL_CURR_LVL_MASK (0x000000FFu)
#define CSL_SGCP_CFG_WTQ_CURR_LVL_CURR_LVL_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_WTQ_CURR_LVL_CURR_LVL_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_WTQ_CURR_LVL_RESETVAL (0x00000000u)

/* WTQ_WTMK_LVL */


#define CSL_SGCP_CFG_WTQ_WTMK_LVL_WATERMARK_MASK (0x000000FFu)
#define CSL_SGCP_CFG_WTQ_WTMK_LVL_WATERMARK_SHIFT (0x00000000u)
#define CSL_SGCP_CFG_WTQ_WTMK_LVL_WATERMARK_RESETVAL (0x00000000u)

#define CSL_SGCP_CFG_WTQ_WTMK_LVL_RESETVAL (0x00000000u)

/* FILL */


#define CSL_SGCP_CFG_FILL_RESETVAL       (0x00000000u)

#endif
