/****************************************************************************\
 *           (C) Copyright 2009, Texas Instruments, Inc.                    *
 *                                                                          *
 *  Redistribution and use in source and binary forms, with or without      *
 *  modification, are permitted provided that the following conditions      *
 *  are met:                                                                *
 *                                                                          *
 *    Redistributions of source code must retain the above copyright        *
 *    notice, this list of conditions and the following disclaimer.         *
 *                                                                          *
 *    Redistributions in binary form must reproduce the above copyright     *
 *    notice, this list of conditions and the following disclaimer in the   *
 *    documentation and/or other materials provided with the                *
 *    distribution.                                                         *
 *                                                                          *
 *    Neither the name of Texas Instruments Incorporated nor the names of   *
 *    its contributors may be used to endorse or promote products derived   *
 *    from this software without specific prior written permission.         *
 *                                                                          *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS     *
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT       *
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR   *
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT    *
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,   *
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT        *
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,   *
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY   *
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT     *
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE   *
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    *
 ****************************************************************************
 *                                                                          *
 * Target processors : TMS320C66xx                                          *
 *                                                                          *
 \****************************************************************************/

//////////////////////////////////////////////////////////////////////////////
// Include Files

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <c6x.h>
#include <math.h>

#include <ti/csl/csl.h>
#include <ti/csl/csl_cache.h>
#include <ti/csl/csl_cacheAux.h>
#include <ti/csl/csl_xmcAux.h>

#include <ti/drv/aif2/aif2.h>
#include <ti/drv/cppi/cppi_drv.h>
#include <ti/drv/cppi/cppi_desc.h>
#include <ti/drv/qmss/qmss_drv.h>
#if EVM_TYPE == 3
#include <ti/platform/evmc6670l/platform_lib/include/evmc66x_pllc.h>
#endif

#if EVM_TYPE == 0
#include <EVM.h>
#endif

//include for GPIO
#include <ti/csl/csl_gpio.h>
#include <ti/csl/csl_gpioAux.h>

#include "cslUtils.h"
#include "mnavUtils.h"
#include "mathUtils.h"

#include <DSP_fft16x16.h>
#include <gen_twiddle_fft16x16.h>
#include <gen_twiddle_fft16x16.c>

#if EVM_TYPE == 5 || EVM_TYPE == 7
#include "appletonScbpSync.h"
#endif

// SPECIAL_SEQUENCE of 1 only used for extensive RF tests on CPRI relay setups, only SPECIAL_SEQUENCE=0 tested upon AIF2 LLD release
#ifndef		SPECIAL_SEQUENCE
#define     SPECIAL_SEQUENCE    0
#endif

// RF test vectors for RF verification
#if SPECIAL_SEQUENCE == 2
#if CPRI_RELAY_RATE == 20
#include "LTEFDD_TM3p1_20M_CellID1.c"
#elif CPRI_RELAY_RATE == 10
#include "LTEFDD_TM3p1_10M_CellID1.c"
#elif CPRI_RELAY_RATE == 5
#include "LTEFDD_TM3p1_5M_CellID1.c"
#endif
#endif
#if  SPECIAL_SEQUENCE == 3
#if CPRI_RELAY_RATE == 20
#include "LTEFDD_TM1p1_20M_CellID1.c"
#elif CPRI_RELAY_RATE == 5
#include "LTEFDD_TM1p1_5M_CellID1.c"
#endif
#endif
#if  SPECIAL_SEQUENCE == 4
#include "LTETDD_1x20_64QAM_PN9_ID1.c"
#endif
/* TEST DESCRIPTION
 * This CPRI LTE Check RF test is designed to work either in internal loopback mode, or with a dual EVM setup connected with a break-out card, or with a
 * CPRI Relay setup (tci6614 evm + scbp + tsw3726), or with a Scbp/Tsw3726 standalone setup.
 * The default project configurations in the pdk-generated workspace are supporting:
 * - EVM_LBACK: test compiled for internal loopback mode. Can be used with device simulators as well.
 * - EVM6614: test compiled for CPRI Relay setup and run in RF loopback mode (rx1/rx2 and tx1/tx2 on tsw3726 are connected together)
 * - SCBP_DSP1: test compiled for Scbp/Tsw3726 standalone setup and run in RF loopback mode (rx1/rx2 and tx1/tx2 on tsw3726 are connected together)
 * - EVM6670_DSP1 and EVM6670_DSP2: test compiled for first and second EVMs of a dual EVM setup connected with a break-out card
 *
 * This CPRI LTE Check RF test runs on a single link of AIF2 and configures 2 AxCs. Both AxCs IQ data are pure single or dual tone sinewaves at given frequencies,
 * such that upon reception of LTE symbols for both antennas, IQ data can be checked with fft software. If the signal doesn't go from digital to analog and back, it
 * can also be checked bitwise.
 *
 * Pre-processing constants of interest:
 * - SUPERPACKET: must be defined if using early versions (<2.0, note most EVMs are equipped with 1.0, correcting Advisory 12) of c6670. Not needed on tci6614
 * - CPRI_RELAY_CFG: Set it to 1 as default. Set to 2 if testing towards tsw3726 RF board.
 * - CPRI_RELAY_RATE: selects the LTE rate to be used. Values: 5, 10, or 20
 * - EVM_TYPE: 1 - KeyStone-I internal loopback or EVM DSP1 (dual EVM setup), 2 - EVM DSP2 (dual EVM setup), 3 - SCBP DSP1, 5 - EVM6614 (Cpri Relay setup), (0 - old Lyrtech C6670 EVM)
 *             6 - KeyStone-II internal loopback (EVM), 7 - EVM6638K2K (Cpri Relay setup), 8 - EVM6638K2K (Drboc+Marconi setup)
 * - LOOPBACK: selects internal loopback mode (SerDes level, AIF2 SW trigger)
 *
 * Note on usage with CPRI relay setup:
 * 		0. FPGA firmware upgrades:
 *          a. Scbp board must be upgraded to the proper SCBP FPGA LTE version for the given LTE rate of interest.
 *          b. Tci6614 EVM boards must be upgraded to v0004 of Fpga firmware
 * 		1. In order to run the CPRI relay test, go to the SCBP CPRI relay web interface and run the following config:
 * 			a. For the CPRI relay loopback (loopback on the link0 through Scbp FPGA, CPRI_RELAY_CFG=1):
 * 				- click on "Relay Init" to configure the pll with the 10Mhz reference clock, enable the SFP and SPI port.
 * 				- Run the "relay LOOPBACK" button to configure the link0 for internal loopback in FPGA.
 * 				- Load and run the code on the Appleton DSP.
 * 			b. For the CPRI relay going through TI's RF (CPRI_RELAY_CFG=2), the radio needs to be configured as well as SCBP FPGA:
 * 				- click on "Radio Init"
 * 				- click on "Relay Init" to configure the pll with the 10Mhz reference clock, enable the SFP and SPI port.
 * 				- load and run the Appleton code.
 * 				- when the boards are synchronized (after few seconds), do a Radio ON to enable the radio.
 *
 *		In case of Cpri relay setup, the reference clock use to synchronize both board is a 10Mhz clock at 3.3V connected to the SCBP.
 *		Then the SCBP generate a 16Hz pps signal that will be used by the Tci6614 board to synchronize with SCBP via the BoardsSync function.
 *
 * Note on Lte Symbol packet descriptors
 * 14 symbols of an AxC subframe time are contained in 14 different monolithic descriptors. The pure single or dual tone sinewaves are generated in a continuous manner
 * across the payload of the 14 symbols of a particular AxC. The test is configured to work at the granularity of a Lte slot. For LTE, AIF2 requires usage of monolithic
 *  descriptor packets with a 16-byte header. In the header, a protocol specific word is required to indicate the antenna carrier number, the symbol number and the direction
 *  (Ingress/Egress). That means that every 0.5 ms, the test will push and pop from the AIF2 HW queues:
 * 7 symbols * numAxCs per link * numLinks * 2 (for Egress/Ingress traffic)
 * This then makes a total of 56 outstanding monolithic packets in the case of LTE 20MHz / 2 AxCs / 1 Links / both directions
 * When defining a descriptor memory region, the following rules apply:
 * - Descriptor size is multiple of 16 bytes, min 32.
 * - Descriptor count is a power of 2, minimum 25.
 * - Memory region base address must be aligned to a 16-byte address boundary.
 * Here are some considerations regarding PktDMA traffic:
 * 		- For Egress, it is up to the user to insure that DMA data is available prior to beginning PE message construction (PE2 event). Breaking real time on DMA has
 * 		similar effects to breaking CorePac MIPS real time. Specifically, AIF2 will fail each affected AxC until the beginning of the next radio frame boundary.
 * 		- For Ingress, it is important that DMA is efficient enough that the AIF2 input	buffers never overflow.
 */


////////////////////////////////////////////////////////////////////////////////
// Constant definitions

#define     TRIG_TIMER          0 	// Used to start AIF2 timers, Frame sync with one shot pulse - could be any timer
#if defined(DEVICE_K2K) || defined(DEVICE_K2H)
#define 	SYNC_TIMER			8
#else
#define     SYNC_TIMER          5	// Used to call the SW PLL periodically - Cpri relay setup only - could be an OS PRD thread as well
#endif
#define     PLL_TIMER           4	// Used by the SW PLL for adjustments against the external 16Hz clock - Cpri relay setup only - could be any timer

//Value for Sin calculation
#if CPRI_RELAY_CFG == 1
#define     Q_FACTOR            511		// When the signal stays digital, reducing Q factor to avoid overflow in fft software
#else
#define     Q_FACTOR            2047 	// 8191
#endif
#if CPRI_RELAY_RATE == 20
#define     SAMP_FREQ_FLOAT     30.72 	// LTE20 sample rate
#elif CPRI_RELAY_RATE == 10
#define     SAMP_FREQ_FLOAT     15.36	// LTE10 sample rate
#elif CPRI_RELAY_RATE == 5
#define     SAMP_FREQ_FLOAT     7.68	// LTE5 sample rate
#else
#error 		"CPRI_RELAY_RATE not valid."
#endif
#define     PI                  3.14159265358979323846



#define     TEST_NUM            2	// Number of test configurations
#define 	_CSL_AIF2_DUMP		0	// Enable the DUMP of the AIF configuration, for debug purposes
#if CPRI_RELAY_RATE == 20
#define     NBCHANNELMAXPERLINK 2	// Max number of AxCs per link
#elif CPRI_RELAY_RATE == 10
#define     NBCHANNELMAXPERLINK 4	// Max number of AxCs per link
#elif CPRI_RELAY_RATE == 5
#define     NBCHANNELMAXPERLINK 8	// Max number of AxCs per link
#endif
#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3
#define     NBCHANNELPERLINK	NBCHANNELMAXPERLINK	// Number of AxCs in use per link (fixed to max for this rf test)
#else
#define     NBCHANNELPERLINK	2	                // Number of AxCs in use per link (fixed to 2)
#endif
#define     NBSYMBOL			AIF2_LTE_SYMBOL_NUM	// Number of symbols per slot
#if CPRI_RELAY_RATE == 20
#define		LTESYMBOLSIZE		((AIF2_LTE20_FFT_SIZE+AIF2_LTE20_CYPRENORMAL1_SIZE)*4 + 16)    // 8848: FFT size + CP first
#define 	LTESYMBOL2SIZE		((AIF2_LTE20_FFT_SIZE+AIF2_LTE20_CYPRENORMAL_SIZE)*4 + 16)     // 8784: FFT size + CP 2nd-6th
#define		FFT_SIZE			AIF2_LTE20_FFT_SIZE
#define		CYPRENORMAL1_SIZE	AIF2_LTE20_CYPRENORMAL1_SIZE
#define		CYPRENORMAL_SIZE	AIF2_LTE20_CYPRENORMAL_SIZE
#elif CPRI_RELAY_RATE == 10
#define		LTESYMBOLSIZE		((AIF2_LTE10_FFT_SIZE+AIF2_LTE10_CYPRENORMAL1_SIZE)*4 + 16)    
#define 	LTESYMBOL2SIZE		((AIF2_LTE10_FFT_SIZE+AIF2_LTE10_CYPRENORMAL_SIZE)*4 + 16)
#define		FFT_SIZE			AIF2_LTE10_FFT_SIZE
#define		CYPRENORMAL1_SIZE	AIF2_LTE10_CYPRENORMAL1_SIZE
#define		CYPRENORMAL_SIZE	AIF2_LTE10_CYPRENORMAL_SIZE
#elif CPRI_RELAY_RATE == 5
#define		LTESYMBOLSIZE		((AIF2_LTE5_FFT_SIZE+AIF2_LTE5_CYPRENORMAL1_SIZE)*4 + 16)
#define 	LTESYMBOL2SIZE		((AIF2_LTE5_FFT_SIZE+AIF2_LTE5_CYPRENORMAL_SIZE)*4 + 16)
#define		FFT_SIZE			AIF2_LTE5_FFT_SIZE
#define		CYPRENORMAL1_SIZE	AIF2_LTE5_CYPRENORMAL1_SIZE
#define		CYPRENORMAL_SIZE	AIF2_LTE5_CYPRENORMAL_SIZE
#endif

#ifdef SUPERPACKET
#define		NBCHANNELINIT		NBCHANNELMAXPERLINK	// In superpacket mode, multiple Lte symbols received within the same Rx monolithic packet
#else
#define		NBCHANNELINIT		1
#endif

#if EVM_TYPE == 0 || EVM_TYPE == 3 || EVM_TYPE == 5 || EVM_TYPE == 6 || EVM_TYPE == 7 || EVM_TYPE == 8
//#define     DESCMSM				1			// Putting packet descriptors in internal MSM
//#else
#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
#define     DESCMSM				0			// else going to DDR
#else
#define     DESCMSM				1			// keep in MSM
#endif
#endif
#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
#if CPRI_RELAY_RATE == 20
#define		NBDESCMAX			1024          // Descriptor count rounded to the next power of 2
#elif CPRI_RELAY_RATE == 10
#define		NBDESCMAX			2048          // Descriptor count rounded to the next power of 2
#elif CPRI_RELAY_RATE == 5
#define		NBDESCMAX			4096          // Descriptor count rounded to the next power of 2
#endif
#else
#if CPRI_RELAY_RATE == 20
#define		NBDESCMAX			64          // Descriptor count rounded to the next power of 2
#elif CPRI_RELAY_RATE == 10
#define		NBDESCMAX			128          // Descriptor count rounded to the next power of 2
#elif CPRI_RELAY_RATE == 5
#define		NBDESCMAX			256          // Descriptor count rounded to the next power of 2
#endif
#endif
#define		MAX_DEBUG_SLOT		400			// For debug, size of monitoring arrays
#if EVM_TYPE == 0 || EVM_TYPE == 3
#define     SYSCLK_INPUT_KHZ    153600  	// on Lyrtech and Scbp EVM, the Frequency is based on an external 153.60 MHz clock
#else
#define     SYSCLK_INPUT_KHZ    122880  	// on Advantech EVM , the Frequency is based on an external 122.88 MHz clock
#endif

#define     DIO_0               CSL_AIF2_DIO_ENGINE_0 // DIO engines are not used in LTE mode - instead PKTDMA and HW queues are used to carry the antenna data from/to AIF2

#define 	MONO_RX_FDQ         2012 //9030 //2012 // Define Rx queue base index for ingress traffic and the associated Rx free descriptor queue base index
#define 	MONO_RX_Q           1000 //9040

#define 	RX_SUCCESS_CNT		32000 // Define a number of consecutive runtime RF check success prior to monitoring runtime failures

#define 	FREQ				1.0
#define     PEAK_LOC_2MHZ		(FFT_SIZE/SAMP_FREQ_FLOAT*FREQ*2) // Used for peak detection after fft on Rx symbols  - 2048/30.72*2MHz, same for Lte5 or Lte10
#define 	PEAK_LOC_1MHZ		(FFT_SIZE/SAMP_FREQ_FLOAT*FREQ)   // Used for peak detection after fft on Rx symbols  - 2048/30.72*1MHz, same for Lte5 or Lte10
#define		N   (2048)											  // Used for twiddle factor generation
#define 	PAD (16)											  // Used for twiddle factor generation

#define SLOT_NUM_FIRST_PUSH	100  			// The first push needs to happen on the last slot number before frame boundary
#if CPRI_RELAY_CFG == 2
#define SLOT_NUM_DATA_CHECK	150002 			// If testInfo.never_end == 0, test stops after this amount of Lte slots
#else
#define SLOT_NUM_DATA_CHECK	7502			// If testInfo.never_end == 0, test stops after this amount of Lte slots
#endif

#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
#define	NBSF	10
#else
#define	NBSF	1
#endif

#define USEPATTERN 2
#define TM 1
#define RAMP 0

//////////////////////////////////////////////////////////////////////////////
// Typedefs

typedef struct {
	Int16 re;
	Int16 im;
	} Complex16;

typedef struct {
        // Test name
        const unsigned char name[32];
        //AIF link enable or disable, 1 or 0
        Uint32                   linkEnable[AIF_MAX_NUM_LINKS];
        //AIF link rate (1=1x; 2=2x; 4= 4x).
        Uint32                   linkRate[AIF_MAX_NUM_LINKS];
        //AIF link data type for outbound burst traffic.
        CSL_Aif2LinkDataType     outboundDataType[AIF_MAX_NUM_LINKS];
        //AIF link data width for outbound burst traffic.
        CSL_Aif2DataWidth        outboundDataWidth[AIF_MAX_NUM_LINKS];
        //AIF link data type for inbound burst traffic.
        CSL_Aif2LinkDataType     inboundDataType[AIF_MAX_NUM_LINKS];
        //AIF link data width for inbound burst traffic.
        CSL_Aif2DataWidth        inboundDataWidth[AIF_MAX_NUM_LINKS];
        //AIF link DIO engine used
        CSL_Aif2DioEngineIndex   dioEngine[AIF_MAX_NUM_LINKS];
        } TestObj;

typedef struct {
	    		Int32	magic;
	    		Int32   revision;
	const 		Int32 	type;
	const		Int32	loopback;
	volatile 	Int32	test_case;
	volatile	Int32	capture_requested;
	volatile	Int32	never_end;
	volatile 	Int32	use_cio;
				Int32	error_condition;
	volatile	Int32	force_stop;
				} test_info_t;

typedef struct {
				Uint8	firstsymbol[LTESYMBOLSIZE  - 16];
				Uint8	othersymbol[6][LTESYMBOL2SIZE - 16];
	} lte_slot_t;

//////////////////////////////////////////////////////////////////////////////
// Global variables
AIF_ConfigObj               aifObj;					// Main AIF2 LLD object for AIF2 configuration
AIF_ConfigHandle            hConfigAif = &aifObj;

volatile unsigned int ntest = 0; 		// used for running multiple tests
volatile unsigned int testcheck = 1; 	// reports pass fail at the end of the test

#ifdef LOOPBACK
volatile unsigned int swSync        = 1;	// AIF2 SW trigger
volatile unsigned int intLoopback   = 1;	// SerDes loopback mode
#else
volatile unsigned int intLoopback   = 0;
#if EVM_TYPE == 3 || EVM_TYPE == 8
volatile unsigned int swSync        = 1;
#else
volatile unsigned int swSync        = 0;
#endif
#endif

volatile unsigned char testEnable[TEST_NUM] =
    {
#if EVM_TYPE == 5 || EVM_TYPE == 7 || EVM_TYPE == 8
        1,     // CPRI 4x - Link 3 is used on CPRI relay setup to connect TCI6614 EVM and SCBP via SFP
        0
#else
        0,     // CPRI 4x - Link 0
		1
#endif
    };

volatile TestObj                     testObjTab[TEST_NUM] = {
	{//1st configuration - CPRI 4x - Link 3 is used on CPRI relay setup to connect TCI6614 EVM and SCBP via SFP
#if CPRI_RELAY_RATE == 20
	  "LTE_RELAY_20MHZ_RF_SINGLE_TONE", // test name
#elif CPRI_RELAY_RATE == 10
	  "LTE_RELAY_10MHZ_RF_SINGLE_TONE", // test name
#elif CPRI_RELAY_RATE == 5
	  "LTE_RELAY_5MHZ_RF_SINGLE_TONE", // test name
#endif
	 // link0          link1          link2          link3          link4          link5
	  {0,             0,             0,             1,             0,             0            },  // link enable
	  {4,             4,             4,             4,             4,             4            },  // link rate
	  {DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL },  // outboundDataType
	  {DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15},  // outboundDataWidth
	  {DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL },  // inboundDataType
	  {DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15},  // inboundDataWidth
	  {DIO_0,         DIO_0,         DIO_0,         DIO_0,         DIO_0,         DIO_0},          // not applicable for LTE test
	},
	{//2nd configuration - CPRI 4x - Link 0
#if CPRI_RELAY_RATE == 20
	  "LTE_RELAY_20MHZ_RF_SINGLE_TONE", // test name
#elif CPRI_RELAY_RATE == 10
	  "LTE_RELAY_10MHZ_RF_SINGLE_TONE", // test name
#elif CPRI_RELAY_RATE == 5
	  "LTE_RELAY_5MHZ_RF_SINGLE_TONE", // test name
#endif
	 // link0          link1          link2          link3          link4          link5
	  {0,             0,             0,             0,             1,             0            },  // link enable
	  {4,             4,             4,             4,             4,             4            },  // link rate
	  {DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL },  // outboundDataType
	  {DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15},  // outboundDataWidth
	  {DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL,  DATA_TYPE_DL },  // inboundDataType
	  {DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15, DATA_WIDTH_15},  // inboundDataWidth
	  {DIO_0,         DIO_0,         DIO_0,         DIO_0,         DIO_0,         DIO_0},          // not applicable for LTE test
	}
   };

/* Monolithic descriptor region for all outstanding symbols in a subframe (1ms)
 * Region base address is 16-byte aligned. (aligning to a L1D 64-byte cache line boundary)
 * The linker will place this >1MBytes buffer in internal shared memory (MSM)
 * symbolcount size is 8.8K bytes for Normal cyclic prefix 20 MHz LTE
 */
#if DESCMSM == 1
#pragma DATA_SECTION(mono_region_test,".aifdescmsm");
#else
#pragma DATA_SECTION(mono_region_test,".aifdescddr");
#endif
#pragma DATA_ALIGN (mono_region_test, 64);
Uint8   mono_region_test[NBDESCMAX * LTESYMBOLSIZE * NBCHANNELINIT];

/*
 * Buffers storing TX and RX symbols for debug and verification
 */
#pragma DATA_SECTION(txSamples,".aifrawtx");
Uint8   	txSamples[NBCHANNELPERLINK][NBSYMBOL*2][LTESYMBOLSIZE - 16];
#pragma DATA_SECTION(rxSamples,".aifrawrx");
Uint8   	rxSamples[NBCHANNELPERLINK][NBSYMBOL*2][LTESYMBOLSIZE - 16];
#pragma DATA_SECTION(rxSlots,".aifrxcapture");
lte_slot_t  rxSlots[NBCHANNELPERLINK][20]; // can capture up to 10ms per channel

#pragma DATA_SECTION(testInfo,".aifcaptcmd");
test_info_t	testInfo = 	{
		0x50CCA06F, 		//magic;
		0x00000000, 		//revision;
		SPECIAL_SEQUENCE, 	//type;
		#ifdef LOOPBACK
		1, 					//loopback;
		#else
		0, 					//no loopback;
		#endif
		-1, 				//test_case;
		0, 					//capture_requested;
		#if EVM_TYPE == 3
		1, 					//never_end;
		#else
		0, 					//no never_end;
		#endif
		1,					//use_cio
		0, 					//error_condition
		0,					//force_stop
};

Uint32  capture_ongoing   = 0;

/*
 * Variables used for RF checks
 */
Uint8   rxBuffer[NBCHANNELPERLINK+1][LTESYMBOLSIZE-16]; // MUST BE IN LL2 to enable HW cache coherency
Uint8   rxCheck[NBCHANNELPERLINK][NBSYMBOL];			// Keeps track of current check of all LTE symbols on a slot per AxC
Uint16  rxRuntimeFail[NBCHANNELPERLINK][NBSYMBOL];		// Keeps track of the number of failures per LTE symbols on a slot per AxC
Uint8   rxCheckCnt=0;									// Counter
Uint16  rxRuntimeSuccess=0;								// Counter

/*
 *	Variables used fft software
 */
#pragma DATA_ALIGN(twiddleFacts, 8);
Int16   twiddleFacts[2*N + 2*PAD];


#pragma DATA_SECTION(symbolPkt,".aifrawrx");
/*
 * Define an array that can contain all descriptor addresses.
 * This way, all packets can be popped from the FDQ and prepared at once for the purpose of this test.
 */
Cppi_MonolithicDesc* symbolPkt[NBCHANNELMAXPERLINK][NBSYMBOL*2*NBSF];

/* Storing first sample of each packet to check packet sequence at runtime */
Complex16 firstSample[NBCHANNELMAXPERLINK][NBSYMBOL*2*NBSF];

/*
 * Define Rx flows for AIF2 ingress traffic
 * The flow will tell AIF2 from which FDQ to pop new symbol descriptors
 */
Cppi_RxFlowCfg rxFlow[AIF_MAX_NUM_LINKS][NBCHANNELMAXPERLINK];

/* Variables for test purposes */
Uint32 nbchanneltotal    = NBCHANNELPERLINK; // Default to 1 link
#ifdef SUPERPACKET
Uint32 nbchannelSuperPacket = 1;             // Default is 1 AxC for a super packet
#else
Uint32 nbchannelSuperPacket = NBCHANNELPERLINK;
#endif
Uint32   activeLink;						// link configured at test init time

/*
 * Slot and symbolcount counters - some used for debug purposes
 */
volatile Uint32 slotcount = 0;
volatile Uint32 symbolcount = 0;
#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
volatile Uint32 packets_already_pushed = 1;
#else
volatile Uint32 packets_already_pushed = 0;
#endif
volatile Uint32 aif2SymbolEgressCount[MAX_DEBUG_SLOT];
volatile Uint32 aif2SymbolIngressCount[MAX_DEBUG_SLOT];
volatile Uint32 getCpuTimestamp[MAX_DEBUG_SLOT];
volatile Uint32 getPhyTimerFrames[MAX_DEBUG_SLOT];
volatile Uint32 getPhyTimerClk[MAX_DEBUG_SLOT];
volatile Uint32 getRxPktCnt[MAX_DEBUG_SLOT]; // for first channel
volatile Uint32 rxPktCnt[NBCHANNELPERLINK * 2]; // assuming 2 link max
unsigned char 	saveDesc[NBCHANNELPERLINK][14][32];
volatile Uint32 dbgslotcount = 0;
volatile Uint32 rxSymNum;
volatile Uint32 rxCaptureNum = 0;

/*
 * Flag used for printing out exceptions at the end of the test.
 * Please note that exceptions are always enabled during this test.
 * Having AIF2 exceptions reported during this test should be considered as a test failure.
 *
 */
Uint32 printexceptions = 1;

//////////////////////////////////////////////////////////////////////////////
// References to external variables

extern Uint8		   keepAifOff;
extern Uint8		   keepStartupDelay;
extern int 		       PEAKDEBUG;
extern Uint32 		   eeLastCpriLossInFrame;
#if SPECIAL_SEQUENCE == 1
// test vectors
extern Uint32 txSeqOdd[2048];
extern Uint32 txSeqEven[2048];
extern Uint32 txSeq1MHz[3072];
extern Uint32 txSeqImd[3072];
extern Uint32 txSeqNoComb[2048];
extern Uint32 txSeqWideBand[2048];
#endif

//////////////////////////////////////////////////////////////////////////////
// Function prototypes

#if _CSL_AIF2_DUMP == 1
void dump_CSL_Aif2Setup (FILE *output, CSL_Aif2Setup *value);
#endif
void getcomplex(Complex16* payload,Uint32 index,Uint32 tx);
#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
void getTMdata(Complex16* payload,Uint32 tx);
void testPattern(Complex16* payload, Uint32 index, Uint32 tx);
#endif
#if SPECIAL_SEQUENCE == 1
void getcomplex1(Complex16* payload,Uint32 index, Uint32 testType1);
#endif

//////////////////////////////////////////////////////////////////////////////
// Function bodies

/*
 * User Isr that is called from pre-defined Isr in cslUtils.c, called every Lte slot
 */
void slotIsr()
{
	Int32                i,chan;
	Uint32               rxSymCnt, payloadLen, *payloadPtr;
	Cppi_MonolithicDesc *ptrMonoDesc;
	Complex16			*checkPtr;

	slotcount++;dbgslotcount++;
	getCpuTimestamp[dbgslotcount]     = TSCL;
	getPhyTimerFrames[dbgslotcount]   = aifObj.hCsl->regs->AT_PHYT_FRM_VALUE_LSBS;
	getPhyTimerClk[dbgslotcount]      = aifObj.hCsl->regs->AT_PHYT_CLKCNT_VALUE;

	if (slotcount == (SLOT_NUM_FIRST_PUSH - 20))
	{
		for(chan = 0; chan < nbchannelSuperPacket; chan++)
		{
			AIF_enablePdCh(&aifObj,chan);
		}
	}

	/*
	 * Rx packet recycling until final check, we need available descriptors in Rx FDQs when actual data is pushed
	 */
	if ((slotcount < SLOT_NUM_DATA_CHECK) || (testInfo.never_end == 1))
	{

		for(chan = 0; chan < nbchannelSuperPacket; chan++)
		{
			rxSymCnt = Qmss_getQueueEntryCount(aifObj.pktDmaConfig.rxQAxC[chan]);

			for(i=0;i<rxSymCnt;i++)
			{
				  ptrMonoDesc = (Cppi_MonolithicDesc *)QMSS_DESC_PTR(Qmss_queuePop(aifObj.pktDmaConfig.rxQAxC[chan]));
				  // Invalidate symbol packet header and get the updated payload address + length
				  CACHE_invL1d((void *)ptrMonoDesc, 16, CACHE_WAIT);
				  Cppi_getData (Cppi_DescType_MONOLITHIC, (Cppi_Desc*)ptrMonoDesc, (Uint8**)&payloadPtr, &payloadLen);

				   // Store Rx symbol number
				   rxSymNum = *(((Uint32*)ptrMonoDesc) + 3);
				   rxSymNum = (rxSymNum>>7)&0x000000FF;

				  if((rxPktCnt[chan]%NBSYMBOL) == 0)
				  {
						//check payload length for first symbol
						if (payloadLen != ((LTESYMBOLSIZE-16)*NBCHANNELINIT)) {
							UTILS_aif2ExceptIntDisable();
							slotcount = SLOT_NUM_DATA_CHECK  + DSP_procId;
							testInfo.never_end = 0;
							testInfo.error_condition = -1;
							printf("FATAL: unexpected payload length:%d, %d\n",((LTESYMBOLSIZE-16)*NBCHANNELINIT),payloadLen);
							AIF_printException(&aifObj);
						}

						if (rxCheckCnt == 0) {
#ifdef SUPERPACKET
							UTILS_deinterleaveLteSuperPacket((Uint32 *)payloadPtr, (Uint32 *)rxBuffer[0], \
													 (Uint32) aifObj.linkConfig[activeLink].cpriPackMode, aifObj.linkConfig[activeLink].numPeAxC, (LTESYMBOLSIZE-16));
							UTILS_deinterleaveLteSuperPacket((Uint32 *)(payloadPtr + aifObj.linkConfig[activeLink].cpriPackMode), (Uint32 *)rxBuffer[1], \
													 (Uint32) aifObj.linkConfig[activeLink].cpriPackMode, aifObj.linkConfig[activeLink].numPeAxC, (LTESYMBOLSIZE-16));
#else
							CACHE_invL1d((void *)payloadPtr, (LTESYMBOLSIZE-16), CACHE_WAIT);
#if SPECIAL_SEQUENCE == 0
							memcpy(&rxBuffer[chan][0],(Uint32 *) payloadPtr, (LTESYMBOLSIZE-16));
#endif
						}
						if (rxCaptureNum == 0)
						{
#if EVM_TYPE == 6 || EVM_TYPE == 8
							if (capture_ongoing) {
								UTILS_triggerEdmaSampleCapt(chan,(Uint32 *)&rxSlots[chan][rxSymNum/NBSYMBOL].firstsymbol[0] ,(Uint32 *)payloadPtr, (LTESYMBOLSIZE-16));
							}
#endif
#endif
						}


				  } else {
						//check payload length for the other 6 symbols
						if (payloadLen != ((LTESYMBOL2SIZE-16)*NBCHANNELINIT)) {
							UTILS_aif2ExceptIntDisable();
							slotcount = SLOT_NUM_DATA_CHECK  + DSP_procId;
							testInfo.never_end = 0;
							testInfo.error_condition = -1;
							printf("FATAL: unexpected payload length:%d, %d\n",((LTESYMBOL2SIZE-16)*NBCHANNELINIT),payloadLen);
							AIF_printException(&aifObj);
						}

						if (rxCheckCnt == (rxPktCnt[chan]%NBSYMBOL)) {
#ifdef SUPERPACKET
							UTILS_deinterleaveLteSuperPacket((Uint32 *)payloadPtr, (Uint32 *)rxBuffer[0], \
													 (Uint32) aifObj.linkConfig[activeLink].cpriPackMode, aifObj.linkConfig[activeLink].numPeAxC, (LTESYMBOL2SIZE-16));
							UTILS_deinterleaveLteSuperPacket((Uint32 *)(payloadPtr + aifObj.linkConfig[activeLink].cpriPackMode), (Uint32 *)rxBuffer[1], \
													 (Uint32) aifObj.linkConfig[activeLink].cpriPackMode, aifObj.linkConfig[activeLink].numPeAxC, (LTESYMBOL2SIZE-16));
#else
							CACHE_invL1d((void *)payloadPtr, (LTESYMBOL2SIZE-16), CACHE_WAIT);
#if SPECIAL_SEQUENCE == 0
							memcpy(&rxBuffer[chan][0],(Uint32 *) payloadPtr, (LTESYMBOL2SIZE-16));
#endif
						}
						if (rxCaptureNum == (rxSymNum%NBSYMBOL))
						{
#if EVM_TYPE == 6 || EVM_TYPE == 8
							if (capture_ongoing) {
								UTILS_triggerEdmaSampleCapt(chan,(Uint32 *)&rxSlots[chan][rxSymNum/NBSYMBOL].othersymbol[(rxSymNum%NBSYMBOL)-1][0],(Uint32 *)payloadPtr, (LTESYMBOL2SIZE-16));
							}
#endif
#endif
						}
				  }
				  // recycle symbol packet on rx free queue
				  Qmss_queuePushDesc(aifObj.pktDmaConfig.rxFqAxC[chan], (Uint32*)ptrMonoDesc);
				  rxPktCnt[chan]++;
			}
		}
	}

	getRxPktCnt[dbgslotcount]      = rxPktCnt[0];

	/*
	 * In this Isr, at this slot, push all s7 ymbols for all AxCs, links at once
	 * It assumes that all symbolPkt were first popped from the FDQs, and properly populated.
	 * AIF2 will returned them in FDQs following the actual transmission via AIF2 protocol encoder.
	 * Note that AIF2 Rx PktDMA channels will starve for data checking since we don't perform
	 * Rx packet recycling at runtime. We don't keep pushing packets beyond a certain slot.
	 */
	if (!packets_already_pushed) {
		/* The first two slots we push the packets that have been initialized and are stored in symbolPkt[][]  */
		if((slotcount == SLOT_NUM_FIRST_PUSH) || (slotcount == (SLOT_NUM_FIRST_PUSH+1)))
		{
			for(i=symbolcount;i<(symbolcount + NBSYMBOL);i++)
			{
				for(chan = 0; chan < nbchanneltotal; chan++)
				{
					Cppi_getData (Cppi_DescType_MONOLITHIC, (Cppi_Desc*)symbolPkt[chan][i], (Uint8**)&payloadPtr, &payloadLen);
					checkPtr = (Complex16*)payloadPtr;
					if ((checkPtr->re != firstSample[chan][i].re) || (checkPtr->im != firstSample[chan][i].im)) {
						UTILS_aif2ExceptIntDisable();
						slotcount = SLOT_NUM_DATA_CHECK  + DSP_procId;
						testInfo.never_end = 0;
						testInfo.error_condition = -1;
						printf("FATAL: unexpected first sample in this packet\n");
						AIF_printException(&aifObj);
					}
					Qmss_queuePushDesc((aifObj.pktDmaConfig.txQAxC[chan]), (Uint32*)symbolPkt[chan][i]);
				}
			}
			symbolcount += NBSYMBOL;
			if (symbolcount == AIF2_LTE_FRAME_SYMBOL_NUM) symbolcount = 0;
			if (slotcount == (SLOT_NUM_FIRST_PUSH+1)) {
				packets_already_pushed = 1;
				AIF_enableException(&aifObj); // From this point, exceptions counter will be incremented until Lte slot prior to data check
			}
		}
	} else {
#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
		if(((slotcount >= (SLOT_NUM_FIRST_PUSH)) && ((slotcount < (SLOT_NUM_DATA_CHECK + (NBSF*2) - 2)) || (testInfo.never_end == 1))))
#else	
		if(((slotcount > (SLOT_NUM_FIRST_PUSH+1)) && (slotcount < SLOT_NUM_DATA_CHECK)) || (testInfo.never_end == 1))
#endif		
		{

			for(i=symbolcount;i<(symbolcount + NBSYMBOL);i++)
			{
				for(chan = 0; chan < nbchanneltotal; chan++)
				{
					// pop from AxC Tx free descriptor queue
					ptrMonoDesc = (Cppi_MonolithicDesc *)QMSS_DESC_PTR(Qmss_queuePop(aifObj.pktDmaConfig.txFqAxC[chan]));
					// Recreate PS data
					CACHE_invL1d((void *)ptrMonoDesc, 16, CACHE_WAIT);
					Cppi_getPSData (Cppi_DescType_MONOLITHIC, Cppi_PSLoc_PS_IN_DESC, (Cppi_Desc*)ptrMonoDesc, (Uint8**)&payloadPtr, &payloadLen);
					payloadPtr[0] = (Uint32 )(0x00008000 + chan + (i << 7));//add symbol number into PS field
					CACHE_wbL1d((void *)payloadPtr, 4, CACHE_WAIT); // writeback the updated PS data in MSM
					Cppi_getData (Cppi_DescType_MONOLITHIC, (Cppi_Desc*)ptrMonoDesc, (Uint8**)&payloadPtr, &payloadLen);
					checkPtr = (Complex16*)payloadPtr;
#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
					if ((checkPtr->re != firstSample[chan][i].re) || (checkPtr->im != firstSample[chan][i].im)) {
#else					
					if ((checkPtr->re != firstSample[chan][i%(2*NBSYMBOL)].re) || (checkPtr->im != firstSample[chan][i%(2*NBSYMBOL)].im)) {
#endif					
						UTILS_aif2ExceptIntDisable();
						slotcount = SLOT_NUM_DATA_CHECK  + DSP_procId;
						testInfo.never_end = 0;
						testInfo.error_condition = -1;
						printf("FATAL: unexpected first sample in this packet\n");
						AIF_printException(&aifObj);
					}
					memcpy(&saveDesc[chan][i%(2*NBSYMBOL)][0],ptrMonoDesc,32);
					Qmss_queuePushDesc((aifObj.pktDmaConfig.txQAxC[chan]), (Uint32*)ptrMonoDesc);
				}
			}
			symbolcount += NBSYMBOL;
			if (symbolcount == AIF2_LTE_FRAME_SYMBOL_NUM) symbolcount = 0;
			if (slotcount == (SLOT_NUM_DATA_CHECK-1)) UTILS_aif2ExceptIntDisable();
#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
			if (slotcount == (SLOT_NUM_FIRST_PUSH+1)) {
				AIF_enableException(&aifObj); // From this point, exceptions counter will be incremented until Lte slot prior to data check
			}
#endif
		}
	}

	if ((slotcount < (SLOT_NUM_DATA_CHECK-1)) || (testInfo.never_end == 1))
	{
#if SPECIAL_SEQUENCE == 0
		// Run-time RF checks
		if (rxCheckCnt == 0)
		{
			DSP_fft16x16(&twiddleFacts[PAD], FFT_SIZE, (Int16*)&rxBuffer[0][CYPRENORMAL1_SIZE*4], (Int16*)&rxBuffer[2][0]);
			if (checkSingleTone((Int16*)&rxBuffer[2][0],FFT_SIZE,PEAK_LOC_1MHZ,0))
			{
				rxCheck[0][0] = 1;
				if (rxRuntimeSuccess < RX_SUCCESS_CNT) rxRuntimeSuccess++;
			} else {
				rxCheck[0][0] = 0;
				if (rxRuntimeSuccess == RX_SUCCESS_CNT){
					rxRuntimeFail[0][0]++;
				}
				else rxRuntimeSuccess = 0;
			}
			DSP_fft16x16(&twiddleFacts[PAD], FFT_SIZE, (Int16*)&rxBuffer[1][CYPRENORMAL1_SIZE*4], (Int16*)&rxBuffer[2][0]);
			if (checkDualTone((Int16*)&rxBuffer[2][0],FFT_SIZE,PEAK_LOC_1MHZ, PEAK_LOC_2MHZ,1))
			{
				rxCheck[1][0] = 1;
				if (rxRuntimeSuccess < RX_SUCCESS_CNT) rxRuntimeSuccess++;
			} else {
				rxCheck[1][0] = 0;
				if (rxRuntimeSuccess == RX_SUCCESS_CNT) {
					rxRuntimeFail[1][0]++;
				}
				else rxRuntimeSuccess = 0;
			}
		} else {
			DSP_fft16x16(&twiddleFacts[PAD], FFT_SIZE, (Int16*)&rxBuffer[0][CYPRENORMAL_SIZE*4], (Int16*)&rxBuffer[2][0]);
			if (checkSingleTone((Int16*)&rxBuffer[2][0],FFT_SIZE,PEAK_LOC_1MHZ,0))
			{
				rxCheck[0][rxCheckCnt] = 1;
				if (rxRuntimeSuccess < RX_SUCCESS_CNT) rxRuntimeSuccess++;
			} else {
				rxCheck[0][rxCheckCnt] = 0;
				if (rxRuntimeSuccess == RX_SUCCESS_CNT) rxRuntimeFail[0][rxCheckCnt]++;
				else rxRuntimeSuccess = 0;
			}
			DSP_fft16x16(&twiddleFacts[PAD], FFT_SIZE, (Int16*)&rxBuffer[1][CYPRENORMAL_SIZE*4], (Int16*)&rxBuffer[2][0]);
			if (checkDualTone((Int16*)&rxBuffer[2][0],FFT_SIZE,PEAK_LOC_1MHZ, PEAK_LOC_2MHZ,1))
			{
				rxCheck[1][rxCheckCnt] = 1;
				if (rxRuntimeSuccess < RX_SUCCESS_CNT) rxRuntimeSuccess++;
			} else {
				rxCheck[1][rxCheckCnt] = 0;
				if (rxRuntimeSuccess == RX_SUCCESS_CNT) rxRuntimeFail[1][rxCheckCnt]++;
				else rxRuntimeSuccess = 0;
			}
		}
#endif		
		rxCheckCnt++;
		if (rxCheckCnt == NBSYMBOL) {
			rxCheckCnt = 0;
		}
		if (rxSymNum == (AIF2_LTE_FRAME_SYMBOL_NUM - 1))
		{
#if EVM_TYPE == 6 || EVM_TYPE == 8
			if ((testInfo.capture_requested==1) && (capture_ongoing==1)) {
				rxCaptureNum++;
				if (rxCaptureNum == NBSYMBOL)
				{
					capture_ongoing   = 0;
					testInfo.capture_requested = 0;
				}
			}
			if ((testInfo.capture_requested==1) && (capture_ongoing==0)) {
				rxCaptureNum      = 0;
				capture_ongoing   = 1;
			}
#endif
		}
	}

	/* PktDMA activity monitoring */
	aif2SymbolEgressCount[dbgslotcount]  = aifObj.hCsl->regs->DB_EDB_EOP_CNT;
	aif2SymbolIngressCount[dbgslotcount] = aifObj.hCsl->regs->AD_ISCH_EOP_CNT;
	// Make sure no overflow occurs on the monitoring arrays
	if (dbgslotcount == (MAX_DEBUG_SLOT-1)) dbgslotcount = 0;
}


int main(void)
{
    Uint32               idx, idx1, idx2, i, payloadLen, monoRxCount, monoTxCount, *payloadPtr2, nblink = 1, chan, rx_count, value,z;
    Uint16               testpass = 0, myboard	= EVM_TYPE;
	Complex16            *payloadPtr;
    Cppi_MonolithicDesc *mono_pkt;
    Qmss_Queue 			 descQueue;
    Cppi_DescTag 		 descTag;
    Qmss_Queue           queueInfo;
    Uint32               thisPiCaptured;

#if SPECIAL_SEQUENCE == 1
    Int32			     testType;
    Uint32			     idx1Max;
	Uint8                *txSamPtr0, *rxSamPtr0, *txSamPtr1, *rxSamPtr1;
    Int8                 verbTest[20];
    FILE                 *infile = NULL;
    FILE                 *outfile = NULL;
#endif
#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
	FILE                 *outfile = NULL;
#endif
#if (CPRI_RELAY_CFG == 1) && (SPECIAL_SEQUENCE == 0)
	Complex16            sampleCheck;
#endif
#if EVM_TYPE == 3
    PllcHwSetup pllc_hwSetup;
#endif
#ifdef SIMULATOR_SUPPORT
	printf ("\n Error: This example code does not run on the simulator.\n\n");
	return(0);
#endif

    /* Make shared memory (MSM) non cacheable for the purpose of testing */
    CSL_XMC_invalidatePrefetchBuffer();
    CACHE_setMemRegionInfo(12,1,0); // MAR12 - cacheable (always), not prefetchable
    CACHE_setMemRegionInfo(13,1,0); // MAR13 - cacheable (always), not prefetchable

    /* Make 3 * 16MB cacheable starting from 0xA1000000*/
    CACHE_setMemRegionInfo(161,1,0);// MAR161 - cacheable (always), not prefetchable
    CACHE_setMemRegionInfo(162,1,0);// MAR162 - cacheable (always), not prefetchable
    CACHE_setMemRegionInfo(163,1,0);// MAR163 - cacheable (always), not prefetchable

	CACHE_setL1DSize (CACHE_L1_32KCACHE);
	CACHE_setL1PSize (CACHE_L1_32KCACHE);

#if SPECIAL_SEQUENCE == 1
	while ((testInfo.test_case == -1) && (infile == NULL))
	{
	if (testInfo.use_cio == 1) outfile = fopen("outtest.dat","w");
    if (outfile) fclose(outfile);
    if (testInfo.use_cio == 1) infile  = fopen("intest.dat","r");
    if(infile == NULL)
    {
        //printf("Input test file doesn't exist");
    	while (testInfo.test_case == -1);
        testType = testInfo.test_case; /* default */
    }
    else
    {
        fscanf(infile,"%s%d",verbTest,&testType);
        fclose(infile);
    }

    if (testInfo.use_cio == 1) outfile = fopen("outtest.dat","a");
    if (outfile) fprintf(outfile,"%s%6d\n","Test type: ",testType);
    if (outfile) fclose(outfile);
    printf("%s%6d\n","Test type: ",testType);
    if(testType == 0) // zero signal
    {
        idx1Max = 1;
    }
    else if(testType == 1) // 1200 consecutive tones
    {
        idx1Max = sizeof(txSeqNoComb)/4;
    }
    else if(testType == 2) // 600 even tones
    {
        idx1Max = sizeof(txSeqEven)/4;
    }
    else if(testType == 3) // 600 odd tones
    {
        idx1Max = sizeof(txSeqOdd)/4;
    }
    else if(testType == 4)  // IMD tones: +/-1MHz
    {
        idx1Max = sizeof(txSeqImd)/4;
    }
    else if(testType == 5)  // Wide band signal
    {
        idx1Max = sizeof(txSeqWideBand)/4;
    }
    else if(testType == 10) /* 1MHz tone */
    {
        idx1Max = sizeof(txSeq1MHz)/4;
    }
    else /* Default: 1MHz tone */
    {
        idx1Max = sizeof(txSeq1MHz)/4;
    }
#endif
#if CPRI_RELAY_CFG == 1
    printf("Beginning AIF2 LTE CPRI relay Software testing\n");
#else
    printf("Starting AIF2 LTE CPRI relay Software\n");
#endif

    UTILS_waitForHw(100000);

    if (myboard == 0)  UTILS_configMasterSlave();
    else if (EVM_TYPE == 5) DSP_procId = 1;
	else if (EVM_TYPE == 6) DSP_procId = 1;
    else if (EVM_TYPE == 7) DSP_procId = 1;
    else if (EVM_TYPE == 8) DSP_procId = 1;
    else if (myboard <= 2)  DSP_procId = EVM_TYPE; // For Advantech: myboard  = 1 (DSP_1) or 2 (DSP_2)
    else DSP_procId = (Uint8)(EVM_TYPE - 2);       // For SCBP: myboard  = 3 (DSP_1) or 4  (DSP_2)

#if EVM_TYPE == 3
    /* Clear local data structures */
	memset(&pllc_hwSetup, 0, sizeof(PllcHwSetup));

	/* Setup PLLC hardware parameters */
	pllc_hwSetup.divEnable  = (CSL_BitMask32) (PLLC_DIVEN_PLLDIV2 |
											   PLLC_DIVEN_PLLDIV5 |
											   PLLC_DIVEN_PLLDIV8) ;

	/* Setup PLLC hardware parameters */
	pllc_hwSetup.pllM       = 16 -1;
	pllc_hwSetup.preDiv   = 1 - 1;
	pllc_hwSetup.pllDiv2  = 3 - 1;
	pllc_hwSetup.pllDiv5  = 5 - 1;
	pllc_hwSetup.pllDiv8  = 64 - 1;
	pllc_hwSetup.postDiv  = 2 -1;

	/* set Pll */
	CorePllcHwSetup(&pllc_hwSetup);
#endif

	// AIF2 LLD programs AT event 5 with period 0.5ms in case of LTE
	aif2evt5_userIsr = slotIsr;

	// Take AIF out of power saver
	AIF_enable();

#ifdef USE_SMA
	// disable link 0 on DSP_1
	testObjTab[ntest].linkEnable[3]  = 0;
	testObjTab[ntest].linkEnable[4]  = 1;
	activeLink = 4;
#endif

#if EVM_TYPE == 6 || EVM_TYPE == 8
	UTILS_openEdmaSampleCapt();
#endif

	// General parameters
	memset(&aifObj, 0, sizeof(aifObj));
	aifObj.aif2ClkSpeedKhz    = (Uint32)SYSCLK_INPUT_KHZ;
	aifObj.protocol           = CSL_AIF2_LINK_PROTOCOL_CPRI;
	aifObj.pktdmaOrDioEngine  = CSL_AIF2_CPPI;
	aifObj.mode               = AIF_LTE_FDD_MODE;
#ifdef SUPERPACKET
	aifObj.superPacket 		  = TRUE;
#else
	aifObj.superPacket 		  = FALSE;
#endif

	if (swSync == 0)
		aifObj.aif2TimerSyncSource= CSL_AIF2_PHYT_CMP_SYNC;
	else
		aifObj.aif2TimerSyncSource= CSL_AIF2_SW_SYNC;

    for(ntest=0;ntest<TEST_NUM;ntest++)
   	{
    	if (testEnable[ntest] == 1 )
    	{
    		chan 	= 0;
    		nblink 	= 0;
    		slotcount = 0;
    		symbolcount = 0;
    		dbgslotcount = 0;
#if SPECIAL_SEQUENCE == 1
    		packets_already_pushed = 0;
    		testcheck = 1;
#endif

			for (i=0;i<AIF_MAX_NUM_LINKS;i++)
			{
				if (testObjTab[ntest].linkEnable[i]==1 && (aifObj.linkConfig[i].RtEnabled==0))
				{
					nblink++;
					// PktDma parameters
					for (idx=0 ; idx<NBCHANNELPERLINK ; idx++)
					{
						aifObj.pktDmaConfig.txRegionAxC[chan]   = UTILS_getMemRegionNum(mono_region_test);
						aifObj.pktDmaConfig.txNumDescAxC[chan]  = NBSYMBOL*2*NBSF; // double num of Pkts
						aifObj.pktDmaConfig.txDescSizeAxC[chan] = LTESYMBOLSIZE;
						aifObj.pktDmaConfig.rxRegionAxC[chan]   = UTILS_getMemRegionNum(mono_region_test);
						aifObj.pktDmaConfig.rxNumDescAxC[chan]  = NBSYMBOL*2*NBSF; // double num of Pkts
						aifObj.pktDmaConfig.rxDescSizeAxC[chan] = LTESYMBOLSIZE*NBCHANNELINIT;

						memset(&rxFlow[i][idx], 0, sizeof(Cppi_RxFlowCfg));
						rxFlow[i][idx].rx_dest_qnum     = MONO_RX_Q+chan;
						rxFlow[i][idx].rx_fdq0_sz0_qnum = MONO_RX_FDQ+chan;
						rxFlow[i][idx].rx_desc_type     = (Uint8)Cppi_DescType_MONOLITHIC;    // MONO
						rxFlow[i][idx].rx_fdq1_qnum     = MONO_RX_FDQ+chan;
						rxFlow[i][idx].rx_fdq2_qnum     = MONO_RX_FDQ+chan;
						rxFlow[i][idx].rx_fdq3_qnum     = MONO_RX_FDQ+chan;
						rxFlow[i][idx].rx_sop_offset    = 12+4;   // desc header size for Monolithic packet with PS
						rxFlow[i][idx].rx_psinfo_present = 1;

						aifObj.pktDmaConfig.hRxFlowAxC[chan]   	= &rxFlow[i][idx];
						aifObj.pktDmaConfig.hRxFlowCtrl[chan]   = NULL;
						chan++;
					}
				} else {
					aifObj.pktDmaConfig.hRxFlowAxC[chan]    = NULL;
				}
			}
    		nbchanneltotal = NBCHANNELPERLINK*nblink;
    		memset(mono_region_test, 0, NBDESCMAX * LTESYMBOLSIZE * NBCHANNELINIT);
    		printf("Software configuration: %s\n", testObjTab[ntest].name);

    		// proceed with HW cleanup but may require GEL_AdvancedReset("System Reset") on PreFileLoaded callback for 100% robustness
    		UTILS_doCleanup(&aifObj,TRIG_TIMER);

			{
				aifObj.radTimerConfig[0].userSpecified                      = TRUE;
				aifObj.radTimerConfig[0].frameTerminalCount                 = 4096;
				if (swSync == 1)
					aifObj.radTimerConfig[0].initClockNum                       = 0;
				else
					aifObj.radTimerConfig[0].initClockNum                       = 2;
				aifObj.radTimerConfig[0].initSymbolNum                      = 0;
				aifObj.radTimerConfig[0].initFrameLsbNum                    = 0;
				aifObj.radTimerConfig[0].initFrameMsbNum                    = 0;
				aifObj.radTimerConfig[0].lte.cpType                         = AIF2_LTE_CPTYPE_NORMAL;
				aifObj.radTimerConfig[0].lte.numSymbolsForSymbolStrobe      = 1;
				aifObj.radTimerConfig[0].lte.numSymbolStrobesForFrameStrobe = 140;
			}

        	for (i=0;i<AIF_MAX_NUM_LINKS;i++)
        	{

				 aifObj.linkConfig[i].linkEnable         = testObjTab[ntest].linkEnable[i];
#ifdef SUPERPACKET
				 aifObj.linkConfig[i].numPeAxC			 = NBCHANNELMAXPERLINK;
				 aifObj.linkConfig[i].numPdAxC			 = NBCHANNELMAXPERLINK;
#else
				 if (testObjTab[ntest].linkEnable[i] == 1)
				 {
					 aifObj.linkConfig[i].numPeAxC			 = NBCHANNELPERLINK;
					 aifObj.linkConfig[i].numPdAxC			 = NBCHANNELPERLINK;
				 }
#endif
				 aifObj.linkConfig[i].linkRate           = (CSL_Aif2LinkRate)testObjTab[ntest].linkRate[i];
#if CPRI_RELAY_RATE == 20
				 aifObj.linkConfig[i].sampleRate		 = AIF_SRATE_30P72MHZ;
				 aifObj.linkConfig[i].cpriPackMode       = AIF2_LTE_CPRI_8b8;
#elif CPRI_RELAY_RATE ==10
				 aifObj.linkConfig[i].sampleRate		 = AIF_SRATE_15P36MHZ;
				 aifObj.linkConfig[i].cpriPackMode       = AIF2_LTE_CPRI_4b4;
#elif CPRI_RELAY_RATE ==5
				 aifObj.linkConfig[i].sampleRate		 = AIF_SRATE_7P68MHZ;
				 aifObj.linkConfig[i].cpriPackMode       = AIF2_LTE_CPRI_2b2;
#endif
				 aifObj.linkConfig[i].outboundDataType   = testObjTab[ntest].outboundDataType[i];
				 aifObj.linkConfig[i].outboundDataWidth  = testObjTab[ntest].outboundDataWidth[i];
				 aifObj.linkConfig[i].inboundDataType    = testObjTab[ntest].inboundDataType[i];
				 aifObj.linkConfig[i].inboundDataWidth   = testObjTab[ntest].inboundDataWidth[i];
				 aifObj.linkConfig[i].psMsgEnable        = 0;
				 if (intLoopback == 1 ) aifObj.linkConfig[i].comType = AIF2_LOOPBACK;
				 else	 				aifObj.linkConfig[i].comType = AIF2_2_AIF2;
				 aifObj.linkConfig[i].dioEngine          = testObjTab[ntest].dioEngine[i]; //NA for pkDMA
            }

			for (i= 0 ; i<AIF_MAX_NUM_LINKS; i++)
			{
				if (aifObj.linkConfig[i].linkEnable)
				{
					activeLink = i;
				}
			}

#if EVM_TYPE == 5 || EVM_TYPE == 7
				aifObj.linkConfig[activeLink].nodeTx      = 0;
				aifObj.linkConfig[activeLink].nodeRx      = 2;
#endif
#if EVM_TYPE == 8
				aifObj.linkConfig[activeLink].nodeTx      = 0;
				aifObj.linkConfig[activeLink].nodeRx      = 1;
#endif

    		if (DSP_procId == 1)
    		{
    			UTILS_initTimer(TRIG_TIMER);
    		}

    		// Interrupt initialization
    		UTILS_aifIntcSetup();

    		/* For SCBP-Appleton EVM run, we'll now proceed with SW clock sync */
#if EVM_TYPE == 5 // DSP_ProcId = 1
    		UTILS_boardsSync(SYNC_TIMER,PLL_TIMER); // required board sync process when using CPRI relay setups
#endif

			// Compute default AIF2 parameters given this user configuration
			AIF_calcParameters(&aifObj);

            // initialization function for qmss and cppi low-level drivers
            UTILS_initQmss((Uint32*)mono_region_test, NBDESCMAX, LTESYMBOLSIZE * NBCHANNELINIT, 0, NULL);

			// initialization of Pktdma and Qmss resources given this user configuration
			AIF_initPktDma(&aifObj);

			// Adjust AIF2 timing parameters if calcParameters didn't implement this LTE case or doesn't match the application Tx/Rx delays
#if EVM_TYPE == 5 || EVM_TYPE == 7
#if CPRI_RELAY_CFG == 2
				aifObj.linkConfig[activeLink].piMin += 20 + 64; // taking into account SCBP FPGA specific extra delay on Rx path when going thru RF
#endif
#endif
#if EVM_TYPE == 8
#if CPRI_RELAY_CFG == 1 || CPRI_RELAY_CFG == 2
				//aifObj.linkConfig[activeLink].piMin = 1500; //10100; // taking into account SCBP FPGA specific extra delay on Rx path when going thru RF
				aifObj.linkConfig[activeLink].piMin = 500; //10100; // taking into account SCBP FPGA specific extra delay on Rx path when going thru RF
#endif
#endif

			// initialization function for the AIF2 H/W CSL structure (can still be overridden afterwards)
			AIF_initHw(&aifObj);

			/*
			 *  LTE Tx packet symbol initialization at once
			 */

			for(chan = 0;chan < nbchanneltotal;chan++)
			{
				for (z=0;z<NBSF;z++) {
				idx1=0;
				for(idx = 0;idx < (NBSYMBOL*2);idx++)
				{
					symbolPkt[chan][idx] = (Cppi_MonolithicDesc *)QMSS_DESC_PTR(Qmss_queuePop(aifObj.pktDmaConfig.txFqAxC[chan]));
					mono_pkt = symbolPkt[chan][idx];

					//Create Mono packet
					Cppi_setDescType((Cppi_Desc *)mono_pkt,Cppi_DescType_MONOLITHIC);
					Cppi_setPacketType(Cppi_DescType_MONOLITHIC,(Cppi_Desc *)mono_pkt,0);
					Cppi_setDataOffset(Cppi_DescType_MONOLITHIC,(Cppi_Desc *)mono_pkt,16);

					if((idx%NBSYMBOL) == 0) {
						Cppi_setPacketLen(Cppi_DescType_MONOLITHIC,(Cppi_Desc *)mono_pkt,(LTESYMBOLSIZE-16));
					} else {
						Cppi_setPacketLen(Cppi_DescType_MONOLITHIC, (Cppi_Desc *)mono_pkt,(LTESYMBOL2SIZE-16));
					}

					Cppi_setPSFlags (Cppi_DescType_MONOLITHIC,(Cppi_Desc *)mono_pkt,1);
					Cppi_setPSLen(Cppi_DescType_MONOLITHIC,(Cppi_Desc *)mono_pkt,4);

					queueInfo = Qmss_getQueueNumber(aifObj.pktDmaConfig.txFqAxC[chan]);
					descQueue.qMgr = queueInfo.qMgr;
					descQueue.qNum = queueInfo.qNum;
					Cppi_setReturnQueue(Cppi_DescType_MONOLITHIC,(Cppi_Desc *)mono_pkt,descQueue);

					descTag.destTagHi = 0;					descTag.destTagLo = 0;
					descTag.srcTagHi  = 0;					descTag.srcTagLo  = 0;
					Cppi_setTag(Cppi_DescType_MONOLITHIC,(Cppi_Desc *)mono_pkt,&descTag);

					// Get payload address
					Cppi_getData (Cppi_DescType_MONOLITHIC, (Cppi_Desc*)mono_pkt, (Uint8**)&payloadPtr, &payloadLen);

					if((idx%NBSYMBOL) == 0)
					{
						 //payload data setup(first symbol)
						for (idx2 = 0; idx2 < (LTESYMBOLSIZE-16)/4; idx2 ++)
						{
							#if SPECIAL_SEQUENCE == 0
							getcomplex(&payloadPtr[idx2],idx1,chan);
							idx1++;
							#elif SPECIAL_SEQUENCE == 1
							getcomplex1(&payloadPtr[idx2],idx1,testType);
							idx1++;
							if(idx1 == idx1Max)
								idx1 = 0;
							#elif SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
								#if USEPATTERN == 1
									testPatternFPGA(&payloadPtr[idx2],idx1,chan);
								#elif USEPATTERN == 2
									getTMdata(&payloadPtr[idx2],chan);
								#endif										
								idx1++;								
							#endif
						}
						if (z == 0) memcpy((void*)&txSamples[chan][idx][0],(void*)payloadPtr,LTESYMBOLSIZE-16);
					} else {
						//payload data setup(other six symbols)
						for (idx2 = 0; idx2 < (LTESYMBOL2SIZE-16)/4; idx2 ++)
						{
							#if SPECIAL_SEQUENCE == 0
							getcomplex(&payloadPtr[idx2],idx1,chan);
							idx1++;
							#elif SPECIAL_SEQUENCE == 1
							getcomplex1(&payloadPtr[idx2],idx1,testType);
							idx1++;
							if(idx1 == idx1Max)
								idx1 = 0;
							#elif SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
								#if USEPATTERN == 1
									testPatternFPGA(&payloadPtr[idx2],idx1,chan);
								#elif USEPATTERN == 2
									getTMdata(&payloadPtr[idx2],chan);
								#endif										
								idx1++;									
							#endif								
						}
						if (z == 0 )memcpy((void*)&txSamples[chan][idx][0],(void*)payloadPtr,LTESYMBOL2SIZE-16);
					}
					firstSample[chan][idx+(z*(NBSYMBOL*2))].re =  payloadPtr[0].re;
					firstSample[chan][idx+(z*(NBSYMBOL*2))].im =  payloadPtr[0].im;

					//Create PS data
					Cppi_getPSData (Cppi_DescType_MONOLITHIC, Cppi_PSLoc_PS_IN_DESC, (Cppi_Desc*)mono_pkt, (Uint8**)&payloadPtr, &payloadLen);
					*((Uint32*)payloadPtr) = (Uint32 )(0x00008000 + chan + (idx << 7));//add symbol number into PS field

					if (packets_already_pushed == 1) Qmss_queuePushDesc((aifObj.pktDmaConfig.txFqAxC[chan]), (Uint32*)mono_pkt);
					//Please note that Tx queue push will be done in slot ISR at the pace of 7 symbols / AxCs
				}
				}
			}
			/*
			 * Perform block writeback on L1D to make sure all symbol packets are coherent with MSM
			 */
			for(idx = 0;idx < NBDESCMAX;idx++) {
				CACHE_wbInvL1d((void *)(mono_region_test+(idx*LTESYMBOLSIZE)), LTESYMBOLSIZE, CACHE_WAIT);
			}
#if SPECIAL_SEQUENCE == 0
			gen_twiddle_fft16x16(&twiddleFacts[PAD], FFT_SIZE);
			memset(rxCheck,0x00,sizeof(rxCheck));
			memset(rxRuntimeFail,0x00,sizeof(rxRuntimeFail));
#endif


#ifdef SUPERPACKET
			// In Lte 5 and 10, we disable the PE channels that are not in use. This tests uses 2 AxCs per link, regardless of the LTE rate definition.
#if CPRI_RELAY_RATE == 10 || CPRI_RELAY_RATE == 5
			aifObj.hAif2Setup->commonSetup->pPeCommonSetup->bEnableCh[2] = FALSE;
			aifObj.hAif2Setup->commonSetup->pPeCommonSetup->bEnableCh[3] = FALSE;
#endif
#if CPRI_RELAY_RATE == 5
			aifObj.hAif2Setup->commonSetup->pPeCommonSetup->bEnableCh[4] = FALSE;
			aifObj.hAif2Setup->commonSetup->pPeCommonSetup->bEnableCh[5] = FALSE;
			aifObj.hAif2Setup->commonSetup->pPeCommonSetup->bEnableCh[6] = FALSE;
			aifObj.hAif2Setup->commonSetup->pPeCommonSetup->bEnableCh[7] = FALSE;
#endif
#endif

			// Disabling this mode, so that, on Cpri relay setup, once AIF2 timers are triggered, they keep running based on the initial pulse. Note there isn't a periodic 10ms pulse generated from EVMTCI6614, just a one shot pulse.
			aifObj.hAif2Setup->commonSetup->pAtCommonSetup->AutoResyncMode = CSL_AIF2_NO_AUTO_RESYNC_MODE;

#if EVM_TYPE == 8
#if CPRI_RELAY_CFG == 1 || CPRI_RELAY_CFG == 2
			aifObj.hAif2Setup->linkSetup[activeLink]->pAtLinkSetup->PiMax += 300; // adding some extra margin on Pi window for debug
#endif
#endif

			for(chan = 0;chan < nbchanneltotal;chan++)
			{
				aifObj.hAif2Setup->commonSetup->pPdCommonSetup->PdChConfig[chan].bChannelEn = 0;
			}

#if _CSL_AIF2_DUMP == 1
			if (DSP_procId == 1)
			{
			   FILE *fout;
			   fout = fopen("csl_aif2_dump.txt","w");
			   if (fout)
			   {
				   dump_CSL_Aif2Setup(fout,aifObj.hAif2Setup);
				   fclose(fout);
			   }

			}
#endif
			// Now programming AIF2 registers
			AIF_startHw(&aifObj);

			// Now triggering AIF2 physical and radio timers
			slotcount = 0;
			if (DSP_procId == 1)
			{
				keepStartupDelay = 0;
				UTILS_triggerFsync(&aifObj);
			}

			// entering the idle loop and monitoring the end of the test, if any.
			monoRxCount = 0;
			monoTxCount = 0;
			while(1)
			{

				asm (" IDLE");
				// wait for one extra slots to run out of Rx free pkts
#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
				if((slotcount >= (SLOT_NUM_DATA_CHECK + (NBSF*2) - 1)) && (testInfo.never_end == 0) ||
#else
				if((slotcount >= (SLOT_NUM_DATA_CHECK + DSP_procId)) && (testInfo.never_end == 0) ||
#endif
				   (testInfo.force_stop == 1) && (testInfo.never_end == 1)
				  )
				{
					//AT disable all events and halt timer
					CSR&= 0xFFFFFFFE;
					//keepAifOff = 1;
					UTILS_doCleanup(&aifObj,TRIG_TIMER);
					break;
				}

				if ((CSL_FEXT(aifObj.hCsl->regs->G_RM_LKS[activeLink].RM_LK_STS0,AIF2_RM_LK_STS0_SYNC_STATUS) != CSL_AIF2_RM_LK_STS0_SYNC_STATUS_ST3) &&
					(slotcount > /*SLOT_NUM_FIRST_PUSH*/37500))
				{
					thisPiCaptured = CSL_FEXT(aifObj.hCsl->regs->PI_DATA[activeLink].AT_PIVALUE_LK,AIF2_AT_PIVALUE_LK_PICAPTURED_VALUE);
					//AT disable all events and halt timer
					CSR&= 0xFFFFFFFE;
					//keepAifOff = 1;
					UTILS_doCleanup(&aifObj,TRIG_TIMER);
					printf("FATAL: CPRI link not in HFNSYNC, initial captured pi: %d\n", thisPiCaptured);
					break;
				}
			}

			// disable interrupts before checking for data
			CSR&= 0xFFFFFFFE;

			if (testInfo.force_stop == 0)
			{

				for(chan =0; chan < nbchannelSuperPacket; chan++)
				{
					monoRxCount = Qmss_getQueueEntryCount(aifObj.pktDmaConfig.rxQAxC[chan]); // get number of received packed on first channel
					monoTxCount = Qmss_getQueueEntryCount(aifObj.pktDmaConfig.txFqAxC[chan]); // channel 0 only
					printf(" Number of monolithic packets received in RX queue channel%d: %d\n", chan, monoRxCount);
					printf(" Number of monolithic packets in TX free queue for channel%d: %d\n", chan, monoTxCount);
				}

				/* Check received symbol packet data */
				testpass = 1;
				for(chan =0; chan < nbchannelSuperPacket; chan++)
				{
					idx1 = 0;
					PEAKDEBUG= 0;
					rx_count = Qmss_getQueueEntryCount((aifObj.pktDmaConfig.rxQAxC[chan]));
					if (rx_count == 0) {testpass =0;testcheck++;}

					for (idx = 0; idx < NBSYMBOL*2*NBSF; idx ++)
					{
						symbolPkt[chan][idx] = (Cppi_MonolithicDesc *)QMSS_DESC_PTR(Qmss_queuePop(aifObj.pktDmaConfig.rxQAxC[chan]));
						CACHE_invL1d((void *)symbolPkt[chan][idx], 16, CACHE_WAIT);
						payloadPtr2 = (Uint32 *)symbolPkt[chan][idx];
						payloadPtr2 += 4; //skip pkt header and PS field (16 bytes)
						//testpass = 1;
						if((idx%NBSYMBOL) == 0)
						{
#ifdef SUPERPACKET
							UTILS_deinterleaveLteSuperPacket((Uint32 *)payloadPtr2, (Uint32 *)rxBuffer[0], \
									(Uint32) aifObj.linkConfig[activeLink].cpriPackMode, aifObj.linkConfig[activeLink].numPeAxC, (LTESYMBOLSIZE-16));
#else
							CACHE_invL1d((void *)payloadPtr2, (LTESYMBOLSIZE-16), CACHE_WAIT);
							memcpy((void*)&rxBuffer[chan][0],(void*)payloadPtr2,LTESYMBOLSIZE-16);
#endif
#if (CPRI_RELAY_CFG == 1) && (SPECIAL_SEQUENCE == 0)
							payloadPtr = (Complex16 *)rxBuffer[chan];
							for (idx2 = 0; idx2 < (LTESYMBOLSIZE-16)/4; idx2 ++)
							{
								getcomplex(&sampleCheck,idx1,chan);
									if ((payloadPtr[idx2].re != sampleCheck.re) || (payloadPtr[idx2].im != sampleCheck.im ))
								{
									testpass = 0; testcheck++;
									printf("receive fail \n");
								}
								idx1++;
							}
#endif
							if (idx < (NBSYMBOL*2)) memcpy((void*)&rxSamples[chan][idx][0],(void*)rxBuffer[chan],LTESYMBOLSIZE-16);
#if SPECIAL_SEQUENCE == 0
							DSP_fft16x16(&twiddleFacts[PAD], FFT_SIZE, (Int16*)&rxBuffer[chan][CYPRENORMAL1_SIZE*4], (Int16*)&rxBuffer[2][0]);
							if((chan == 0) || (chan == 2)||(chan == 4) || (chan == 6))
							{
								if (!checkSingleTone((Int16*)&rxBuffer[2][0],FFT_SIZE,PEAK_LOC_1MHZ,0)) {
									testpass = 0;testcheck++;
									rxCheck[chan][0] = 0;
									rxRuntimeFail[chan][0]++;
								}
							} else {
								if (!checkDualTone((Int16*)&rxBuffer[2][0],FFT_SIZE,PEAK_LOC_1MHZ, PEAK_LOC_2MHZ,1)) {
									testpass = 0;testcheck++;
									rxCheck[chan][0] = 0;
									rxRuntimeFail[chan][0]++;
								}
							}
#endif
#ifdef SUPERPACKET
							UTILS_deinterleaveLteSuperPacket((Uint32 *)(payloadPtr2+aifObj.linkConfig[activeLink].cpriPackMode), (Uint32 *)rxBuffer[1], \
									(Uint32) aifObj.linkConfig[activeLink].cpriPackMode, aifObj.linkConfig[activeLink].numPeAxC, (LTESYMBOLSIZE-16));
							memcpy((void*)&rxSamples[chan+1][idx][0],(void*)rxBuffer[chan+1],LTESYMBOLSIZE-16);
#if SPECIAL_SEQUENCE == 0
							DSP_fft16x16(&twiddleFacts[PAD], FFT_SIZE, (Int16*)&rxBuffer[chan+1][CYPRENORMAL1_SIZE*4], (Int16*)&rxBuffer[2][0]);
							if (!checkDualTone((Int16*)&rxBuffer[2][0],FFT_SIZE,PEAK_LOC_1MHZ, PEAK_LOC_2MHZ,1)) {
								testpass = 0;testcheck++;
								rxCheck[1][0] = 0;
							}
#endif
#endif
						} else {
#ifdef SUPERPACKET
							UTILS_deinterleaveLteSuperPacket((Uint32 *)payloadPtr2, (Uint32 *)rxBuffer[0], \
									(Uint32) aifObj.linkConfig[activeLink].cpriPackMode, aifObj.linkConfig[activeLink].numPeAxC, (LTESYMBOL2SIZE-16));
#else
							CACHE_invL1d((void *)payloadPtr2, (LTESYMBOL2SIZE-16), CACHE_WAIT);
							memcpy((void*)&rxBuffer[chan][0],(void*)payloadPtr2,LTESYMBOL2SIZE-16);
#endif
#if (CPRI_RELAY_CFG == 1) && (SPECIAL_SEQUENCE == 0)
							payloadPtr = (Complex16 *)rxBuffer[chan];
							for (idx2 = 0; idx2 < (LTESYMBOL2SIZE-16)/4; idx2 ++)
							{
								getcomplex(&sampleCheck,idx1,chan);
									if ((payloadPtr[idx2].re != sampleCheck.re) || (payloadPtr[idx2].im != sampleCheck.im ))
								{
									testpass = 0; testcheck++;
									printf("receive fail \n");
								}
								idx1++;
							}
#endif
							if (idx < (NBSYMBOL*2)) memcpy((void*)&rxSamples[chan][idx][0],(void*)rxBuffer[chan],LTESYMBOL2SIZE-16);
#if SPECIAL_SEQUENCE == 0
							DSP_fft16x16(&twiddleFacts[PAD], FFT_SIZE, (Int16*)&rxBuffer[chan][CYPRENORMAL_SIZE*4], (Int16*)&rxBuffer[2][0]);
							if((chan == 0) || (chan == 2)||(chan == 4) || (chan == 6))
							{
								if (!checkSingleTone((Int16*)&rxBuffer[2][0],FFT_SIZE,PEAK_LOC_1MHZ,0)) {
									testpass = 0;testcheck++;
									rxCheck[chan][idx%NBSYMBOL] = 0;
									rxRuntimeFail[chan][idx%NBSYMBOL]++;
								}
							} else {
								if (!checkDualTone((Int16*)&rxBuffer[2][0],FFT_SIZE,PEAK_LOC_1MHZ, PEAK_LOC_2MHZ,1)) {
									testpass = 0;testcheck++;
									rxCheck[chan][idx%NBSYMBOL] = 0;
									rxRuntimeFail[chan][idx%NBSYMBOL]++;
								}
							}
#endif
#ifdef SUPERPACKET
							UTILS_deinterleaveLteSuperPacket((Uint32 *)(payloadPtr2+aifObj.linkConfig[activeLink].cpriPackMode), (Uint32 *)rxBuffer[1], \
									(Uint32) aifObj.linkConfig[activeLink].cpriPackMode, aifObj.linkConfig[activeLink].numPeAxC, (LTESYMBOL2SIZE-16));
							memcpy((void*)&rxSamples[chan+1][idx][0],(void*)rxBuffer[chan+1],LTESYMBOL2SIZE-16);
#if SPECIAL_SEQUENCE == 0
							DSP_fft16x16(&twiddleFacts[PAD], FFT_SIZE, (Int16*)&rxBuffer[chan+1][CYPRENORMAL_SIZE*4], (Int16*)&rxBuffer[2][0]);
							if (!checkDualTone((Int16*)&rxBuffer[2][0],FFT_SIZE,PEAK_LOC_1MHZ, PEAK_LOC_2MHZ,1)) {
								testpass = 0;testcheck++;
								rxCheck[1][idx%NBSYMBOL] = 0;
							}
#endif
#endif
						}
						Qmss_queuePushDesc(aifObj.pktDmaConfig.rxFqAxC[chan], (Uint32*) symbolPkt[chan][idx]);

					}
					printf(" Test a) Monolithic Packet Data Recv: on chan: %d are :%d \n", chan, rx_count);
				}


#if SPECIAL_SEQUENCE == 1
				/* Save RF loopback data */
				txSamPtr0 =  &txSamples[0][0][0];
				rxSamPtr0 =  &rxSamples[0][0][0];
				txSamPtr1 =  &txSamples[1][0][0];
				rxSamPtr1 =  &rxSamples[1][0][0];

				if(testType == 0) // zero signal
				{

					if (testInfo.use_cio == 1) outfile = fopen("test0rx0.bin","wb");  // antenna 0, rx
					if (outfile) fwrite(rxSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1) outfile = fopen("test0rx1.bin","wb");  // antenna 1, rx
					if (outfile) fwrite(rxSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
				}
				else if(testType == 1) // 1200 consecutive tones
				{
					if (testInfo.use_cio == 1)  outfile = fopen("test1tx0.bin","wb");  // antenna 0, tx
					if (outfile) fwrite(txSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test1rx0.bin","wb");  // antenna 0, rx
					if (outfile) fwrite(rxSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test1tx1.bin","wb");  // antenna 1, tx
					if (outfile) fwrite(txSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test1rx1.bin","wb");  // antenna 1, rx
					if (outfile) fwrite(rxSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
				}
				else if(testType == 2) // 600 even tones
				{
					if (testInfo.use_cio == 1)  outfile = fopen("test2rx0.bin","wb");  // antenna 0, rx
					if (outfile) fwrite(rxSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test2rx1.bin","wb");  // antenna 1, rx
					if (outfile) fwrite(rxSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
				}
				else if(testType == 3) // 600 odd tones
				{
					if (testInfo.use_cio == 1)  outfile = fopen("test3rx0.bin","wb");  // antenna 0, rx
					if (outfile) fwrite(rxSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test3rx1.bin","wb");  // antenna 1, rx
					if (outfile) fwrite(rxSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
				}
				else if(testType == 4)  // IMD tones: +/-1MHz
				{
					if (testInfo.use_cio == 1)  outfile = fopen("test4rx0.bin","wb");  // antenna 0, rx
					if (outfile) fwrite(rxSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test4rx1.bin","wb");  // antenna 1, rx
					if (outfile) fwrite(rxSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
				}
				else if(testType == 5)  // Wide band signal
				{
					if (testInfo.use_cio == 1)  outfile = fopen("test5tx0.bin","wb");  // antenna 0, tx
					if (outfile) fwrite(txSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test5rx0.bin","wb");  // antenna 0, rx
					if (outfile) fwrite(rxSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test5tx1.bin","wb");  // antenna 1, tx
					if (outfile) fwrite(txSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test5rx1.bin","wb");  // antenna 1, rx
					if (outfile) fwrite(rxSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
				}
				else if(testType == 10) /* 1MHz tone */
				{
					if (testInfo.use_cio == 1)  outfile = fopen("test10tx0.bin","wb");  // antenna 0, tx
					if (outfile) fwrite(txSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test10rx0.bin","wb");  // antenna 0, rx
					if (outfile) fwrite(rxSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test10tx1.bin","wb");  // antenna 1, tx
					if (outfile) fwrite(txSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test10rx1.bin","wb");  // antenna 1, rx
					if (outfile) fwrite(rxSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
				}
				else /* Default: 1MHz tone */
				{
					if (testInfo.use_cio == 1)  outfile = fopen("test10tx0.bin","wb");  // antenna 0, tx
					if (outfile) fwrite(txSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test10rx0.bin","wb");  // antenna 0, rx
					if (outfile) fwrite(rxSamPtr0, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test10tx1.bin","wb");  // antenna 1, tx
					if (outfile) fwrite(txSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
					if (testInfo.use_cio == 1)  outfile = fopen("test10rx1.bin","wb");  // antenna 1, rx
					if (outfile) fwrite(rxSamPtr1, 1, 4*30912, outfile);
					if (outfile) fclose(outfile);
				}
#endif


				if (testpass == 1) {
					printf(" Test a) Monolithic Packet Data Send/Recv: PASS on channel: %d \n", chan);
				} else {
					printf(" Test a) Monolithic Packet Data Send/Recv: FAIL\n");
					for(chan =0; chan < nbchannelSuperPacket; chan++)
					{
						for (idx = 0; idx < NBSYMBOL; idx ++)
						{
							if (rxRuntimeFail[chan][idx]) {
								printf("Rx data check failed on Antenna%d Symbol%d\n",chan,idx);
							}
						}
					}
				}

				/* read the descriptor counts of the Monolithic queues. */
				value =0;
				for (i =0 ; i< nbchanneltotal; i++) {
					value += Qmss_getQueueEntryCount(aifObj.pktDmaConfig.txQAxC[i]);
				}
				if (value != 0) printf(" Test b1) Monolithic Packet Tx Descriptor Counts:%d FAIL\n",value);
				else printf(" Test b1) Monolithic Packet Tx Descriptor Counts:%d PASS\n",value);
				value =0;
				for (i =0 ; i< nbchanneltotal; i++) {
					value += Qmss_getQueueEntryCount(aifObj.pktDmaConfig.txFqAxC[i]); // channel0
				}
				if (value != nbchanneltotal*NBSYMBOL*2*NBSF) printf(" Test b2) Monolithic Packet Tx Complete Descriptor Counts:%d FAIL\n",value);
				else printf(" Test b2) Monolithic Packet Tx Complete Descriptor Counts:%d PASS\n",value);
				value =0;
				for (i =0 ; i< nbchannelSuperPacket; i++) {
					value += Qmss_getQueueEntryCount(aifObj.pktDmaConfig.rxQAxC[i]);
				}
				if (value != 0) printf(" Test b3) Monolithic Packet Rx Descriptor Counts:%d FAIL\n",value);
				else printf(" Test b3) Monolithic Packet Rx Descriptor Counts:%d PASS\n",value);
				value =0;
				for (i =0 ; i< nbchannelSuperPacket; i++) {
					value += Qmss_getQueueEntryCount(aifObj.pktDmaConfig.rxFqAxC[i]);
				}
				if (value != nbchannelSuperPacket*NBSYMBOL*2*NBSF) printf(" Test b4) Monolithic Packet Rx Free Descriptor Counts:%d FAIL\n",value);
				else printf(" Test b4) Monolithic Packet Rx Free Descriptor Counts:%d PASS\n",value);

#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
				// Store all received symbols into a dat file
				for(chan =0; chan < nbchannelSuperPacket; chan++)
				{

#if SPECIAL_SEQUENCE == 2 //TM == 3
#if CPRI_RELAY_RATE == 20
					if (chan == 0) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_20M_CellID1_AxC0.dat","wb");
					}
					else {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_20M_CellID1_AxC1.dat","wb");
					}
#elif CPRI_RELAY_RATE == 10
					if (chan == 0) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_10M_CellID1_AxC0.dat","wb");
					}
					else if (chan == 1) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_10M_CellID1_AxC1.dat","wb");
					}
					else if (chan == 2) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_10M_CellID1_AxC2.dat","wb");
					}
					else if (chan == 3) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_10M_CellID1_AxC3.dat","wb");
					}
#elif CPRI_RELAY_RATE == 5
					if (chan == 0) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_5M_CellID1_AxC0.dat","wb");
					}
					else if (chan == 1) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_5M_CellID1_AxC1.dat","wb");
					}
					else if (chan == 2) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_5M_CellID1_AxC2.dat","wb");
					}
					else if (chan == 3) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_5M_CellID1_AxC3.dat","wb");
					}
					else if (chan == 4) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_5M_CellID1_AxC4.dat","wb");
					}
					else if (chan == 5) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_5M_CellID1_AxC5.dat","wb");
					}
					else if (chan == 6) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_5M_CellID1_AxC6.dat","wb");
					}
					else if (chan == 7) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM3p1_5M_CellID1_AxC7.dat","wb");
					}
#endif
#elif SPECIAL_SEQUENCE == 3
#if CPRI_RELAY_RATE == 20
					if (chan == 0) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM1p1_20M_CellID1_AxC0.dat","wb");
					}
					else {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM1p1_20M_CellID1_AxC1.dat","wb");
					}
#elif CPRI_RELAY_RATE == 5
					if (chan == 0) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM1p1_5M_CellID1_AxC0.dat","wb");
					}
					else if (chan == 1) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM1p1_5M_CellID1_AxC1.dat","wb");
					}
					else if (chan == 2) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM1p1_5M_CellID1_AxC2.dat","wb");
					}
					else if (chan == 3) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM1p1_5M_CellID1_AxC3.dat","wb");
					}
					else if (chan == 4) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM1p1_5M_CellID1_AxC4.dat","wb");
					}
					else if (chan == 5) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM1p1_5M_CellID1_AxC5.dat","wb");
					}
					else if (chan == 6) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM1p1_5M_CellID1_AxC6.dat","wb");
					}
					else if (chan == 7) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTEFDD_TM1p1_5M_CellID1_AxC7.dat","wb");
					}
#endif
#elif SPECIAL_SEQUENCE == 4
					if (chan == 0) {
						if (testInfo.use_cio == 1)  outfile = fopen("LTETDD_1x20_64QAM_PN9_ID1_AxC0.dat","wb");
					}
					else {
						if (testInfo.use_cio == 1)  outfile = fopen("LTETDD_1x20_64QAM_PN9_ID1_AxC1.dat","wb");
					}
#endif

					for (idx = 0; idx < NBSYMBOL*2*NBSF; idx ++)
					{
						payloadPtr2 = (Uint32 *)symbolPkt[chan][idx];
						payloadPtr2 += 4; //skip pkt header and PS field (16 bytes)

						if((idx%NBSYMBOL) == 0) payloadLen = LTESYMBOLSIZE-16;
						else                    payloadLen = LTESYMBOL2SIZE-16;
						CACHE_invL1d((void *)payloadPtr2, payloadLen, CACHE_WAIT);
						payloadPtr = (Complex16 *)payloadPtr2;
						for (idx2 = 0; idx2 < payloadLen/4; idx2 ++)
						{
							if (outfile) fprintf(outfile,"%d %d\n",payloadPtr[idx2].re,payloadPtr[idx2].im );
						}
					}
					if (outfile) fclose(outfile);
				}
#endif
			} // force_stop == 0

			for (i =0 ; i< nbchannelSuperPacket; i++) {
				Qmss_queueEmpty(aifObj.pktDmaConfig.txQAxC[i]);
				Qmss_queueEmpty(aifObj.pktDmaConfig.rxQAxC[i]);
				Qmss_queueEmpty(aifObj.pktDmaConfig.txFqAxC[i]);
				Qmss_queueEmpty(aifObj.pktDmaConfig.rxFqAxC[i]);

				Qmss_queueClose(aifObj.pktDmaConfig.txQAxC[i]);
				Qmss_queueClose(aifObj.pktDmaConfig.rxQAxC[i]);
				Qmss_queueClose(aifObj.pktDmaConfig.txFqAxC[i]);
				Qmss_queueClose(aifObj.pktDmaConfig.rxFqAxC[i]);
			}
#if defined(DEVICE_K2K) || defined(DEVICE_K2H)
			Qmss_removeMemoryRegion(aifObj.pktDmaConfig.txRegionAxC[0], 0);
			Qmss_exit();
#endif
#if USERM
			UTILS_resetRm();
#endif

			UTILS_doCleanup(&aifObj,TRIG_TIMER);

			if (printexceptions == 1)
			{
				if (eeLastCpriLossInFrame)
					printf(" Last CPRI loss occurred at frame number:%d \n",eeLastCpriLossInFrame);
				AIF_printException(&aifObj);
			}

			printf("\nEnding %s test\n", testObjTab[ntest].name);
 	    }
    }

    CACHE_wbInvAllL1dWait();

#if CPRI_RELAY_RATE == 20
    printf("Test: ending AIF2 LTE 20MHz RF test \n");
#elif CPRI_RELAY_RATE == 10
    printf("Test: ending AIF2 LTE 10MHz RF test \n");
#elif CPRI_RELAY_RATE == 5
    printf("Test: ending AIF2 LTE 5MHz RF test \n");
#endif

    if (aifObj.aif2EeCount.eeFlag != 0) testcheck++;

    if (testcheck == 1) {
           testcheck = 0;
           printf("All tests have passed\n");
    } else {
           printf("Some tests have failed\n");
    }

#if SPECIAL_SEQUENCE == 1
    testInfo.test_case = -1;
	} // while
#endif

    return (0);
}


// These modes are only used for extensive RF tests on CPRI relay setups
#define     DUAL_TONE_FIVE_NINE 0
#define     QUAD_TONE_ONE_TWO   0
#define     QUAD_TONE_FIVE_NINE 0
#define     EIGHTEEN_TONES      0
#define     TWENTY_FOUR_TONES   0
#define     FORTY_EIGHT_TONES   0
#define     NINETY_SIX_TONES    0

#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
void testPattern(Complex16* payload, Uint32 index, Uint32 tx)
{
	/* note it is 15 bits signed!!! */
	Complex16 x1;
	Complex16 y;
	/* constants */
	if (RAMP == 0)
	{
	if (tx == 0)
	{
		x1.re = 0x5234;/*1234*/
		x1.im = 0x33D5;/*1678*/
		y = x1;
	}
	else if (tx == 1)
	{
		x1.re =0x23d5;/*1555*/
		x1.im =0xF210;/*2AAA*/
		y = x1;
	}
	}
	/* ramp */
	else if (RAMP == 1)
	{
	if (tx == 0)
	{
		x1.re = (Int16) (index%1024-512);
		x1.im = (Int16) (index%1024);
		y = x1;
	}
	else if (tx == 1)
	{
		x1.re =(Int16) (index%1024-256);
		x1.im =(Int16) (index%1024-128);
		y = x1;
	}
	}


    payload->re = y.re;
    payload->im = y.im;
}
#endif

void getcomplex(Complex16* payload,Uint32 index,Uint32 tx)
{
	float freq;
	Complex16 x1;
	Complex16 y;
	if ((tx==0)||(tx==2)||(tx==4)||(tx==6))
	{
                // 1 MHz signal
                freq = FREQ;
                x1.re = (Int16) ( (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x1.im = (Int16) ( (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                y = x1;
	} else if ((tx==1)|| (tx==3)||(tx==5)|| (tx==7))
	{
                Complex16         x2;
                // 1 MHz signal
                freq = FREQ;
                x1.re = (Int16) (0.5 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x1.im = (Int16) (0.5 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // 2 MHz signal
                freq = 2*FREQ;
                x2.re = (Int16) (0.5 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x2.im = (Int16) (0.5 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // dual tone signal
                y.re = x1.re + x2.re;
                y.im = x1.im + x2.im;
	}
#if DUAL_TONE_FIVE_NINE == 1
                Complex16         x2;
                // 5 MHz signal
                freq = 5;
                x1.re = (Int16) (0.5 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x1.im = (Int16) (0.5 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // 9 MHz signal
                freq = 9;
                x2.re = (Int16) (0.5 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x2.im = (Int16) (0.5 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // dual tone signal
                y.re = x1.re + x2.re;
                y.im = x1.im + x2.im;

#elif QUAD_TONE_ONE_TWO == 1
                Complex16         x2,x3,x4;
                // 1 MHz signal
                freq = 1;
                x1.re = (Int16) (0.25 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x1.im = (Int16) (0.25 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // 2 MHz signal
                freq = 2;
                x2.re = (Int16) (0.25 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x2.im = (Int16) (0.25 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // -1 MHz signal
                freq = 1;
                x3.re = (Int16) (0.25 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x3.im = (Int16) (-0.25 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // -2 MHz signal
                freq = 2;
                x4.re = (Int16) (0.25 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x4.im = (Int16) (-0.25 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // quad tone signal
                y.re = x1.re + x2.re + x3.re + x4.re;
                y.im = x1.im + x2.im + x3.im + x4.im;

#elif QUAD_TONE_FIVE_NINE == 1
                Complex16         x2,x3,x4;
                // 5 MHz signal
                freq = 5;
                x1.re = (Int16) (0.25 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x1.im = (Int16) (0.25 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // 9 MHz signal
                freq = 9;
                x2.re = (Int16) (0.25 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x2.im = (Int16) (0.25 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // -5 MHz signal
                freq = 5;
                x3.re = (Int16) (0.25 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x3.im = (Int16) (-0.25 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // -9 MHz signal
                freq = 9;
                x4.re = (Int16) (0.25 * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                x4.im = (Int16) (-0.25 * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                // quad tone signal
                y.re = x1.re + x2.re + x3.re + x4.re;
                y.im = x1.im + x2.im + x3.im + x4.im;

#elif EIGHTEEN_TONES == 1
                Complex16         x2;
                Uint32            ii;
                float             scale;

                scale = 1.0f/18.0f;
                y.re = 0;
                y.im = 0;
                for (ii = 0; ii < 9; ii ++)
                {
                    // Plus MHz signal
                    freq = ii + 1;
                    x1.re = (Int16) (scale * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    x1.im = (Int16) (scale * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    // Minus MHz signal
                    x2.re = (Int16) (scale * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    x2.im = (Int16) (-scale * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    y.re = y.re + x1.re + x2.re;
                    y.im = y.im + x1.im + x2.im;
                }

#elif TWENTY_FOUR_TONES == 1
                Complex16         x2;
                Uint32            ii;
                float             scale;

                scale = 1.0f/24.0f;
                y.re = 0;
                y.im = 0;
                for (ii = 0; ii < 12; ii ++)
                {
                    // Plus MHz signal
                    freq = ii + 1;
                    x1.re = (Int16) (scale * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    x1.im = (Int16) (scale * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    // Minus MHz signal
                    x2.re = (Int16) (scale * (cos(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    x2.im = (Int16) (-scale * (sin(2*PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    y.re = y.re + x1.re + x2.re;
                    y.im = y.im + x1.im + x2.im;
                }

#elif FORTY_EIGHT_TONES == 1
                Complex16         x2;
                Uint32            ii;
                float             scale;

                scale = 1.0f/48.0f;
                y.re = 0;
                y.im = 0;
                for (ii = 0; ii < 24; ii ++)
                {
                    // Plus MHz signal
                    freq = ii + 1;
                    x1.re = (Int16) (scale * (cos(PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    x1.im = (Int16) (scale * (sin(PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    // Minus MHz signal
                    x2.re = (Int16) (scale * (cos(PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    x2.im = (Int16) (-scale * (sin(PI*freq*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    y.re = y.re + x1.re + x2.re;
                    y.im = y.im + x1.im + x2.im;
                }

#elif NINETY_SIX_TONES == 1
                Complex16         x2;
                Uint32            ii;
                float             scale,freq1;

                scale = 1.0f/96.0f;
                y.re = 0;
                y.im = 0;
                for (ii = 0; ii < 48; ii ++)
                {
                    // Plus MHz signal
                    freq = ii + 1;
                    freq1 = (float)freq/2;
                    x1.re = (Int16) (scale * (cos(PI*freq1*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    x1.im = (Int16) (scale * (sin(PI*freq1*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    // Minus MHz signal
                    x2.re = (Int16) (scale * (cos(PI*freq1*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    x2.im = (Int16) (-scale * (sin(PI*freq1*(1/SAMP_FREQ_FLOAT)*index)) * Q_FACTOR );
                    y.re = y.re + x1.re + x2.re;
                    y.im = y.im + x1.im + x2.im;
                }
#endif
                payload->re = y.re;
                payload->im = y.im;
}

#if SPECIAL_SEQUENCE == 2 || SPECIAL_SEQUENCE == 3 || SPECIAL_SEQUENCE == 4
#if SPECIAL_SEQUENCE == 2
#if CPRI_RELAY_RATE == 20
Complex16 *tx0Ptr = (Complex16 *)LTEFDD_TM3p1_20M_CellID1;
Complex16 *tx1Ptr = (Complex16 *)LTEFDD_TM3p1_20M_CellID1;
#elif CPRI_RELAY_RATE == 10
Complex16 *tx0Ptr = (Complex16 *)LTEFDD_TM3p1_10M_CellID1;
Complex16 *tx1Ptr = (Complex16 *)LTEFDD_TM3p1_10M_CellID1;
Complex16 *tx2Ptr = (Complex16 *)LTEFDD_TM3p1_10M_CellID1;
Complex16 *tx3Ptr = (Complex16 *)LTEFDD_TM3p1_10M_CellID1;
#elif CPRI_RELAY_RATE == 5
Complex16 *tx0Ptr = (Complex16 *)LTEFDD_TM3p1_5M_CellID1;
Complex16 *tx1Ptr = (Complex16 *)LTEFDD_TM3p1_5M_CellID1;
Complex16 *tx2Ptr = (Complex16 *)LTEFDD_TM3p1_5M_CellID1;
Complex16 *tx3Ptr = (Complex16 *)LTEFDD_TM3p1_5M_CellID1;
Complex16 *tx4Ptr = (Complex16 *)LTEFDD_TM3p1_5M_CellID1;
Complex16 *tx5Ptr = (Complex16 *)LTEFDD_TM3p1_5M_CellID1;
Complex16 *tx6Ptr = (Complex16 *)LTEFDD_TM3p1_5M_CellID1;
Complex16 *tx7Ptr = (Complex16 *)LTEFDD_TM3p1_5M_CellID1;
#endif
#endif
#if SPECIAL_SEQUENCE == 3
#if CPRI_RELAY_RATE == 20
Complex16 *tx0Ptr = (Complex16 *)LTEFDD_TM1p1_20M_CellID1;
Complex16 *tx1Ptr = (Complex16 *)LTEFDD_TM1p1_20M_CellID1;
#elif CPRI_RELAY_RATE == 5
Complex16 *tx0Ptr = (Complex16 *)LTEFDD_TM1p1_5M_CellID1;
Complex16 *tx1Ptr = (Complex16 *)LTEFDD_TM1p1_5M_CellID1;
Complex16 *tx2Ptr = (Complex16 *)LTEFDD_TM1p1_5M_CellID1;
Complex16 *tx3Ptr = (Complex16 *)LTEFDD_TM1p1_5M_CellID1;
Complex16 *tx4Ptr = (Complex16 *)LTEFDD_TM1p1_5M_CellID1;
Complex16 *tx5Ptr = (Complex16 *)LTEFDD_TM1p1_5M_CellID1;
Complex16 *tx6Ptr = (Complex16 *)LTEFDD_TM1p1_5M_CellID1;
Complex16 *tx7Ptr = (Complex16 *)LTEFDD_TM1p1_5M_CellID1;
#endif
#endif
#if SPECIAL_SEQUENCE == 4
Complex16 *tx0Ptr = (Complex16 *)LTETDD_20M_CellID1;
Complex16 *tx1Ptr = (Complex16 *)LTETDD_20M_CellID1;
#endif

void getTMdata(Complex16* payload,Uint32 tx)
{
	Complex16 y;
	if (tx==0)
	{
       y.re = tx0Ptr->re;
       y.im = tx0Ptr->im;
       tx0Ptr++;
	} else if (tx==1)
	{
	   y.re = tx1Ptr->re;
	   y.im = tx1Ptr->im;
	   tx1Ptr++;
	}
#if CPRI_RELAY_RATE == 10 || CPRI_RELAY_RATE == 5
	else if (tx==2)
	{
	   y.re = tx2Ptr->re;
	   y.im = tx2Ptr->im;
	   tx2Ptr++;
	}  else if (tx==3)
	{
	   y.re = tx3Ptr->re;
	   y.im = tx3Ptr->im;
	   tx3Ptr++;
	}
#endif
#if CPRI_RELAY_RATE == 5
	else if (tx==4)
	{
	   y.re = tx4Ptr->re;
	   y.im = tx4Ptr->im;
	   tx4Ptr++;
	}  else if (tx==5)
	{
	   y.re = tx5Ptr->re;
	   y.im = tx5Ptr->im;
	   tx5Ptr++;
	}  else if (tx==6)
	{
	   y.re = tx6Ptr->re;
	   y.im = tx6Ptr->im;
	   tx6Ptr++;
	}  else if (tx==7)
	{
	   y.re = tx7Ptr->re;
	   y.im = tx7Ptr->im;
	   tx7Ptr++;
	}
#endif
    payload->re = y.re;
    payload->im = y.im;
}
#endif

#if SPECIAL_SEQUENCE == 1

void getcomplex1(Complex16* payload,Uint32 index, Uint32 testType1)
{
	Complex16 y;

    if(testType1 == 0) // Zero signal
    {
    	y.re = 0;
	    y.im = 0;
    }
    else if(testType1 == 1) // 1200 consecutive tones
    {
    	y.re = (Int16)(txSeqNoComb[index] >> 16);
	    y.im = (Int16)((txSeqNoComb[index]<<16)>>16);
    }
    else if(testType1 == 2) // 600 even tones comb
    {
    	y.re = (Int16)(txSeqEven[index] >> 16);
	    y.im = (Int16)((txSeqEven[index]<<16)>>16);
    }
    else if(testType1 == 3) // 600 odd tones comb
    {
    	y.re = (Int16)(txSeqOdd[index] >> 16);
	    y.im = (Int16)((txSeqOdd[index]<<16)>>16);
    }
    else if(testType1 == 4) // IMD tones: +/-1MHz
    {
    	y.re = (Int16)(txSeqImd[index] >> 16);
	    y.im = (Int16)((txSeqImd[index]<<16)>>16);
    }
    else if(testType1 == 5) // Wide band signal
    {
    	y.re = (Int16)(txSeqWideBand[index] >> 16);
	    y.im = (Int16)((txSeqWideBand[index]<<16)>>16);
    }
    else if(testType1 == 10) // 1MHz tone
    {
    	y.re = (Int16)(txSeq1MHz[index] >> 16);
	    y.im = (Int16)((txSeq1MHz[index]<<16)>>16);
    }
    else // Default: 1MHz tone
    {
    	y.re = (Int16)(txSeq1MHz[index] >> 16);
	    y.im = (Int16)((txSeq1MHz[index]<<16)>>16);
    }


    payload->re = y.re;
    payload->im = y.im;
}

void getcomplex2(Complex16* payload,Uint32 index)
{
	Complex16 y;

	y.re = (Int16)(txSeq1MHz[index] >> 16);
	y.im = (Int16)((txSeq1MHz[index]<<16)>>16);

    payload->re = y.re;
    payload->im = y.im;

//    payload->re = 0;
//    payload->im = 0;
}

#pragma DATA_SECTION(txSeqWideBand,".aifdescmsm");
Uint32 txSeqWideBand[2048] = {
0xef290121,0x09e9f189,0x100cf8c4,0xfab8ee85,0x05db10fa,0xf1840922,0xf8111046,0x100afab3,
0xfc74107e,0xf4220da0,0x0da20c54,0xf1c2f62f,0x03ebef9f,0xfa3eee94,0xfa200fa2,0xf47ef560,
0xf8b5ee88,0xf04e0860,0x0c27f52d,0x106f05d9,0x117bfc67,0xf1cdf9a5,0x0743f42a,0x1194f44e,
0xf254f456,0x0f53055f,0x02491238,0x0d490b91,0xfbecf2a2,0x0d19fa76,0x15570450,0xfba4ecc2,
0x0a5c0cfe,0xfb670fd6,0x085710f3,0xffa2f0af,0x0c7ffce4,0x15fd038b,0xfa34eecf,0x0be2084b,
0xffd9128d,0x0ccd0afe,0xfa2ef4de,0x06fdf417,0x156cf83d,0xeefbf481,0x0e61fefb,0x0d6008cf,
0x1141fdc6,0xf26efd60,0xf7f5f89f,0xfcb9e634,0xf3421108,0xfd9ff03e,0x0a7af490,0xf9f4ed44,
0x01bd0f43,0xf9d708d9,0xeb120ea4,0x1223023f,0xf7be0c14,0xed82fe57,0xf97d124f,0x059ff3a7,
0x0cb6fc22,0x16fbfde4,0xf3f7f700,0x07baf74f,0x153b05cd,0x0625efc6,0xfd5b0ae7,0xf13a068d,
0xec78046e,0x0ad00762,0xffeb096a,0xe7c205a3,0x05ae0f3a,0xfa3af871,0x08b4eef2,0x091ff0fb,
0xf6330117,0xf692fe57,0x07ebe4ee,0xef8f0202,0x0972f9fc,0x0fa30d68,0x0f070827,0xfffaf8ad,
0x001cf37b,0x1d3f0456,0xf9c0eeba,0x09be072e,0xfbdf120d,0x022b123d,0x0578fa48,0x09f8f723,
0x12e714cb,0x0663ef3f,0x03ea088c,0xf6eb0f5f,0xfa761089,0x085ffc69,0x093ff6a0,0x13e41522,
0x03fdef16,0x069305b2,0xf9c2118c,0x01160fb7,0x0500fab6,0x037ef079,0x1b5806b0,0xf91beead,
0x069cfffa,0x0adc0cff,0x0c7f09c0,0xfe82f668,0xf14bf9a6,0x0da7e49f,0xedff0584,0xfedff75f,
0x0d28f757,0x076af03b,0xf7940529,0xfcbd0e07,0xe2df005f,0x0a090ad8,0xfc840899,0xee07f937,
0xf2230793,0x0618008e,0x0df7f7ef,0x15ef0cc5,0xffbcf479,0x015ff76b,0x14370c24,0x0ac0fa7e,
0xfedfff7a,0xee670975,0xed34f709,0xfe150b4b,0x076f08c6,0xe496fea5,0xfe2008f9,0xfd960226,
0x0b93eb9e,0x1004fa89,0xfde8f542,0xf0ca046c,0x1219e5e5,0xf652fd50,0x01fefa39,0x0ffd119a,
0x07c80d5e,0x0941018b,0xfd27ed3c,0x1b590f86,0x038df2d2,0x048a01d2,0xfb081264,0xf7e610c3,
0x068c04a5,0x0b22f364,0x0c4118a9,0x0a92fb53,0x043dfe2c,0xf4bc11eb,0xf30a0869,0x05cb0947,
0x0cabf040,0x0c511acc,0x09c0f802,0x0554fe19,0xf8b710de,0xf7990d2a,0x07c603bd,0x0461ec66,
0x17b00b8f,0x0471f4d9,0xffbef7d8,0x0a9e1009,0x04380cbd,0x08cffad7,0xed37f38f,0x122eec0f,
0xf544f84c,0xf79bff32,0x0e7cf4f3,0x0ccef9e8,0xf877f7fb,0xf94b148c,0xe68af7b9,0xfc7c0b13,
0x04af08fa,0xed61fa5e,0xf350fbaa,0xfe8a0a08,0x1280f453,0x10181222,0x0a0bf9bc,0xfbe2f44d,
0x12d90ac6,0x097d05e9,0x050df6b3,0xeb760c35,0xf0acf188,0xf42a078d,0x0bb70a7a,0xe7e1fe91,
0xf840fefb,0xfe570bb9,0x0b73e8cf,0x11f5ffa8,0x069ff101,0xeda9058d,0x102eea21,0x0204fa83,
0xf915f90b,0x12091143,0x03510f5d,0x0c81099b,0xfd49eb03,0x158d0da2,0x0ae1fda2,0x0175f925,
0xfd6a1382,0xf2e90e58,0x03720b3c,0x0be4f31e,0x0a9311e9,0x091f0958,0x0776f41b,0xf5571474,
0xf0bb0317,0x00180fa7,0x0eeeeef3,0x0a1514cf,0x0a2f0414,0x0675f5a8,0xfae11035,0xf3540af6,
0x05c408a0,0x05d0ecee,0x12b20460,0x0caa0033,0xfb0cee0a,0x0b451023,0x00420b9f,0x0c350169,
0xeea6eec1,0x0a2cf159,0x0178eedf,0xeeb604f1,0x0d4df11e,0x0d620007,0xfd03f06b,0xf5a415ff,
0xecc5fa3e,0xf0800652,0x0b9d0a2d,0xedafff72,0xf4b6f442,0xf8b60de4,0x1354f348,0x0e9e0ddc,
0x0fb900d0,0xf8fff245,0x1026039f,0x0a0b0dc7,0x078df1e0,0xedcc0d35,0xef4bf479,0xf02c021c,
0x0b1a0a55,0xf09e03e2,0xf072f7e2,0x01cd1051,0x0609e9cb,0x135cfbd3,0x0a3bf17b,0xf11103e0,
0x0471eff0,0x0db4f4e9,0xf19ffb66,0x13940acf,0x04ec1181,0x0d890c00,0xfdb1ef21,0x0efc01f6,
0x11a707a4,0xfe3af274,0x01d511ea,0xf3830fee,0x00910d9a,0x0a77f5c2,0x0bd804f7,0x09e8142a,
0x06e3eda1,0xfacb1333,0xeffc0547,0xfd630fe9,0x0c66f200,0x0c7f06f9,0x0ad60e6f,0x0596ef5c,
0xff0f0cb6,0xf40e0d15,0x028c08f6,0x05fcf110,0x0be2f6c4,0x14560744,0xf5b7e9ae,0x0b340a79,
0x01ec0aea,0x0b53048e,0xf21eeeac,0xfc01f43e,0x0871e757,0xeb60098d,0x0604f00f,0x0db8fe6e,
0xfeb5ef69,0xf5d2127d,0xf2bb04a2,0xe88703f0,0x0e5b08ab,0xf3a005e5,0xf0a0f3ae,0xf8e90d46,
0x0e3cf4f9,0x10e401e8,0x12b604b1,0xf8d2f2fd,0x0842fac9,0x10960e70,0x03cdf1e9,0xf5690a4f,
0xeb22ffe0,0xef34fe70,0x06d10903,0xfe4f0786,0xe6d8fa94,0x07310c90,0xfecdf15a,0x1089ef91,
0x09e2f35c,0xf74aff19,0xf76cfb15,0x10e8e968,0xf09d0215,0x0f7c00bf,0x0de510ae,0x0de00998,
0xffdff61b,0x03d4f554,0x19e20877,0xfa51f20a,0x050b0afb,0xfb3f1473,0xff680e17,0x08f0f996,
0x08a0f65d,0x11b2161d,0x0148ee22,0x018e0aac,0xf3920e63,0xfd1c0ce0,0x085cf7ff,0x0abaf56e,
0x10b6119f,0x011dee3f,0x016b048f,0xfb18118f,0xff45084f,0x060df559,0xfef8ebcb,0x1a9e027c,
0xf139ee45,0x05c000c3,0x08700924,0x09040478,0xf51ff1b8,0xedfafaaf,0x0363e22a,0xef8b0b24,
0xfb44f76e,0x0af9f566,0xfe0df322,0xf7640c2e,0xfc75104c,0xe6580897,0x0b8805a3,0xfff40720,
0xeaa4fd30,0xfb61086d,0x0807fa7a,0x0e0df0fd,0x14e80229,0xfaaef493,0xfadaf80d,0x176d037f,
0xffb1f7f9,0xfab70223,0xee951125,0xed6bff6a,0x0271097f,0x0b1801fc,0xe4df08d3,0x062b0305,
0xfeb1fc43,0x015ee410,0x0832f2af,0xf8ccf8a9,0xf4d50a5e,0x03d0e052,0xf82904f5,0x0474fcab,
0x188f049b,0x0e59055f,0x0476f8fc,0xf440f33f,0x1c6bfb9f,0xfa88f722,0x0142023a,0x0a5d13b2,
0x01660ef0,0x0938fb99,0xfcedee16,0x19a10976,0xfe59f602,0xffb8fdee,0x012315a4,0xfd1b0b33,
0x07c6fd0e,0xfdb1e9e2,0x17230763,0xfdd5f370,0xfbd1fbf3,0x07da10bb,0xfe8f0a39,0x0580f6b8,
0xee3eed4b,0x1569f37e,0xf395f6e6,0xf847fd6e,0x0f1000e3,0x07670357,0xf6a9f56b,0xe78b083c,
0xf453e784,0xf46b06c3,0xf93c0789,0xfe64ed91,0xfe4cf6f9,0xf6900802,0x0c151357,0xee6511dc,
0x06310668,0x09a4fd0b,0xeef50d63,0xf9560467,0x07c1ffc9,0xfe39e5d4,0x1276f7a5,0xfc0bf47c,
0xf06b010c,0x111bf27f,0x0305fcea,0xf643fcd2,0x00921ab0,0xee3d093f,0x021f0b35,0x0c80f5ac,
0xf3c814d8,0xfc7801d5,0x0653fd8f,0xea90eafc,0x0050edad,0xf396f802,0xff951193,0xefcdeaa0,
0xfbd5fc5c,0xfebb04d5,0x1410ee6e,0x103bfe05,0x04dbf482,0xec1bffbd,0x0d0cecc3,0x0080f76d,
0xf7db0291,0x16ac04e9,0x09430d3c,0x091af99c,0xef9ef35e,0x11abf5cd,0x0480f9c7,0xf324fc23,
0x11f00cc1,0x01cd0d2d,0x08a7fbeb,0xece9f00e,0x0eabf55e,0x0123f74c,0xeff3feac,0x10be04bc,
0x050a0b3a,0x01c4f70e,0xe57bfc9a,0xff41eddc,0xf988f739,0xef870b12,0x0ad6f3ed,0x07d60045,
0xf683f99e,0xefa81756,0xebfdfccb,0xf0d403fe,0x0850105c,0xee85f63e,0xfc08f6f1,0xf7240aa8,
0x181706a8,0x01ae1316,0x076d0b43,0x03b0efad,0x0103124f,0xf7e70a9a,0x09d4fc89,0xeadfeeda,
0x0230eddd,0xf96df382,0xf3d70ea2,0xfd9ff027,0x052ef556,0xf20a0570,0x12580e79,0xfe711428,
0x054e0ab9,0x0214f018,0x053d0c08,0xfe240f0a,0x0344f322,0xe6070502,0xece8f2c6,0xf0fc003c,
0x08630a3b,0xf12f02f7,0xed42f9f3,0x096208ce,0xfa58e708,0x0af6ef7c,0xfb95f1eb,0xf49f0c04,
0xf5b7f4b8,0xfcd3edde,0xf8970d8e,0x0f84f156,0x10c8ff87,0x0570f685,0xecad015f,0xfb51f4c1,
0x0467eea3,0xf0c00c22,0x0ffaf878,0x0e5e06f0,0x040df86a,0xeae40290,0xf6f3f617,0x00f1f0b2,
0xeff70f53,0x0a6df7f1,0x0cae009a,0xfe68fb4e,0xec520d08,0xf0b10314,0xf20df347,0xff781a43,
0xfb78f36f,0x04d0f8f4,0xf76cff33,0x03d51aa9,0xfc810fee,0xef1c1086,0x15d60195,0xf334099c,
0xf33ffc9e,0xffe60cc0,0x12c6f46e,0x0ee6fff7,0x12180750,0xf3eef239,0x099e034a,0x07051058,
0x0253f74b,0xea6b044d,0xec89fb71,0xf202f70d,0x01c811db,0xf86b0105,0xf427f08b,0xfec30d8d,
0x0e8efc22,0x159d04e6,0x0a31077a,0xf9adf555,0xff43fdd5,0x14dc0b85,0xf2d5f7fc,0xfa7b10e4,
0xe8e61162,0xf60e0871,0x067e03d3,0x05e303db,0xe8d51462,0x0d65f964,0xebdffc65,0xf1eeec93,
0xf28afa3f,0xffe70a97,0xfa290b8a,0xe810f4a2,0x07030d5f,0xfd0af152,0x02beed1f,0xffe8f57d,
0xf4690b5c,0xf8ca09d0,0xedaeedc5,0x043c118c,0xfefff6ea,0x0bbaf0a4,0xfee0fa78,0xf7890bde,
0xf5e20fa5,0xeff6f199,0x041114a5,0x012afa97,0x017af1a7,0x015afd50,0xfbc212b0,0x070d14c5,
0xe73c056f,0x16030bc5,0xfa9300ea,0xf7fbf91b,0xfb8b01de,0x13c60b9f,0x13f70224,0x060d1a8c,
0x0a1af027,0x0588051f,0xf8170e77,0x066e04b1,0x02acef41,0xfcefed49,0x11c7f2bd,0xf2120140,
0xfd09fe8f,0x1412fb11,0xfc47fe4c,0xf8c30c4d,0xf8cc1878,0xeecb0608,0x0b4608c6,0x082201cf,
0xe9f90957,0x07a40183,0x0534f9e5,0x0663e61e,0x0e02fb83,0xf77afb7a,0xf6920919,0x1202ebca,
0xf965098e,0x044d0777,0x10041bd6,0x00370db0,0x088901bf,0x002ef21c,0x0dd91d8e,0xfd62f745,
0xf8ff0842,0xe8a80e2f,0xf31b06a1,0x03ff077f,0x0f760250,0xee0714e4,0x07a7005d,0xfb76fb87,
0xe86cfb6d,0xf781f7b0,0xff660d93,0x10250891,0xe8a10d42,0x0a1900f0,0x019dff3a,0xee7af20b,
0xfc9dfa81,0x019c09d7,0x14260cf7,0xee610bca,0x0c940378,0x063ffab4,0xedf0fdbe,0xfde3f83d,
0x09e40b0e,0x1b70f96f,0xffa9176a,0x0d4bf5c8,0x03d5f973,0xf7bd0ac8,0xfbb500f4,0x0ff6f6ce,
0x042be57f,0x18c5ff37,0xfbb6f48d,0xf9edf7f9,0x10430807,0x03750072,0xf6d6f4f9,0xe737036a,
0xf6edec74,0xfa210520,0x02410bab,0xfaafeb4a,0x01cdfd8c,0x02240a94,0x1baa089d,0x026411b1,
0x0aacfddc,0x00e9efd4,0x06f714ad,0xfeebffd4,0x00dbf50a,0xe41ff9a7,0xfbc2ef44,0xf7cd01e7,
0x09e90e8e,0xf078efa4,0x037bfda3,0x0823060c,0x19a7edd7,0x11a402d2,0x05b3f6f8,0xefbdff84,
0x1643f59b,0x04100031,0xfa5b05a3,0x1280169a,0x0059107d,0x0afb0114,0xfeeeee37,0x11bf0ced,
0x046502f1,0xf907f8f9,0xfa9f1a09,0xf474071a,0x08b10644,0x0b27ed33,0x098c10cc,0x036e01b5,
0xfda3f303,0xf455131a,0xf42a01ce,0x082302d7,0x0c3eea23,0x0b3a0a2d,0x04adff06,0xfa08ee8f,
0xfcb11279,0xf5f30284,0x082dfad2,0xfc26e293,0x0df2fb47,0x030cf7c4,0xecd3f675,0x0d750758,
0xfd1d06a8,0xfd2af259,0xe13ff885,0xfb6aedc8,0xf6d1f78e,0xf5840ff0,0x031aee26,0x05e7fcd3,
0xf1ab0319,0x03b41aed,0xf08a09de,0xfb4e0874,0x1067fa3c,0xefe006aa,0xf563fbbf,0x0b77019b,
0x059de3f4,0x0f66f852,0x03d0f714,0xec41feab,0x0b9cf90a,0x092100b7,0xefcafd7e,0xfd3a18ac,
0xeef50acb,0xfca40622,0x0d70f774,0xf85507d9,0xf293050c,0x0b70f32a,0xea9aedb0,0xfe38e834,
0xf7c1f9ab,0xff4a0c25,0xf69cf7bc,0xfb58ed4d,0x05fe0e62,0x1075e89e,0x12f3fdd5,0x02daf3fa,
0xef420306,0x0113f204,0x0b04f4ed,0xf3430931,0x171e01f3,0x0b880994,0x058bfc19,0xee81f452,
0x026ff7a2,0x0cc9f797,0xebad0685,0x118d04f8,0x055f0ed6,0x0232f9c4,0xead3f750,0xfc84f45b,
0x07dbf897,0xe9c40886,0x0d760242,0x0789076d,0xfae0fe1e,0xe5a10253,0xf116ff3f,0xfb19f145,
0xf6221bae,0x0376f38d,0x06b30089,0xf7a201af,0xf8281e77,0xf83c0d48,0xed4908a5,0x1642072a,
0xf1730374,0xf87ff7d1,0x01c40c44,0x188cfa67,0x0db304a5,0x0b8b0a86,0xf594efe7,0x05c50695,
0xffae112e,0xfea5f53b,0xe745fec3,0xeddcf79f,0xf78af7ba,0x0020129c,0xfb33ffb7,0xf9b5efa7,
0x025d104a,0x1195ff28,0x14ab0878,0x049f0775,0xf8d2f572,0xfd1fffb2,0x10a80f4a,0xed7cf8da,
0xf66812a4,0xe78b0fb5,0xf893057e,0x07010207,0x044f0228,0xe7bc1094,0x0c1ef463,0xea56f945,
0xf184ed82,0xf5affcfb,0x02170c2a,0xfc66099d,0xe9fff53f,0x0c13090f,0xfda5efe6,0x00e3ecf8,
0xff81fafe,0xf6750eb4,0xfca40b31,0xee76f06f,0x0c121071,0x0049f5b2,0x0948f062,0xfe57ffcb,
0xfaed10ef,0xfc021141,0xf0f7f61b,0x0dbb113c,0x02c1f969,0xff34f276,0x04820246,0x040e153c,
0x0f4c1139,0xed17099c,0x1b070078,0xfc08ff12,0xf873fbdb,0x02ec0110,0x1a97025f,0x1390f803,
0x0db713a3,0xffd8ead8,0x047c025e,0xfe270e04,0x04c6fc4a,0xf8e9ec2f,0xf3b7f168,0x0985eeec,
0xf50f0b67,0xff1e01a7,0x0f06f3ed,0xfc2005ca,0x00a31219,0x083f17ee,0xf5e00af0,0x0ef0fcf0,
0x05cffac7,0xf3731130,0x06a7f725,0x003ef36f,0xf4b1e7cc,0x0953f6b6,0xf7760558,0x01930ce0,
0x02b4e72b,0x059a0e61,0x0b5d059c,0x1f23088d,0x05e70969,0x0434f99c,0xf522f8cc,0x1c4c0bb7,
0xf405ffa3,0xfe2e0c94,0xfaeb1b93,0xfc5f091e,0x08e1fef4,0x0930f448,0x021c19e5,0x0047f770,
0xf624ffce,0xed6a0ee5,0xf78bfeec,0x0d050538,0x0f34f636,0xfb9916e7,0x037df48a,0xfd20fa95,
0xea9e0683,0xfcf9fbd7,0x0c460139,0x1429f273,0xff2c123d,0x0545f27a,0xfaeff5fa,0xf4760c97,
0xf9b7f93d,0x0ed8f6ab,0x047ee356,0x10af088f,0xf794f00d,0xf769f9f4,0x04d30ba6,0xfa43ff6a,
0xf941eb3e,0xe6b2f1e7,0x06e6ec20,0xf33c02ff,0xf790064a,0x0c11f37a,0xfeca01fd,0xf0b908b2,
0xfc9819bc,0xecd9008d,0x05ed0472,0x0bdcfc6b,0xeb1ffede,0x0181f9c0,0x0dc6fd33,0x0cd3e4a9,
0x0e55021a,0xfb2bf61a,0xeee2ff50,0x134cfd36,0xfb870414,0xf0f5005d,0xf67e1b81,0xeff1ff7d,
0x038304a8,0x0d58f3ff,0xee2e0b73,0xfd38f738,0x060bf2ce,0xecece51c,0x03f0f0a1,0xf7cafdf7,
0x01a70f9c,0xf708ea31,0x03d6fc5b,0x09ce05ca,0x1541eb34,0x0d1c0013,0xfba8f6fd,0xee550481,
0x0accef7c,0x02c9ff26,0xfacd0bd7,0x1a3a019d,0x048f09c2,0xff33f57e,0xe9f2f9fb,0x0cd1f624,
0xff630068,0xf2b2095f,0x148607c0,0xffda0a53,0xfb07f6a6,0xe5d3fb5d,0x0566f5aa,0xfcda0032,
0xf13f0f22,0x11f2febd,0x01050a68,0xf304fc9e,0xe4d40f58,0xf7ecf77d,0xf9ed02f7,0x015c1747,
0x025df155,0x06b40493,0xf5360d4f,0x069c1fff,0xf3a90a01,0xfe7508da,0x13bafe69,0xee5803f9,
0xfde2faae,0x0d540862,0x1547ee25,0x0c9507a8,0x04a3ff91,0xee81f6bb,0x0be90b33,0xfd810a7c,
0xf4e6f59f,0xe44a0c1f,0xf284f935,0xfa76033f,0x0ccd0fab,0xf4f9f9c1,0xfdd6f8e2,0x0d130d90,
0x1460f1fc,0x104a05f1,0x00fbffe7,0xee98fda1,0x08b9034e,0x0998087f,0xea4d054d,0x016b1c9f,
0xf05e108e,0x023904f8,0x06a8f645,0xfe750a1a,0xf4180e9b,0x00afecf6,0xe2ad0758,0xf1a6f582,
0xfab80848,0x0fb00645,0xf6e707f7,0xf174feb6,0x108dfba7,0xeda8efb6,0xfd1bf3b2,0xfc8c038d,
0x09661397,0xfb210379,0xf301fe2c,0x1741010d,0xf37bf1d0,0x0406f245,0xfe680856,0x0fb91196,
0xfefb09aa,0xf770ff74,0x18e3fe28,0xf4abf610,0xfe7cf6d8,0x08cd0415,0x19e807ae,0x0c47031a,
0xfceb0b89,0x1056e5cb,0xf5f00909,0xfaaffa46,0x099dfc25,0x102ce3c0,0x079ef64d,0x0f73fe99,
0xe86bf556,0x0cbc028e,0x01270990,0xfaf3f39f,0xe4830088,0xf4bffa55,0xfa24f5d6,0x09be12bb,
0xfd67f815,0x04c0f13e,0x03910df1,0x18ca0562,0x0ed908fd,0x02b7063f,0xfe42ec6a,0x00e9017c,
0x01a70f4c,0xf8e9eda0,0xec58ff8c,0xec9df7ee,0xfffcf9a4,0x08e90ae6,0x0457fe33,0xf17cf090,
0x16dd0502,0x09afecf9,0x1583f083,0x031afedb,0xf70e00f5,0xfc66016e,0x1610f0a8,0xf5b81253,
0x15c50611,0x0e9c0ff3,0x04b3ff71,0xf8f9f461,0xff19f89b,0x1419094a,0xede9fd1e,0x0375114c,
0x01871158,0xfe8d0050,0x0322edeb,0xfd20f612,0x10440bd1,0xeaf7f5ed,0xff7f0b7d,0xfa711080,
0xfe43fb0c,0xfd47ed1e,0xfab2f06a,0x0d840707,0xe8a2f82b,0xfdb009ed,0x031b0bcf,0xf5acfdb2,
0xf08eee27,0xea55f9dc,0x0bfef43f,0xe7a71035,0x04300245,0x070b0271,0xf82404dd,0xe6400d2d,
0xf4321155,0xeedef64c,0x0deb11dd,0xfd63ff34,0xfb30f440,0x02f4085e,0x11f30d6f,0x114f03fc,
0xfd961064,0xff3eee93,0xfba0fe49,0xf9b9118c,0xfb49f559,0xf2b7f148,0xea0af4e9,0x0389f5cb,
0xf8120f6e,0x022108a0,0xfed7ed20,0x04bd0f09,0x09510b6f,0x17c308be,0xfaaf0b77,0xfeb6f51d,
0xf25bfa75,0x0d4a1371,0xec1efb50,0xf1920543,0xe60a1209,0xf8c8fbb7,0x048c057a,0x0b55f9d7,
0xe53e0c68,0x07a1f29e,0xf6d9f4c5,0xed57ed6f,0xfe5afb59,0xfeb70aad,0x06340cc1,0xec4af2da,
0x0a9902ff,0x07f4f6fd,0xfc7eea01,0x067ffef9,0xf5a50c81,0x03b6120d,0xf12cf15c,0x0d050833,
0x08aaff89,0x03ffeb8e,0x05ac0475,0xfaf20e55,0x05ac173e,0xf34df6e1,0x0dbc0830,0x0db3fd8f,
0xf8f7f14c,0x0c450050,0x05e212f2,0x19dd0c2f,0xf2af090c,0x11c4f905,0x0707f695,0xf3b700a5,
0x0599f833,0x1788fd2f,0x1184eaf6,0x0cc90b84,0xfaf8f371,0xf840f845,0x079e0ed6,0xf9f7fc60,
0xf6bbeef2,0xe7a5fa7d,0x048bf14a,0xfd9d0914,0x04780daf,0x051eed1f,0x079006bc,0x036d10fd,
0x193c0deb,0xfaec0ab0,0x06fdf840,0xfebeeebe,0xff57126f,0xf99af8ac,0xfc88eefb,0xe5a0f88a,
0x02ebf2ca,0xffea06d5,0x0dea0c24,0xf6d7ef3a,0x0b76fd68,0x119f05b6,0x166aeb40,0x0c97055e,
0xfbb3fae7,0xf1c40692,0x12b7f7bc,0x0427079e,0xfa0f0ed0,0x184a1099,0xfdaf0aa1,0x04c5f70f,
0xf4a5f1b3,0x10000882,0xfc8e04fb,0xf077ffcc,0x040419b6,0xf77e02e8,0x078df871,0xfdabe9b4,
0x08aa0a59,0xfbcb007c,0xee1ef81b,0xffe415d5,0xf488000a,0x063cf426,0xf7cde787,0x08f4031c,
0xf9e90047,0xea18fb5d,0x07021106,0xf4f602f2,0xf905f1b5,0xe6abf09d,0x02b3f9ed,0xfb9d00db,
0xec5c10f8,0x0f71fc54,0xfb7f0b16,0xedb700ac,0xe9191789,0xf68cfb2b,0xfbdb03cc,0x10ee0e30,
0xf3a8f371,0x0796fd42,0x04161169,0x1ba3052b,0xfe2f0be3,0x00a5ffee,0xf88fec04,0xfdd00fd4,
0xf411023a,0xfedeedde,0xe460f515,0xfee9f4eb,0xfcaa02f8,0x01141500,0xfef3f4ef,0x0672fbf6,
0x02d915f5,0x186602e0,0x046f0df2,0xfc71fe23,0xf201f3dd,0x0288093b,0xfe910cf2,0xe875f6c1,
0xf032173c,0xed45011a,0x030101b9,0x0bf4f9d1,0xf8350489,0xef0601b6,0x0b2becca,0xe4fef64c,
0xfca0f1e9,0xfcf50710,0x0bf10d10,0xf781ffe3,0xf70cf5f9,0x14c801b7,0xf80de97f,0x0527f716,
0xfd5b06ce,0x025115ae,0xfd02ffd7,0xf996f75c,0x1819092a,0xfbdfed8b,0x099cf855,0xfe6b0b32,
0x090e160d,0xfec705aa,0xfab3f9d1,0x1b1f031e,0xf88df1f5,0x0447f81c,0x0ac50855,0x17540d50,
0x093902d3,0xf9200574,0x13f6e77e,0xf30c0496,0xfd2bf7a9,0x0ca9fa4d,0x13afe7e1,0x05b3f8e5,
0x09ca03bb,0xe7a6f369,0x09e60707,0xfd88089f,0xf774f35d,0xe565fdd4,0xf7e2fbfe,0x006ff781,
0x0abd14d0,0x010af701,0x06a2f422,0x071c1019,0x17840659,0x0c850653,0xfd1703be,0xfbc2eb13,
0xfd3e02e7,0x006c0d41,0xf346ed12,0xed3e0033,0xeea0fb13,0x05d9f9a8,0x0bb60a4d,0x065afadf,
0xf1a6f29c,0x1b7cffc8,0x0630ed35,0x1101ef96,0xff5f04b9,0xf73304a9,0xfdf4054f,0x134bef10,
0xfa8418d7,0x16370136,0x0e240b99,0xfe93fceb,0xf2f5f7f0,0xfc39fbb6,0x12f6069a,0xebd105a1,
0x06dc10c0,0x05aa0cf8,0xf9e4fd98,0xfaf7ecd9,0xf742fb1d,0x10e006fd,0xe564023f,0x03370b47,
0xffc71005,0xf8daf842,0xf3aaf093,0xf43bf6f4,0x0d6d04d0,0xe72806dd,0x023e0c5c,0x073c07bc,
0xf1150386,0xe9bef856,0xecc60889,0x0801f280,0xf6fa1d80,0x07b6ffb4,0x06d6ffc5,0xfc2b0bc9,
0xf3251a00,0x036e1123,0xf001fe41,0x187d0176,0xfdd5fe14,0xf6e3f819,0x0b91032a,0x16c4fd0d,
0x0c04f78c,0x038f0d00,0xefd1f426,0xf9b5029b,0x054f10c1,0xf13cf9ed,0xeb7fff01,0xec4107a1,
0x0083f6d9,0x09d50f20,0x096b0215,0xf3a8f318,0x120a0602,0x0fb8ff39,0x121cf3ea,0x00b20ca2,
0xf2e6fc24,0xf39e08ee,0x154402e5,0xee8f0ee8,0xfa5f0f4d,0x01251aea,0xf745fdc3,0x06d1f9e9,
0xfda5f2ab,0xfaa81993,0xf51ff038,0xf144ff1c,0xe92406ef,0x00bbfb28,0x0b820488,0x0d64fc1d,
0xeb3a0873,0x0787f261,0xfb61f33c,0xec99f9b2,0x06b2fae8,0x0a6c0cfe,0x116000f5,0xed8f0342,
0x0c74f359,0x02d3f44c,0xeee1f680,0x0aa8fba3,0x0da80974,0x1601fe09,0xf191060f,0x09dcf068,
0xff61f0c6,0xf04001c1,0x063cf2c3,0x1420fc5e,0x0dbbea94,0x00b00d5f,0xf7d5ee14,0xf4ccf738,
0xfd3f0d11,0xf736f4e7,0xfef3e8e5,0xed6eee6c,0x0c4dfb8a,0xf306074e,0xf86d0af5,0x0f54fa4f,
0xf9250a0e,0xee1508dc,0xfb531717,0xf591f684,0x0bb80073,0x0e1ef843,0xedbcfa74,0x09cef628,
0x11b0fc2a,0x0a08e750,0x06190897,0xf3fffbf1,0xee6f05e3,0x111f0097,0xf67609e9,0xedf10629,
0xfd721925,0xf473f9b4,0x085bfb30,0x081aee76,0xf04d09fc,0xfb47f204,0x023bec2e,0xe885f113,
0x0645f6d6,0xffb908c2,0x0b7c0baf,0xf622efca,0x0930faa9,0x12310227,0x06aae681,0x089d040c,
0xf3f6036c,0xf821107e,0x049af0fd,0x0825041f,0x066e114b,0x147ef307,0x013809e2,0xf2cafe87,
0xedd40d03,0x0803f65c,0x03f206f3,0x021e1541,0x122ff6cf,0x01810bf7,0xefe002ad,0xf09a129e,
0x01a7f81c,0x06bd05cc,0x094615bb,0x0ab3f079,0x06990afd,0xf7ae0f4e,0x01dd1b16,0xfc79fcf9,
0x0553ff98,0x1a36028e,0xf30df47a,0x0db5fd52,0x0cc20d8a,0x1d5d00e4,0xfcec06a3,0x00b1fd2c,
0xfb7fe8c5,0xfc3010cc,0xf73ef911,0x07cceec4,0xefc1eb42,0x08fafdea,0xff0704cc,0xf7d21558,
0x0cadf7a8,0x083708d2,0xf39b10b8,0x0c961734,0xf8fa042c,0x032ff9ee,0x0a1eed80,0xf7250716,
0xf7c3fcd8,0x0963e9e0,0xee38f222,0x0576f628,0x03ff08cd,0x051f11fa,0x04a1f7b0,0x089ef770,
0x1012165b,0x1563f424,0x0ab109a8,0xf6ecfe1f,0xf0c60169,0x0696024b,0x0cd908e3,0xe9d10dd9,
0x120f12e9,0xf91f099f,0x017af675,0xf762ef3e,0x03c604f7,0xffa80ced,0xe99bf6ea,0xfe061668,
0xf7ba0273,0x0336f591,0x02d3eb38,0xfe4b0226,0xff270acc,0xe802f066,0xfdef12c7,0xf44d0175,
0x0336f216,0xfb32e9df,0xff79fe30,0x001e0a1c,0xe405f98f,0x03c51040,0xf8ce0521,0xf3f8f470,
0xec61f11c,0xf8ce0060,0x09240079,0xea5e1880,0x0ee3fe2b,0x001e09a7,0xf17806db,0xec7c1509,
0xfe9d048b,0xfb6bf929,0x1a410bad,0xf751f67a,0x048ef831,0x0b370ca0,0x1853012b,0x03790191,
0xfa270676,0xf194eb27,0xfd1209e5,0xf8aa0a58,0xf4f5eeec,0xe9e6fc79,0xf6c7fd72,0x07e3fe21,
0x08f21473,0x0474fb3b,0xff0cf41a,0x122f1131,0x1000fc92,0x0d170115,0xf50f0824,0xf042f8e4,
0xf9cd089d,0x0ec109e4,0xe2b70804,0xff35114e,0xf5940fae,0x0034f48e,0x0688f67c,0xfdd8f8a3,
0xf1d81356,0xfbade3c1,0xec3205a5,0xf315f9f4,0x083b00ae,0x10950118,0x044fff43,0xecd5fe49,
0x10adef8f,0xf3ccf3a7,0xf7d7f8d3,0x0b88011c,0x0dd00e1b,0x097efd08,0xee2efe7a,0x1694ee88,
0xf760f776,0xf9c7f414,0x0dad0422,0x12190644,0x0ba8fe96,0xf00e0015,0x0e81ea4f,0xf5c1f71e,
0xf65afe8d,0x0c7cf36d,0x142ff9bb,0x0540ef58,0xfc0f1067,0xf0ffe522,0xf7d1072a,0xfaac04f5,
0xf8f8f2e1,0xf889e721,0xf26efb53,0x0dd7fd8e,0xedfb1403,0x04d502dc,0x0b1000df,0xf4820a1d,
0xf33b122d,0x01390bf7,0xf732f5b1,0x1560f9ea,0x014bf7e6,0xf148f9a9,0x1014f75a,0x0d1df2a0,
0x0265efca,0x03910bbc,0xebfd0272,0xfa3b0995,0x1047ff70,0xefc70e7e,0xf7a90d3e,0x025a1210,
0xf551f49d,0x0ae6f45b,0xfc73f0f6,0xf3310fa3,0xfb11e80f,0xf759f475,0xeb66f866,0x0c9bfc54,
0x05b00afb,0x0ee00258,0xedbef0ca,0x162efcca,0x07aef53b,0x01d0ecf0,0x046909b6,0xf8ae0cc2,
0x01900e6d,0x0295eb86,0x0ce00dd8,0x0e77019a,0x0957f21d,0x009a0d1e,0xefff0907,0xfdba109d,
0x04c5ef1d,0x0c1d10a3,0x0b35068f,0x0ba0f2b1,0xff950f95,0xf4510c8c,0xfffd13fa,0x00b0ef6d,
0x0fed0b56,0x102500d3,0xff27f0fc,0x0cff0b25,0x00a81422,0x12a00bb7,0xf203fa51,0x11c2f5cb,
0x0782f3c0,0xf269fca0,0x0d1af763,0x1590ffa5,0x0c40ef59,0xfda60d1a,0xf3a2f48c,0xf26efa95,
0x04631028,0xf308f82b,0xf550f017,0xebe2001f,0x0c51f9ad,0x03a70e6f,0x0a440dd9,0x0434ee30,
0x0af90bcb,0x05f7115e,0x159d03cb,0xf41a03d6,0xfd6af1d1,0xf52cf124,0x001f116a,0xf30ff78c,
0xf4e0f063,0xeba30580,0x07cff54f,0x0b8f07e5,0x124102a2,0xf41ef386,0x0cb8f8bd,0x14b2fd73,
0x0251e9e5,0x089008ef,0xf485087e,0xfb19101f,0x0b22f4a8,0x08fd0955,0x02e7148c,0x16bcfae8,
0xf8af0ad9,0xf3f2f733,0xed0c037e,0x0f2a0090,0xfda70cde,0xf2dd0ecd,0x12b30ad5,0xf449031d,
0xf6c9f3f5,0xecd7f94c,0x0b0f066b,0xfc0a0984,0xee130f78,0x11fe0868,0xf31006c1,0xf395f38e,
0xe9fd0111,0x0a5cffda,0x00940c6e,0xf68a1500,0x1287feb1,0xf9bd0b80,0xee140478,0xf14d1048,
0x04f1fb34,0x08c401c7,0x114d142a,0x0088ec68,0x0b2d0a6d,0x00a01125,0x11cd1159,0xf878fb48,
0x003afa27,0x0b48e8b3,0xeff009a1,0xfff6f218,0x0ff4f78c,0xff30e843,0x04100963,0xfa6e0651,
0xebbd0e1a,0x0fe10129,0xfe5a0cf8,0xec0105df,0xfe7b16f9,0xfb92f9cd,0x0771f87f,0x1245f37f,
0xf30efff2,0xfc70f705,0x12d3f154,0xf73eee84,0x080e000d,0xffeb0e25,0xfbdc130c,0x09b0fad5,
0x0a08fe5b,0x04bd1b85,0x1331fcae,0x00680a6a,0xf16cf9f4,0xf0e4fb59,0x025906d1,0x06a50c55,
0xe3170569,0x0b0d1365,0xf47601ca,0x0329f153,0xfa59ee4a,0xff950559,0xf85e0c25,0xebbbef2f,
0xf8c0141e,0xf9e9fb44,0x0559f34c,0x0671ec50,0xf9bc0382,0xfac9095e,0xe943ecf7,0xfc5410c8,
0xf562fd92,0x0639ef12,0xfd3eed02,0xfe0e00b7,0xfc460da1,0xe514f758,0x02f011fb,0xf967015d,
0xf3b0f392,0xf10bf1b8,0xfb8905be,0x0c7d03c9,0xebf41a85,0x11c0fd0e,0xff220a78,0xf26406c7,
0xf0901373,0x050cffd3,0xffd8f6d7,0x1d83064a,0xf6fdf5db,0x0604f705,0x0e1d0ba6,0x156cfc21,
0xfe390034,0xf67904b6,0xeceaee67,0xfe6f09d4,0xfa120a6a,0xf175eed8,0xed720217,0xfc8eff4d,
0x0d13fd8e,0x0fb00f80,0x0432f8e1,0xfdaef3ea,0x17790c3e,0x0b6bf759,0x075cfed6,0xf3430bc7,
0xedc8ff5a,0xfddd09f0,0x0f8104c7,0xe67a103e,0x05790cf5,0xfcc10a95,0xfa4aef79,0x01cef137,
0xf8ccfa81,0xfa86137a,0xef03e6eb,0xf3c50a74,0xf689fecc,0x0c4df6e5,0x0f45f835,0x017af974,
0xee210610,0x0630e58f,0xf0f7fcb3,0xf967fd3d,0x0ee7fa62,0x12df01bc,0x0371f703,0xef3904c0,
0x078fe43e,0xf47bfd36,0xf6aafc3f,0x108bf88e,0x1076fb5e,0x03c9f656,0xf05d0aa1,0xfb09e505,
0xf26f027a,0xf9a9042e,0x022aedf8,0x09a2ef79,0xf670f6d8,0x05f6119c,0xe273fbfb,0x006e0b80,
0x011a082b,0xf064fabb,0xecc6f7c2,0xf955083d,0x0d8df809,0x06f019d2,0x082cfe8e,0x07b4f700,
0x02c41249,0x061c10cf,0x09920208,0xf096fa26,0x0708ea35,0xf88ff8dd,0xf43f0933,0x0209eaa1,
0xfdb9f179,0xf53df96d,0x0f560961,0xf9ac12f9,0x08710a07,0x0794f0db,0x06611744,0x06340a3e,
0x0e1c02a5,0xec51ffe0,0xf8fff0a1,0xf09dfce7,0x090f11c1,0xe775f867,0xf5120269,0xf6de0bba,
0x0665eef2,0x0e6efa8f,0x068bf25b,0xecb3089c,0x05c8e90c,0xfa88f455,0xf339fca8,0x106efe2a,
0x0d8d0b43,0x0de7fdb4,0xef26f783,0x11b6f3b8,0x0674f428,0xf50bf5ef,0x113c0637,0x06940fd6,
0x100002aa,0xf073f454,0x136ff5df,0x072bf493,0xf4e3f691,0x1137030e,0x0b6d0d92,0x0faffd63,
0xee38fbf8,0x09b5edec,0x00f7f195,0xf03c00f8,0x0e4df4ed,0x1133ff4d,0x071af0eb,0xf4230dd3,
0xf331f196,0xf18af9ea,0xfefa104d,0xf580f123,0xff97eed8,0xefb7fa0a,0x0fee08df,0xf6da0fdb,
0xff5110a5,0x0ef8f883,0xfa3810ff,0xf2820abe,0x074a104e,0xf98feef6,0x0fb9f808,0x0995f159};

#pragma DATA_SECTION(txSeqNoComb,".aifdescmsm");
Uint32 txSeqNoComb[2048] = {
0x01231366,0xfb1c0050,0xf9b0eae1,0x0bdcf5b6,0x15d90a7b,0x0ae00ef3,0x033c0e8f,0x0665135c,
0x09cd118c,0x109404b7,0x12abf7ec,0xfe77f406,0xed89f9e0,0x0080036c,0x1342086c,0xfc800736,
0xe497fff3,0xf606f1d0,0x0bc2e883,0x0561ef37,0x015ff4e4,0x09c3eb00,0xfdb1ea25,0xe77200a3,
0xf25d0d6f,0x0f4301da,0x0dadfe18,0xf5720794,0xf032ffa5,0x00adeda7,0x0eeaf17f,0x138800ea,
0x12cd048b,0x10450446,0x118c0298,0x123df4c7,0x03cfecac,0xef19fb6e,0xf2c70743,0x0b8400f8,
0x0ef401ba,0xf4ad0aa6,0xe8a3ff8e,0xfcc7eaec,0x0ccdeb6a,0x07c5f58f,0x0803f2ba,0x0ed4ed23,
0xffacf04f,0xe920f7c1,0xf3c00422,0x0d0b0f48,0x069007a5,0xf24af5a6,0xfcdcf3b7,0x14bd0054,
0x11dd0b40,0x00621370,0xfc1815ff,0xfee20fe2,0x00d90ff8,0x09d21431,0x11bf0292,0x094eeb03,
0xfa79f7af,0xf62310c3,0xfb300368,0x04d8eb27,0x0f0ef9d9,0x0e4c14c3,0x02371443,0xfaa30d28,
0xfb3d1315,0xfe301434,0x08bb0c09,0x142203fc,0x0930f71e,0xf466eea8,0xfab6fe50,0x0c0a1100,
0xfe2b06bc,0xe906f198,0xfa6aedd3,0x15e2f1bd,0x1057f2e5,0x0604f6be,0x113ff574,0x0cafecc0,
0xee0ff1b6,0xea1d042d,0x08720a96,0x0ff20518,0xf77b0243,0xf117fad8,0x0695f06b,0x14abf800,
0x12700a15,0x0eb20ded,0x0c180a88,0x0d2c0b26,0x141b018e,0x0e4cf0f5,0xf61cf203,0xee8effbc,
0x05320595,0x0e6c0720,0xf61705eb,0xe9caf7a5,0x01cfeabd,0x1575f19d,0x0e21fb11,0x0ac8f832,
0x1413f5bc,0x0a63f481,0xf0e7efc4,0xef65fae8,0x033912d6,0x05510f47,0xf889f3f3,0xff16f189,
0x11910830,0x0df812a3,0xf9eb11d8,0xf2f313b1,0xf82a0f9e,0xfa310cbc,0xff9a150f,0x0dd60d97,
0x11daf24f,0x0135f197,0xf1830a1b,0xf7a105c5,0x09d7ef50,0x112efbdf,0x07a217d1,0xfacf15b2,
0xf60109fa,0xf5830ef1,0xf68c11ab,0x013e0cc6,0x10d00af0,0x0eb3fdc5,0xfcf9eab5,0xf9f4f6ca,
0x05251240,0xff24092f,0xf04debb0,0xfd98ea87,0x1829f8b5,0x169ef8ef,0x0927f8a5,0x111ffca4,
0x13dff3c5,0xf826ec25,0xe879fae7,0xffb40c05,0x0edb0ac5,0xfbe90187,0xf24ff877,0x0726f2a2,
0x16c0fc67,0x10e50eb6,0x09c91262,0x081a0cfd,0x08ce0e37,0x109f08ea,0x1264f6ae,0xfe1eeede,
0xee88f931,0xfe6c04b6,0x0c9809e3,0xf9f2054a,0xeba4f421,0x021bea43,0x18dbf5d2,0x11bdffc7,
0x0a4dfb6c,0x13b1fabd,0x0fa8fa42,0xf767ee84,0xee70f359,0xfc5e10c3,0x026d14e7,0xfb81f6a2,
0x000befa0,0x0df509d4,0x0ad01648,0xf7c010b3,0xeeae10e2,0xf3dc0e97,0xf76f0983,0xfaaf1246,
0x088f12b2,0x13cbf8ec,0x07a8eefe,0xf22d0460,0xf37806f1,0x0946f2cc,0x12f8fb66,0x05a916fe,
0xf6c71645,0xf4080851,0xf4300b6a,0xf35c0ecf,0xfcc40b17,0x0dec0cbc,0x10d702a0,0x0251eacd,
0xfb29f076,0x01df0f4a,0xffa20c1c,0xf4d0ebe6,0xfe5ee78f,0x16ddf9d0,0x1993fc79,0x0b8ef9b0,
0x0eb5febb,0x152df83b,0xff60ec03,0xe97af5a2,0xf8da09ce,0x0d1c0d53,0x008f0379,0xf2def881,
0x0420f2ca,0x1718fcc4,0x11dc0f6e,0x079713b1,0x06210d71,0x07390e46,0x0d460b17,0x125ff990,
0x034bee6e,0xef8df5ac,0xf8dc01da,0x0b2509b3,0xfe9306cf,0xec35f4c5,0xfe18e8f8,0x18f1f526,
0x149d0130,0x08f5fc6a,0x1128fb42,0x11ccfd18,0xfa76f074,0xecfeefa7,0xf91b0d24,0x01a5185b,
0xfbd4fb4d,0xfea3ee4b,0x0bf3070b,0x0ae716e2,0xf9311188,0xee64109d,0xf2060ee4,0xf6cd0831,
0xfa640f99,0x063713f4,0x127dfc09,0x0aececd9,0xf532009a,0xf0b308b1,0x0516f4ef,0x1399f7d8,
0x087c13bd,0xf73517d6,0xf3b90971,0xf53d09d6,0xf3830daa,0xfafb09cf,0x0d0e0aeb,0x124b0377,
0x039febb6,0xfa82ebf2,0x01710a51,0x017b0e22,0xf5ccefa9,0xfb0ee557,0x1355f551,0x1ae4fb01,
0x0d61f8ee,0x0bfefd10,0x135df82a,0x026eed16,0xe9ebf4f5,0xf3f707e6,0x0c750cdf,0x05ae055c,
0xf2f1fae5,0xfe53f252,0x15bcf8c4,0x15930bcd,0x096912d3,0x06a10ce2,0x086e0c8c,0x0bf809c8,
0x1031f8ed,0x0498edc8,0xef6cf52e,0xf3db0048,0x0a330723,0x042307b7,0xebf8f935,0xf5bde934,
0x1538ef9b,0x1732fd79,0x07c1fbc8,0x0d39f8d0,0x1232fb80,0xfaf6f35f,0xe92cf106,0xf7ad0a6d,
0x05211997,0xfc470119,0xfa2deebb,0x0a24015f,0x0ec41400,0xfea11360,0xf1eb1351,0xf329115e,
0xf7a9090b,0xfd090db0,0x07d012a6,0x1029fbc2,0x0975e97d,0xf7f7fda3,0xf0ca0c35,0xff1bf7b5,
0x10ccf16c,0x0def0cbc,0xfd3d19a2,0xf5db0d71,0xf79209f1,0xf66c0e02,0xfb6f09ed,0x0d2b066a,
0x1372ff4f,0x0177ec37,0xf57cea14,0x0100043c,0x05c40dc3,0xf55cf5d9,0xf2b2e62d,0x0b71edb3,
0x1991f3b1,0x0dd1f559,0x0868f961,0x0edcf48c,0x0185ed85,0xe935f8a8,0xf0c2092b,0x0cde09f6,
0x0b890440,0xf3eeff1b,0xf67bf464,0x1076f1da,0x1947021c,0x0eca0e6b,0x097d0afd,0x0b1f08af,
0x0c2005b2,0x0c06f5fe,0x0158ec7d,0xeda8f7b0,0xef7102b9,0x0896036a,0x0a13050c,0xed780084,
0xeaaeef7d,0x0adbe896,0x168bf38f,0x069af990,0x073df60d,0x0f8ff5ea,0xfa60f639,0xe4b3f928,
0xf6c90a5d,0x0cc416a8,0x0033066e,0xf3e4f353,0x058efaf6,0x14270baf,0x088412a5,0xfa7116b7,
0xf8c214f8,0xfacf0b5e,0x012f0b91,0x0c150df2,0x0d34f8f4,0x01e1e674,0xf7eafad6,0xf5421077,
0xfa49fd97,0x07c7eb3b,0x10cf0049,0x08cc175d,0xfce7125c,0xfb2c0aeb,0xfbce0e0c,0xfe710ace,
0x0be90031,0x1153f64c,0xfc3cece3,0xec41ee07,0xfd4bff18,0x0b0308d4,0xf6cbfd25,0xe791ee7e,
0xfc72e917,0x113ee8b7,0x0a4beef4,0x0290f5dd,0x0686f09b,0xfc9dee27,0xe94d0062,0xf12e0ee0,
0x0d2f055f,0x0fd4fd8f,0xf7720309,0xefd9fc4a,0x04f0ecec,0x165ef294,0x13f6038b,0x0d980617,
0x0cd4021a,0x0b5dff0e,0x0541f351,0xf93eed56,0xeb7bfdd8,0xee8d0a90,0x059300eb,0x0cebfd20,
0xf369075d,0xe3acff8e,0xf91ee86b,0x0c43e6a2,0x03c9f58e,0xffc1f658,0x072cefe2,0xf934f862,
0xe5a007ec,0xf80a0e63,0x14c00cab,0x08a9067f,0xf08dfd72,0xfcc0f88d,0x14e8fd67,0x13b109b5,
0x080c1523,0x03db158c,0x01740cb7,0x05520803,0x0f1c049b,0x086ff4c2,0xf4dee8ed,0xf340face,
0xfe2411d0,0xfb8b05e0,0xf93aec2a,0x096ef1e2,0x144f0b22,0x0a1c120e,0x00c00b27,0x02300b71,
0x04070a06,0x0761fab9,0x0709ecc1,0xf435f01e,0xe44efbb1,0xf6400002,0x0c31ff27,0xfbe801e0,
0xe21600df,0xe9d8f175,0xfe18e2e8,0xff23e99d,0xfa45f5c3,0xfb0ff1b5,0xf4bbf278,0xedaf0a3b,
0xf981161f,0x0c830044,0x0cc0f245,0xfc690323,0xf1290916,0xf655f1d0,0x05a7e572,0x1036f2e9,
0x0f2cfc93,0x0a5bf9fd,0x0656f7e9,0xfcb3f46f,0xef8ef55e,0xec6907fe,0xf699147d,0x038101c3,
0x0743f36e,0xfc42084a,0xebfc147a,0xe998f844,0xf521e32a,0xfbcdf240,0xfa58fb6d,0xf9e2f0ad,
0xf697fab7,0xf2d71608,0x00a713d9,0x1581fc6d,0x0efcfbdd,0xf6440850,0xf4edff6d,0x09f9efe9,
0x159af6d5,0x143907cc,0x10aa0c87,0x0a3e087b,0x079902a5,0x0b2bf92d,0x0002f1fc,0xe958f66b,
0xedae0337,0x075e0ca9,0x05390911,0xee81f960,0xf621eead,0x12d5f698,0x164d0453,0x07cd0725,
0x06680584,0x096d0492,0x00bcf96c,0xf4dced6d,0xec2cfa29,0xe8d61088,0xf4430a98,0x04bdf723,
0x00e60023,0xed7d1536,0xe4420aa1,0xe7eaf030,0xed9aef43,0xf2cdfc5a,0xf2f1fbb9,0xef6bfdeb,
0xf891110c,0x0a77151d,0x0adffaee,0xfe18eb7f,0xfd32ff34,0xfe8510f7,0xf167023a,0xec16eb8c,
0xfc68e952,0x07a5f1ad,0x020ff4a2,0xfc64f600,0xf690fb91,0xee09057f,0xf5e2129b,0x08b1159b,
0x06a202a2,0xf97df21d,0x002f02a3,0x06021b33,0xf02f115a,0xe001f85e,0xef3ef87d,0xfaf501ec,
0xf164fc92,0xf3ac00d1,0x08e61518,0x117f0ed4,0x09a5eec9,0x056eecb1,0x027508c9,0xf9510b2c,
0xf72ff15b,0x032ee7ac,0x0ff5f1d0,0x12c5f8b5,0x0d91fc34,0x0626fc8b,0xff1af46a,0xf547f673,
0xec0b0b53,0xf40712e8,0x0ab402ef,0x0d9ffea0,0xf45d09d9,0xe8d501fb,0xfe07ecee,0x0f95ed5b,
0x0a0efbe8,0x05f6fedc,0x08bafba8,0xfc68fca1,0xe9b5ffea,0xedd30c34,0x00281c06,0x02fa1398,
0xfabafa50,0xfe81fc09,0x0715172c,0xfd0e1f02,0xe86d0f57,0xe5dd06e7,0xf384088f,0xf78608ab,
0xf6050bca,0x06600e13,0x16f5028a,0x0628f465,0xecdef5d7,0xf77d002d,0x0d6b0825,0xffb60d29,
0xe4aa0900,0xe6f5fa4e,0xf688f239,0xf756f792,0xf4d5fe1e,0xf8c30538,0xfcbd10f2,0x087c1247,
0x170a03b7,0x0a88fab5,0xf0eefe99,0xfbff0100,0x199c04e0,0x0dcf1300,0xec3f19c9,0xee6a0dad,
0xff8e0408,0xf82008e6,0xf8230adb,0x1371010b,0x1766f5bb,0xf736ef60,0xed75f167,0x04fafe37,
0x08bf0926,0xf1d0039f,0xe9c5f4cb,0xf608eb80,0xff5beb0b,0x0244f14a,0xfff7f8eb,0xf58ffc9b,
0xf27404b6,0x010414ed,0x0c3714a7,0x0774faf5,0x03a1f071,0x04460925,0xfa9b176a,0xee8bffc6,
0xf250eaa2,0xfd9bf277,0x0184faf7,0x005af78b,0xfc45ffd2,0xf838133f,0x0364171f,0x188e0ad9,
0x160a0336,0xfc8e0322,0xf9090102,0x12f30013,0x1d790a32,0x0ac9199b,0xfd051bcc,0x015d0f43,
0x05a808e9,0x06fa0bc9,0x0c49005c,0x09edeb9c,0xf943f223,0xeebe0c60,0xf9720b89,0x0a3cf709,
0x0ccfff34,0x012119d2,0xf4601900,0xf0130636,0xf39b0379,0xfa0508c7,0x02b90767,0x0d9e061d,
0x12c2fdc5,0x0b6bebad,0xfebfefbe,0xf9210a7a,0xfe2b0857,0x099deb14,0x139bf126,0x13a81532,
0x0a5517c4,0x02bb01f6,0x036f0568,0x07110b25,0x053bf175,0xfa99e3c8,0xed60ff3d,0xec25107d,
0xfb2ffe0c,0x083cf694,0x02720aee,0xf2141431,0xe8620711,0xe9e4fc27,0xf1c0fa44,0xf876fcec,
0xfa4e06da,0x01220dbb,0x1257042d,0x1706f746,0x006ff65f,0xf087f950,0x036efbec,0x156c0673,
0x02471056,0xe90a0b06,0xee05fff5,0xfb89fc89,0xf9bffd25,0xfc8d0107,0x0f2b085e,0x18fd01b6,
0x0f5beaec,0x0533e6b4,0x030bff12,0x00ac0893,0x005df0e0,0x0b1ae267,0x199bf449,0x1ae105a2,
0x0f1201ae,0x0852fb38,0x0a67fa6f,0x01dbf4f6,0xee10f317,0xee28023d,0x05a61192,0x0c470a40,
0xfac3f6f5,0xfbc7f1ca,0x14c5fe5d,0x1a100c3c,0x06a7102d,0xfedc0c60,0x05d40640,0x0727fe03,
0x0497f337,0xfe70ec79,0xee47f15e,0xebd4fe2b,0x04040690,0x0af30318,0xefc3f6e2,0xebffec27,
0x0fa2ec18,0x1b45f550,0x037bfd48,0xfffffdbd,0x0aeafa62,0xf638fa8c,0xe0b5035a,0xf7ea1138,
0x10bf1542,0x0107079a,0xf399f87e,0x06f1fb8d,0x141c0ba7,0x074816bb,0xfb881647,0xf9f70e84,
0xfa7106ae,0x030303fd,0x0d17fefa,0x04ebef42,0xf560e736,0xf493fab8,0xf9510f03,0xf99f0109,
0x0239ead0,0x0f2ef7e3,0x0c0213e5,0xff7113f3,0xfba004a0,0xfc2703c6,0xfd790374,0x04a3f239,
0x01d3e5b7,0xeb2eeed7,0xe23afb49,0xf9effce5,0x08a5fd75,0xf36b0004,0xe0f2f8c0,0xee88e8f9,
0x00e4e3af,0x00b8eef9,0xfb2af8be,0xf8ecf76e,0xf454fd3c,0xf44110af,0x01611408,0x0e7cfc3c,
0x0a55f08a,0xf9fd0265,0xf0c50807,0xf866ef82,0x0782e32b,0x0e7cf47e,0x0ae90099,0x04fdfb33,
0xfd9bf95c,0xf20afd9a,0xeb3b036e,0xf235117e,0xfea21656,0x0406ff8b,0x01bef270,0xfa500bde,
0xef1f1938,0xe910f970,0xefe0e4e3,0xfb0bf930,0xfdba02e0,0xfa2df730,0xfbb1057f,0x05ed1da4,
0x11680ad5,0x130dec35,0x07e8f827,0xfaf60d3e,0xf9a5fe46,0x0498ea5c,0x119cf1ed,0x1680ff5f,
0x1003030e,0x05b5047c,0x0126fe92,0xfcb8f45b,0xef03fc3f,0xe73d0ec0,0xf8e30e82,0x0e7603ab,
0x04c304c7,0xec3f0429,0xf0abf579,0x0b98eef3,0x1387fa47,0x06cd038c,0x01fb03d4,0x020e02d3,
0xf3980064,0xe59003d9,0xef7c1601,0x00fd1fa4,0x00610b55,0xf998f854,0xff9807a1,0x026f1e69,
0xf1681996,0xe2ae081b,0xec4802dd,0xfab50572,0xfa0b07f7,0xfd970ad7,0x10fa06dc,0x149cf9d9,
0xfa84f2a2,0xec08f8e7,0xff97036b,0x0be20b06,0xf6240c7c,0xe2a60358,0xecc2f6ae,0xfb8bf490,
0xfb98fbb4,0xfab6036b,0x008a0c88,0x08c5125e,0x14050922,0x1601fa74,0x00fefaa4,0xf1be025e,
0x06e501cb,0x1bdb050d,0x06da14e3,0xec881975,0xf5f808dc,0x02f6ff00,0xfb7405ce,0x01c802f8,
0x15f7f0f5,0x08b6e9eb,0xe834f386,0xee67fb3e,0x0addfe99,0x053804f6,0xeb2d04f8,0xe8bff767,
0xf5d6eba1,0xfc37eebf,0x0027f887,0xffc1ff60,0xf851069c,0xff5a1011,0x149f1189,0x13db0321,
0xfeaef245,0xfdbdf6a0,0x0b180cca,0x00ad13a8,0xeb78001e,0xef40f078,0xfff2f637,0x0335fcfa,
0x00fffcd6,0x05e307d6,0x0e45156f,0x18350901,0x1c4af1fc,0x0da2f68e,0xfb7e0834,0x024d008b,
0x17b6f02f,0x1d54fcda,0x13b614b2,0x0b30126c,0x065e0296,0x06280029,0x0884fe34,0xffafef9f,
0xf005ee5a,0xf24d072e,0x01bb15dc,0x03df0303,0x00dcf071,0x0c25fe17,0x12391593,0x026516d0,
0xf5fc0a2f,0xfc68046a,0x03f1021d,0x0737f9b8,0x0a42ef40,0xffd9e9a7,0xee96ee35,0xf5a7fee8,
0x08870abc,0x0070fd1b,0xf2f1e766,0x082debe1,0x1f1f010c,0x0ec305c5,0xfb35fed7,0x03cf001c,
0x0248fefc,0xe85bf70c,0xe4e6013b,0xfe6218cb,0x05d1158b,0xf944fadb,0xfdfaf61a,0x0cc50b66,
0x06e917fd,0xf61f1404,0xf1e60cec,0xf6f70467,0xfe00fed0,0x07e300ab,0x0bc8f952,0x02a8e671,
0xf775e99c,0xf3db0575,0xf6f30aac,0x0166f289,0x0d6ef01b,0x0b980c62,0xfdf117d9,0xf7300787,
0xf909fdc3,0xfa88ffed,0x0056f79a,0x06a8e843,0xf983e605,0xe412f058,0xeb3efa0e,0x04c4fe65,
0x01ccfe15,0xe7c9f832,0xe6c1ed0f,0xff0be492,0x0885ea0e,0xff07f8ba,0xfa2cfd7e,0xf94dfb36,
0xf49607ce,0xf95f17ce,0x0aad0ab7,0x10d0f1ba,0x01d8f727,0xf2900938,0xf485fcaa,0x0218e56e,
0x0cf7ec7d,0x0d7b0057,0x064501c8,0xfdf5fcd2,0xf56cffa4,0xed0403c6,0xedbd0d56,0xfaa71926,
0x05180cfb,0x0301f3ea,0xfc8ffca7,0xf680188d,0xed630d48,0xea2aeb4a,0xf64ceda7,0x029a035a,
0xffc9ffde,0xfc44fd39,0x075113c2,0x13d915f6,0x12f0f478,0x0a64e9aa,0x01ec040d,0xfac90b40,
0xfbc9f31c,0x088ae90d,0x1433f692,0x126b0112,0x085e03f5,0x00360395,0xfa0dfc4e,0xf1b6fc3a,
0xebcf0e59,0xf42d17b8,0x083c07e3,0x0e37fd88,0xf9f906fd,0xea09058c,0xf99bf258,0x0febee2f,
0x0d72fe88,0x01f0081c,0x01ed058c,0xfc5d0633,0xebc30d7c,0xeef01766,0x07dd1e03,0x0dda14ec,
0xfbd200e8,0xf9d8fe1b,0x0b3011d7,0x08b11edb,0xf0af1768,0xe9bb0b65,0xf92c0582,0x01e2048f,
0x01a10668,0x0b2f01a8,0x12bcf33c,0x0134ef3b,0xead7fdde,0xf37806aa,0x0c1f01e7,0x0a2f06cf,
0xf0f112a8,0xe7080ab6,0xf313f875,0xfcc4f82b,0xfeee0299,0x06140648,0x10e60712,0x15eb0189,
0x1252f11d,0x0544ef78,0xf72304b5,0xfc020843,0x118df405,0x1811fa7a,0x07181a33,0xfac818f8,
0xfdcefd24,0xff4ffc0d,0xfe500520,0x028cefed,0xfd81e05f,0xea7ef9e6,0xe6dd0e58,0xfcacfed4,
0x0a46f73d,0xfd950a61,0xed041030,0xe9a4fee1,0xeef9f4fd,0xf919f7a6,0x0260fb80,0x0381044f,
0x074a0b2e,0x16630077,0x1896f208,0xff9df3e0,0xf025faae,0x03edfc64,0x14e20491,0x01b10eb4,
0xea0e08a8,0xf049fae7,0x003af75d,0x01e9f94f,0x04fafaca,0x149cfdb4,0x1a4ff670,0x0a87e394,
0xfce2e3de,0x0096fdfd,0x049506fa,0xff31ef51,0x02cbe0cf,0x148af01e,0x19f00037,0x0944004a,
0xfd51fcc0,0xffcdfa9c,0xf865f9d1,0xe866022e,0xf1f40e15,0x0ec90cdb,0x1034019e,0xf76bfa05,
0xf61cf5e9,0x10bcf5a3,0x1a580017,0x09aa0bf6,0xfdfb09d8,0xfeb3ffe0,0xfbbaf8eb,0xf3adf32a,
0xec05f49b,0xe72d043f,0xf0d60dcc,0x06dd0204,0x0853f9d8,0xee53029c,0xe578fe75,0xfe79e8aa,
0x0e63e925,0x03470171,0xfd690757,0x01fefe0b,0xf99e0aa9,0xf49f1de5,0x0b6c12b4,0x1c75fd9c,
0x07a6ffd2,0xf2000591,0xffd2fa5e,0x158ef66f,0x14f9068e,0x0a40117f,0x02380bd8,0xfb5a039f,
0xfac9fc5e,0xfb59f471,0xed6ff659,0xe244033e,0xf55a0c45,0x0bfc0b37,0xff7a036f,0xec3ff758,
0xfca6f1d0,0x15ecfca7,0x0f160a00,0xfb900a50,0xf966063d,0xf97d0453,0xebb3fe44,0xe24fffbb,
0xeb0b143b,0xf83d1e23,0xfd5c0730,0xfd8bf66e,0xfbc60b02,0xf4421de6,0xe8cd0d3b,0xe6a2f83d,
0xf420fb45,0x010d03a7,0x008c0457,0x038006ea,0x139f05cd,0x13f0f813,0xf90feeef,0xecfaf881,
0x01c206fb,0x099b0bea,0xf0ab0741,0xe3d9fbc8,0xf69cf22a,0x0511f588,0x0183005f,0x01bb07a6,
0x08f10def,0x0ef510b8,0x16b304a8,0x1430f5f6,0xfcc3fa4f,0xf25a04c6,0x0bde024a,0x1af10484,
0x0018151c,0xeadd15ba,0xf96aff84,0x03fef6f3,0xfc8a0049,0x0476f90f,0x10abe5c3,0xfbcbe937,
0xe2d0fbb4,0xf2e4ffa4,0x0c8afd28,0x022404af,0xeaeb0691,0xea7cf875,0xf694ee06,0xff45f2e0,
0x0598fc4f,0x05240470,0x02010c08,0x0e1f0cb1,0x1cea0322,0x0f37f762,0xf6b7f2c3,0xfc8bfa6a,
0x0fa40a04,0x04e50f96,0xebed025f,0xee72f4d2,0x02ebf5c1,0x0906fa0e,0x06dafbb6,0x107d0321,
0x1c5a04fc,0x189af19f,0x0ad3e2e0,0x0207f521,0x00e1099c,0x0389fade,0x0aede56c,0x15d4f141,
0x185108d8,0x0b300943,0xfd6cfe23,0xfd6efb87,0xfc6dfa96,0xed4af9b8,0xe8dd0456,0x0092112c,
0x118d0c38,0x01b4fb5f,0xf564f33f,0x0965f915,0x1a510506,0x0b610da2,0xf9190b98,0xfa5301b3,
0xfd59f8f4,0xf759f27d,0xf04defa9,0xe924f927,0xe9aa0840,0xfe0b0850,0x0d23fd96,0xf93ffc85,
0xe488fcac,0xf916ef13,0x140ae9f7,0x0a67fdb4,0xfa840bb9,0x007e037f,0xfe3f04ef,0xefc818aa,
0xfdb61aa8,0x1ac8069e,0x120afebc,0xf43603c3,0xf81efe0a,0x11d8f816,0x15e004b7,0x08f91254,
0x00560e74,0xf9c40475,0xf739fd7f,0xfb3cf58d,0xf37cf314,0xe2aefd45,0xeb60098d,0x07260ce4,
0x06fb0713,0xf063fa53,0xf52df147,0x1079f9da,0x132d09f9,0xfe630cac,0xf599070b,0xf7d305a8,
0xef64012b,0xe367fd21,0xe6aa0cb5,0xf4de1ecd,0xfe1c1052,0xfeb2f727,0xfc5c0101,0xf7c71a54,
0xede2141c,0xe6f6fb94,0xf096f6f7,0x01ce003d,0x05390357,0x030504aa,0x0faf04cc,0x17cefa27,
0x0171ef71,0xeb67f53c,0xf9e5033f,0x0c670a92,0xfb7009a9,0xe5590105,0xefb8f4e8,0x03d5f301,
0x0610fd0a,0x041705d7,0x0a100b0f,0x10750e7d,0x161b0588,0x15bef4db,0x02f4f5c4,0xf1e0043c,
0x01d403c6,0x1997fdb1,0x0ce10c6f,0xf154198c,0xf2ad0778,0x00c9f37f,0xfecbf9fb,0xfe9dfbf4,
0x08a9e7c2,0xff05e3bc,0xe63afb9e,0xea2006b0,0x0629fc80,0x0a5efe4f,0xf3dc0a65,0xe87503c8,
0xf0e3f28b,0xfc15f078,0x04a5f970,0x08f700d0,0x07ad0818,0x0d6f09e6,0x1aacfe7a,0x1422f2bb,
0xf8f8f3e5,0xf36bfac2,0x0b4c0186,0x10c80a07,0xf5d20afa,0xe83bfe63,0xfa52f3a1,0x08e8f4bd,
0x068af863,0x0c4efa74,0x1ad1fabd,0x16acef90,0x025ae168,0xfaf8ec47,0x025705f8,0x02e70377,
0xfe8de922,0x07fbe538,0x16d4fb02,0x11ef06ab,0xfedf0257,0xf7e4ff64,0xf9ecfeea,0xf0bd00f3,
0xea180b8b,0xfe4e11dd,0x150d0719,0x0909fb47,0xf167fa4f,0xfad8f816,0x1544f62e,0x151d0267,
0x010a0ece,0xf8990868,0xf924fcc7,0xf2a8fa09,0xea58fa25,0xe8b40128,0xee5c10bb,0xfd500eff,
0x0a8ffa11,0x00c2f999,0xeac20b3b,0xebc5fff1,0x018be4d3,0x0aa7ef90,0x04580c6c,0x02cf09ad,
0x03c801d5,0x012316db,0x08b81ddd,0x17ddfe8b,0x138def0e,0xfd14038e,0xf51f08e9,0x038af45e,
0x1165f1f1,0x125e04f0,0x0a780d25,0xfe41097c,0xf5770590,0xf44cfdc7,0xf051fbe8,0xe7ff0ba4,
0xefcb163b,0x08790a22,0x0f1fff93,0xf85703dd,0xeb380088,0xff41f380,0x1415f658,0x0cd5076f,
0xfd7f0f09,0xfb910c27,0xf83a0bbe,0xec16102a,0xf0221830,0x08221d49,0x0fb411a5,0xfdbafd28,
0xf84ffc8e,0x08ef105a,0x08d21a84,0xf0e41132,0xe9fa0425,0xfcfbfc51,0x07cffacc,0x04e5fdd2,
0x0a3df90b,0x0deeeba8,0xfb3aede4,0xe94e02c3,0xf64c09e4,0x0d31fef2,0x0a490256,0xf54911b6,
0xec320b5b,0xf4ddf659,0x00b1f33b,0x079cfcf8,0x0d30fe8f,0x1393fa99,0x137af3ae,0x074fe962,
0xf987efff,0xf85f087e,0x01220971,0x0951ef6a,0x0ea4f16b,0x0dc61320,0x012d17b3,0xf3d4fc6a,
0xf541f6e7,0xfaf00084,0xf2c0f2d9,0xe74aeb05,0xeb6b08dc,0xf8071bbb,0xff21021d,0x02f9f080,
0x0422067c,0xfb35171e,0xeee30996,0xeedffae1,0xf9edf77f,0x03eff597,0x0a41f898,0x0e55faa2,
0x0bdcec8b,0x00b2e37a,0xf40cf865,0xf21a0b7c,0xffe8fd64,0x0ee0f135,0x0a030565,0xf71415c3,
0xefe4057c,0xf706f27a,0xfae6f344,0xfce8f373,0x0409e82e,0xfee6e3ad,0xe91eee5a,0xe5cffbb9,
0xff79018a,0x09d0003b,0xf2fcfb11,0xe70cf33a,0xfc06ebdf,0x0de3eef9,0x0764ff37,0xfdf20aec,
0xfd3a084d,0xfd500abb,0x01e91754,0x0d810fc9,0x0fbcf303,0x02c1ee81,0xf7080751,0xf5b80a60,
0xfaefefd3,0x0513e8ab,0x0d99fe98,0x097a0bc0,0xfdcc08ba,0xf71e0aed,0xf5401252,0xf95315c9,
0x07ee15d4,0x10050afb,0x024af6a4,0xf793f664,0x02120f7b,0x02691759,0xec4cff5d,0xeaf1efb1,
0x0754f8ba,0x1100fec0,0x048dfbb8,0x0dfbff8f,0x1faffece,0x0d18ed88,0xf14fe6be,0xfa07fb6b,
0x09990cc8,0xfbd60290,0xf091f065,0x011ced08,0x0f8df5f6,0x0b1b021e,0x04fd0b64,0x00010d5a,
0xfa500e94,0x033015fb,0x13b11509,0x0ff6ffaf,0x007fef01,0xfff5fda9,0x02741350,0xf71b0954,
0xf34beeda,0x03c2ed54,0x10600036,0x0dac070a,0x0b4c0591,0x0f220fa3,0x14ad13bd,0x1a48fe5b,
0x152eed2f,0x00eafb4d,0xf6e809b7,0x0734fc77,0x17b9f2f4,0x125d06a6,0x046b1697,0xfb52091a,
0xf6a3f8d9,0xf83ff938,0xf8f1f875,0xeda3f3d2,0xe8a3ffc7,0xfc891369,0x0cc50f76,0x0172f888,
0xfacdf137,0x0c4a01c8,0x111c1159,0xfb050ec6,0xeed9021a,0xf78cf8fa,0xfb56f42a,0xf68cee7a,
0xf25aed43,0xea78f8fe,0xeb2507da,0x026808ab,0x0eb5ffc0,0xf692fb1f,0xe8d6f74c,0x05c0f0e4,
0x1a06f6ed,0x05ba0a0d,0xf68210e2,0xff5f086c,0xfb200bac,0xef901a54,0x03301726,0x1c090413,
0x0bd4fd14,0xf0cc00ad,0xfaa2fcfc,0x125dfb58,0x11020827,0x0125125d,0xf75d0b8a,0xf28affcc,
0xf2d0f92c,0xf573f51f,0xed08f7e3,0xe3b7047a,0xf3d20e22,0x0caa0b7a,0x063d0290,0xefadf99b,
0xf733f51b,0x11f3fc7d,0x11790aaf,0xf9d70fca,0xf1030b36,0xf52a07a9,0xed4f0634,0xe450091e,
0xf1d315fd,0x06281bb1,0x05d0078e,0xfbc3f417,0xfe7b0240,0x01f2190c,0xf496117e,0xe9bffb0f,
0xf735f538,0x09d5fa3c,0x0ad7fc04,0x0922fbcd,0x1150f62f,0x0c82ecdf,0xf344f209,0xea51030c,
0x015206fb,0x106301d7,0xfde707b1,0xe9c60a20,0xf19bf940,0x041aedfb,0x0ab3f85b,0x0c270197,
0x128ffeeb,0x167efab1,0x0f9bf1f0,0x01b6ea78,0xf71cfa53,0xf8860e1b,0x04f6ffc8,0x0f67ed5d,
0x0c6e0488,0xff421d2c,0xf3f207ce,0xf22aefb5,0xf6adf9ea,0xf6c1fba8,0xee7ce8dc,0xe906f51b,
0xf05b17a8,0xfd621204,0x04a3f33a,0x04e1f818,0xff39118d,0xf46e0f30,0xee5bfc31,0xf622f4b2,
0x03b2f30e,0x0aeaf3db,0x0d2df9d2,0x0d85f420,0x0635e4a0,0xf7d6ecce,0xf05607ac,0xf91608c3,
0x08fef482,0x0d66f8a9,0x001c103f,0xf1390fb5,0xf0fbf8be,0xf879ee70,0xfba0f248,0xfe67ee40,
0xff75e56c,0xf212eafc,0xe429fc7e,0xf2c505cc,0x0b8901d4,0x0386fddb,0xea12fcd9,0xeebef4ad,
0x08b3ecab,0x0f24f7ea,0x04d20bec,0x01580ea7,0x0286098a,0x04b41208,0x0de51433,0x11aafb50,
0x0480e96f,0xf8bcfc7d,0xf9f11050,0xfa0b00b7,0xfa41eab8,0x0755f209,0x1168066d,0x07b50dbd,
0xfc300d90,0xfcd311bd,0x006c1655,0x087413f7,0x13de0856,0x0af2f8f6,0xf4d8f507,0xfa9e02f7,
0x0e9b1106,0xfefd0cb1,0xe431fcb5,0xf4e3f2a7,0x1209f336,0x0b3af7c6,0x03a0f8dd,0x1692f337,
0x12f8ec27,0xef05eda3,0xea13f949,0x084d0589,0x0af50853,0xf1c8ffbe,0xf053f393,0x047befc3,
0x0d41f83c,0x0cd504b1,0x0baf0c72,0x057a0f6d,0x07ce0f95,0x180f0a06,0x16b3fd06,0xfd09f163,
0xf532f566,0x07610791,0x087b104e,0xf2ae01b9,0xef91f009,0x05b0f137,0x12d8fa8f,0x0f24fca2,
0x103cff72,0x18d10395,0x16e3f76c,0x0722e5aa,0xfa8ceffe,0xfb640a6f,0x00d007d3,0x036feecd,
0x09c4ee85,0x11520741,0x08cd11a1,0xf4910827,0xeede019b,0xf5540207,0xef9b04c7,0xe9ef0ce8,
0xff1511e3,0x15d50804,0x0848fb2b,0xf096f925,0xfa90fa4f,0x12d8fbda,0x0ffe069f,0xfaba10de,
0xf0e20a99,0xf18efe8c,0xeecdfc32,0xea2affe7,0xeb8f0835,0xf61f1359,0x05b20d6e,0x0c04f7f5,
0x0025f836,0xf0d60c59,0xf22b046d,0x0144e835,0x0d30efe5,0x0e820f50,0x09b81004,0x073203de,
0x0c3c11d9,0x139215ef,0x1232f503,0x06ece687,0xfb4e036f,0xf76d0fd6,0xfd82f6d5,0x096bed71,
0x0fec01fc,0x09760edc,0xfcc30d81,0xf4340d35,0xf0d10976,0xf0b907de,0xf6a61565,0x03051973,
0x0d9f00b8,0x0b46f1b5,0xfbb10446,0xf0990d60,0xfa38f6ce,0x0cabec32,0x107f01f2,0x08411337,
0x04980f81,0x02e20f65,0xff1518b1,0x07cd165f,0x18e20585,0x1253f977,0xf742fb21,0xf4190064,
0x0ce401b0,0x13cd0625,0xfda10f85,0xee780cbd,0xf3bcf922,0xfaa6edad,0xfbaff3ab,0xf910f362,
0xf0e2ecc6,0xed32fcbb,0xf9191603,0x05b10d56,0x04c4f161,0x0374f517,0x06c30ff1,0xfe401320,
0xef0aff23,0xf06ff35b,0xfd1af214,0x00a1ee62,0xfc4ceb13,0xf55aee93,0xec18f8ec,0xf13106bf,
0x07b30c80,0x0b0a0219,0xf400f4a4,0xf487f3cf,0x1387fcd1,0x16680847,0xf7a3118e,0xefa61060,
0xfd080906,0xf4ce0d4a,0xed5c180f,0x09691223,0x1c130109,0x011bfb4b,0xecd5fccd,0x02c0fb2f,
0x14590182,0x04dd0f4d,0xf3e20f04,0xf11f00e3,0xefc0f844,0xf196f575,0xf4bdf30b,0xeb71fa81,
0xe73309b0,0xfecd0e67,0x11f60724,0xffedfec5,0xee49f73a,0x020af657,0x169803df,0x07311162,
0xf0c10f1d,0xf0bd0890,0xf35e082a,0xea360769,0xeb820b3f,0x000c1747,0x0d2b12dc,0x0482f872,
0xfbb6f0c4,0x017108ba,0x02931541,0xf3830421,0xed52f3a6,0xff90f1a9,0x0fbaf2e3,0x0bd3f602,
0x089ff6d9,0x0c8decf0,0xfff4eaab,0xea90fec0,0xf1920bdb,0x0c84009b,0x0e97fd0d,0xf7450b0c,
0xece907a0,0xf89bf142,0x05a5ebb8,0x0bd2f6da,0x0ff6f985,0x11c1f566,0x0cdef1b7,0x0030eb98,
0xf42cf22b,0xf5c10a84,0x00e40edf,0x0565f441,0x0580ee55,0x09910cfa,0x033a199a,0xee62034c,
0xe813f7cc,0xf4b20002,0xf215fcda,0xe3a2f8ec,0xefc40c9c,0x09b419f1,0x083603f3,0xfb34ee1f,
0x02f1fb23,0x08e01095,0xf7d50dd5,0xec9afd1c,0xf698f201,0xffbdee0a,0x0295ee8a,0x062fefaf,
0xfe34ec5e,0xedc5ee93,0xf0580244,0x00d212ee,0x02f1051b,0xff1aee66,0x0774f7f7,0x08f31376,
0xf7241307,0xeaeefbd7,0xefc7f4b3,0xf39cfa0d,0xf031f329,0xed3af121,0xecfa0810,0xf577170c,
0x078503c3,0x0d8af356,0xfdac02b3,0xf0720df7,0xf5a2fa76,0x0151e9fa,0x0c34f5be,0x142a051a,
0x11070595,0x0c6c0351,0x14e700ec,0x147ef5fa,0xfa46ee03,0xec8df7fd,0x01f40876,0x0d0d0bfe,
0xf6e6018c,0xed9bf4bc,0x04fdf0dd,0x1574f918,0x101e0401,0x0d9708a7,0x124e0949,0x12f10499,
0x1073f60b,0x0680ed84,0xf38dfb62,0xf11d0936,0x0827ffb8,0x12e2f967,0xfe790bcf,0xec771277,
0xf100f7f2,0xf884e71c,0xf922f3a5,0xfa1df53c,0xf6d0e74a,0xedd0f5a4,0xefae1483,0x00230e8e,
0x0bfbf3fa,0x07b3fa0c,0xfaaa0f72,0xf182068f,0xf57befe8,0x03e9ed68,0x0e96f4ca,0x101ff763,
0x102ef9a3,0x0ebdf4d5,0x044de955,0xf5a3f194,0xf0fa0a37,0xfbc60a6c,0x0b6ef66c,0x0c6cfbc0,
0xfa1f120c,0xec0f0a69,0xf343eec8,0xfe0ae9e9,0xfdaff38f,0xfec9ee3c,0x0029e790,0xf1a3f591,
0xe79e07c7,0xfdba094b,0x13b002f3,0x02f60177,0xeca0fef4,0xf9cbf630,0x1137f32a,0x127a006c,
0x0b0110fd,0x08931270,0x06ec0c83,0x0bed0e25,0x14ed09c4,0x0c7ff3ea,0xf9c5ea7e,0xf93301bf};

#pragma DATA_SECTION(txSeqEven,".aifdescmsm");
Uint32 txSeqEven[2048] = {
0x0986f68d,0xfd62fcc9,0xf3b40925,0x03b70a6f,0x116bfec6,0x0896f59f,0xfe15f44b,0xfde5f2d2,
0xfc87f239,0xfa44f5a3,0xfffaf482,0x08baf1a1,0x0be2fdc1,0x076f0e72,0xfcd0081b,0xf5fbf769,
0xfd3cfcb0,0x088209f9,0x06f60074,0xfc00f18f,0xf4affae4,0xf5210ca6,0xfc640e78,0x04a10a54,
0x05100cb0,0x01cc0df5,0x02420ba9,0xfcc30abc,0xf0420559,0xf459f909,0x084af411,0x09b3fdd8,
0xf92b0890,0xfb3d065d,0x0b07fb1e,0x04b6f53b,0xf15afc38,0xf22507e7,0xffd30cf1,0x03b50cba,
0x03210cba,0x06030b43,0x03cd0a19,0xfb440cb7,0xf53d084d,0xf59df7aa,0xfddff17e,0x09320084,
0x086407d1,0xfaf1fab6,0xf618f842,0x00f10922,0x0b170ad4,0x0b1af6a7,0x04d1ed7b,0xfc78f4f8,
0xf876f606,0xfb38f14d,0xfcb3f3f3,0xfe5df69c,0x09a9f5aa,0x107cfead,0x01e00cd2,0xf4ae09d5,
0xff0cf996,0x0752f5a5,0xfb1801e9,0xf7a60ac4,0x09540533,0x1037f91c,0x024df25c,0xf8f0f301,
0xf9fdf51f,0xf8a8f62f,0xf825f70d,0xfe9df544,0x0634f424,0x0b57fe4e,0x0a190c8f,0xfd21099a,
0xf369fc4d,0xfed5fe59,0x0cc60716,0x03fefe70,0xf3f1f553,0xf4c4046f,0xff1714f0,0x05a50e0c,
0x09ae050c,0x0aac0ab2,0x07e70c67,0x05af0693,0xff720a26,0xf3ab0c26,0xf3e4fb24,0x02c8eec7,
0x0743fd97,0xfea00d0d,0x00010305,0x05d2f417,0xfbbff92c,0xf1f60821,0xfd250e3c,0x0b4d0b33,
0x0b8c070d,0x09d604f3,0x0b69048f,0x08000680,0x017e0a7d,0xfa370996,0xf1fdfe67,0xf69df440,
0x08acf84f,0x09b300a0,0xf5f7fff2,0xf4a4ff80,0x0a4103d9,0x0e1cfcd1,0xfb5fedb2,0xf26af019,
0xf562fedb,0xf30cff25,0xf159f812,0xf6c5fc1d,0xfabefbec,0xfffcefec,0x0ac2f4b8,0x0bfb0bac,
0xff870d40,0xf8c7f885,0xfcf6f6d8,0x00e408bc,0x04ec08d7,0x085bf6a7,0x0007f026,0xf242f8e3,
0xf0720030,0xf57a025a,0xf55b02d4,0xf552008e,0xf8b4fb95,0xfcc3f651,0x0720f556,0x1102fe43,
0x070c0a6a,0xf7d00979,0x00a8fcf5,0x0d1bf7d5,0xfec3ff65,0xf2f30876,0x06a70bba,0x17bc06dc,
0x0dd5fbc5,0x0743f63e,0x0f42fac9,0x0d2afcf9,0x0546fc33,0x0956063e,0x06e710d9,0xf401067d,
0xf02ef6ac,0x041bfb27,0x0cc30450,0xfefffd9f,0xf595f9ec,0xfca206ce,0x083c0ce5,0x0eb80065,
0x0d16f51c,0x0684f48e,0x03e6f5c8,0x0604f748,0x0716fb60,0x080f007d,0x06920919,0xfb640fd8,
0xf19e058e,0xf882f4c0,0x023afa82,0xff770cb0,0xfe3c078c,0x02b6f3fd,0xf98ef66a,0xeb76095c,
0xf3b90fc1,0x03850c01,0xff790ce4,0xf8c20d1c,0xff64080f,0xfc2a03ec,0xee7ffe3f,0xf7cff4aa,
0x0eb0f3bc,0x0a8affb9,0xf7610870,0xfbbc044a,0x0a54fba7,0x0343f7f5,0xf369fccb,0xf41007fa,
0xff1b0f68,0x061b0d39,0x07d208bd,0x05a8078c,0x019d06ff,0xfe120677,0xf7ea0323,0xf2c5f779,
0xfb96ee91,0x0b8ef79d,0x0a13033a,0xf973fd41,0xf5f0f774,0x03fd021c,0x0c7703a2,0x0588efdc,
0xfa1ee832,0xf3adf788,0xf3c5fd92,0xf71bf538,0xf8caf768,0xfb8dfce6,0x052ff487,0x0dd7f4d8,
0x09bf0a5e,0xff531131,0xfb61fc20,0xfc95f346,0xfeca0475,0x04690b35,0x0851fac8,0x012eefb0,
0xf52cf635,0xf0feff4a,0xf3c802d8,0xf70b0357,0xf9b700fa,0xfaeffca3,0xfd50f841,0x0803f5b9,
0x12e1fb4e,0x0bd10887,0xfc910ca7,0xff620021,0x0b08f61f,0x042efd57,0xf8a40942,0x052d0a91,
0x17cb0293,0x126ef8cb,0x0590f3c1,0x08a1f67e,0x0c45fa9e,0x058bfba4,0x05eb01bf,0x0a540cef,
0xfcc70c82,0xed51ff4b,0xf9fdf928,0x0d94fd88,0x050ffe9c,0xf3dcfeb2,0xfba605ab,0x0df00743,
0x0edafaf4,0x04d1f05f,0xffb9f1cf,0xfe46f5fb,0xfdfff7ff,0x01c4fad6,0x06fdfda7,0x08f403ea,
0x05640fc0,0xfb4310f7,0xf2e400be,0xf926f9b8,0x06e30743,0x074a0a84,0xfab0fabc,0xf40cfb96,
0xf984120b,0x03031783,0x0a42084d,0x0b450500,0x06960bda,0x035d0707,0x00c20242,0xf79008a6,
0xf1010319,0xfa46ef6d,0x06a5f0b7,0x0569074c,0x00800aa8,0x0186f829,0xfe1ef548,0xf7f106e8,
0xff6e0fa0,0x0e0307ae,0x1028fefb,0x0a04fc1f,0x07dbfc44,0x0616ff07,0x02310362,0xfe990732,
0xf5b107f3,0xec9d0083,0xf565f429,0x0522f353,0xfff10176,0xf3e20966,0xfd9eff4a,0x0740f3d8,
0xf585f6bd,0xe61401ea,0xf30b0a07,0xfee70ba7,0xf7aa0855,0xf6bd0478,0xfefc01ba,0xf9eefb3b,
0xf582f25c,0x07a5f2ec,0x1465fe05,0x02d5058d,0xf397040d,0x008b004a,0x0c07fc25,0xff19f8b6,
0xf147fe1b,0xf6750a92,0x023b0f8d,0x07350a4b,0x067b0574,0x032e03cf,0xff280214,0xfb0d005d,
0xf5fafa82,0xf63fef1c,0x02cced24,0x0e1cfa7d,0x05710178,0xf56ff95f,0xf8f0f85b,0x096a00ef,
0x0a98f9db,0xfb2fe937,0xf134ee38,0xf2eaffd5,0xf5fdff8a,0xf7acf780,0xfbc7fc21,0x0144fcea,
0x06f3f236,0x0cf2f7e5,0x0cf00d6f,0x021d0cfb,0xf74cf8e8,0xfa71f87b,0x06230777,0x091702e2,
0xff36f272,0xf464f512,0xf25704ae,0xf7480a92,0xfcc307e8,0xff610512,0xff0c00b6,0xfd6dfb8f,
0xfee9f668,0x0717efde,0x102df231,0x0f3b02c6,0x059109ec,0xffe0f977,0x0167efcd,0x03c10068,
0x07ee0a20,0x0ec4f769,0x0c4ee7d3,0xfe35efcb,0xf7c8f7a2,0xff46f457,0x030ef721,0x0160fecc,
0x094cfe3b,0x10b200ee,0x04310e85,0xf5260f03,0xfaecfabc,0x0477f1ec,0xff8e0194,0xfe090b1c,
0x0860fddb,0x0796f020,0xf7a7f2f0,0xf084fc7e,0xf68301a0,0xfaee024c,0xfd44002d,0x01eafc75,
0x05a3f951,0x0c1af8f9,0x150bfef0,0x0f8f09f5,0xfe480d0e,0xfe2500ce,0x0c5bf56d,0x08a3fbfd,
0xfbc0095e,0x072808d7,0x1a13fc40,0x1185f32f,0x0063f290,0x03e5f5d6,0x0988f9fa,0x021dfe18,
0x031e02ec,0x0bcc0985,0x00620d2c,0xedb20720,0xf696fb62,0x0a78f642,0x0548fc12,0xf72a049d,
0xff720592,0x0e58fca3,0x08eaf222,0xf9def092,0xf541f779,0xf8dffd74,0xfd29febc,0x01a8fe72,
0x0611fe11,0x0bb1fff4,0x11220808,0x0b14103d,0xfa830cfb,0xf8320200,0x0994fd4a,0x0ea1ffe2,
0xfd460309,0xf8f907e6,0x0e280c02,0x195a04b3,0x0ce1f708,0x0518f564,0x099dfdd2,0x064e0023,
0xfedd007d,0x01690993,0xfee40deb,0xefaf015b,0xf070f595,0x072ff93d,0x0d96fef9,0xfab4fe20,
0xf55400d5,0x07de050a,0x1110fd48,0x05d1f094,0xfb8deff1,0xfa88f7e7,0xfbbffc94,0xff4bfe9a,
0x051200da,0x087c034c,0x09ee0a6c,0x06ab12e2,0xf9f50e41,0xf2d7003c,0x0147fdd1,0x0f7f0501,
0x03910354,0xf3fc004a,0xff370af9,0x1279117c,0x11b402eb,0x0901f61d,0x08affcd6,0x067702fb,
0xfeabff05,0xfcb90390,0xfb930c8b,0xf1e50241,0xeff9f0e8,0x0157f4ff,0x0dc10203,0x0261ff43,
0xf53cfa20,0xfd56029d,0x0d060614,0x0e3af87f,0x03b0ee1e,0xfbfaf2c9,0xfb80fa09,0xfe5dfd6e,
0x019500f2,0x04ba0432,0x06d30935,0x037d119f,0xf8d9108f,0xf1aa014d,0xfaa7fa32,0x09e50445,
0x0844074c,0xf888fdde,0xf6040258,0x0658124f,0x11720dda,0x0ce5fa89,0x071df8cb,0x05c60294,
0x00eb005e,0xfabafe1f,0xf8a707da,0xf48d05fa,0xf027f279,0xf9f0ee3d,0x0ae5fec7,0x09220339,
0xf83ef90b,0xf66ffbee,0x06b506e8,0x0f49006e,0x080bf0bc,0xff18eef1,0xfb8ff70b,0xfb8cfc1d,
0xfee5ffa8,0x0327038f,0x04550730,0x023d0e50,0xfb9a121f,0xf234066e,0xf39cf8f0,0x03b8fe93,
0x0b860841,0xfdb3011d,0xf2b9fc90,0xfe830b81,0x0e22126e,0x0dec00fa,0x07b3f54f,0x0575fe02,
0x00fd01f1,0xfa88fc8b,0xf8960236,0xf5a40889,0xef14f9fa,0xf348ebb2,0x0497f665,0x0b6b0343,
0xfdf2fcb7,0xf3f2f83f,0xfe65028b,0x0ca703ec,0x0b2ff4d2,0xffaeece2,0xf8f8f3e7,0xf9bcfb4b,
0xfcf3feae,0x00250243,0x032c054e,0x04610a63,0xffc31178,0xf5330d6e,0xf037fdf7,0xfb8cf999,
0x09ff037c,0x04ce0465,0xf491fd44,0xf718048d,0x0a911004,0x112605b6,0x072bf469,0x01ddf740,
0x020b00e0,0xfbc7fe78,0xf632feee,0xf722086f,0xf22e040d,0xeb6af229,0xf7b6efd4,0x0ad2fcc9,
0x050fff72,0xf26cfa6e,0xf68dff0e,0x097d02c8,0x0af8f7aa,0xfd3ced2a,0xf5d9f20c,0xf69dfb92,
0xf945ff77,0xfe7c017c,0x03600399,0x04e20669,0x05150d6f,0xff231193,0xf1ee0865,0xf176fc35,
0x0455fc84,0x0b3b01bd,0xf9180136,0xf2310384,0x07050a1f,0x138104b2,0x067df560,0xfca3f2aa,
0x0003fcdf,0xfcb000fa,0xf549007b,0xf8750750,0xf7dd0b78,0xea2100f0,0xea14f4f5,0x0014f595,
0x0878fb92,0xf78cff0b,0xf1060218,0x019d011c,0x0980f78b,0xfb6fefc9,0xef2cf483,0xf1bafe6c,
0xf88702ba,0xfd3f0298,0x01b1022b,0x05c7026e,0x09a60639,0x09480d8a,0xfd580ff4,0xf1110800,
0xf8fffcf3,0x0864f9a8,0x0223002c,0xf456086b,0xffb507ea,0x123cfd75,0x0885f3fa,0xf510f475,
0xf7a9fb34,0xff2e0105,0xf87d0527,0xf7950921,0xffe90c96,0xf6c50dba,0xe5dc0826,0xef57fb83,
0x035ff497,0xfe74fdf5,0xf2550a24,0xfbc50568,0x0512f696,0xf7e6f330,0xeae9fd33,0xf05a0633,
0xf99307cf,0xfd9a0543,0x02070175,0x0552fe8b,0x07b0fe2b,0x0de10147,0x0d460967,0xfe321090,
0xf528093a,0xfe0bf83f,0x031bf7b8,0xfc7a094d,0xffb20c2f,0x0a9af831,0x036eee4b,0xf1d2fa73,
0xf1de0341,0xfd09018b,0xfe71060c,0xfe190cbf,0x05e609f5,0x06400ba0,0xf8b116b3,0xf03b115d,
0xf543facc,0xfb84f7df,0xfdec0b3d,0x002a0d93,0xfdf2fae5,0xf4aaf750,0xef3b0807,0xf57e112d,
0xff950bfc,0x03b9059b,0x028e00b8,0x0149fbc4,0x0296f8e2,0x06edf644,0x0c76f793,0x0d9f04bb,
0x05b30f90,0xf9c504a0,0xf6ebf70b,0x00e300aa,0x095f0ada,0x034bfb7c,0xf662eeee,0xf206ff76,
0xf71e0f73,0xfd7c07e5,0x02f901b5,0x07e007f2,0x0a150509,0x0bcbfdfd,0x0ec909fd,0x0a281810,
0xfaab0da0,0xf329fea7,0x001d033a,0x0c2908c5,0x022300dc,0xf2fb0034,0xf7400def,0x065b1332,
0x0b930904,0x0705ffd4,0x022ffd58,0xfe4afbd0,0xfaa3fa6a,0xf8eef788,0xfb4af1ac,0x04c7f1e5,
0x0ec8fd18,0x086206be,0xf6f305ca,0xf80c0108,0x09a0fd63,0x0697fa64,0xf046fde4,0xf0400922,
0x05fc0edb,0x0aff0822,0x01d2ff5d,0x05cdfbbf,0x0b53f8df,0x0367f513,0x05d7f4ac,0x170dfa67,
0x1395052d,0xfcd10cc3,0xfb2e066f,0x0a57f8e7,0x0667f90c,0xf9de07a8,0x02af0e22,0x11f30434,
0x0e7ef93b,0x02fff764,0xfde6fabd,0xfa79ff2b,0xf79702ca,0xf6c903c2,0xf22e0230,0xef66fc19,
0xfa66f250,0x0763f333,0x055a046c,0xfeae0c88,0xff3efc73,0xfd55f342,0xf8850620,0xffcc13d0,
0x0d0f0483,0x0c5bf5d8,0x01a8faad,0xfc81fbe2,0xfab4f41e,0xf626f72f,0xf487fb4f,0xf9e9ee58,
0x0304e856,0x0ae9fc3a,0x0977095d,0xfd2ffbe8,0xf683f486,0x00bd0214,0x0c5f054f,0x08daf4f5,
0xfd77edce,0xf722f846,0xf76401de,0xfbd4051c,0x00e207dd,0x01f809d4,0x00880c7e,0xfda51006,
0xf5090a5e,0xef59fc3f,0xfc27f7ac,0x0c66fef7,0x03c50232,0xf2600141,0xfbea0541,0x10d304bb,
0x0b59f852,0xf80cf12b,0xf655f9e2,0xfb6f03b1,0xf5bb0582,0xf41807bb,0xfaa40bdb,0xf43109dc,
0xe7d8011f,0xf20af7bd,0x0601f4b8,0x02fbfd4f,0xf5a208e3,0xfb3005c8,0x0561f741,0xfbb9f3e9,
0xee1d0000,0xf33909e1,0x00a70989,0x0600052c,0x069900a2,0x089afd4a,0x0b54fcea,0x0e5aff25,
0x0d8b05d4,0x03ad0f14,0xf8e30bd1,0xf8fbf9e3,0xff80f54c,0x02ee0700,0x04480b5b,0x0329f60d,
0xfaaeef0e,0xf2740400,0xf6cd0f15,0x021705dd,0x0785052e,0x08770bee,0x0b1a05f8,0x0cd0034f,
0x08de125f,0xfee31643,0xf4c002a1,0xf6b4f963,0x055404b4,0x0ad606a1,0xfc96fcf2,0xf23d0199,
0xfd900f1a,0x0c0a0cdc,0x0b39ff82,0x03b3f8d0,0xff6ef839,0xfbccf7cc,0xf8aaf768,0xf90af490,
0xfdc3f091,0x07e1f42e,0x0eaaff5a,0x041b0769,0xf58706b7,0xfce2ff3f,0x0a51f7ea,0xfe96fb54,
0xef2d082e,0xfe180d42,0x12080505,0x0a8afcca,0xff50f90b,0x0516f414,0x0506f1ef,0xfbfff446,
0x0468f23e,0x140af27b,0x0d47025e,0xfe220f01,0xfed00172,0x01eef1d4,0xfd82fd3b,0x01eb0c75,
0x0cd5028d,0x0949f206,0xfbe4f342,0xf6b2fd48,0xf7f8038c,0xf8d307e2,0xfaef0a47,0xfb020ac0,
0xf5510b8a,0xf1080510,0xf4a4f677,0xfed9f416,0x093b01f3,0x06e80627,0xf783fcf7,0xf522ff7f,
0x08bb09b5,0x10fb013d,0xff9ef0a2,0xf452f3e8,0xf97d01ad,0xf6af046a,0xef5a0395,0xf5b5086e,
0xf797079b,0xeaf2fd18,0xeffdf4fd,0x08b5f587,0x0a3afcd1,0xf6840653,0xf83e070a,0x0806fb77,
0x0169f423,0xf101fca9,0xf44308d1,0x013a0b58,0x072906b8,0x0a5d012b,0x0be8fda8,0x0a63fd6d,
0x0d4afef7,0x0fec03a9,0x05be0d17,0xf8e70e49,0xf8b7fdff,0xfdf2f383,0x014201c1,0x061b0c13,
0x04d5fb23,0xf87eefa8,0xf2e80247,0xfc561224,0x04d2091f,0x07e301d7,0x0d410737,0x0ebc048b,
0x0a82feb0,0x0bd20945,0x09e613d2,0xf83e0954,0xefe5fc0f,0x02cefdbb,0x0e9500af,0xfdccfe4f,
0xf311030c,0x020a0b00,0x0e75060d,0x090ff8f5,0x0051f3cf,0xf9e1f745,0xf4a8fa99,0xf51efb06,
0xf5f7f9b1,0xf3cbf681,0xfc3df290,0x0c0ff44a,0x0a7500de,0xfc590c82,0xfc4a04a4,0x02b5f444,
0xfc59f997,0xf9210da0,0x06960c5c,0x0ea2f84c,0x0510f263,0xfb37f8ec,0xf8a0f625,0xf630f2f2,
0xf583f9ba,0xf90ef7b8,0xfe4aec34,0x0761f364,0x0e0007ff,0x03940851,0xf3fbfad0,0xf99efd4e,
0x0a4a05b7,0x08bafcfd,0xf9d4f2ca,0xf3cafbf2,0xf7af0a6f,0xfe920ce8,0x064a09d9,0x089209ba,
0x05ec0aa2,0x06960bf3,0x02d80d98,0xf41d0a17,0xf0c3ff32,0x025af59d,0x09b1f8e1,0xfc73064e,
0xfaf90a7c,0x091cfcbd,0x05cff1d3,0xf33cfb37,0xf1700913,0xfe7b0ab3,0x03f80a72,0x03ee0e7d,
0x06d70c27,0x05ea0891,0xfe580f2b,0xf6dc0ee7,0xf40dfb96,0xfa47f1af,0x06fd00c5,0x09760900,
0xfcd7fc03,0xf53bf905,0xfd84090e,0x087e0cdd,0x0ba7fcc6,0x07bff228,0xff3cf421,0xf9a9f52a,
0xfbdcf34d,0xfd52f34c,0xfd9ef353,0x0842f598,0x1162ff4d,0x03e509a5,0xf3cf08bf,0xfd5dfdd4,
0x0986f68d,0xfd62fcc9,0xf3b40925,0x03b70a6f,0x116bfec6,0x0896f59f,0xfe15f44b,0xfde5f2d2,
0xfc87f239,0xfa44f5a3,0xfffaf482,0x08baf1a1,0x0be2fdc1,0x076f0e72,0xfcd0081b,0xf5fbf769,
0xfd3cfcb0,0x088209f9,0x06f60074,0xfc00f18f,0xf4affae4,0xf5210ca6,0xfc640e78,0x04a10a54,
0x05100cb0,0x01cc0df5,0x02420ba9,0xfcc30abc,0xf0420559,0xf459f909,0x084af411,0x09b3fdd8,
0xf92b0890,0xfb3d065d,0x0b07fb1e,0x04b6f53b,0xf15afc38,0xf22507e7,0xffd30cf1,0x03b50cba,
0x03210cba,0x06030b43,0x03cd0a19,0xfb440cb7,0xf53d084d,0xf59df7aa,0xfddff17e,0x09320084,
0x086407d1,0xfaf1fab6,0xf618f842,0x00f10922,0x0b170ad4,0x0b1af6a7,0x04d1ed7b,0xfc78f4f8,
0xf876f606,0xfb38f14d,0xfcb3f3f3,0xfe5df69c,0x09a9f5aa,0x107cfead,0x01e00cd2,0xf4ae09d5,
0xff0cf996,0x0752f5a5,0xfb1801e9,0xf7a60ac4,0x09540533,0x1037f91c,0x024df25c,0xf8f0f301,
0xf9fdf51f,0xf8a8f62f,0xf825f70d,0xfe9df544,0x0634f424,0x0b57fe4e,0x0a190c8f,0xfd21099a,
0xf369fc4d,0xfed5fe59,0x0cc60716,0x03fefe70,0xf3f1f553,0xf4c4046f,0xff1714f0,0x05a50e0c,
0x09ae050c,0x0aac0ab2,0x07e70c67,0x05af0693,0xff720a26,0xf3ab0c26,0xf3e4fb24,0x02c8eec7,
0x0743fd97,0xfea00d0d,0x00010305,0x05d2f417,0xfbbff92c,0xf1f60821,0xfd250e3c,0x0b4d0b33,
0x0b8c070d,0x09d604f3,0x0b69048f,0x08000680,0x017e0a7d,0xfa370996,0xf1fdfe67,0xf69df440,
0x08acf84f,0x09b300a0,0xf5f7fff2,0xf4a4ff80,0x0a4103d9,0x0e1cfcd1,0xfb5fedb2,0xf26af019,
0xf562fedb,0xf30cff25,0xf159f812,0xf6c5fc1d,0xfabefbec,0xfffcefec,0x0ac2f4b8,0x0bfb0bac,
0xff870d40,0xf8c7f885,0xfcf6f6d8,0x00e408bc,0x04ec08d7,0x085bf6a7,0x0007f026,0xf242f8e3,
0xf0720030,0xf57a025a,0xf55b02d4,0xf552008e,0xf8b4fb95,0xfcc3f651,0x0720f556,0x1102fe43,
0x070c0a6a,0xf7d00979,0x00a8fcf5,0x0d1bf7d5,0xfec3ff65,0xf2f30876,0x06a70bba,0x17bc06dc,
0x0dd5fbc5,0x0743f63e,0x0f42fac9,0x0d2afcf9,0x0546fc33,0x0956063e,0x06e710d9,0xf401067d,
0xf02ef6ac,0x041bfb27,0x0cc30450,0xfefffd9f,0xf595f9ec,0xfca206ce,0x083c0ce5,0x0eb80065,
0x0d16f51c,0x0684f48e,0x03e6f5c8,0x0604f748,0x0716fb60,0x080f007d,0x06920919,0xfb640fd8,
0xf19e058e,0xf882f4c0,0x023afa82,0xff770cb0,0xfe3c078c,0x02b6f3fd,0xf98ef66a,0xeb76095c,
0xf3b90fc1,0x03850c01,0xff790ce4,0xf8c20d1c,0xff64080f,0xfc2a03ec,0xee7ffe3f,0xf7cff4aa,
0x0eb0f3bc,0x0a8affb9,0xf7610870,0xfbbc044a,0x0a54fba7,0x0343f7f5,0xf369fccb,0xf41007fa,
0xff1b0f68,0x061b0d39,0x07d208bd,0x05a8078c,0x019d06ff,0xfe120677,0xf7ea0323,0xf2c5f779,
0xfb96ee91,0x0b8ef79d,0x0a13033a,0xf973fd41,0xf5f0f774,0x03fd021c,0x0c7703a2,0x0588efdc,
0xfa1ee832,0xf3adf788,0xf3c5fd92,0xf71bf538,0xf8caf768,0xfb8dfce6,0x052ff487,0x0dd7f4d8,
0x09bf0a5e,0xff531131,0xfb61fc20,0xfc95f346,0xfeca0475,0x04690b35,0x0851fac8,0x012eefb0,
0xf52cf635,0xf0feff4a,0xf3c802d8,0xf70b0357,0xf9b700fa,0xfaeffca3,0xfd50f841,0x0803f5b9,
0x12e1fb4e,0x0bd10887,0xfc910ca7,0xff620021,0x0b08f61f,0x042efd57,0xf8a40942,0x052d0a91,
0x17cb0293,0x126ef8cb,0x0590f3c1,0x08a1f67e,0x0c45fa9e,0x058bfba4,0x05eb01bf,0x0a540cef,
0xfcc70c82,0xed51ff4b,0xf9fdf928,0x0d94fd88,0x050ffe9c,0xf3dcfeb2,0xfba605ab,0x0df00743,
0x0edafaf4,0x04d1f05f,0xffb9f1cf,0xfe46f5fb,0xfdfff7ff,0x01c4fad6,0x06fdfda7,0x08f403ea,
0x05640fc0,0xfb4310f7,0xf2e400be,0xf926f9b8,0x06e30743,0x074a0a84,0xfab0fabc,0xf40cfb96,
0xf984120b,0x03031783,0x0a42084d,0x0b450500,0x06960bda,0x035d0707,0x00c20242,0xf79008a6,
0xf1010319,0xfa46ef6d,0x06a5f0b7,0x0569074c,0x00800aa8,0x0186f829,0xfe1ef548,0xf7f106e8,
0xff6e0fa0,0x0e0307ae,0x1028fefb,0x0a04fc1f,0x07dbfc44,0x0616ff07,0x02310362,0xfe990732,
0xf5b107f3,0xec9d0083,0xf565f429,0x0522f353,0xfff10176,0xf3e20966,0xfd9eff4a,0x0740f3d8,
0xf585f6bd,0xe61401ea,0xf30b0a07,0xfee70ba7,0xf7aa0855,0xf6bd0478,0xfefc01ba,0xf9eefb3b,
0xf582f25c,0x07a5f2ec,0x1465fe05,0x02d5058d,0xf397040d,0x008b004a,0x0c07fc25,0xff19f8b6,
0xf147fe1b,0xf6750a92,0x023b0f8d,0x07350a4b,0x067b0574,0x032e03cf,0xff280214,0xfb0d005d,
0xf5fafa82,0xf63fef1c,0x02cced24,0x0e1cfa7d,0x05710178,0xf56ff95f,0xf8f0f85b,0x096a00ef,
0x0a98f9db,0xfb2fe937,0xf134ee38,0xf2eaffd5,0xf5fdff8a,0xf7acf780,0xfbc7fc21,0x0144fcea,
0x06f3f236,0x0cf2f7e5,0x0cf00d6f,0x021d0cfb,0xf74cf8e8,0xfa71f87b,0x06230777,0x091702e2,
0xff36f272,0xf464f512,0xf25704ae,0xf7480a92,0xfcc307e8,0xff610512,0xff0c00b6,0xfd6dfb8f,
0xfee9f668,0x0717efde,0x102df231,0x0f3b02c6,0x059109ec,0xffe0f977,0x0167efcd,0x03c10068,
0x07ee0a20,0x0ec4f769,0x0c4ee7d3,0xfe35efcb,0xf7c8f7a2,0xff46f457,0x030ef721,0x0160fecc,
0x094cfe3b,0x10b200ee,0x04310e85,0xf5260f03,0xfaecfabc,0x0477f1ec,0xff8e0194,0xfe090b1c,
0x0860fddb,0x0796f020,0xf7a7f2f0,0xf084fc7e,0xf68301a0,0xfaee024c,0xfd44002d,0x01eafc75,
0x05a3f951,0x0c1af8f9,0x150bfef0,0x0f8f09f5,0xfe480d0e,0xfe2500ce,0x0c5bf56d,0x08a3fbfd,
0xfbc0095e,0x072808d7,0x1a13fc40,0x1185f32f,0x0063f290,0x03e5f5d6,0x0988f9fa,0x021dfe18,
0x031e02ec,0x0bcc0985,0x00620d2c,0xedb20720,0xf696fb62,0x0a78f642,0x0548fc12,0xf72a049d,
0xff720592,0x0e58fca3,0x08eaf222,0xf9def092,0xf541f779,0xf8dffd74,0xfd29febc,0x01a8fe72,
0x0611fe11,0x0bb1fff4,0x11220808,0x0b14103d,0xfa830cfb,0xf8320200,0x0994fd4a,0x0ea1ffe2,
0xfd460309,0xf8f907e6,0x0e280c02,0x195a04b3,0x0ce1f708,0x0518f564,0x099dfdd2,0x064e0023,
0xfedd007d,0x01690993,0xfee40deb,0xefaf015b,0xf070f595,0x072ff93d,0x0d96fef9,0xfab4fe20,
0xf55400d5,0x07de050a,0x1110fd48,0x05d1f094,0xfb8deff1,0xfa88f7e7,0xfbbffc94,0xff4bfe9a,
0x051200da,0x087c034c,0x09ee0a6c,0x06ab12e2,0xf9f50e41,0xf2d7003c,0x0147fdd1,0x0f7f0501,
0x03910354,0xf3fc004a,0xff370af9,0x1279117c,0x11b402eb,0x0901f61d,0x08affcd6,0x067702fb,
0xfeabff05,0xfcb90390,0xfb930c8b,0xf1e50241,0xeff9f0e8,0x0157f4ff,0x0dc10203,0x0261ff43,
0xf53cfa20,0xfd56029d,0x0d060614,0x0e3af87f,0x03b0ee1e,0xfbfaf2c9,0xfb80fa09,0xfe5dfd6e,
0x019500f2,0x04ba0432,0x06d30935,0x037d119f,0xf8d9108f,0xf1aa014d,0xfaa7fa32,0x09e50445,
0x0844074c,0xf888fdde,0xf6040258,0x0658124f,0x11720dda,0x0ce5fa89,0x071df8cb,0x05c60294,
0x00eb005e,0xfabafe1f,0xf8a707da,0xf48d05fa,0xf027f279,0xf9f0ee3d,0x0ae5fec7,0x09220339,
0xf83ef90b,0xf66ffbee,0x06b506e8,0x0f49006e,0x080bf0bc,0xff18eef1,0xfb8ff70b,0xfb8cfc1d,
0xfee5ffa8,0x0327038f,0x04550730,0x023d0e50,0xfb9a121f,0xf234066e,0xf39cf8f0,0x03b8fe93,
0x0b860841,0xfdb3011d,0xf2b9fc90,0xfe830b81,0x0e22126e,0x0dec00fa,0x07b3f54f,0x0575fe02,
0x00fd01f1,0xfa88fc8b,0xf8960236,0xf5a40889,0xef14f9fa,0xf348ebb2,0x0497f665,0x0b6b0343,
0xfdf2fcb7,0xf3f2f83f,0xfe65028b,0x0ca703ec,0x0b2ff4d2,0xffaeece2,0xf8f8f3e7,0xf9bcfb4b,
0xfcf3feae,0x00250243,0x032c054e,0x04610a63,0xffc31178,0xf5330d6e,0xf037fdf7,0xfb8cf999,
0x09ff037c,0x04ce0465,0xf491fd44,0xf718048d,0x0a911004,0x112605b6,0x072bf469,0x01ddf740,
0x020b00e0,0xfbc7fe78,0xf632feee,0xf722086f,0xf22e040d,0xeb6af229,0xf7b6efd4,0x0ad2fcc9,
0x050fff72,0xf26cfa6e,0xf68dff0e,0x097d02c8,0x0af8f7aa,0xfd3ced2a,0xf5d9f20c,0xf69dfb92,
0xf945ff77,0xfe7c017c,0x03600399,0x04e20669,0x05150d6f,0xff231193,0xf1ee0865,0xf176fc35,
0x0455fc84,0x0b3b01bd,0xf9180136,0xf2310384,0x07050a1f,0x138104b2,0x067df560,0xfca3f2aa,
0x0003fcdf,0xfcb000fa,0xf549007b,0xf8750750,0xf7dd0b78,0xea2100f0,0xea14f4f5,0x0014f595,
0x0878fb92,0xf78cff0b,0xf1060218,0x019d011c,0x0980f78b,0xfb6fefc9,0xef2cf483,0xf1bafe6c,
0xf88702ba,0xfd3f0298,0x01b1022b,0x05c7026e,0x09a60639,0x09480d8a,0xfd580ff4,0xf1110800,
0xf8fffcf3,0x0864f9a8,0x0223002c,0xf456086b,0xffb507ea,0x123cfd75,0x0885f3fa,0xf510f475,
0xf7a9fb34,0xff2e0105,0xf87d0527,0xf7950921,0xffe90c96,0xf6c50dba,0xe5dc0826,0xef57fb83,
0x035ff497,0xfe74fdf5,0xf2550a24,0xfbc50568,0x0512f696,0xf7e6f330,0xeae9fd33,0xf05a0633,
0xf99307cf,0xfd9a0543,0x02070175,0x0552fe8b,0x07b0fe2b,0x0de10147,0x0d460967,0xfe321090,
0xf528093a,0xfe0bf83f,0x031bf7b8,0xfc7a094d,0xffb20c2f,0x0a9af831,0x036eee4b,0xf1d2fa73,
0xf1de0341,0xfd09018b,0xfe71060c,0xfe190cbf,0x05e609f5,0x06400ba0,0xf8b116b3,0xf03b115d,
0xf543facc,0xfb84f7df,0xfdec0b3d,0x002a0d93,0xfdf2fae5,0xf4aaf750,0xef3b0807,0xf57e112d,
0xff950bfc,0x03b9059b,0x028e00b8,0x0149fbc4,0x0296f8e2,0x06edf644,0x0c76f793,0x0d9f04bb,
0x05b30f90,0xf9c504a0,0xf6ebf70b,0x00e300aa,0x095f0ada,0x034bfb7c,0xf662eeee,0xf206ff76,
0xf71e0f73,0xfd7c07e5,0x02f901b5,0x07e007f2,0x0a150509,0x0bcbfdfd,0x0ec909fd,0x0a281810,
0xfaab0da0,0xf329fea7,0x001d033a,0x0c2908c5,0x022300dc,0xf2fb0034,0xf7400def,0x065b1332,
0x0b930904,0x0705ffd4,0x022ffd58,0xfe4afbd0,0xfaa3fa6a,0xf8eef788,0xfb4af1ac,0x04c7f1e5,
0x0ec8fd18,0x086206be,0xf6f305ca,0xf80c0108,0x09a0fd63,0x0697fa64,0xf046fde4,0xf0400922,
0x05fc0edb,0x0aff0822,0x01d2ff5d,0x05cdfbbf,0x0b53f8df,0x0367f513,0x05d7f4ac,0x170dfa67,
0x1395052d,0xfcd10cc3,0xfb2e066f,0x0a57f8e7,0x0667f90c,0xf9de07a8,0x02af0e22,0x11f30434,
0x0e7ef93b,0x02fff764,0xfde6fabd,0xfa79ff2b,0xf79702ca,0xf6c903c2,0xf22e0230,0xef66fc19,
0xfa66f250,0x0763f333,0x055a046c,0xfeae0c88,0xff3efc73,0xfd55f342,0xf8850620,0xffcc13d0,
0x0d0f0483,0x0c5bf5d8,0x01a8faad,0xfc81fbe2,0xfab4f41e,0xf626f72f,0xf487fb4f,0xf9e9ee58,
0x0304e856,0x0ae9fc3a,0x0977095d,0xfd2ffbe8,0xf683f486,0x00bd0214,0x0c5f054f,0x08daf4f5,
0xfd77edce,0xf722f846,0xf76401de,0xfbd4051c,0x00e207dd,0x01f809d4,0x00880c7e,0xfda51006,
0xf5090a5e,0xef59fc3f,0xfc27f7ac,0x0c66fef7,0x03c50232,0xf2600141,0xfbea0541,0x10d304bb,
0x0b59f852,0xf80cf12b,0xf655f9e2,0xfb6f03b1,0xf5bb0582,0xf41807bb,0xfaa40bdb,0xf43109dc,
0xe7d8011f,0xf20af7bd,0x0601f4b8,0x02fbfd4f,0xf5a208e3,0xfb3005c8,0x0561f741,0xfbb9f3e9,
0xee1d0000,0xf33909e1,0x00a70989,0x0600052c,0x069900a2,0x089afd4a,0x0b54fcea,0x0e5aff25,
0x0d8b05d4,0x03ad0f14,0xf8e30bd1,0xf8fbf9e3,0xff80f54c,0x02ee0700,0x04480b5b,0x0329f60d,
0xfaaeef0e,0xf2740400,0xf6cd0f15,0x021705dd,0x0785052e,0x08770bee,0x0b1a05f8,0x0cd0034f,
0x08de125f,0xfee31643,0xf4c002a1,0xf6b4f963,0x055404b4,0x0ad606a1,0xfc96fcf2,0xf23d0199,
0xfd900f1a,0x0c0a0cdc,0x0b39ff82,0x03b3f8d0,0xff6ef839,0xfbccf7cc,0xf8aaf768,0xf90af490,
0xfdc3f091,0x07e1f42e,0x0eaaff5a,0x041b0769,0xf58706b7,0xfce2ff3f,0x0a51f7ea,0xfe96fb54,
0xef2d082e,0xfe180d42,0x12080505,0x0a8afcca,0xff50f90b,0x0516f414,0x0506f1ef,0xfbfff446,
0x0468f23e,0x140af27b,0x0d47025e,0xfe220f01,0xfed00172,0x01eef1d4,0xfd82fd3b,0x01eb0c75,
0x0cd5028d,0x0949f206,0xfbe4f342,0xf6b2fd48,0xf7f8038c,0xf8d307e2,0xfaef0a47,0xfb020ac0,
0xf5510b8a,0xf1080510,0xf4a4f677,0xfed9f416,0x093b01f3,0x06e80627,0xf783fcf7,0xf522ff7f,
0x08bb09b5,0x10fb013d,0xff9ef0a2,0xf452f3e8,0xf97d01ad,0xf6af046a,0xef5a0395,0xf5b5086e,
0xf797079b,0xeaf2fd18,0xeffdf4fd,0x08b5f587,0x0a3afcd1,0xf6840653,0xf83e070a,0x0806fb77,
0x0169f423,0xf101fca9,0xf44308d1,0x013a0b58,0x072906b8,0x0a5d012b,0x0be8fda8,0x0a63fd6d,
0x0d4afef7,0x0fec03a9,0x05be0d17,0xf8e70e49,0xf8b7fdff,0xfdf2f383,0x014201c1,0x061b0c13,
0x04d5fb23,0xf87eefa8,0xf2e80247,0xfc561224,0x04d2091f,0x07e301d7,0x0d410737,0x0ebc048b,
0x0a82feb0,0x0bd20945,0x09e613d2,0xf83e0954,0xefe5fc0f,0x02cefdbb,0x0e9500af,0xfdccfe4f,
0xf311030c,0x020a0b00,0x0e75060d,0x090ff8f5,0x0051f3cf,0xf9e1f745,0xf4a8fa99,0xf51efb06,
0xf5f7f9b1,0xf3cbf681,0xfc3df290,0x0c0ff44a,0x0a7500de,0xfc590c82,0xfc4a04a4,0x02b5f444,
0xfc59f997,0xf9210da0,0x06960c5c,0x0ea2f84c,0x0510f263,0xfb37f8ec,0xf8a0f625,0xf630f2f2,
0xf583f9ba,0xf90ef7b8,0xfe4aec34,0x0761f364,0x0e0007ff,0x03940851,0xf3fbfad0,0xf99efd4e,
0x0a4a05b7,0x08bafcfd,0xf9d4f2ca,0xf3cafbf2,0xf7af0a6f,0xfe920ce8,0x064a09d9,0x089209ba,
0x05ec0aa2,0x06960bf3,0x02d80d98,0xf41d0a17,0xf0c3ff32,0x025af59d,0x09b1f8e1,0xfc73064e,
0xfaf90a7c,0x091cfcbd,0x05cff1d3,0xf33cfb37,0xf1700913,0xfe7b0ab3,0x03f80a72,0x03ee0e7d,
0x06d70c27,0x05ea0891,0xfe580f2b,0xf6dc0ee7,0xf40dfb96,0xfa47f1af,0x06fd00c5,0x09760900,
0xfcd7fc03,0xf53bf905,0xfd84090e,0x087e0cdd,0x0ba7fcc6,0x07bff228,0xff3cf421,0xf9a9f52a,
0xfbdcf34d,0xfd52f34c,0xfd9ef353,0x0842f598,0x1162ff4d,0x03e509a5,0xf3cf08bf,0xfd5dfdd4};

#pragma DATA_SECTION(txSeqOdd,".aifdescmsm");
Uint32 txSeqOdd[2048] = {
0x0986f68d,0xfd69fcc2,0xf3ac091d,0x03900a84,0x1161fef7,0x08c0f5c9,0xfe39f464,0xfdf5f2e0,
0xfc98f228,0xfa32f57d,0xffb6f45d,0x0883f132,0x0bf5fce7,0x07da0deb,0xfd580856,0xf61df777,
0xfce3fc07,0x085e09a2,0x077a00d4,0xfcbcf157,0xf50cf98f,0xf4ec0b73,0xfbca0e09,0x04360a07,
0x05260c62,0x02070e09,0x02a10c08,0xfda40b67,0xf0ac0698,0xf32cfa3e,0x070cf420,0x0a32fcf9,
0xf9d50826,0xfa61070c,0x0a96fc01,0x0633f508,0xf27dfacd,0xf13d066a,0xfe780c36,0x031b0c8d,
0x02b40cf1,0x05e50bea,0x04990adb,0xfc580df0,0xf5910aff,0xf4b9fa9f,0xfbfaf21f,0x07d7ffca,
0x08f708ed,0xfc04fcb9,0xf54bf827,0xfec908b5,0x09c70d8b,0x0b61fa9d,0x0624ef29,0xfdd6f55a,
0xf8c0f701,0xfa9df1c4,0xfbe5f34b,0xfca1f5df,0x0772f422,0x10dcfba0,0x04b30af4,0xf56d0b4c,
0xfd57fbad,0x0777f515,0xfc81ffec,0xf60d0aa3,0x067407ad,0x10dafc2c,0x054af411,0xfa9af347,
0xfa85f4c6,0xf8e4f576,0xf6fbf61e,0xfc29f41d,0x03e9f14d,0x0a56f947,0x0ba208d8,0x003b09ad,
0xf3c4fc8c,0xfbc7fbee,0x0bcb058f,0x071bff24,0xf626f303,0xf31ffe38,0xfbf3114a,0x02fb0e8e,
0x07f204c9,0x0a8e0946,0x090e0cf2,0x07c10791,0x030b0a5c,0xf6730f67,0xf24800f6,0xff7ef010,
0x072bf9bd,0xff9c0be4,0xfeff0698,0x0645f5cc,0xfeb9f5d3,0xf19a03c8,0xf8220c9c,0x07560bf0,
0x0a90087d,0x09950648,0x0c5e0588,0x0b340716,0x05cd0bdb,0xfed50ded,0xf4890508,0xf3f8f8a0,
0x054cf8c3,0x0cc100fc,0xfac301e4,0xf27b00ed,0x06280669,0x11690331,0x028af2e7,0xf635ef0d,
0xf72afc9d,0xf4c000ad,0xf086f96a,0xf39cfbbd,0xf6f1fe1b,0xfaa4f17d,0x060aeefa,0x0c8404ef,
0x031f0f3d,0xf9b8fd3f,0xfb5ff49d,0xff1a0516,0x034c0c7b,0x098cfcee,0x05ccf117,0xf799f5af,
0xf131fd41,0xf44a00b2,0xf4000291,0xf20f01fe,0xf38afde1,0xf5aaf79c,0xfe39f312,0x0c35f810,
0x096a0568,0xf8190a68,0xfa04004c,0x09f5f72f,0x01f6fac8,0xef590434,0xfa6b0af1,0x10dc0a8b,
0x0e5d0112,0x0596f819,0x0cd2f95e,0x0f9efbb7,0x07f4f906,0x0ac1ffba,0x0de60ebb,0xfcc00c9d,
0xef24fb76,0xfd0df932,0x0c6e036b,0x04630043,0xf6adf851,0xf75501c4,0x01800e18,0x0af207ec,
0x0de1faec,0x0977f66d,0x059cf58b,0x0702f49e,0x08ecf667,0x0b19f9d0,0x0d4d019d,0x05b30d3b,
0xf7e90b36,0xf7bdf8e1,0x0206f47d,0x02b40698,0x00260bde,0x0635f8b0,0x0305efd6,0xf17afe8e,
0xef4d0a8d,0xff580a25,0x02170b8d,0xf9bd0f04,0xfe350d13,0x00810a29,0xf0d10680,0xedf1fc06,
0x04f2f3db,0x0df9fa4c,0xfc6f05f9,0xf71b0789,0x06c5000a,0x0983f886,0xf9a8f78f,0xf1acfff3,
0xf8490add,0x00af0e1c,0x05980bb3,0x06d60af1,0x04c80b85,0x02570cb4,0xfced0d70,0xf34a0527,
0xf37df6b6,0x038ef686,0x0cc20390,0x0072041b,0xf46bfaf4,0xfc3d01ae,0x0a1e0c56,0x0b96fef1,
0x02c5ecc3,0xf979f32c,0xf4dffe54,0xf513f86c,0xf52ff53e,0xf45ffc24,0xfa89f693,0x06f4ed1f,
0x0b60fc52,0x04291055,0xfd660625,0xfbeef3b1,0xfc06fc4f,0x003c0ca3,0x084a05b7,0x08a8f517,
0xfe25f272,0xf4abf97e,0xf264fefc,0xf2e9021c,0xf3e202ba,0xf3da0010,0xf25cfb4b,0xf841f50d,
0x07a7f366,0x0cb9fe08,0xff180ab8,0xf8250701,0x0382f902,0x05cef6c8,0xf64d020d,0xf52a0ae5,
0x09df09d5,0x129601cc,0x0804f8af,0x05a8f58d,0x0c97f76c,0x09c7f6c2,0x06cff7f3,0x0f020386,
0x0bb50d88,0xf60b0753,0xf119fcca,0x059ffcb0,0x0c6dfe82,0xfa2bfc97,0xf2a201b8,0x02440abf,
0x0e3806c4,0x0aaaf952,0x04acf2f2,0x01a0f35c,0xfebff31f,0xff10f34d,0x0402f3a2,0x09aef54c,
0x0c610097,0x07180d8e,0xfa5a071c,0xf52df7ae,0x001efc68,0x0a6d08f5,0x0481feec,0xf852f0db,
0xf4a2fe89,0xf9aa121c,0x024b0d81,0x09530475,0x09fa0a8f,0x084b0cd1,0x08d7062c,0x03550ae4,
0xf63a10f4,0xf3310063,0xfe9fef0e,0x0522fb53,0x01dc0cf3,0x020a0375,0x0226f340,0xf909f9eb,
0xf4fa0a58,0x00ef0d99,0x0c7f0723,0x0cd401c2,0x0c08fea4,0x0d79fde1,0x0ca30068,0x0c020546,
0x07880b49,0xf9270c5b,0xf27f0196,0x0076f521,0x08d8f91a,0xfc610787,0xf9c4096c,0x0accfcaf,
0x0a3ff3f0,0xf321f79b,0xed4800c8,0xfad7084f,0xfb1e0b1f,0xf3890a89,0xf93c0aa3,0xfb1108bf,
0xeed1ff09,0xf2a0f4ea,0x0a51f6d0,0x0df40035,0xf9b204cc,0xf6020442,0x0759017e,0x0aaffab6,
0xfaaaf655,0xf17afdea,0xf7260a25,0xff750e07,0x040f0c20,0x05550baa,0x040f0be3,0x01760ce9,
0xfb720d2e,0xf2de03f4,0xf46cf61f,0x042cf73f,0x0c9f0374,0xffd00351,0xf3b2fc3b,0xfd7f034c,
0x0ce60a1d,0x0a9cfb10,0xfd60ec9a,0xf651f644,0xf5130136,0xf31cfb6b,0xf229f99e,0xf432000e,
0xf81df7f3,0xffcfec10,0x0989f9b0,0x0a7f0d84,0xff4005a0,0xf640f6a1,0xfbcbff93,0x076e0b14,
0x097fff61,0x005af143,0xf665f6ba,0xf2e302aa,0xf4a60789,0xf77e098a,0xf8a00a4a,0xf6850837,
0xf29104fb,0xf362fccc,0xfd27f1c9,0x0778f60f,0x072b088d,0xfffe0a32,0xfc6ff7b7,0xfc02f62b,
0xfc740ad5,0x03c50ec6,0x0dd6fade,0x0a76f0d6,0xfcfcf686,0xf98af572,0xfe2ff01f,0xfbd8f427,
0xfc01f6b4,0x09fbf2be,0x10bafb5b,0x02520d99,0xf7cd0b94,0xff22f7ce,0x0207f515,0xfac6064c,
0xff330c45,0x0be7fee8,0x0881f36d,0xf996f43e,0xf38af9be,0xf41dfe0f,0xf2bb003b,0xf2f3ff59,
0xf443fbac,0xf5f2f64b,0x00f7f2ef,0x0dc9f91f,0x06ce06d8,0xf7ac0ae6,0xfd21fe8c,0x0835f4de,
0xfcd8fd18,0xf2000a63,0x03310b17,0x140301b5,0x0a99f957,0x0159f539,0x0867f3de,0x08b0f3ff,
0x01c2f511,0x0a8cf9b0,0x13cc0379,0x02fd0b2c,0xf0f107f5,0xfbe8fd76,0x0a44f7d8,0xffe9fca6,
0xf4c505fa,0x00710947,0x0e4901c0,0x09caf68d,0xfe28f23c,0xf860f4e7,0xf694f781,0xf678f7cb,
0xf7c5f663,0xfab8f308,0x03e5f32b,0x0e94fce0,0x091f07df,0xf7580777,0xf6c9ffc9,0x0842fbfc,
0x0898fba0,0xf4a5fd42,0xf24d059f,0x07290dc5,0x109207b0,0x08fefab4,0x093ef86d,0x0f41fbce,
0x0b08f904,0x085cfa89,0x0eda0818,0x07d80ee8,0xf2e6047d,0xf2f9fb47,0x086bfd5a,0x0aeffe60,
0xf79bfcf7,0xf43103b1,0x05b20aa3,0x0ea90351,0x0850f63d,0x019cf225,0xfdc6f3b9,0xfaa2f403,
0xfbbef400,0xfff9f2f3,0x051af2f8,0x0c49fca1,0x0be909c2,0xfc34084e,0xf257fd71,0x00cffd30,
0x0df6019d,0x000efb96,0xefc1f985,0xf8e608a4,0x091211c1,0x0acf0575,0x0a16fb74,0x0f1a0056,
0x0e6b00b3,0x09e8fbb5,0x0b850556,0x0824122e,0xf7e208b8,0xf0f9f83f,0x0064fb3b,0x0c97036a,
0x01e4fdb2,0xf436faf2,0xf99d06db,0x08640c2c,0x0db40038,0x08adf4dc,0x028bf33d,0xffa6f35f,
0xff54f311,0x00e6f383,0x0570f35e,0x0c06f983,0x0c9107f4,0x00c80c17,0xf47aff4d,0xf9bef9a9,
0x093502c4,0x090501db,0xf851f632,0xf1cbfcb8,0xfdf01027,0x091f0f61,0x0a5d0049,0x0befffa0,
0x0f18053b,0x0cf7ffb4,0x09d00069,0x081a0f89,0xfe7b101c,0xf222fc4a,0xf79ff5e7,0x0944023f,
0x09f2033d,0xf94bf94e,0xf416fe95,0x01040c26,0x0bd708da,0x0b83fa73,0x0723f3e9,0x02b2f3ae,
0xff9ef303,0x00d5f365,0x04fdf3a8,0x097cf5eb,0x0cc001d8,0x07a00d35,0xf91c05f5,0xf3faf943,
0x026afe04,0x0cde055f,0x006efb4c,0xf1e3f5d3,0xf788074a,0x04d21356,0x09510742,0x0b10fdb5,
0x0ec10392,0x0dcd0346,0x0a8dfd9d,0x0a7507c0,0x04a71347,0xf63e06b7,0xf27af609,0x0193fbc9,
0x0c1d04d4,0x018ffd7d,0xf471fa2c,0xf98f06f2,0x08340c7e,0x0db4003d,0x08aff4ee,0x02a2f354,
0xffd0f357,0xff41f316,0x00bcf37e,0x056bf341,0x0c01f982,0x0ca707cc,0x00f90bc1,0xf452ffb1,
0xf9b4fa6a,0x09d5020a,0x08c40070,0xf683f728,0xf1abff63,0x0117109a,0x0bae0d34,0x0a15fe25,
0x0bd1fd8f,0x0ff8021c,0x0c60fcdd,0x099bfe95,0x0b8b0da4,0x01e30fb7,0xf127ff66,0xf5e0f880,
0x0a38ffda,0x09dd001c,0xf6e0fb8c,0xf4c002cd,0x05a40b61,0x0e0803c2,0x0889f634,0x022ff244,
0xfdacf3be,0xfa83f3fb,0xfbfff40d,0xffb3f2d6,0x0486f2f2,0x0c9afc87,0x0c6e08f8,0xfbbd083b,
0xf249ff14,0x0220fd37,0x0dc7fea8,0xfd02fb6e,0xeeb9fe95,0xfd820b51,0x0e730da2,0x0b650045,
0x0842f81c,0x0e6dfb17,0x0ccffa72,0x0749f7ee,0x0d7900f7,0x0ec10cd7,0xfb6a0aa3,0xef790068,
0xff65fbd9,0x0c3efbb2,0xfef0fd38,0xf39403d4,0x00600950,0x0ead0301,0x09eaf6c1,0xfe2ef216,
0xf8bff4e0,0xf6fff761,0xf64bf7db,0xf748f678,0xfa8ef316,0x03e2f34b,0x0e46fc0e,0x08d806d5,
0xf7fe08df,0xf8340139,0x07edf8fe,0x0533f985,0xf2f40315,0xf78e0b20,0x0eb60826,0x115efdf9,
0x03bff699,0x048ff452,0x0a99f3d2,0x03caf450,0x03ebf6ea,0x1200fd24,0x0e270711,0xf75c0ca2,
0xf4c80449,0x0566f6cc,0x0442f806,0xf75c0644,0xfe4e0b0f,0x0d51ffa8,0x0878f467,0xf9cff3f8,
0xf484f932,0xf3c4fdde,0xf2690036,0xf3a1ff6e,0xf3d1fc0d,0xf51af6db,0x013ef294,0x0cf2f7e8,
0x05f8072a,0xfa9a0c1c,0xfe85fcaa,0x0278f2e1,0xfa100227,0xfadf1052,0x0b8404c6,0x0ff0f46b,
0x01a6f49d,0xfa46f69e,0xfe09f10b,0xfbf6f22b,0xf967f792,0x03e9f311,0x0e73f334,0x09500645,
0xfede10c7,0xfbd2ff7b,0xfc32f2f8,0xfd9001cb,0x03cc0d07,0x08d7fee2,0x02eff103,0xf72cf6e3,
0xf1e101fb,0xf48a06e0,0xf80d0985,0xf85f0a42,0xf6180885,0xf35805d6,0xf3d1fd02,0xfb01f1a3,
0x05f5f6b9,0x0a2807ff,0x01be0755,0xf724f814,0xf97bfc75,0x06080d4c,0x0bbf055b,0x04c9ef36,
0xfb34f059,0xf5cefe92,0xf2dbfd28,0xf247f8af,0xf448ffbb,0xf58bfd87,0xf8c9eec1,0x044ef19c,
0x0e53053e,0x062308b0,0xf5d9fdbb,0xf7dcff15,0x0878059d,0x0accfd52,0xfb1af41d,0xf17ffc9f,
0xf70f0a3d,0xff350da5,0x03010c28,0x04f00bcc,0x050f0ba4,0x02220d37,0xfb7d0d4b,0xf300043e,
0xf41df877,0x03e1f77f,0x0c48fea8,0xfdcc0353,0xf40404d8,0x04d50359,0x107efb4e,0xfdc4f41e,
0xece2f93f,0xf58804ff,0xfc590a7b,0xf4d60a6a,0xf6850afa,0xfd930a4d,0xf39404e0,0xec6afbe3,
0xffa0f468,0x0eb8f6f6,0x01680415,0xf7cd0aea,0x04330039,0x0754f491,0xf787fa78,0xf35b088e,
0x015a0d0a,0x0b100836,0x0c330281,0x0d51feba,0x0cd4fde0,0x0bf4000d,0x0da6042d,0x07d80ad5,
0xf94c0dec,0xf51e027e,0xfe8ff371,0x0310f9e7,0x01200bba,0x03f10613,0x036bf172,0xf7e3f55e,
0xf2780bb5,0xfd1c0fb7,0x07950685,0x088c096c,0x08ec0d79,0x0a6f0624,0x06470784,0xfda312bc,
0xf64f0a05,0xf52af3ff,0xfe3cf5dc,0x0986072f,0x06a503f0,0xf8f8f6e1,0xf5d4fea5,0x013b0d56,
0x0b21081f,0x0b9cf956,0x06e3f3bf,0x010ff39a,0xfe3bf306,0x0029f367,0x0313f2ec,0x0757f4e4,
0x0dd1004e,0x0a150af2,0xf89306bb,0xf321fdb7,0x04f9fd7f,0x0cdafe32,0xf9c7fb86,0xef830167,
0x01de0c75,0x108209e4,0x0a31fc68,0x06ebf64b,0x0cadf790,0x0949f65b,0x04b1f62e,0x0e4efd14,
0x11580689,0xfe310b8c,0xf21b076f,0xfefdfb71,0x078bf5a5,0xfc840016,0xf91f0b63,0x07700541,
0x0cc4f70d,0xff57f302,0xf39df852,0xf2f8fe02,0xf42f01c9,0xf35702d5,0xf28f00b3,0xf2ddfc8b,
0xf8b7f58f,0x0460f1bb,0x0a18fcf4,0x04370c66,0xfd3e05e3,0xfbcef454,0xfc4bfb3a,0x002c0f54,
0x08bc0855,0x0ad6f124,0x0082f03f,0xf610fbc2,0xf480f8a4,0xf573f4ff,0xf499fd0d,0xf68afa45,
0xfdecece4,0x07f7f421,0x0cb108fd,0x03b208a8,0xf5e4fbb4,0xf8b2ff15,0x08d7065e,0x0a96fcba,
0xfa23f3ee,0xf11cfdcc,0xf8410b02,0x007b0d8c,0x039d0be9,0x06120b37,0x06b50afb,0x03770d16,
0xfcb50d9b,0xf3c805a8,0xf399fa93,0x02a8f6ed,0x0b55fbf6,0xfdeb047c,0xf63c0854,0x06de0077,
0x0d7ff52b,0xf7a0f6b3,0xeb820236,0xfa1a0902,0x01970b6d,0xfa290eb2,0xfd8b0da3,0x03810a07,
0xf6ad0b15,0xecf80632,0xfad6f541,0x0738f106,0x028b0405,0x008e0ce4,0x03f6fc17,0xfcd6f330,
0xf56e02f5,0xfe950f0e,0x0b4e078a,0x0cacfcac,0x09b4f7db,0x081af525,0x05d6f4e5,0x06f6f613,
0x0c58f7af,0x0d6b0116,0x068d0d6b,0xfbcb0946,0xf50efaa6,0xfcadfb25,0x0b2c0422,0x06c5fe6a,
0xf305f76f,0xf33d0455,0x07c510e8,0x0e340769,0x0785fa41,0x0bddfa67,0x1036fb49,0x07b6f796,
0x0881fbc0,0x12e406d9,0x06ef0beb,0xf06b0810,0xf730ff44,0x0a08f776,0x0293fa95,0xf55706c6,
0x00d309e2,0x0e09fe47,0x0575f3ea,0xf86df4c2,0xf466fb01,0xf2850066,0xf2b102be,0xf4e701bd,
0xf264ff47,0xf2bbf9cc,0xff36f1db,0x09b2f51a,0x0699069d,0x00aa0bee,0xfd68fafb,0xf982f56e,
0xfd4d0877,0x09770de9,0x0b0cf7f6,0xff6cecdb,0xf7f9f92d,0xf5aafe8f,0xf149f8f8,0xf209fd18,
0xf70100fc,0xf602f4ea,0xfa89ee0e,0x0c37fbb9,0x0f250719,0xf9f80345,0xf2f300aa,0x05e90296,
0x0c52fce2,0xfb16f6bb,0xf1cefe57,0xf9f20b10,0x02de0ddb,0x08c3091f,0x0ca805dd,0x0ad205bd,
0x09a0073a,0x0a7b0a3f,0x002b0d1b,0xf1fd0965,0xf718fc18,0x0507f307,0x030ffdcd,0xfd4e0caf,
0x04520406,0x057bf145,0xf766f6ad,0xf20d0aff,0xfd6b0e3f,0x068d0741,0x08490a88,0x0a1e0c86,
0x09c20571,0x057308a5,0xffd412df,0xf6f808ec,0xf24cf529,0xfe89f7b8,0x0cb60517,0x04a7011e,
0xf4c5f9a9,0xf8b3037b,0x07b50c0e,0x0c2f0123,0x0737f34a,0xfffbf233,0xf8a8f5ae,0xf751f5d9,
0xfa5cf524,0xf9f4f411,0xfe95f2fc,0x0d0bf753,0x0e5b026b,0xfc2b0afb,0xf680065c,0x042ff8e4,
0x0463f60d,0xf6830461,0xfb570dff,0x0da4035f,0x0de3f5de,0x007ef4ef,0xfb8df540,0xfbc7f17e,
0xf913f44d,0xfa7ff7ba,0x0242f12b,0x0975f25a,0x0bb605e0,0x04fa0e9d,0xf86bfef3,0xf6aef76c,
0x038904a2,0x0a9a06ef,0x01e8f6d6,0xf71af3bf,0xf44f0413,0xf8790e4c,0x01040c0d,0x06660afc,
0x040f0cc6,0x02990cb1,0x023a0c99,0xf7900a3f,0xeea40086,0xfc41f649,0x0c38f749,0x029b0233,
0xf67a0973,0x0297033e,0x0c54f6e3,0xfc70f57c,0xee9f0109,0xf7400a37,0x01c70b9c,0x020b0d20,
0x03680dd8,0x05ce0a83,0x004a0ba3,0xf77d0ece,0xf40b0319,0xf826f215,0x02a8f7aa,0x09e30889,
0x031d03f9,0xf7a2f65e,0xf886ff2c,0x03440ea9,0x0af40671,0x0b14f48d,0x0436f1f7,0xfbcaf5f9,
0xfadaf39e,0xfdf9f1f7,0xfd5ff3f8,0x025cf499,0x0f54f968,0x0cd405c2,0xf8f40be0,0xf5ce0307,
0x062bf7da,0x059ff8f4,0xf56a03ff,0xf9cd0af8,0x0d830533,0x0ec3f996,0x0188f3ca,0xfce5f373,
0xfd4cf30f,0xfa1bf416,0xfb67f525,0x03a8f210,0x0a6ff501,0x0b470561,0x04060de1,0xf8290036,
0xf709f713,0x03fc0347,0x0ab507d9,0x0137f74b,0xf639f275,0xf49f0563,0xf9dc10d7,0x022a0aa6,
0x074008ff,0x05630e3c,0x041b0cb5,0x035f0a21,0xf88e0bde,0xef240460,0xfb4df50c,0x0a93f4b4,
0x02a90453,0xf8890aeb,0x037f0014,0x09f3f55d,0xf98cf853,0xef2603d4,0xfab60bef,0x05660cb9,
0x057b0b3a,0x071c0a8a,0x090509e2,0x03d70be3,0xfc170eb3,0xf5aa06b9,0xf45ef728,0xffc5f653,
0x0c3c0374,0x04390412,0xf435fa71,0xf8e500dc,0x09da0cfd,0x0ce101c8,0x040deeb6,0xfd05f172,
0xf80efb37,0xf572f6ba,0xf6f2f30e,0xf83ff86f,0xfcf5f5a4,0x098df099,0x0db8ff0a,0x00820ff0,
0xf8d50643,0x0064f41c,0x0101f968,0xf9bb0a34,0x01470a2d,0x0e66fc38,0x07def364,0xf8aaf410,
0xf570f783,0xf66bf9b8,0xf3a2fa78,0xf4ccf8ea,0xfa33f425,0x012bf213,0x0b77faf8,0x0c080760,
0xfab4073d,0xf33fff04,0x053dfe1c,0x0d85ff13,0xf9d8f997,0xee97fccf,0xfd760d19,0x09cb10f3,
0x08d60363,0x0b40ff53,0x0f7a0696,0x0c640443,0x090f01e5,0x055c0e83,0xf9f61106,0xf37cfb11,
0xfce1f0c3,0x064802c1,0x04a10b63,0x00e6faea,0xfcb4f385,0xf6740312,0xfa340ee9,0x08670a51,
0x0ecf02bf,0x0bb6ff4e,0x0c00fd6f,0x0df1fe02,0x0c76021f,0x0a560864,0x01c70cee,0xf3cb07f0,
0xf696fa98,0x07e7f598,0x05fcffb4,0xf60b08d1,0xfe0a0538,0x10a7fbcc,0x0595f50f,0xef24f575,
0xf1a3feee,0xfa6a07e7,0xf32e06a2,0xf0620449,0xf80c06fa,0xf53f0046,0xf21af145,0x0340f363,
0x10dc048a,0x02f306ce,0xf392fc95,0xfb9dffbd,0x095307af,0x08abfe3c,0xfe80f1e8,0xf50ef814,
0xf21f0514,0xf6890993,0xfa640a75,0xf8fe0b62,0xf7140999,0xf4e70630,0xf2b3fe63,0xfa4df2c5,
0x0817f4ca,0x0843071f,0xfdfa0b83,0xfd4cf968,0xffdaf422,0xf9cb0750,0xfcfb102a,0x0e860172,
0x10b3f573,0x00a8f5db,0xfde9f473,0x0643f0fc,0x01cbf2ed,0xff7ff5d7,0x0f2ff980,0x120f03fa,
0xfb0e0c25,0xf20705b4,0x0391fa07,0x08e5f877,0xf93bfff6,0xf67d077a,0x06580871,0x0e54000d,
0x07b7f523,0xff51f1e4,0xfa68f44d,0xf92af50f,0xfb38f47b,0xfda9f34c,0x0313f290,0x0cb6fad9,
0x0c83094a,0xfc72097a,0xf33efc70,0xff8efbe5,0x0b95050c,0x03c3fe52,0xf5e2f3aa,0xf46a010f,
0xfd3b133d,0x06870cd4,0x0b2101ac,0x0aed0794,0x0ad10ac2,0x0ba103dc,0x0577096d,0xf90c12e1,
0xf4a003ae,0xfbd7efab,0x029af9db,0x04120c4f,0x03fa03b1,0xffc4f35d,0xf7b6fa49,0xf7580ae9,
0x01db0d8e,0x0b550682,0x0d9c0104,0x0d17fde4,0x0c1efd46,0x0c26fff0,0x0da404b5,0x07bf0af3,
0xf8590c9a,0xf34701f8,0x00e8f548,0x07dbf8ff,0xfc7e06fe,0xfa320938,0x09b3fdf3,0x0ad6f51b,
0xf621f62b,0xed6afe34,0xf7fc0751,0xfa580a73,0xf3690894,0xf639093e,0xf931080d,0xf0fefc7a,
0xf44bf278,0x09f5f8ad,0x0ee70336,0xfa610350,0xf393017e,0x05d50369,0x0d5efe48,0xfdbcf541,
0xf1c8f93c,0xf55606ae,0xfb540d0e,0xfe600ca4,0x01410ce1,0x00f00cb3,0xfbfe0c5e,0xf6520ab4,
0xf39fff69,0xf8e8f272,0x05a6f8e4,0x0ad30852,0xffe20398,0xf593f70b,0xfb7f0114,0x07ae0f25,
0x0b5e0177,0x0656ede4,0xfdb5f27f,0xf6adfb8b,0xf606f571,0xf7b5f32f,0xf729f9d4,0xfcabf51c,
0x09c6ef0c,0x0ccfff9d,0x016110f2,0xfade04ad,0xfe24f30d,0xfdf6fc8b,0xfdda0cc0,0x06f70615,
0x0b06f5a8,0xff11f267,0xf381f8dd,0xf32cfe3e,0xf3f8015c,0xf287021f,0xf35dff98,0xf3fefaba,
0xf878f4b7,0x06d9f3a5,0x0d81fe6a,0xff8a0adf,0xf72806e6,0x039ff879,0x063cf694,0xf5340351,
0xf5c10c10,0x0cdf0865,0x12b8ff38,0x0529f7b1,0x04e2f4e1,0x0c77f577,0x06c4f55d,0x04eff741,
0x112f00f7,0x0d600b16,0xf5af0930,0xf20cffcb,0x064efb34,0x09fefbbe,0xf8a7fe82,0xf551054a,
0x055609ab,0x0e860216,0x08daf5db,0x008bf1f9,0xfbf1f3e0,0xfaabf456,0xfbf1f41d,0xfe8af317,
0x048ef2d2,0x0d22fc0c,0x0b9409e1,0xfbd408c1,0xf361fc8c,0x0030fcaf,0x0c4e03c5,0x0281fcb4,
0xf31af5e3,0xf56404f0,0x02a01366,0x09af09bc,0x0aedfeca,0x0ce40495,0x0dd70662,0x0bcefff2,
0x07e3080d,0x003113f0,0xf6770650,0xf581f27c,0x00c0fa60,0x09c0095f,0x0435006d,0xf892f4ec,
0xf681009f,0xffa60ebd,0x099b0946,0x0d1dfd56,0x0b5af877,0x0882f676,0x0760f5b6,0x097bf7c9,
0x0d6ffb05,0x0c9e0334,0x02d90e37,0xf88809f1,0xf8d5f773,0x0002f5ce,0x03910849,0x03fe09d5,
0x038cf52b,0xfc3bf13a,0xf22a0522,0xf58a0f2a,0x0304097a,0x06760a8e,0x01d10fe1,0x04280bd9,
0x03ff094c,0xf6050d42,0xef4604a5,0xfdaef267,0x0833f46c,0x00de0832,0xfdf90aeb,0x053af9b4,
0x00cdf3bb,0xf4190118,0xf77f0c93,0x066a0bc2,0x0c760642,0x0be301f1,0x0d45ffc5,0x0d0d00a7,
0x0bbd0454,0x0a0e09b5,0xff090d11,0xf23706e1,0xf932f928,0x0854f51a,0x02df0174,0xf7cb0b22,
0x032802e8,0x0e00f59d,0xfccff4e9,0xebfdfe4b,0xf56706a9,0xfea70ac7,0xf7990c22,0xf7500c01,
0xfe3e0aef,0xf5740650,0xec34fc87,0xfd03f4d4,0x0f0ff80b,0x0418028a,0xf5bc0828,0x0017035a,
0x0b3bfa06,0xff8ff6b9,0xf1b7fe40,0xf6360973,0x01d80dc4,0x07a00b19,0x096c087f,0x09880835,
0x083b099d,0x05480cf8,0xfc1b0cd5,0xf16c0320,0xf6e1f821,0x08a8f889,0x09370037,0xf7be0404,
0xf7680460,0x0b5b02be,0x0db3fa61,0xf8d7f23b,0xef6ef850,0xf702054c,0xf6c20793,0xf0bf0432,
0xf4f806fc,0xf7a40577,0xf126f7e8,0xf828f118,0x0d1afb83,0x0d0704b9,0xf79502a6,0xf51101a0,
0x08650309,0x0bcffc4f,0xfa4ef55d,0xf157fcaf,0xf7b009c3,0xfe640ddb,0x023a0c47,0x055e0bfd,
0x04420c00,0x00070d0d,0xfae60d08,0xf3b7035f,0xf417f63e,0x03ccf7b2,0x0da9028f,0xff3102d0,
0xf20afe63,0xfff2046a,0x103f067b,0x071af75c,0xf6eeee3f,0xf531fa8b,0xf5ea048c,0xf0e6ffaa,
0xf195ff4d,0xf618044b,0xf47bfaaa,0xf7dcedd2,0x081ef748,0x0f0707c1,0xff9c04c5,0xf369fc96,
0xfe1c024e,0x0bca050e,0x0663f925,0xf79cf3d4,0xf24cffc8,0xf7530b24,0xfd750cc3,0x005a0ca1,
0x00ac0cef,0xff1a0c7d,0xfa900ca2,0xf3fa067d,0xf36ff80c,0xff38f3e9,0x0b8600b3,0x06420657,
0xf6cbfd3c,0xf6fbfe25,0x07af09ce,0x0e350348,0x0210efd9,0xf6e1f09f,0xf5a3ffb7,0xf4110060,
0xf0e8fac5,0xf309004c,0xf630ff97,0xf7e6f077,0x0185efe4,0x0dde03b6,0x08610a19,0xf6bcfdc1,
0xf60efcc3,0x06b506b2,0x0bea016b,0xfefcf3da,0xf429f726,0xf47d058d,0xf8dd0c17,0xfd4e0c52,
0x00620cfd,0xff2b0c9b,0xfb030c58,0xf6840a15,0xf340fe28,0xf860f2cb,0x06e4fa0b,0x0c0606bd,
0xfd9601fc,0xf322faa1,0xff9204b4,0x0e1d0a2d,0x0878f8b6,0xfb2eecaa,0xf6aff8be,0xf4f0024b,
0xf13ffc6e,0xf233fcba,0xf5730263,0xf58bf840,0xfb59ecb9,0x09c2f949,0x0d8609f7,0xfe6d0437,
0xf3e3fb2c,0xfe710283,0x0b8f05d4,0x0671f90e,0xf7ccf382,0xf24cffc3,0xf7510b12,0xfd5e0cac,
0x00300ca9,0x00bf0cea,0xff440c82,0xfa950cbf,0xf3ff067e,0xf359f834,0xff07f43f,0x0bae004f,
0x064c0596,0xf62bfdf6,0xf73cff90,0x097d08d8,0x0e55009d,0xfee9ef66,0xf452f2cc,0xf5eb01db,
0xf42f0271,0xf008fde4,0xf3a00323,0xf665016b,0xf475f25c,0xfe1df049,0x0ed9009a,0x0a200780,
0xf5c80026,0xf623ffe4,0x09200474,0x0b40fd33,0xfa5cf49f,0xf1f8fc3e,0xf77709cc,0xfdd10dbc,
0x02540c42,0x057d0c05,0x04010bf3,0x004d0d2a,0xfb7a0d0e,0xf3660379,0xf392f708,0x0443f7c5,
0x0db700ec,0xfde002c9,0xf2390158,0x02fe0492,0x1147016b,0x027ef4af,0xf18df25e,0xf49bffbb,
0xf7be07e4,0xf19304e9,0xf331058e,0xf8b70812,0xf287ff09,0xf13ff329,0x0496f55d,0x1087ff98,
0x009b0427,0xf3c2044e,0x011002c8,0x0c6cfc2c,0xffa0f6b0,0xf153fcff,0xf616093f,0x01d20dea,
0x07410b20,0x0901089f,0x09b50825,0x08b80988,0x05720cea,0xfc1e0cb5,0xf1ba03f2,0xf728f92b,
0x0802f721,0x07ccfec7,0xf8130702,0xfacd067b,0x0d0cfceb,0x0872f4e0,0xf14af7da,0xeea20207,
0xfc410967,0xfb710bae,0xf5670c2e,0xfc360bb0,0xfc150916,0xee0002dc,0xf1d9f8ef,0x08a4f35e,
0x0b38fbb7,0xfa9a0934,0xfbbe07fa,0x08a4f9bc,0x01b2f4f1,0xf2af0058,0xf7880b99,0x06310c08,
0x0b7c06ce,0x0c3c0222,0x0d97ffca,0x0c5f0092,0x0c2f03f3,0x0ae60925,0xfec20d6c,0xf30e0818,
0xfa08f8d6,0x0566f3e4,0x017b0356,0xfd880d1f,0x05f0fdd9,0x0521efae,0xf47cfb3a,0xf0100b95,
0xfe5a0b63,0x05ba0962,0x01f70ef5,0x040a0dd5,0x0699086e,0xfc170cef,0xf18d0ccc,0xf6b0f9bb,
0x0122ef39,0x042e0085,0x03ce0d08,0x0270fe35,0xfc34f2f9,0xf729011e,0xfd110efd,0x08d4091d,
0x0e1ffe05,0x0b76f920,0x07f3f67b,0x07a1f5be,0x09e8f77b,0x0ca8fa2a,0x0c2f02fe,0x04ff0e5d,
0xfa0b0947,0xf5d8f801,0xfe42f8ab,0x08dc07ec,0x0685038b,0xf9f8f2b4,0xf441faa5,0xfb3710ca,
0x04cc0fa7,0x0a32016e,0x0d2502d8,0x0db90751,0x0bb80045,0x0a750279,0x0737113f,0xfbb20e64,
0xf1adfac2,0xf9ddf750,0x0a270245,0x082400eb,0xf788fa63,0xf53402ae,0x04e60be3,0x0e810361,
0x08f1f5c3,0x00cbf25b,0xfcfff3d8,0xfb10f434,0xfaf1f45c,0xfddef2c9,0x0483f2b5,0x0d00fbc2,
0x0be30789,0xfc1f0881,0xf3b80158,0x0234fcad,0x0bfcfb28,0xfb2bfca7,0xef8204b2,0x023c0be2,
0x131e06c1,0x0a78fb01,0x03a7f585,0x0b2af596,0x097bf506,0x026df5b3,0x0c6cfb20,0x1396041d,
0x00600b98,0xf148090a,0xfe98fbeb,0x0833f516,0xfbcdffc7,0xf8ac0b6f,0x08790588,0x0ca5f772,
0xfea6f2f6,0xf4f0f7ca,0xf3cdfd7f,0xf2af0146,0xf32c0220,0xf40cfff3,0xf25afbd3,0xf828f52b,
0x06b4f214,0x0ae2fd82,0x01710c8f,0xfcf00619,0xfee0f446,0xfc0ff9ed,0xfc950e8e,0x081d0aa2,
0x0d88f44b,0x02e4f049,0xf86bf97b,0xf774f694,0xf714f287,0xf591f9dc,0xf9b9f87c,0x025ded44,
0x09b1f5fb,0x0ad60c01,0x01c40a24,0xf67af8d1,0xf95bfc10,0x0708091f,0x0a2c015b,0xfec5f2aa,
0xf4dff7e1,0xf46406aa,0xf91d0c41,0xfef10c66,0x01c50cfa,0xffd70c99,0xfced0d14,0xf8a90b1c,
0xf22fffb2,0xf5ebf50e,0x076df945,0x0cdf0249,0xfb070281,0xf32601ce,0x0639047a,0x107dfe99,
0xfe22f38b,0xef7ef61c,0xf5cf0398,0xf91509b5,0xf3530870,0xf6b709a5,0xfb4f09d2,0xf1b202ec,
0xeea8f977,0x01cff474,0x0de5f891,0x0103048f,0xf8750a5b,0x037cffea,0x06e1f49d,0xf890fabf,
0xf33c08f3,0x00a90cfe,0x0c6307ae,0x0d0801fe,0x0bd1fe37,0x0ca9fd2b,0x0d71ff4d,0x0d230375,
0x07490a71,0xfba00e45,0xf5e8030c,0xfbc9f39a,0x02c2fa1d,0x04320bac,0x03b504c6,0xffd4f0ac,
0xf744f7ab,0xf52a0edc,0xff7e0fc1,0x09f0043e,0x0b80075c,0x0a8d0b01,0x0b6702f3,0x097605bb,
0x0214131c,0xf8090bdf,0xf34ff703,0xfc4ef758,0x0a1c044c,0x074e00eb,0xf729f9a2,0xf56a0346,
0x05dd0c12,0x0ee40234,0x07bff4fe,0xff85f274,0xfc63f417,0xf9eef4c9,0xf94bf505,0xfc89f2ea,
0x034bf265,0x0c38fa58,0x0c67056d,0xfd580913,0xf4ab040a,0x0215fb84,0x09c4f7ac,0xf922ff89,
0xf2810ad5,0x0860094d,0x147efdca,0x05e6f6fe,0xfe69f493,0x05d7f14e,0x0275f25d,0xfc7ff5f9,
0x0953f4eb,0x1308f9ce,0x052a0abf,0xf8c80efa,0xfd75fbfb,0xff72f31c,0xfc0a03e9,0x032a0cd0,
0x0a92fd0b,0x016bf0f2,0xf4b2f876,0xf3540354,0xf64c0825,0xf7e60adb,0xfa2a0b1b,0xf90a09ed,
0xf3a80851,0xf295feea,0xf973f295,0x0435f6ba,0x0af2055a,0x035304db,0xf4d4fbde,0xf93b0196,
0x0cfb0891,0x0cc3fbab,0xf83bef18,0xf1ccf897,0xf87b05bf,0xf4230599,0xefca04b7,0xf84a086a,
0xf77f0440,0xed1cf927,0xf911f415,0x0f95f7f0,0x08d000bc,0xf5f8088a,0xfd6d056b,0x0aa9f93a,
0xff2df61e,0xf1f701b9,0xfa8b0c16,0x07930b3e,0x0b9a04ff,0x0d7bff9a,0x0d4ffd42,0x0b19fe43,
0x0d9c00b9,0x0d450634,0x00ca0e25,0xf64e0ae6,0xf967f963,0xff56f412,0x02980505,0x067e0a92,
0x02b3f789,0xf689f217,0xf4f4080a,0x00941325,0x080706d3,0x0a560171,0x0eb70708,0x0df702e8,
0x08ffff04,0x09fe0b16,0x057711f2,0xf3c90447,0xf0dbf8e7,0x0608fcbb,0x0d0dff56,0xfa17fd6a,
0xf3ae031e,0x04ea0945,0x0e3201a9,0x060ef4f0,0xfd22f225,0xf73df6e1,0xf358fa23,0xf52efa43,
0xf660f8c6,0xf585f5c1,0xffd5f2e5,0x0e03f69b,0x08e803e8,0xfaf90cf9,0xfcf10233,0x02b2f351,
0xfbaefbfa,0xfa850ebb,0x089a0953,0x0df3f501,0x0295f1c1,0xf973f8bf,0xf7b7f578,0xf5e2f37a,
0xf63efa8f,0xfa8df75b,0x002ced21,0x0908f714,0x0db40ad7,0x01770848,0xf34afae9,0xfb59fee2,
0x0b3b0657,0x074dfc85,0xf84bf3f2,0xf3d1fedd,0xf8c90cb6,0x00050dcd,0x07580a52,0x08af0a27,
0x05a40adc,0x060c0bef,0x016b0d04,0xf2f508ad,0xf1a5fd95,0x03d5f505,0x0980f9a4,0xfbd1071c,
0xfb9d09f3,0x097dfb9f,0x04a9f201,0xf25cfca1,0xf21d0a22,0xff820b11,0x04730ac0,0x04390e82,
0x06ed0bb3,0x05810846,0xfdbe0ed5,0xf68b0da6,0xf44afa20,0xfb06f163,0x0795010d,0x09520894,
0xfc77fb5e,0xf566f911,0xfe18092a,0x08e60c41,0x0bb1fbed,0x0787f1b4,0xfefcf3f3,0xf99af504,
0xfbf1f33a,0xfd67f34f,0xfdc6f367,0x0870f5c1,0x115cff7a,0x03bf09b7,0xf3c808b7,0xfd65fdcd};

#pragma DATA_SECTION(txSeq1MHz,".aifdescmsm");
Uint32 txSeq1MHz[3072] = {
0x1fff0000,0x1f54067f,0x1d5b0cb9,0x1a28126c,0x15df175a,0x10ac1b4e,0x0ac71e20,0x046f1faf,
0xfde91fed,0xf7781ed6,0xf1621c76,0xebe818e6,0xe745144c,0xe3a90ed9,0xe13c08c9,0xe018025a,
0xe048fbd3,0xe1caf578,0xe48fef8d,0xe879ea52,0xed5de5fe,0xf309e2c0,0xf93fe0ba,0xffbde002,
0x063de09f,0x0c7ce28b,0x1235e5b1,0x172ce9f0,0x1b2bef1b,0x1e09f4fa,0x1fa6fb4f,0x1ff101d4,
0x1ee70847,0x1c940e62,0x190f13e4,0x147f1891,0x0f151c37,0x09091eb1,0x029d1fe3,0xfc161fc1,
0xf5b81e4c,0xefc71b93,0xea8417b5,0xe62612d9,0xe2dc0d34,0xe0c90702,0xe0030086,0xe092fa04,
0xe271f3c2,0xe58bee02,0xe9c0e903,0xeee2e4f8,0xf4bbe20e,0xfb0ce064,0x0191e00b,0x0807e108,
0x0e26e34e,0x13afe6c7,0x1865eb4d,0x1c17f0b0,0x1e9ef6b7,0x1fddfd20,0x1fc903a8,0x1e610a09,
0x1bb50fff,0x17e1154a,0x130f19b3,0x0d711d08,0x07431f29,0x00c91ffc,0xfa461f7a,0xf4001da8,
0xee3a1a9a,0xe9311670,0xe51c1156,0xe2260b83,0xe06f0536,0xe008feb2,0xe0f7f83a,0xe331f216,
0xe69eec86,0xeb1ae7c6,0xf076e409,0xf677e176,0xfcdee029,0x0365e030,0x09c9e18a,0x0fc5e42a,
0x1518e7f2,0x198aecbb,0x1cecf252,0x1f19f87b,0x1ffafef4,0x1f860578,0x1dc10bc2,0x1abf118e,
0x169f169f,0x118e1abf,0x0bc21dc1,0x05781f86,0xfef41ffa,0xf87b1f19,0xf2521cec,0xecbb198a,
0xe7f21518,0xe42a0fc5,0xe18a09c9,0xe0300365,0xe029fcde,0xe176f677,0xe409f076,0xe7c6eb1a,
0xec86e69e,0xf216e331,0xf83ae0f7,0xfeb2e008,0x0536e06f,0x0b83e226,0x1156e51c,0x1670e931,
0x1a9aee3a,0x1da8f400,0x1f7afa46,0x1ffc00c9,0x1f290743,0x1d080d71,0x19b3130f,0x154a17e1,
0x0fff1bb5,0x0a091e61,0x03a81fc9,0xfd201fdd,0xf6b71e9e,0xf0b01c17,0xeb4d1865,0xe6c713af,
0xe34e0e26,0xe1080807,0xe00b0191,0xe064fb0c,0xe20ef4bb,0xe4f8eee2,0xe903e9c0,0xee02e58b,
0xf3c2e271,0xfa04e092,0x0086e003,0x0702e0c9,0x0d34e2dc,0x12d9e626,0x17b5ea84,0x1b93efc7,
0x1e4cf5b8,0x1fc1fc16,0x1fe3029d,0x1eb10909,0x1c370f15,0x1891147f,0x13e4190f,0x0e621c94,
0x08471ee7,0x01d41ff1,0xfb4f1fa6,0xf4fa1e09,0xef1b1b2b,0xe9f0172c,0xe5b11235,0xe28b0c7c,
0xe09f063d,0xe002ffbd,0xe0baf93f,0xe2c0f309,0xe5feed5d,0xea52e879,0xef8de48f,0xf578e1ca,
0xfbd3e048,0x025ae018,0x08c9e13c,0x0ed9e3a9,0x144ce745,0x18e6ebe8,0x1c76f162,0x1ed6f778,
0x1fedfde9,0x1faf046f,0x1e200ac7,0x1b4e10ac,0x175a15df,0x126c1a28,0x0cb91d5b,0x067f1f54,
0x00001fff,0xf9811f54,0xf3471d5b,0xed941a28,0xe8a615df,0xe4b210ac,0xe1e00ac7,0xe051046f,
0xe013fde9,0xe12af778,0xe38af162,0xe71aebe8,0xebb4e745,0xf127e3a9,0xf737e13c,0xfda6e018,
0x042de048,0x0a88e1ca,0x1073e48f,0x15aee879,0x1a02ed5d,0x1d40f309,0x1f46f93f,0x1ffeffbd,
0x1f61063d,0x1d750c7c,0x1a4f1235,0x1610172c,0x10e51b2b,0x0b061e09,0x04b11fa6,0xfe2c1ff1,
0xf7b91ee7,0xf19e1c94,0xec1c190f,0xe76f147f,0xe3c90f15,0xe14f0909,0xe01d029d,0xe03ffc16,
0xe1b4f5b8,0xe46defc7,0xe84bea84,0xed27e626,0xf2cce2dc,0xf8fee0c9,0xff7ae003,0x05fce092,
0x0c3ee271,0x11fee58b,0x16fde9c0,0x1b08eee2,0x1df2f4bb,0x1f9cfb0c,0x1ff50191,0x1ef80807,
0x1cb20e26,0x193913af,0x14b31865,0x0f501c17,0x09491e9e,0x02e01fdd,0xfc581fc9,0xf5f71e61,
0xf0011bb5,0xeab617e1,0xe64d130f,0xe2f80d71,0xe0d70743,0xe00400c9,0xe086fa46,0xe258f400,
0xe566ee3a,0xe990e931,0xeeaae51c,0xf47de226,0xfacae06f,0x014ee008,0x07c6e0f7,0x0deae331,
0x137ae69e,0x183aeb1a,0x1bf7f076,0x1e8af677,0x1fd7fcde,0x1fd00365,0x1e7609c9,0x1bd60fc5,
0x180e1518,0x1345198a,0x0dae1cec,0x07851f19,0x010c1ffa,0xfa881f86,0xf43e1dc1,0xee721abf,
0xe961169f,0xe541118e,0xe23f0bc2,0xe07a0578,0xe006fef4,0xe0e7f87b,0xe314f252,0xe676ecbb,
0xeae8e7f2,0xf03be42a,0xf637e18a,0xfc9be030,0x0322e029,0x0989e176,0x0f8ae409,0x14e6e7c6,
0x1962ec86,0x1ccff216,0x1f09f83a,0x1ff8feb2,0x1f910536,0x1dda0b83,0x1ae41156,0x16cf1670,
0x11c61a9a,0x0c001da8,0x05ba1f7a,0xff371ffc,0xf8bd1f29,0xf28f1d08,0xecf119b3,0xe81f154a,
0xe44b0fff,0xe19f0a09,0xe03703a8,0xe023fd20,0xe162f6b7,0xe3e9f0b0,0xe79beb4d,0xec51e6c7,
0xf1dae34e,0xf7f9e108,0xfe6fe00b,0x04f4e064,0x0b45e20e,0x111ee4f8,0x1640e903,0x1a75ee02,
0x1d8ff3c2,0x1f6efa04,0x1ffd0086,0x1f370702,0x1d240d34,0x19da12d9,0x157c17b5,0x10391b93,
0x0a481e4c,0x03ea1fc1,0xfd631fe3,0xf6f71eb1,0xf0eb1c37,0xeb811891,0xe6f113e4,0xe36c0e62,
0xe1190847,0xe00f01d4,0xe05afb4f,0xe1f7f4fa,0xe4d5ef1b,0xe8d4e9f0,0xedcbe5b1,0xf384e28b,
0xf9c3e09f,0x0043e002,0x06c1e0ba,0x0cf7e2c0,0x12a3e5fe,0x1787ea52,0x1b71ef8d,0x1e36f578,
0x1fb8fbd3,0x1fe8025a,0x1ec408c9,0x1c570ed9,0x18bb144c,0x141818e6,0x0e9e1c76,0x08881ed6,
0x02171fed,0xfb911faf,0xf5391e20,0xef541b4e,0xea21175a,0xe5d8126c,0xe2a50cb9,0xe0ac067f,
0xe0010000,0xe0acf981,0xe2a5f347,0xe5d8ed94,0xea21e8a6,0xef54e4b2,0xf539e1e0,0xfb91e051,
0x0217e013,0x0888e12a,0x0e9ee38a,0x1418e71a,0x18bbebb4,0x1c57f127,0x1ec4f737,0x1fe8fda6,
0x1fb8042d,0x1e360a88,0x1b711073,0x178715ae,0x12a31a02,0x0cf71d40,0x06c11f46,0x00431ffe,
0xf9c31f61,0xf3841d75,0xedcb1a4f,0xe8d41610,0xe4d510e5,0xe1f70b06,0xe05a04b1,0xe00ffe2c,
0xe119f7b9,0xe36cf19e,0xe6f1ec1c,0xeb81e76f,0xf0ebe3c9,0xf6f7e14f,0xfd63e01d,0x03eae03f,
0x0a48e1b4,0x1039e46d,0x157ce84b,0x19daed27,0x1d24f2cc,0x1f37f8fe,0x1ffdff7a,0x1f6e05fc,
0x1d8f0c3e,0x1a7511fe,0x164016fd,0x111e1b08,0x0b451df2,0x04f41f9c,0xfe6f1ff5,0xf7f91ef8,
0xf1da1cb2,0xec511939,0xe79b14b3,0xe3e90f50,0xe1620949,0xe02302e0,0xe037fc58,0xe19ff5f7,
0xe44bf001,0xe81feab6,0xecf1e64d,0xf28fe2f8,0xf8bde0d7,0xff37e004,0x05bae086,0x0c00e258,
0x11c6e566,0x16cfe990,0x1ae4eeaa,0x1ddaf47d,0x1f91faca,0x1ff8014e,0x1f0907c6,0x1ccf0dea,
0x1962137a,0x14e6183a,0x0f8a1bf7,0x09891e8a,0x03221fd7,0xfc9b1fd0,0xf6371e76,0xf03b1bd6,
0xeae8180e,0xe6761345,0xe3140dae,0xe0e70785,0xe006010c,0xe07afa88,0xe23ff43e,0xe541ee72,
0xe961e961,0xee72e541,0xf43ee23f,0xfa88e07a,0x010ce006,0x0785e0e7,0x0daee314,0x1345e676,
0x180eeae8,0x1bd6f03b,0x1e76f637,0x1fd0fc9b,0x1fd70322,0x1e8a0989,0x1bf70f8a,0x183a14e6,
0x137a1962,0x0dea1ccf,0x07c61f09,0x014e1ff8,0xfaca1f91,0xf47d1dda,0xeeaa1ae4,0xe99016cf,
0xe56611c6,0xe2580c00,0xe08605ba,0xe004ff37,0xe0d7f8bd,0xe2f8f28f,0xe64decf1,0xeab6e81f,
0xf001e44b,0xf5f7e19f,0xfc58e037,0x02e0e023,0x0949e162,0x0f50e3e9,0x14b3e79b,0x1939ec51,
0x1cb2f1da,0x1ef8f7f9,0x1ff5fe6f,0x1f9c04f4,0x1df20b45,0x1b08111e,0x16fd1640,0x11fe1a75,
0x0c3e1d8f,0x05fc1f6e,0xff7a1ffd,0xf8fe1f37,0xf2cc1d24,0xed2719da,0xe84b157c,0xe46d1039,
0xe1b40a48,0xe03f03ea,0xe01dfd63,0xe14ff6f7,0xe3c9f0eb,0xe76feb81,0xec1ce6f1,0xf19ee36c,
0xf7b9e119,0xfe2ce00f,0x04b1e05a,0x0b06e1f7,0x10e5e4d5,0x1610e8d4,0x1a4fedcb,0x1d75f384,
0x1f61f9c3,0x1ffe0043,0x1f4606c1,0x1d400cf7,0x1a0212a3,0x15ae1787,0x10731b71,0x0a881e36,
0x042d1fb8,0xfda61fe8,0xf7371ec4,0xf1271c57,0xebb418bb,0xe71a1418,0xe38a0e9e,0xe12a0888,
0xe0130217,0xe051fb91,0xe1e0f539,0xe4b2ef54,0xe8a6ea21,0xed94e5d8,0xf347e2a5,0xf981e0ac,
0x0000e001,0x067fe0ac,0x0cb9e2a5,0x126ce5d8,0x175aea21,0x1b4eef54,0x1e20f539,0x1faffb91,
0x1fed0217,0x1ed60888,0x1c760e9e,0x18e61418,0x144c18bb,0x0ed91c57,0x08c91ec4,0x025a1fe8,
0xfbd31fb8,0xf5781e36,0xef8d1b71,0xea521787,0xe5fe12a3,0xe2c00cf7,0xe0ba06c1,0xe0020043,
0xe09ff9c3,0xe28bf384,0xe5b1edcb,0xe9f0e8d4,0xef1be4d5,0xf4fae1f7,0xfb4fe05a,0x01d4e00f,
0x0847e119,0x0e62e36c,0x13e4e6f1,0x1891eb81,0x1c37f0eb,0x1eb1f6f7,0x1fe3fd63,0x1fc103ea,
0x1e4c0a48,0x1b931039,0x17b5157c,0x12d919da,0x0d341d24,0x07021f37,0x00861ffd,0xfa041f6e,
0xf3c21d8f,0xee021a75,0xe9031640,0xe4f8111e,0xe20e0b45,0xe06404f4,0xe00bfe6f,0xe108f7f9,
0xe34ef1da,0xe6c7ec51,0xeb4de79b,0xf0b0e3e9,0xf6b7e162,0xfd20e023,0x03a8e037,0x0a09e19f,
0x0fffe44b,0x154ae81f,0x19b3ecf1,0x1d08f28f,0x1f29f8bd,0x1ffcff37,0x1f7a05ba,0x1da80c00,
0x1a9a11c6,0x167016cf,0x11561ae4,0x0b831dda,0x05361f91,0xfeb21ff8,0xf83a1f09,0xf2161ccf,
0xec861962,0xe7c614e6,0xe4090f8a,0xe1760989,0xe0290322,0xe030fc9b,0xe18af637,0xe42af03b,
0xe7f2eae8,0xecbbe676,0xf252e314,0xf87be0e7,0xfef4e006,0x0578e07a,0x0bc2e23f,0x118ee541,
0x169fe961,0x1abfee72,0x1dc1f43e,0x1f86fa88,0x1ffa010c,0x1f190785,0x1cec0dae,0x198a1345,
0x1518180e,0x0fc51bd6,0x09c91e76,0x03651fd0,0xfcde1fd7,0xf6771e8a,0xf0761bf7,0xeb1a183a,
0xe69e137a,0xe3310dea,0xe0f707c6,0xe008014e,0xe06ffaca,0xe226f47d,0xe51ceeaa,0xe931e990,
0xee3ae566,0xf400e258,0xfa46e086,0x00c9e004,0x0743e0d7,0x0d71e2f8,0x130fe64d,0x17e1eab6,
0x1bb5f001,0x1e61f5f7,0x1fc9fc58,0x1fdd02e0,0x1e9e0949,0x1c170f50,0x186514b3,0x13af1939,
0x0e261cb2,0x08071ef8,0x01911ff5,0xfb0c1f9c,0xf4bb1df2,0xeee21b08,0xe9c016fd,0xe58b11fe,
0xe2710c3e,0xe09205fc,0xe003ff7a,0xe0c9f8fe,0xe2dcf2cc,0xe626ed27,0xea84e84b,0xefc7e46d,
0xf5b8e1b4,0xfc16e03f,0x029de01d,0x0909e14f,0x0f15e3c9,0x147fe76f,0x190fec1c,0x1c94f19e,
0x1ee7f7b9,0x1ff1fe2c,0x1fa604b1,0x1e090b06,0x1b2b10e5,0x172c1610,0x12351a4f,0x0c7c1d75,
0x063d1f61,0xffbd1ffe,0xf93f1f46,0xf3091d40,0xed5d1a02,0xe87915ae,0xe48f1073,0xe1ca0a88,
0xe048042d,0xe018fda6,0xe13cf737,0xe3a9f127,0xe745ebb4,0xebe8e71a,0xf162e38a,0xf778e12a,
0xfde9e013,0x046fe051,0x0ac7e1e0,0x10ace4b2,0x15dfe8a6,0x1a28ed94,0x1d5bf347,0x1f54f981,
0x1fff0000,0x1f54067f,0x1d5b0cb9,0x1a28126c,0x15df175a,0x10ac1b4e,0x0ac71e20,0x046f1faf,
0xfde91fed,0xf7781ed6,0xf1621c76,0xebe818e6,0xe745144c,0xe3a90ed9,0xe13c08c9,0xe018025a,
0xe048fbd3,0xe1caf578,0xe48fef8d,0xe879ea52,0xed5de5fe,0xf309e2c0,0xf93fe0ba,0xffbde002,
0x063de09f,0x0c7ce28b,0x1235e5b1,0x172ce9f0,0x1b2bef1b,0x1e09f4fa,0x1fa6fb4f,0x1ff101d4,
0x1ee70847,0x1c940e62,0x190f13e4,0x147f1891,0x0f151c37,0x09091eb1,0x029d1fe3,0xfc161fc1,
0xf5b81e4c,0xefc71b93,0xea8417b5,0xe62612d9,0xe2dc0d34,0xe0c90702,0xe0030086,0xe092fa04,
0xe271f3c2,0xe58bee02,0xe9c0e903,0xeee2e4f8,0xf4bbe20e,0xfb0ce064,0x0191e00b,0x0807e108,
0x0e26e34e,0x13afe6c7,0x1865eb4d,0x1c17f0b0,0x1e9ef6b7,0x1fddfd20,0x1fc903a8,0x1e610a09,
0x1bb50fff,0x17e1154a,0x130f19b3,0x0d711d08,0x07431f29,0x00c91ffc,0xfa461f7a,0xf4001da8,
0xee3a1a9a,0xe9311670,0xe51c1156,0xe2260b83,0xe06f0536,0xe008feb2,0xe0f7f83a,0xe331f216,
0xe69eec86,0xeb1ae7c6,0xf076e409,0xf677e176,0xfcdee029,0x0365e030,0x09c9e18a,0x0fc5e42a,
0x1518e7f2,0x198aecbb,0x1cecf252,0x1f19f87b,0x1ffafef4,0x1f860578,0x1dc10bc2,0x1abf118e,
0x169f169f,0x118e1abf,0x0bc21dc1,0x05781f86,0xfef41ffa,0xf87b1f19,0xf2521cec,0xecbb198a,
0xe7f21518,0xe42a0fc5,0xe18a09c9,0xe0300365,0xe029fcde,0xe176f677,0xe409f076,0xe7c6eb1a,
0xec86e69e,0xf216e331,0xf83ae0f7,0xfeb2e008,0x0536e06f,0x0b83e226,0x1156e51c,0x1670e931,
0x1a9aee3a,0x1da8f400,0x1f7afa46,0x1ffc00c9,0x1f290743,0x1d080d71,0x19b3130f,0x154a17e1,
0x0fff1bb5,0x0a091e61,0x03a81fc9,0xfd201fdd,0xf6b71e9e,0xf0b01c17,0xeb4d1865,0xe6c713af,
0xe34e0e26,0xe1080807,0xe00b0191,0xe064fb0c,0xe20ef4bb,0xe4f8eee2,0xe903e9c0,0xee02e58b,
0xf3c2e271,0xfa04e092,0x0086e003,0x0702e0c9,0x0d34e2dc,0x12d9e626,0x17b5ea84,0x1b93efc7,
0x1e4cf5b8,0x1fc1fc16,0x1fe3029d,0x1eb10909,0x1c370f15,0x1891147f,0x13e4190f,0x0e621c94,
0x08471ee7,0x01d41ff1,0xfb4f1fa6,0xf4fa1e09,0xef1b1b2b,0xe9f0172c,0xe5b11235,0xe28b0c7c,
0xe09f063d,0xe002ffbd,0xe0baf93f,0xe2c0f309,0xe5feed5d,0xea52e879,0xef8de48f,0xf578e1ca,
0xfbd3e048,0x025ae018,0x08c9e13c,0x0ed9e3a9,0x144ce745,0x18e6ebe8,0x1c76f162,0x1ed6f778,
0x1fedfde9,0x1faf046f,0x1e200ac7,0x1b4e10ac,0x175a15df,0x126c1a28,0x0cb91d5b,0x067f1f54,
0x00001fff,0xf9811f54,0xf3471d5b,0xed941a28,0xe8a615df,0xe4b210ac,0xe1e00ac7,0xe051046f,
0xe013fde9,0xe12af778,0xe38af162,0xe71aebe8,0xebb4e745,0xf127e3a9,0xf737e13c,0xfda6e018,
0x042de048,0x0a88e1ca,0x1073e48f,0x15aee879,0x1a02ed5d,0x1d40f309,0x1f46f93f,0x1ffeffbd,
0x1f61063d,0x1d750c7c,0x1a4f1235,0x1610172c,0x10e51b2b,0x0b061e09,0x04b11fa6,0xfe2c1ff1,
0xf7b91ee7,0xf19e1c94,0xec1c190f,0xe76f147f,0xe3c90f15,0xe14f0909,0xe01d029d,0xe03ffc16,
0xe1b4f5b8,0xe46defc7,0xe84bea84,0xed27e626,0xf2cce2dc,0xf8fee0c9,0xff7ae003,0x05fce092,
0x0c3ee271,0x11fee58b,0x16fde9c0,0x1b08eee2,0x1df2f4bb,0x1f9cfb0c,0x1ff50191,0x1ef80807,
0x1cb20e26,0x193913af,0x14b31865,0x0f501c17,0x09491e9e,0x02e01fdd,0xfc581fc9,0xf5f71e61,
0xf0011bb5,0xeab617e1,0xe64d130f,0xe2f80d71,0xe0d70743,0xe00400c9,0xe086fa46,0xe258f400,
0xe566ee3a,0xe990e931,0xeeaae51c,0xf47de226,0xfacae06f,0x014ee008,0x07c6e0f7,0x0deae331,
0x137ae69e,0x183aeb1a,0x1bf7f076,0x1e8af677,0x1fd7fcde,0x1fd00365,0x1e7609c9,0x1bd60fc5,
0x180e1518,0x1345198a,0x0dae1cec,0x07851f19,0x010c1ffa,0xfa881f86,0xf43e1dc1,0xee721abf,
0xe961169f,0xe541118e,0xe23f0bc2,0xe07a0578,0xe006fef4,0xe0e7f87b,0xe314f252,0xe676ecbb,
0xeae8e7f2,0xf03be42a,0xf637e18a,0xfc9be030,0x0322e029,0x0989e176,0x0f8ae409,0x14e6e7c6,
0x1962ec86,0x1ccff216,0x1f09f83a,0x1ff8feb2,0x1f910536,0x1dda0b83,0x1ae41156,0x16cf1670,
0x11c61a9a,0x0c001da8,0x05ba1f7a,0xff371ffc,0xf8bd1f29,0xf28f1d08,0xecf119b3,0xe81f154a,
0xe44b0fff,0xe19f0a09,0xe03703a8,0xe023fd20,0xe162f6b7,0xe3e9f0b0,0xe79beb4d,0xec51e6c7,
0xf1dae34e,0xf7f9e108,0xfe6fe00b,0x04f4e064,0x0b45e20e,0x111ee4f8,0x1640e903,0x1a75ee02,
0x1d8ff3c2,0x1f6efa04,0x1ffd0086,0x1f370702,0x1d240d34,0x19da12d9,0x157c17b5,0x10391b93,
0x0a481e4c,0x03ea1fc1,0xfd631fe3,0xf6f71eb1,0xf0eb1c37,0xeb811891,0xe6f113e4,0xe36c0e62,
0xe1190847,0xe00f01d4,0xe05afb4f,0xe1f7f4fa,0xe4d5ef1b,0xe8d4e9f0,0xedcbe5b1,0xf384e28b,
0xf9c3e09f,0x0043e002,0x06c1e0ba,0x0cf7e2c0,0x12a3e5fe,0x1787ea52,0x1b71ef8d,0x1e36f578,
0x1fb8fbd3,0x1fe8025a,0x1ec408c9,0x1c570ed9,0x18bb144c,0x141818e6,0x0e9e1c76,0x08881ed6,
0x02171fed,0xfb911faf,0xf5391e20,0xef541b4e,0xea21175a,0xe5d8126c,0xe2a50cb9,0xe0ac067f,
0xe0010000,0xe0acf981,0xe2a5f347,0xe5d8ed94,0xea21e8a6,0xef54e4b2,0xf539e1e0,0xfb91e051,
0x0217e013,0x0888e12a,0x0e9ee38a,0x1418e71a,0x18bbebb4,0x1c57f127,0x1ec4f737,0x1fe8fda6,
0x1fb8042d,0x1e360a88,0x1b711073,0x178715ae,0x12a31a02,0x0cf71d40,0x06c11f46,0x00431ffe,
0xf9c31f61,0xf3841d75,0xedcb1a4f,0xe8d41610,0xe4d510e5,0xe1f70b06,0xe05a04b1,0xe00ffe2c,
0xe119f7b9,0xe36cf19e,0xe6f1ec1c,0xeb81e76f,0xf0ebe3c9,0xf6f7e14f,0xfd63e01d,0x03eae03f,
0x0a48e1b4,0x1039e46d,0x157ce84b,0x19daed27,0x1d24f2cc,0x1f37f8fe,0x1ffdff7a,0x1f6e05fc,
0x1d8f0c3e,0x1a7511fe,0x164016fd,0x111e1b08,0x0b451df2,0x04f41f9c,0xfe6f1ff5,0xf7f91ef8,
0xf1da1cb2,0xec511939,0xe79b14b3,0xe3e90f50,0xe1620949,0xe02302e0,0xe037fc58,0xe19ff5f7,
0xe44bf001,0xe81feab6,0xecf1e64d,0xf28fe2f8,0xf8bde0d7,0xff37e004,0x05bae086,0x0c00e258,
0x11c6e566,0x16cfe990,0x1ae4eeaa,0x1ddaf47d,0x1f91faca,0x1ff8014e,0x1f0907c6,0x1ccf0dea,
0x1962137a,0x14e6183a,0x0f8a1bf7,0x09891e8a,0x03221fd7,0xfc9b1fd0,0xf6371e76,0xf03b1bd6,
0xeae8180e,0xe6761345,0xe3140dae,0xe0e70785,0xe006010c,0xe07afa88,0xe23ff43e,0xe541ee72,
0xe961e961,0xee72e541,0xf43ee23f,0xfa88e07a,0x010ce006,0x0785e0e7,0x0daee314,0x1345e676,
0x180eeae8,0x1bd6f03b,0x1e76f637,0x1fd0fc9b,0x1fd70322,0x1e8a0989,0x1bf70f8a,0x183a14e6,
0x137a1962,0x0dea1ccf,0x07c61f09,0x014e1ff8,0xfaca1f91,0xf47d1dda,0xeeaa1ae4,0xe99016cf,
0xe56611c6,0xe2580c00,0xe08605ba,0xe004ff37,0xe0d7f8bd,0xe2f8f28f,0xe64decf1,0xeab6e81f,
0xf001e44b,0xf5f7e19f,0xfc58e037,0x02e0e023,0x0949e162,0x0f50e3e9,0x14b3e79b,0x1939ec51,
0x1cb2f1da,0x1ef8f7f9,0x1ff5fe6f,0x1f9c04f4,0x1df20b45,0x1b08111e,0x16fd1640,0x11fe1a75,
0x0c3e1d8f,0x05fc1f6e,0xff7a1ffd,0xf8fe1f37,0xf2cc1d24,0xed2719da,0xe84b157c,0xe46d1039,
0xe1b40a48,0xe03f03ea,0xe01dfd63,0xe14ff6f7,0xe3c9f0eb,0xe76feb81,0xec1ce6f1,0xf19ee36c,
0xf7b9e119,0xfe2ce00f,0x04b1e05a,0x0b06e1f7,0x10e5e4d5,0x1610e8d4,0x1a4fedcb,0x1d75f384,
0x1f61f9c3,0x1ffe0043,0x1f4606c1,0x1d400cf7,0x1a0212a3,0x15ae1787,0x10731b71,0x0a881e36,
0x042d1fb8,0xfda61fe8,0xf7371ec4,0xf1271c57,0xebb418bb,0xe71a1418,0xe38a0e9e,0xe12a0888,
0xe0130217,0xe051fb91,0xe1e0f539,0xe4b2ef54,0xe8a6ea21,0xed94e5d8,0xf347e2a5,0xf981e0ac,
0x0000e001,0x067fe0ac,0x0cb9e2a5,0x126ce5d8,0x175aea21,0x1b4eef54,0x1e20f539,0x1faffb91,
0x1fed0217,0x1ed60888,0x1c760e9e,0x18e61418,0x144c18bb,0x0ed91c57,0x08c91ec4,0x025a1fe8,
0xfbd31fb8,0xf5781e36,0xef8d1b71,0xea521787,0xe5fe12a3,0xe2c00cf7,0xe0ba06c1,0xe0020043,
0xe09ff9c3,0xe28bf384,0xe5b1edcb,0xe9f0e8d4,0xef1be4d5,0xf4fae1f7,0xfb4fe05a,0x01d4e00f,
0x0847e119,0x0e62e36c,0x13e4e6f1,0x1891eb81,0x1c37f0eb,0x1eb1f6f7,0x1fe3fd63,0x1fc103ea,
0x1e4c0a48,0x1b931039,0x17b5157c,0x12d919da,0x0d341d24,0x07021f37,0x00861ffd,0xfa041f6e,
0xf3c21d8f,0xee021a75,0xe9031640,0xe4f8111e,0xe20e0b45,0xe06404f4,0xe00bfe6f,0xe108f7f9,
0xe34ef1da,0xe6c7ec51,0xeb4de79b,0xf0b0e3e9,0xf6b7e162,0xfd20e023,0x03a8e037,0x0a09e19f,
0x0fffe44b,0x154ae81f,0x19b3ecf1,0x1d08f28f,0x1f29f8bd,0x1ffcff37,0x1f7a05ba,0x1da80c00,
0x1a9a11c6,0x167016cf,0x11561ae4,0x0b831dda,0x05361f91,0xfeb21ff8,0xf83a1f09,0xf2161ccf,
0xec861962,0xe7c614e6,0xe4090f8a,0xe1760989,0xe0290322,0xe030fc9b,0xe18af637,0xe42af03b,
0xe7f2eae8,0xecbbe676,0xf252e314,0xf87be0e7,0xfef4e006,0x0578e07a,0x0bc2e23f,0x118ee541,
0x169fe961,0x1abfee72,0x1dc1f43e,0x1f86fa88,0x1ffa010c,0x1f190785,0x1cec0dae,0x198a1345,
0x1518180e,0x0fc51bd6,0x09c91e76,0x03651fd0,0xfcde1fd7,0xf6771e8a,0xf0761bf7,0xeb1a183a,
0xe69e137a,0xe3310dea,0xe0f707c6,0xe008014e,0xe06ffaca,0xe226f47d,0xe51ceeaa,0xe931e990,
0xee3ae566,0xf400e258,0xfa46e086,0x00c9e004,0x0743e0d7,0x0d71e2f8,0x130fe64d,0x17e1eab6,
0x1bb5f001,0x1e61f5f7,0x1fc9fc58,0x1fdd02e0,0x1e9e0949,0x1c170f50,0x186514b3,0x13af1939,
0x0e261cb2,0x08071ef8,0x01911ff5,0xfb0c1f9c,0xf4bb1df2,0xeee21b08,0xe9c016fd,0xe58b11fe,
0xe2710c3e,0xe09205fc,0xe003ff7a,0xe0c9f8fe,0xe2dcf2cc,0xe626ed27,0xea84e84b,0xefc7e46d,
0xf5b8e1b4,0xfc16e03f,0x029de01d,0x0909e14f,0x0f15e3c9,0x147fe76f,0x190fec1c,0x1c94f19e,
0x1ee7f7b9,0x1ff1fe2c,0x1fa604b1,0x1e090b06,0x1b2b10e5,0x172c1610,0x12351a4f,0x0c7c1d75,
0x063d1f61,0xffbd1ffe,0xf93f1f46,0xf3091d40,0xed5d1a02,0xe87915ae,0xe48f1073,0xe1ca0a88,
0xe048042d,0xe018fda6,0xe13cf737,0xe3a9f127,0xe745ebb4,0xebe8e71a,0xf162e38a,0xf778e12a,
0xfde9e013,0x046fe051,0x0ac7e1e0,0x10ace4b2,0x15dfe8a6,0x1a28ed94,0x1d5bf347,0x1f54f981,
0x1fff0000,0x1f54067f,0x1d5b0cb9,0x1a28126c,0x15df175a,0x10ac1b4e,0x0ac71e20,0x046f1faf,
0xfde91fed,0xf7781ed6,0xf1621c76,0xebe818e6,0xe745144c,0xe3a90ed9,0xe13c08c9,0xe018025a,
0xe048fbd3,0xe1caf578,0xe48fef8d,0xe879ea52,0xed5de5fe,0xf309e2c0,0xf93fe0ba,0xffbde002,
0x063de09f,0x0c7ce28b,0x1235e5b1,0x172ce9f0,0x1b2bef1b,0x1e09f4fa,0x1fa6fb4f,0x1ff101d4,
0x1ee70847,0x1c940e62,0x190f13e4,0x147f1891,0x0f151c37,0x09091eb1,0x029d1fe3,0xfc161fc1,
0xf5b81e4c,0xefc71b93,0xea8417b5,0xe62612d9,0xe2dc0d34,0xe0c90702,0xe0030086,0xe092fa04,
0xe271f3c2,0xe58bee02,0xe9c0e903,0xeee2e4f8,0xf4bbe20e,0xfb0ce064,0x0191e00b,0x0807e108,
0x0e26e34e,0x13afe6c7,0x1865eb4d,0x1c17f0b0,0x1e9ef6b7,0x1fddfd20,0x1fc903a8,0x1e610a09,
0x1bb50fff,0x17e1154a,0x130f19b3,0x0d711d08,0x07431f29,0x00c91ffc,0xfa461f7a,0xf4001da8,
0xee3a1a9a,0xe9311670,0xe51c1156,0xe2260b83,0xe06f0536,0xe008feb2,0xe0f7f83a,0xe331f216,
0xe69eec86,0xeb1ae7c6,0xf076e409,0xf677e176,0xfcdee029,0x0365e030,0x09c9e18a,0x0fc5e42a,
0x1518e7f2,0x198aecbb,0x1cecf252,0x1f19f87b,0x1ffafef4,0x1f860578,0x1dc10bc2,0x1abf118e,
0x169f169f,0x118e1abf,0x0bc21dc1,0x05781f86,0xfef41ffa,0xf87b1f19,0xf2521cec,0xecbb198a,
0xe7f21518,0xe42a0fc5,0xe18a09c9,0xe0300365,0xe029fcde,0xe176f677,0xe409f076,0xe7c6eb1a,
0xec86e69e,0xf216e331,0xf83ae0f7,0xfeb2e008,0x0536e06f,0x0b83e226,0x1156e51c,0x1670e931,
0x1a9aee3a,0x1da8f400,0x1f7afa46,0x1ffc00c9,0x1f290743,0x1d080d71,0x19b3130f,0x154a17e1,
0x0fff1bb5,0x0a091e61,0x03a81fc9,0xfd201fdd,0xf6b71e9e,0xf0b01c17,0xeb4d1865,0xe6c713af,
0xe34e0e26,0xe1080807,0xe00b0191,0xe064fb0c,0xe20ef4bb,0xe4f8eee2,0xe903e9c0,0xee02e58b,
0xf3c2e271,0xfa04e092,0x0086e003,0x0702e0c9,0x0d34e2dc,0x12d9e626,0x17b5ea84,0x1b93efc7,
0x1e4cf5b8,0x1fc1fc16,0x1fe3029d,0x1eb10909,0x1c370f15,0x1891147f,0x13e4190f,0x0e621c94,
0x08471ee7,0x01d41ff1,0xfb4f1fa6,0xf4fa1e09,0xef1b1b2b,0xe9f0172c,0xe5b11235,0xe28b0c7c,
0xe09f063d,0xe002ffbd,0xe0baf93f,0xe2c0f309,0xe5feed5d,0xea52e879,0xef8de48f,0xf578e1ca,
0xfbd3e048,0x025ae018,0x08c9e13c,0x0ed9e3a9,0x144ce745,0x18e6ebe8,0x1c76f162,0x1ed6f778,
0x1fedfde9,0x1faf046f,0x1e200ac7,0x1b4e10ac,0x175a15df,0x126c1a28,0x0cb91d5b,0x067f1f54,
0x00001fff,0xf9811f54,0xf3471d5b,0xed941a28,0xe8a615df,0xe4b210ac,0xe1e00ac7,0xe051046f,
0xe013fde9,0xe12af778,0xe38af162,0xe71aebe8,0xebb4e745,0xf127e3a9,0xf737e13c,0xfda6e018,
0x042de048,0x0a88e1ca,0x1073e48f,0x15aee879,0x1a02ed5d,0x1d40f309,0x1f46f93f,0x1ffeffbd,
0x1f61063d,0x1d750c7c,0x1a4f1235,0x1610172c,0x10e51b2b,0x0b061e09,0x04b11fa6,0xfe2c1ff1,
0xf7b91ee7,0xf19e1c94,0xec1c190f,0xe76f147f,0xe3c90f15,0xe14f0909,0xe01d029d,0xe03ffc16,
0xe1b4f5b8,0xe46defc7,0xe84bea84,0xed27e626,0xf2cce2dc,0xf8fee0c9,0xff7ae003,0x05fce092,
0x0c3ee271,0x11fee58b,0x16fde9c0,0x1b08eee2,0x1df2f4bb,0x1f9cfb0c,0x1ff50191,0x1ef80807,
0x1cb20e26,0x193913af,0x14b31865,0x0f501c17,0x09491e9e,0x02e01fdd,0xfc581fc9,0xf5f71e61,
0xf0011bb5,0xeab617e1,0xe64d130f,0xe2f80d71,0xe0d70743,0xe00400c9,0xe086fa46,0xe258f400,
0xe566ee3a,0xe990e931,0xeeaae51c,0xf47de226,0xfacae06f,0x014ee008,0x07c6e0f7,0x0deae331,
0x137ae69e,0x183aeb1a,0x1bf7f076,0x1e8af677,0x1fd7fcde,0x1fd00365,0x1e7609c9,0x1bd60fc5,
0x180e1518,0x1345198a,0x0dae1cec,0x07851f19,0x010c1ffa,0xfa881f86,0xf43e1dc1,0xee721abf,
0xe961169f,0xe541118e,0xe23f0bc2,0xe07a0578,0xe006fef4,0xe0e7f87b,0xe314f252,0xe676ecbb,
0xeae8e7f2,0xf03be42a,0xf637e18a,0xfc9be030,0x0322e029,0x0989e176,0x0f8ae409,0x14e6e7c6,
0x1962ec86,0x1ccff216,0x1f09f83a,0x1ff8feb2,0x1f910536,0x1dda0b83,0x1ae41156,0x16cf1670,
0x11c61a9a,0x0c001da8,0x05ba1f7a,0xff371ffc,0xf8bd1f29,0xf28f1d08,0xecf119b3,0xe81f154a,
0xe44b0fff,0xe19f0a09,0xe03703a8,0xe023fd20,0xe162f6b7,0xe3e9f0b0,0xe79beb4d,0xec51e6c7,
0xf1dae34e,0xf7f9e108,0xfe6fe00b,0x04f4e064,0x0b45e20e,0x111ee4f8,0x1640e903,0x1a75ee02,
0x1d8ff3c2,0x1f6efa04,0x1ffd0086,0x1f370702,0x1d240d34,0x19da12d9,0x157c17b5,0x10391b93,
0x0a481e4c,0x03ea1fc1,0xfd631fe3,0xf6f71eb1,0xf0eb1c37,0xeb811891,0xe6f113e4,0xe36c0e62,
0xe1190847,0xe00f01d4,0xe05afb4f,0xe1f7f4fa,0xe4d5ef1b,0xe8d4e9f0,0xedcbe5b1,0xf384e28b,
0xf9c3e09f,0x0043e002,0x06c1e0ba,0x0cf7e2c0,0x12a3e5fe,0x1787ea52,0x1b71ef8d,0x1e36f578,
0x1fb8fbd3,0x1fe8025a,0x1ec408c9,0x1c570ed9,0x18bb144c,0x141818e6,0x0e9e1c76,0x08881ed6,
0x02171fed,0xfb911faf,0xf5391e20,0xef541b4e,0xea21175a,0xe5d8126c,0xe2a50cb9,0xe0ac067f,
0xe0010000,0xe0acf981,0xe2a5f347,0xe5d8ed94,0xea21e8a6,0xef54e4b2,0xf539e1e0,0xfb91e051,
0x0217e013,0x0888e12a,0x0e9ee38a,0x1418e71a,0x18bbebb4,0x1c57f127,0x1ec4f737,0x1fe8fda6,
0x1fb8042d,0x1e360a88,0x1b711073,0x178715ae,0x12a31a02,0x0cf71d40,0x06c11f46,0x00431ffe,
0xf9c31f61,0xf3841d75,0xedcb1a4f,0xe8d41610,0xe4d510e5,0xe1f70b06,0xe05a04b1,0xe00ffe2c,
0xe119f7b9,0xe36cf19e,0xe6f1ec1c,0xeb81e76f,0xf0ebe3c9,0xf6f7e14f,0xfd63e01d,0x03eae03f,
0x0a48e1b4,0x1039e46d,0x157ce84b,0x19daed27,0x1d24f2cc,0x1f37f8fe,0x1ffdff7a,0x1f6e05fc,
0x1d8f0c3e,0x1a7511fe,0x164016fd,0x111e1b08,0x0b451df2,0x04f41f9c,0xfe6f1ff5,0xf7f91ef8,
0xf1da1cb2,0xec511939,0xe79b14b3,0xe3e90f50,0xe1620949,0xe02302e0,0xe037fc58,0xe19ff5f7,
0xe44bf001,0xe81feab6,0xecf1e64d,0xf28fe2f8,0xf8bde0d7,0xff37e004,0x05bae086,0x0c00e258,
0x11c6e566,0x16cfe990,0x1ae4eeaa,0x1ddaf47d,0x1f91faca,0x1ff8014e,0x1f0907c6,0x1ccf0dea,
0x1962137a,0x14e6183a,0x0f8a1bf7,0x09891e8a,0x03221fd7,0xfc9b1fd0,0xf6371e76,0xf03b1bd6,
0xeae8180e,0xe6761345,0xe3140dae,0xe0e70785,0xe006010c,0xe07afa88,0xe23ff43e,0xe541ee72,
0xe961e961,0xee72e541,0xf43ee23f,0xfa88e07a,0x010ce006,0x0785e0e7,0x0daee314,0x1345e676,
0x180eeae8,0x1bd6f03b,0x1e76f637,0x1fd0fc9b,0x1fd70322,0x1e8a0989,0x1bf70f8a,0x183a14e6,
0x137a1962,0x0dea1ccf,0x07c61f09,0x014e1ff8,0xfaca1f91,0xf47d1dda,0xeeaa1ae4,0xe99016cf,
0xe56611c6,0xe2580c00,0xe08605ba,0xe004ff37,0xe0d7f8bd,0xe2f8f28f,0xe64decf1,0xeab6e81f,
0xf001e44b,0xf5f7e19f,0xfc58e037,0x02e0e023,0x0949e162,0x0f50e3e9,0x14b3e79b,0x1939ec51,
0x1cb2f1da,0x1ef8f7f9,0x1ff5fe6f,0x1f9c04f4,0x1df20b45,0x1b08111e,0x16fd1640,0x11fe1a75,
0x0c3e1d8f,0x05fc1f6e,0xff7a1ffd,0xf8fe1f37,0xf2cc1d24,0xed2719da,0xe84b157c,0xe46d1039,
0xe1b40a48,0xe03f03ea,0xe01dfd63,0xe14ff6f7,0xe3c9f0eb,0xe76feb81,0xec1ce6f1,0xf19ee36c,
0xf7b9e119,0xfe2ce00f,0x04b1e05a,0x0b06e1f7,0x10e5e4d5,0x1610e8d4,0x1a4fedcb,0x1d75f384,
0x1f61f9c3,0x1ffe0043,0x1f4606c1,0x1d400cf7,0x1a0212a3,0x15ae1787,0x10731b71,0x0a881e36,
0x042d1fb8,0xfda61fe8,0xf7371ec4,0xf1271c57,0xebb418bb,0xe71a1418,0xe38a0e9e,0xe12a0888,
0xe0130217,0xe051fb91,0xe1e0f539,0xe4b2ef54,0xe8a6ea21,0xed94e5d8,0xf347e2a5,0xf981e0ac,
0x0000e001,0x067fe0ac,0x0cb9e2a5,0x126ce5d8,0x175aea21,0x1b4eef54,0x1e20f539,0x1faffb91,
0x1fed0217,0x1ed60888,0x1c760e9e,0x18e61418,0x144c18bb,0x0ed91c57,0x08c91ec4,0x025a1fe8,
0xfbd31fb8,0xf5781e36,0xef8d1b71,0xea521787,0xe5fe12a3,0xe2c00cf7,0xe0ba06c1,0xe0020043,
0xe09ff9c3,0xe28bf384,0xe5b1edcb,0xe9f0e8d4,0xef1be4d5,0xf4fae1f7,0xfb4fe05a,0x01d4e00f,
0x0847e119,0x0e62e36c,0x13e4e6f1,0x1891eb81,0x1c37f0eb,0x1eb1f6f7,0x1fe3fd63,0x1fc103ea,
0x1e4c0a48,0x1b931039,0x17b5157c,0x12d919da,0x0d341d24,0x07021f37,0x00861ffd,0xfa041f6e,
0xf3c21d8f,0xee021a75,0xe9031640,0xe4f8111e,0xe20e0b45,0xe06404f4,0xe00bfe6f,0xe108f7f9,
0xe34ef1da,0xe6c7ec51,0xeb4de79b,0xf0b0e3e9,0xf6b7e162,0xfd20e023,0x03a8e037,0x0a09e19f,
0x0fffe44b,0x154ae81f,0x19b3ecf1,0x1d08f28f,0x1f29f8bd,0x1ffcff37,0x1f7a05ba,0x1da80c00,
0x1a9a11c6,0x167016cf,0x11561ae4,0x0b831dda,0x05361f91,0xfeb21ff8,0xf83a1f09,0xf2161ccf,
0xec861962,0xe7c614e6,0xe4090f8a,0xe1760989,0xe0290322,0xe030fc9b,0xe18af637,0xe42af03b,
0xe7f2eae8,0xecbbe676,0xf252e314,0xf87be0e7,0xfef4e006,0x0578e07a,0x0bc2e23f,0x118ee541,
0x169fe961,0x1abfee72,0x1dc1f43e,0x1f86fa88,0x1ffa010c,0x1f190785,0x1cec0dae,0x198a1345,
0x1518180e,0x0fc51bd6,0x09c91e76,0x03651fd0,0xfcde1fd7,0xf6771e8a,0xf0761bf7,0xeb1a183a,
0xe69e137a,0xe3310dea,0xe0f707c6,0xe008014e,0xe06ffaca,0xe226f47d,0xe51ceeaa,0xe931e990,
0xee3ae566,0xf400e258,0xfa46e086,0x00c9e004,0x0743e0d7,0x0d71e2f8,0x130fe64d,0x17e1eab6,
0x1bb5f001,0x1e61f5f7,0x1fc9fc58,0x1fdd02e0,0x1e9e0949,0x1c170f50,0x186514b3,0x13af1939,
0x0e261cb2,0x08071ef8,0x01911ff5,0xfb0c1f9c,0xf4bb1df2,0xeee21b08,0xe9c016fd,0xe58b11fe,
0xe2710c3e,0xe09205fc,0xe003ff7a,0xe0c9f8fe,0xe2dcf2cc,0xe626ed27,0xea84e84b,0xefc7e46d,
0xf5b8e1b4,0xfc16e03f,0x029de01d,0x0909e14f,0x0f15e3c9,0x147fe76f,0x190fec1c,0x1c94f19e,
0x1ee7f7b9,0x1ff1fe2c,0x1fa604b1,0x1e090b06,0x1b2b10e5,0x172c1610,0x12351a4f,0x0c7c1d75,
0x063d1f61,0xffbd1ffe,0xf93f1f46,0xf3091d40,0xed5d1a02,0xe87915ae,0xe48f1073,0xe1ca0a88,
0xe048042d,0xe018fda6,0xe13cf737,0xe3a9f127,0xe745ebb4,0xebe8e71a,0xf162e38a,0xf778e12a,
0xfde9e013,0x046fe051,0x0ac7e1e0,0x10ace4b2,0x15dfe8a6,0x1a28ed94,0x1d5bf347,0x1f54f981,
0x1fff0000,0x1f54067f,0x1d5b0cb9,0x1a28126c,0x15df175a,0x10ac1b4e,0x0ac71e20,0x046f1faf,
0xfde91fed,0xf7781ed6,0xf1621c76,0xebe818e6,0xe745144c,0xe3a90ed9,0xe13c08c9,0xe018025a,
0xe048fbd3,0xe1caf578,0xe48fef8d,0xe879ea52,0xed5de5fe,0xf309e2c0,0xf93fe0ba,0xffbde002,
0x063de09f,0x0c7ce28b,0x1235e5b1,0x172ce9f0,0x1b2bef1b,0x1e09f4fa,0x1fa6fb4f,0x1ff101d4,
0x1ee70847,0x1c940e62,0x190f13e4,0x147f1891,0x0f151c37,0x09091eb1,0x029d1fe3,0xfc161fc1,
0xf5b81e4c,0xefc71b93,0xea8417b5,0xe62612d9,0xe2dc0d34,0xe0c90702,0xe0030086,0xe092fa04,
0xe271f3c2,0xe58bee02,0xe9c0e903,0xeee2e4f8,0xf4bbe20e,0xfb0ce064,0x0191e00b,0x0807e108,
0x0e26e34e,0x13afe6c7,0x1865eb4d,0x1c17f0b0,0x1e9ef6b7,0x1fddfd20,0x1fc903a8,0x1e610a09,
0x1bb50fff,0x17e1154a,0x130f19b3,0x0d711d08,0x07431f29,0x00c91ffc,0xfa461f7a,0xf4001da8,
0xee3a1a9a,0xe9311670,0xe51c1156,0xe2260b83,0xe06f0536,0xe008feb2,0xe0f7f83a,0xe331f216,
0xe69eec86,0xeb1ae7c6,0xf076e409,0xf677e176,0xfcdee029,0x0365e030,0x09c9e18a,0x0fc5e42a,
0x1518e7f2,0x198aecbb,0x1cecf252,0x1f19f87b,0x1ffafef4,0x1f860578,0x1dc10bc2,0x1abf118e,
0x169f169f,0x118e1abf,0x0bc21dc1,0x05781f86,0xfef41ffa,0xf87b1f19,0xf2521cec,0xecbb198a,
0xe7f21518,0xe42a0fc5,0xe18a09c9,0xe0300365,0xe029fcde,0xe176f677,0xe409f076,0xe7c6eb1a,
0xec86e69e,0xf216e331,0xf83ae0f7,0xfeb2e008,0x0536e06f,0x0b83e226,0x1156e51c,0x1670e931,
0x1a9aee3a,0x1da8f400,0x1f7afa46,0x1ffc00c9,0x1f290743,0x1d080d71,0x19b3130f,0x154a17e1,
0x0fff1bb5,0x0a091e61,0x03a81fc9,0xfd201fdd,0xf6b71e9e,0xf0b01c17,0xeb4d1865,0xe6c713af,
0xe34e0e26,0xe1080807,0xe00b0191,0xe064fb0c,0xe20ef4bb,0xe4f8eee2,0xe903e9c0,0xee02e58b,
0xf3c2e271,0xfa04e092,0x0086e003,0x0702e0c9,0x0d34e2dc,0x12d9e626,0x17b5ea84,0x1b93efc7,
0x1e4cf5b8,0x1fc1fc16,0x1fe3029d,0x1eb10909,0x1c370f15,0x1891147f,0x13e4190f,0x0e621c94,
0x08471ee7,0x01d41ff1,0xfb4f1fa6,0xf4fa1e09,0xef1b1b2b,0xe9f0172c,0xe5b11235,0xe28b0c7c,
0xe09f063d,0xe002ffbd,0xe0baf93f,0xe2c0f309,0xe5feed5d,0xea52e879,0xef8de48f,0xf578e1ca,
0xfbd3e048,0x025ae018,0x08c9e13c,0x0ed9e3a9,0x144ce745,0x18e6ebe8,0x1c76f162,0x1ed6f778,
0x1fedfde9,0x1faf046f,0x1e200ac7,0x1b4e10ac,0x175a15df,0x126c1a28,0x0cb91d5b,0x067f1f54,
0x00001fff,0xf9811f54,0xf3471d5b,0xed941a28,0xe8a615df,0xe4b210ac,0xe1e00ac7,0xe051046f,
0xe013fde9,0xe12af778,0xe38af162,0xe71aebe8,0xebb4e745,0xf127e3a9,0xf737e13c,0xfda6e018,
0x042de048,0x0a88e1ca,0x1073e48f,0x15aee879,0x1a02ed5d,0x1d40f309,0x1f46f93f,0x1ffeffbd,
0x1f61063d,0x1d750c7c,0x1a4f1235,0x1610172c,0x10e51b2b,0x0b061e09,0x04b11fa6,0xfe2c1ff1,
0xf7b91ee7,0xf19e1c94,0xec1c190f,0xe76f147f,0xe3c90f15,0xe14f0909,0xe01d029d,0xe03ffc16,
0xe1b4f5b8,0xe46defc7,0xe84bea84,0xed27e626,0xf2cce2dc,0xf8fee0c9,0xff7ae003,0x05fce092,
0x0c3ee271,0x11fee58b,0x16fde9c0,0x1b08eee2,0x1df2f4bb,0x1f9cfb0c,0x1ff50191,0x1ef80807,
0x1cb20e26,0x193913af,0x14b31865,0x0f501c17,0x09491e9e,0x02e01fdd,0xfc581fc9,0xf5f71e61,
0xf0011bb5,0xeab617e1,0xe64d130f,0xe2f80d71,0xe0d70743,0xe00400c9,0xe086fa46,0xe258f400,
0xe566ee3a,0xe990e931,0xeeaae51c,0xf47de226,0xfacae06f,0x014ee008,0x07c6e0f7,0x0deae331,
0x137ae69e,0x183aeb1a,0x1bf7f076,0x1e8af677,0x1fd7fcde,0x1fd00365,0x1e7609c9,0x1bd60fc5,
0x180e1518,0x1345198a,0x0dae1cec,0x07851f19,0x010c1ffa,0xfa881f86,0xf43e1dc1,0xee721abf,
0xe961169f,0xe541118e,0xe23f0bc2,0xe07a0578,0xe006fef4,0xe0e7f87b,0xe314f252,0xe676ecbb,
0xeae8e7f2,0xf03be42a,0xf637e18a,0xfc9be030,0x0322e029,0x0989e176,0x0f8ae409,0x14e6e7c6,
0x1962ec86,0x1ccff216,0x1f09f83a,0x1ff8feb2,0x1f910536,0x1dda0b83,0x1ae41156,0x16cf1670,
0x11c61a9a,0x0c001da8,0x05ba1f7a,0xff371ffc,0xf8bd1f29,0xf28f1d08,0xecf119b3,0xe81f154a,
0xe44b0fff,0xe19f0a09,0xe03703a8,0xe023fd20,0xe162f6b7,0xe3e9f0b0,0xe79beb4d,0xec51e6c7,
0xf1dae34e,0xf7f9e108,0xfe6fe00b,0x04f4e064,0x0b45e20e,0x111ee4f8,0x1640e903,0x1a75ee02,
0x1d8ff3c2,0x1f6efa04,0x1ffd0086,0x1f370702,0x1d240d34,0x19da12d9,0x157c17b5,0x10391b93,
0x0a481e4c,0x03ea1fc1,0xfd631fe3,0xf6f71eb1,0xf0eb1c37,0xeb811891,0xe6f113e4,0xe36c0e62,
0xe1190847,0xe00f01d4,0xe05afb4f,0xe1f7f4fa,0xe4d5ef1b,0xe8d4e9f0,0xedcbe5b1,0xf384e28b,
0xf9c3e09f,0x0043e002,0x06c1e0ba,0x0cf7e2c0,0x12a3e5fe,0x1787ea52,0x1b71ef8d,0x1e36f578,
0x1fb8fbd3,0x1fe8025a,0x1ec408c9,0x1c570ed9,0x18bb144c,0x141818e6,0x0e9e1c76,0x08881ed6,
0x02171fed,0xfb911faf,0xf5391e20,0xef541b4e,0xea21175a,0xe5d8126c,0xe2a50cb9,0xe0ac067f,
0xe0010000,0xe0acf981,0xe2a5f347,0xe5d8ed94,0xea21e8a6,0xef54e4b2,0xf539e1e0,0xfb91e051,
0x0217e013,0x0888e12a,0x0e9ee38a,0x1418e71a,0x18bbebb4,0x1c57f127,0x1ec4f737,0x1fe8fda6,
0x1fb8042d,0x1e360a88,0x1b711073,0x178715ae,0x12a31a02,0x0cf71d40,0x06c11f46,0x00431ffe,
0xf9c31f61,0xf3841d75,0xedcb1a4f,0xe8d41610,0xe4d510e5,0xe1f70b06,0xe05a04b1,0xe00ffe2c,
0xe119f7b9,0xe36cf19e,0xe6f1ec1c,0xeb81e76f,0xf0ebe3c9,0xf6f7e14f,0xfd63e01d,0x03eae03f,
0x0a48e1b4,0x1039e46d,0x157ce84b,0x19daed27,0x1d24f2cc,0x1f37f8fe,0x1ffdff7a,0x1f6e05fc,
0x1d8f0c3e,0x1a7511fe,0x164016fd,0x111e1b08,0x0b451df2,0x04f41f9c,0xfe6f1ff5,0xf7f91ef8,
0xf1da1cb2,0xec511939,0xe79b14b3,0xe3e90f50,0xe1620949,0xe02302e0,0xe037fc58,0xe19ff5f7,
0xe44bf001,0xe81feab6,0xecf1e64d,0xf28fe2f8,0xf8bde0d7,0xff37e004,0x05bae086,0x0c00e258,
0x11c6e566,0x16cfe990,0x1ae4eeaa,0x1ddaf47d,0x1f91faca,0x1ff8014e,0x1f0907c6,0x1ccf0dea,
0x1962137a,0x14e6183a,0x0f8a1bf7,0x09891e8a,0x03221fd7,0xfc9b1fd0,0xf6371e76,0xf03b1bd6,
0xeae8180e,0xe6761345,0xe3140dae,0xe0e70785,0xe006010c,0xe07afa88,0xe23ff43e,0xe541ee72,
0xe961e961,0xee72e541,0xf43ee23f,0xfa88e07a,0x010ce006,0x0785e0e7,0x0daee314,0x1345e676,
0x180eeae8,0x1bd6f03b,0x1e76f637,0x1fd0fc9b,0x1fd70322,0x1e8a0989,0x1bf70f8a,0x183a14e6,
0x137a1962,0x0dea1ccf,0x07c61f09,0x014e1ff8,0xfaca1f91,0xf47d1dda,0xeeaa1ae4,0xe99016cf,
0xe56611c6,0xe2580c00,0xe08605ba,0xe004ff37,0xe0d7f8bd,0xe2f8f28f,0xe64decf1,0xeab6e81f,
0xf001e44b,0xf5f7e19f,0xfc58e037,0x02e0e023,0x0949e162,0x0f50e3e9,0x14b3e79b,0x1939ec51,
0x1cb2f1da,0x1ef8f7f9,0x1ff5fe6f,0x1f9c04f4,0x1df20b45,0x1b08111e,0x16fd1640,0x11fe1a75,
0x0c3e1d8f,0x05fc1f6e,0xff7a1ffd,0xf8fe1f37,0xf2cc1d24,0xed2719da,0xe84b157c,0xe46d1039,
0xe1b40a48,0xe03f03ea,0xe01dfd63,0xe14ff6f7,0xe3c9f0eb,0xe76feb81,0xec1ce6f1,0xf19ee36c,
0xf7b9e119,0xfe2ce00f,0x04b1e05a,0x0b06e1f7,0x10e5e4d5,0x1610e8d4,0x1a4fedcb,0x1d75f384,
0x1f61f9c3,0x1ffe0043,0x1f4606c1,0x1d400cf7,0x1a0212a3,0x15ae1787,0x10731b71,0x0a881e36,
0x042d1fb8,0xfda61fe8,0xf7371ec4,0xf1271c57,0xebb418bb,0xe71a1418,0xe38a0e9e,0xe12a0888,
0xe0130217,0xe051fb91,0xe1e0f539,0xe4b2ef54,0xe8a6ea21,0xed94e5d8,0xf347e2a5,0xf981e0ac,
0x0000e001,0x067fe0ac,0x0cb9e2a5,0x126ce5d8,0x175aea21,0x1b4eef54,0x1e20f539,0x1faffb91,
0x1fed0217,0x1ed60888,0x1c760e9e,0x18e61418,0x144c18bb,0x0ed91c57,0x08c91ec4,0x025a1fe8,
0xfbd31fb8,0xf5781e36,0xef8d1b71,0xea521787,0xe5fe12a3,0xe2c00cf7,0xe0ba06c1,0xe0020043,
0xe09ff9c3,0xe28bf384,0xe5b1edcb,0xe9f0e8d4,0xef1be4d5,0xf4fae1f7,0xfb4fe05a,0x01d4e00f,
0x0847e119,0x0e62e36c,0x13e4e6f1,0x1891eb81,0x1c37f0eb,0x1eb1f6f7,0x1fe3fd63,0x1fc103ea,
0x1e4c0a48,0x1b931039,0x17b5157c,0x12d919da,0x0d341d24,0x07021f37,0x00861ffd,0xfa041f6e,
0xf3c21d8f,0xee021a75,0xe9031640,0xe4f8111e,0xe20e0b45,0xe06404f4,0xe00bfe6f,0xe108f7f9,
0xe34ef1da,0xe6c7ec51,0xeb4de79b,0xf0b0e3e9,0xf6b7e162,0xfd20e023,0x03a8e037,0x0a09e19f,
0x0fffe44b,0x154ae81f,0x19b3ecf1,0x1d08f28f,0x1f29f8bd,0x1ffcff37,0x1f7a05ba,0x1da80c00,
0x1a9a11c6,0x167016cf,0x11561ae4,0x0b831dda,0x05361f91,0xfeb21ff8,0xf83a1f09,0xf2161ccf,
0xec861962,0xe7c614e6,0xe4090f8a,0xe1760989,0xe0290322,0xe030fc9b,0xe18af637,0xe42af03b,
0xe7f2eae8,0xecbbe676,0xf252e314,0xf87be0e7,0xfef4e006,0x0578e07a,0x0bc2e23f,0x118ee541,
0x169fe961,0x1abfee72,0x1dc1f43e,0x1f86fa88,0x1ffa010c,0x1f190785,0x1cec0dae,0x198a1345,
0x1518180e,0x0fc51bd6,0x09c91e76,0x03651fd0,0xfcde1fd7,0xf6771e8a,0xf0761bf7,0xeb1a183a,
0xe69e137a,0xe3310dea,0xe0f707c6,0xe008014e,0xe06ffaca,0xe226f47d,0xe51ceeaa,0xe931e990,
0xee3ae566,0xf400e258,0xfa46e086,0x00c9e004,0x0743e0d7,0x0d71e2f8,0x130fe64d,0x17e1eab6,
0x1bb5f001,0x1e61f5f7,0x1fc9fc58,0x1fdd02e0,0x1e9e0949,0x1c170f50,0x186514b3,0x13af1939,
0x0e261cb2,0x08071ef8,0x01911ff5,0xfb0c1f9c,0xf4bb1df2,0xeee21b08,0xe9c016fd,0xe58b11fe,
0xe2710c3e,0xe09205fc,0xe003ff7a,0xe0c9f8fe,0xe2dcf2cc,0xe626ed27,0xea84e84b,0xefc7e46d,
0xf5b8e1b4,0xfc16e03f,0x029de01d,0x0909e14f,0x0f15e3c9,0x147fe76f,0x190fec1c,0x1c94f19e,
0x1ee7f7b9,0x1ff1fe2c,0x1fa604b1,0x1e090b06,0x1b2b10e5,0x172c1610,0x12351a4f,0x0c7c1d75,
0x063d1f61,0xffbd1ffe,0xf93f1f46,0xf3091d40,0xed5d1a02,0xe87915ae,0xe48f1073,0xe1ca0a88,
0xe048042d,0xe018fda6,0xe13cf737,0xe3a9f127,0xe745ebb4,0xebe8e71a,0xf162e38a,0xf778e12a,
0xfde9e013,0x046fe051,0x0ac7e1e0,0x10ace4b2,0x15dfe8a6,0x1a28ed94,0x1d5bf347,0x1f54f981};

#pragma DATA_SECTION(txSeqImd,".aifdescmsm");
Uint32 txSeqImd[3072] = {
0x1fff0000,0x1e57031d,0x199d0550,0x127805d9,0x09e30449,0x01060093,0xf906fb17,0xf2d6f48d,
0xef18edf3,0xee03e85c,0xef60e4c4,0xf294e3ea,0xf6c2e62a,0xfaf0eb6c,0xfe34f329,0xffdffc7a,
0xff98063a,0xfd6d0f36,0xf9d21655,0xf58b1ac8,0xf18b1c27,0xeec61a7a,0xee0d163d,0xefe01042,
0xf4580991,0xfb1e033b,0x0378fe2f,0x0c5ffb0e,0x14a9fa1a,0x1b37fb2a,0x1f22fdb5,0x1fdd00e9,
0x1d4e03db,0x17d105a8,0x102905a2,0x07620374,0xfea8ff32,0xf713f953,0xf186f2aa,0xee86ec3d,
0xee2be71d,0xf01ee43b,0xf3b1e43a,0xf7f8e759,0xfbfaed5f,0xfedbf5a8,0xffffff37,0xff2a08df,
0xfc89116f,0xf8a717e0,0xf45a1b7c,0xf09a1bfa,0xee571985,0xee4b14b2,0xf0de0e69,0xf60807b7,
0xfd5701a7,0x05f4fd18,0x0ecefa91,0x16b7fa37,0x1c9cfbc2,0x1facfe93,0x1f7901cd,0x1c0a0483,
0x15da05db,0x0dc5053f,0x04e20275,0xfc60fdaf,0xf549f77f,0xf06af0cb,0xee2aeaa1,0xee81e60c,
0xf0fee3eb,0xf4dce4c9,0xf929e8c3,0xfceeef80,0xff5ef841,0xfff601f6,0xfe980b6d,0xfb8b137d,
0xf7731931,0xf3341bf0,0xefc81b91,0xee141860,0xeebe130a,0xf2100c87,0xf7e405e9,0xffaa0032,
0x0875fc2b,0x112afa41,0x189cfa7a,0x1dc7fc74,0x1ff4ff7b,0x1ed302a7,0x1a8e050e,0x13bc05e6,
0x0b4f04af,0x026a014d,0xfa35fc0f,0xf3adf5a1,0xef84eef7,0xee03e924,0xef03e52c,0xf1f9e3d9,
0xf610e598,0xfa4fea65,0xfdc6f1ca,0xffbbfaed,0xffc604b0,0xfde30ddf,0xfa77155b,0xf63c1a46,
0xf21f1c25,0xef191aef,0xee01170f,0xef67114a,0xf3750aa4,0xf9e8042e,0x0211fee0,0x0af5fb69,
0x136cfa1c,0x1a53fae1,0x1eb6fd3b,0x1ff80064,0x1ded0371,0x18de057a,0x117e05c7,0x08d103f3,
0x00000000,0xf82cfa57,0xf240f3be,0xeed3ed34,0xee0ee7ce,0xefade482,0xf30ce405,0xf747e6a4,
0xfb65ec3c,0xfe80f437,0xfff2fda6,0xff6e075e,0xfd0f102e,0xf9531705,0xf5081b1d,0xf1201c1b,
0xee911a17,0xee221598,0xf0460f78,0xf50c08c4,0xfc0e028b,0x0487fdb3,0x0d6bfad3,0x158ffa21,
0x1bd7fb68,0x1f65fe13,0x1fba014c,0x1cca0426,0x16ff05c2,0x0f25057d,0x0650030c,0xfdaafe90,
0xf64af88c,0xf106f1dc,0xee58eb88,0xee4ae6a2,0xf07ae411,0xf430e470,0xf87ce7ed,0xfc66ee43,
0xff17f6c2,0x00000064,0xfef009fa,0xfc1f1256,0xf8241877,0xf3db1bb5,0xf03c1bd4,0xee34190d,
0xee761400,0xf15b0d9b,0xf6cf06ef,0xfe530103,0x0707fcae,0x0fd3fa69,0x178cfa4f,0x1d23fc0b,
0x1fd3fef6,0x1f3a022c,0x1b6d04c2,0x14f605e4,0x0cb90507,0x03d201fb,0xfb6efd00,0xf493f6b3,
0xf001f001,0xee13e9f9,0xeeb4e5a6,0xf167e3dc,0xf55fe51a,0xf9a8e96f,0xfd4ef077,0xff8bf964,
0xffe60322,0xfe4e0c7d,0xfb171450,0xf6ee19af,0xf2bb1c0e,0xef791b53,0xee0617d4,0xef00124d,
0xf2a30bb8,0xf8bd0529,0x00aeff9d,0x0988fbd3,0x1225fa2c,0x195efaa2,0x1e35fcc7,0x1ffeffdf,
0x1e780300,0x19da0540,0x12ca05de,0x0a3f0464,0x015f00c3,0xf951fb55,0xf30af4d2,0xef31ee34,
0xee02e88d,0xef47e4dd,0xf26ce3e4,0xf695e603,0xfac8eb29,0xfe1af2d0,0xffd7fc17,0xffa505d8,
0xfd8c0ee1,0xf9fc1618,0xf5b71aaa,0xf1af1c28,0xeeda1a99,0xee091673,0xefc01084,0xf41e09d6,
0xfad00377,0x031dfe5a,0x0c04fb23,0x145bfa19,0x1b00fb17,0x1f09fd96,0x1fe600c8,0x1d7803c1,
0x1816059d,0x107f05ad,0x07be0395,0xfefdff67,0xf758f995,0xf1b3f2ef,0xee98ec7a,0xee22e748,
0xf001e44b,0xf387e42b,0xf7cce72a,0xfbd6ed15,0xfec5f54b,0xfffdfed3,0xff3c087f,0xfcab1120,
0xf8d217ab,0xf4851b66,0xf0bb1c04,0xee6419ab,0xee3f14ed,0xf0b60ead,0xf5c807fa,0xfd0401df,
0x0599fd3e,0x0e76faa0,0x166efa30,0x1c6cfbab,0x1f9cfe73,0x1f8b01ad,0x1c3c046c,0x162405d6,
0x0e1d0550,0x053d029c,0xfcb1fde8,0xf588f7c3,0xf090f10f,0xee34eada,0xee72e630,0xf0dce3f3,
0xf4b1e4b1,0xf8fee88b,0xfccdef30,0xff4df7e1,0xfffa0191,0xfeaf0b11,0xfbb01334,0xf7a01904,
0xf35e1be3,0xefe41ba4,0xee1b188c,0xeeab1348,0xf1e10ccc,0xf79e062a,0xff530065,0x081afc4a,
0x10d5fa4a,0x1859fa6e,0x1da0fc59,0x1fedff59,0x1eee0289,0x1ac704fc,0x140c05e7,0x0baa04c6,
0x02c4017a,0xfa82fc4c,0xf3e5f5e6,0xefa1ef39,0xee05e959,0xeeeee549,0xf1d4e3d8,0xf5e4e576,
0xfa25ea26,0xfda9f174,0xffb0fa8a,0xffcf044d,0xfdff0d88,0xfaa0151a,0xf6691a22,0xf2461c21,
0xef301b0a,0xee011741,0xef4c118b,0xf33f0ae9,0xf99c046c,0x01b8ff0e,0x0a9afb82,0x131bfa1f,
0x1a17fad0,0x1e98fd1d,0x1ffc0042,0x1e120355,0x191e056c,0x11d205ce,0x092c0411,0x00570031,
0xf874fa98,0xf271f403,0xeee9ed74,0xee0ae7fc,0xef93e497,0xf2e3e3fb,0xf71be67a,0xfb3eebf6,
0xfe67f3dd,0xffecfd42,0xff7c06fd,0xfd2f0fdc,0xf97e16cb,0xf5331b02,0xf1431c20,0xeea21a39,
0xee1a15d0,0xf0230fbc,0xf4cf0908,0xfbbe02c5,0x042dfddb,0x0d12fae6,0x1543fa1e,0x1ba3fb53,
0x1f50fdf3,0x1fc7012b,0x1cf7040e,0x174605ba,0x0f7c058a,0x06ab0330,0xfdfefec7,0xf68cf8cf,
0xf130f220,0xee67ebc4,0xee3fe6ca,0xf05be41e,0xf405e45d,0xf850e7ba,0xfc43edf6,0xff04f664,
0x00000000,0xff04099c,0xfc43120a,0xf8501846,0xf4051ba3,0xf05b1be2,0xee3f1936,0xee67143c,
0xf1300de0,0xf68c0731,0xfdfe0139,0x06abfcd0,0x0f7cfa76,0x1746fa46,0x1cf7fbf2,0x1fc7fed5,
0x1f50020d,0x1ba304ad,0x154305e2,0x0d12051a,0x042d0225,0xfbbefd3b,0xf4cff6f8,0xf023f044,
0xee1aea30,0xeea2e5c7,0xf143e3e0,0xf533e4fe,0xf97ee935,0xfd2ff024,0xff7cf903,0xffec02be,
0xfe670c23,0xfb3e140a,0xf71b1986,0xf2e31c05,0xef931b69,0xee0a1804,0xeee9128c,0xf2710bfd,
0xf8740568,0x0057ffcf,0x092cfbef,0x11d2fa32,0x191efa94,0x1e12fcab,0x1ffcffbe,0x1e9802e3,
0x1a170530,0x131b05e1,0x0a9a047e,0x01b800f2,0xf99cfb94,0xf33ff517,0xef4cee75,0xee01e8bf,
0xef30e4f6,0xf246e3df,0xf669e5de,0xfaa0eae6,0xfdfff278,0xffcffbb3,0xffb00576,0xfda90e8c,
0xfa2515da,0xf5e41a8a,0xf1d41c28,0xeeee1ab7,0xee0516a7,0xefa110c7,0xf3e50a1a,0xfa8203b4,
0x02c4fe86,0x0baafb3a,0x140cfa19,0x1ac7fb04,0x1eeefd77,0x1fed00a7,0x1da003a7,0x18590592,
0x10d505b6,0x081a03b6,0xff53ff9b,0xf79ef9d6,0xf1e1f334,0xeeabecb8,0xee1be774,0xefe4e45c,
0xf35ee41d,0xf7a0e6fc,0xfbb0eccc,0xfeaff4ef,0xfffafe6f,0xff4d081f,0xfccd10d0,0xf8fe1775,
0xf4b11b4f,0xf0dc1c0d,0xee7219d0,0xee341526,0xf0900ef1,0xf588083d,0xfcb10218,0x053dfd64,
0x0e1dfab0,0x1624fa2a,0x1c3cfb94,0x1f8bfe53,0x1f9c018d,0x1c6c0455,0x166e05d0,0x0e760560,
0x059902c2,0xfd04fe21,0xf5c8f806,0xf0b6f153,0xee3feb13,0xee64e655,0xf0bbe3fc,0xf485e49a,
0xf8d2e855,0xfcabeee0,0xff3cf781,0xfffd012d,0xfec50ab5,0xfbd612eb,0xf7cc18d6,0xf3871bd5,
0xf0011bb5,0xee2218b8,0xee981386,0xf1b30d11,0xf758066b,0xfefd0099,0x07befc6b,0x107ffa53,
0x1816fa63,0x1d78fc3f,0x1fe6ff38,0x1f09026a,0x1b0004e9,0x145b05e7,0x0c0404dd,0x031d01a6,
0xfad0fc89,0xf41ef62a,0xefc0ef7c,0xee09e98d,0xeedae567,0xf1afe3d8,0xf5b7e556,0xf9fce9e8,
0xfd8cf11f,0xffa5fa28,0xffd703e9,0xfe1a0d30,0xfac814d7,0xf69519fd,0xf26c1c1c,0xef471b23,
0xee021773,0xef3111cc,0xf30a0b2e,0xf95104ab,0x015fff3d,0x0a3ffb9c,0x12cafa22,0x19dafac0,
0x1e78fd00,0x1ffe0021,0x1e350339,0x195e055e,0x122505d4,0x0988042d,0x00ae0063,0xf8bdfad7,
0xf2a3f448,0xef00edb3,0xee06e82c,0xef79e4ad,0xf2bbe3f2,0xf6eee651,0xfb17ebb0,0xfe4ef383,
0xffe6fcde,0xff8b069c,0xfd4e0f89,0xf9a81691,0xf55f1ae6,0xf1671c24,0xeeb41a5a,0xee131607,
0xf0010fff,0xf493094d,0xfb6e0300,0x03d2fe05,0x0cb9faf9,0x14f6fa1c,0x1b6dfb3e,0x1f3afdd4,
0x1fd3010a,0x1d2303f5,0x178c05b1,0x0fd30597,0x07070352,0xfe53fefd,0xf6cff911,0xf15bf265,
0xee76ec00,0xee34e6f3,0xf03ce42c,0xf3dbe44b,0xf824e789,0xfc1fedaa,0xfef0f606,0x0000ff9c,
0xff17093e,0xfc6611bd,0xf87c1813,0xf4301b90,0xf07a1bef,0xee4a195e,0xee581478,0xf1060e24,
0xf64a0774,0xfdaa0170,0x0650fcf4,0x0f25fa83,0x16fffa3e,0x1ccafbda,0x1fbafeb4,0x1f6501ed,
0x1bd70498,0x158f05df,0x0d6b052d,0x0487024d,0xfc0efd75,0xf50cf73c,0xf046f088,0xee22ea68,
0xee91e5e9,0xf120e3e5,0xf508e4e3,0xf953e8fb,0xfd0fefd2,0xff6ef8a2,0xfff2025a,0xfe800bc9,
0xfb6513c4,0xf747195c,0xf30c1bfb,0xefad1b7e,0xee0e1832,0xeed312cc,0xf2400c42,0xf82c05a9,
0x00000000,0x08d1fc0d,0x117efa39,0x18defa86,0x1dedfc8f,0x1ff8ff9c,0x1eb602c5,0x1a53051f,
0x136c05e4,0x0af50497,0x02110120,0xf9e8fbd2,0xf375f55c,0xef67eeb6,0xee01e8f1,0xef19e511,
0xf21fe3db,0xf63ce5ba,0xfa77eaa5,0xfde3f221,0xffc6fb50,0xffbb0513,0xfdc60e36,0xfa4f159b,
0xf6101a68,0xf1f91c27,0xef031ad4,0xee0316dc,0xef841109,0xf3ad0a5f,0xfa3503f1,0x026afeb3,
0x0b4ffb51,0x13bcfa1a,0x1a8efaf2,0x1ed3fd59,0x1ff40085,0x1dc7038c,0x189c0586,0x112a05bf,
0x087503d5,0xffaaffce,0xf7e4fa17,0xf210f379,0xeebeecf6,0xee14e7a0,0xefc8e46f,0xf334e410,
0xf773e6cf,0xfb8bec83,0xfe98f493,0xfff6fe0a,0xff5e07bf,0xfcee1080,0xf929173d,0xf4dc1b37,
0xf0fe1c15,0xee8119f4,0xee2a155f,0xf06a0f35,0xf5490881,0xfc600251,0x04e2fd8b,0x0dc5fac1,
0x15dafa25,0x1c0afb7d,0x1f79fe33,0x1fac016d,0x1c9c043e,0x16b705c9,0x0ece056f,0x05f402e8,
0xfd57fe59,0xf608f849,0xf0def197,0xee4beb4e,0xee57e67b,0xf09ae406,0xf45ae484,0xf8a7e820,
0xfc89ee91,0xff2af721,0xffff00c9,0xfedb0a58,0xfbfa12a1,0xf7f818a7,0xf3b11bc6,0xf01e1bc5,
0xee2b18e3,0xee8613c3,0xf1860d56,0xf71306ad,0xfea800ce,0x0762fc8c,0x1029fa5e,0x17d1fa58,
0x1d4efc25,0x1fddff17,0x1f22024b,0x1b3704d6,0x14a905e6,0x0c5f04f2,0x037801d1,0xfb1efcc5,
0xf458f66f,0xefe0efbe,0xee0de9c3,0xeec6e586,0xf18be3d9,0xf58be538,0xf9d2e9ab,0xfd6df0ca,
0xff98f9c6,0xffdf0386,0xfe340cd7,0xfaf01494,0xf6c219d6,0xf2941c16,0xef601b3c,0xee0317a4,
0xef18120d,0xf2d60b73,0xf90604e9,0x0106ff6d,0x09e3fbb7,0x1278fa27,0x199dfab0,0x1e57fce3,
0x1fff0000,0x1e57031d,0x199d0550,0x127805d9,0x09e30449,0x01060093,0xf906fb17,0xf2d6f48d,
0xef18edf3,0xee03e85c,0xef60e4c4,0xf294e3ea,0xf6c2e62a,0xfaf0eb6c,0xfe34f329,0xffdffc7a,
0xff98063a,0xfd6d0f36,0xf9d21655,0xf58b1ac8,0xf18b1c27,0xeec61a7a,0xee0d163d,0xefe01042,
0xf4580991,0xfb1e033b,0x0378fe2f,0x0c5ffb0e,0x14a9fa1a,0x1b37fb2a,0x1f22fdb5,0x1fdd00e9,
0x1d4e03db,0x17d105a8,0x102905a2,0x07620374,0xfea8ff32,0xf713f953,0xf186f2aa,0xee86ec3d,
0xee2be71d,0xf01ee43b,0xf3b1e43a,0xf7f8e759,0xfbfaed5f,0xfedbf5a8,0xffffff37,0xff2a08df,
0xfc89116f,0xf8a717e0,0xf45a1b7c,0xf09a1bfa,0xee571985,0xee4b14b2,0xf0de0e69,0xf60807b7,
0xfd5701a7,0x05f4fd18,0x0ecefa91,0x16b7fa37,0x1c9cfbc2,0x1facfe93,0x1f7901cd,0x1c0a0483,
0x15da05db,0x0dc5053f,0x04e20275,0xfc60fdaf,0xf549f77f,0xf06af0cb,0xee2aeaa1,0xee81e60c,
0xf0fee3eb,0xf4dce4c9,0xf929e8c3,0xfceeef80,0xff5ef841,0xfff601f6,0xfe980b6d,0xfb8b137d,
0xf7731931,0xf3341bf0,0xefc81b91,0xee141860,0xeebe130a,0xf2100c87,0xf7e405e9,0xffaa0032,
0x0875fc2b,0x112afa41,0x189cfa7a,0x1dc7fc74,0x1ff4ff7b,0x1ed302a7,0x1a8e050e,0x13bc05e6,
0x0b4f04af,0x026a014d,0xfa35fc0f,0xf3adf5a1,0xef84eef7,0xee03e924,0xef03e52c,0xf1f9e3d9,
0xf610e598,0xfa4fea65,0xfdc6f1ca,0xffbbfaed,0xffc604b0,0xfde30ddf,0xfa77155b,0xf63c1a46,
0xf21f1c25,0xef191aef,0xee01170f,0xef67114a,0xf3750aa4,0xf9e8042e,0x0211fee0,0x0af5fb69,
0x136cfa1c,0x1a53fae1,0x1eb6fd3b,0x1ff80064,0x1ded0371,0x18de057a,0x117e05c7,0x08d103f3,
0x00000000,0xf82cfa57,0xf240f3be,0xeed3ed34,0xee0ee7ce,0xefade482,0xf30ce405,0xf747e6a4,
0xfb65ec3c,0xfe80f437,0xfff2fda6,0xff6e075e,0xfd0f102e,0xf9531705,0xf5081b1d,0xf1201c1b,
0xee911a17,0xee221598,0xf0460f78,0xf50c08c4,0xfc0e028b,0x0487fdb3,0x0d6bfad3,0x158ffa21,
0x1bd7fb68,0x1f65fe13,0x1fba014c,0x1cca0426,0x16ff05c2,0x0f25057d,0x0650030c,0xfdaafe90,
0xf64af88c,0xf106f1dc,0xee58eb88,0xee4ae6a2,0xf07ae411,0xf430e470,0xf87ce7ed,0xfc66ee43,
0xff17f6c2,0x00000064,0xfef009fa,0xfc1f1256,0xf8241877,0xf3db1bb5,0xf03c1bd4,0xee34190d,
0xee761400,0xf15b0d9b,0xf6cf06ef,0xfe530103,0x0707fcae,0x0fd3fa69,0x178cfa4f,0x1d23fc0b,
0x1fd3fef6,0x1f3a022c,0x1b6d04c2,0x14f605e4,0x0cb90507,0x03d201fb,0xfb6efd00,0xf493f6b3,
0xf001f001,0xee13e9f9,0xeeb4e5a6,0xf167e3dc,0xf55fe51a,0xf9a8e96f,0xfd4ef077,0xff8bf964,
0xffe60322,0xfe4e0c7d,0xfb171450,0xf6ee19af,0xf2bb1c0e,0xef791b53,0xee0617d4,0xef00124d,
0xf2a30bb8,0xf8bd0529,0x00aeff9d,0x0988fbd3,0x1225fa2c,0x195efaa2,0x1e35fcc7,0x1ffeffdf,
0x1e780300,0x19da0540,0x12ca05de,0x0a3f0464,0x015f00c3,0xf951fb55,0xf30af4d2,0xef31ee34,
0xee02e88d,0xef47e4dd,0xf26ce3e4,0xf695e603,0xfac8eb29,0xfe1af2d0,0xffd7fc17,0xffa505d8,
0xfd8c0ee1,0xf9fc1618,0xf5b71aaa,0xf1af1c28,0xeeda1a99,0xee091673,0xefc01084,0xf41e09d6,
0xfad00377,0x031dfe5a,0x0c04fb23,0x145bfa19,0x1b00fb17,0x1f09fd96,0x1fe600c8,0x1d7803c1,
0x1816059d,0x107f05ad,0x07be0395,0xfefdff67,0xf758f995,0xf1b3f2ef,0xee98ec7a,0xee22e748,
0xf001e44b,0xf387e42b,0xf7cce72a,0xfbd6ed15,0xfec5f54b,0xfffdfed3,0xff3c087f,0xfcab1120,
0xf8d217ab,0xf4851b66,0xf0bb1c04,0xee6419ab,0xee3f14ed,0xf0b60ead,0xf5c807fa,0xfd0401df,
0x0599fd3e,0x0e76faa0,0x166efa30,0x1c6cfbab,0x1f9cfe73,0x1f8b01ad,0x1c3c046c,0x162405d6,
0x0e1d0550,0x053d029c,0xfcb1fde8,0xf588f7c3,0xf090f10f,0xee34eada,0xee72e630,0xf0dce3f3,
0xf4b1e4b1,0xf8fee88b,0xfccdef30,0xff4df7e1,0xfffa0191,0xfeaf0b11,0xfbb01334,0xf7a01904,
0xf35e1be3,0xefe41ba4,0xee1b188c,0xeeab1348,0xf1e10ccc,0xf79e062a,0xff530065,0x081afc4a,
0x10d5fa4a,0x1859fa6e,0x1da0fc59,0x1fedff59,0x1eee0289,0x1ac704fc,0x140c05e7,0x0baa04c6,
0x02c4017a,0xfa82fc4c,0xf3e5f5e6,0xefa1ef39,0xee05e959,0xeeeee549,0xf1d4e3d8,0xf5e4e576,
0xfa25ea26,0xfda9f174,0xffb0fa8a,0xffcf044d,0xfdff0d88,0xfaa0151a,0xf6691a22,0xf2461c21,
0xef301b0a,0xee011741,0xef4c118b,0xf33f0ae9,0xf99c046c,0x01b8ff0e,0x0a9afb82,0x131bfa1f,
0x1a17fad0,0x1e98fd1d,0x1ffc0042,0x1e120355,0x191e056c,0x11d205ce,0x092c0411,0x00570031,
0xf874fa98,0xf271f403,0xeee9ed74,0xee0ae7fc,0xef93e497,0xf2e3e3fb,0xf71be67a,0xfb3eebf6,
0xfe67f3dd,0xffecfd42,0xff7c06fd,0xfd2f0fdc,0xf97e16cb,0xf5331b02,0xf1431c20,0xeea21a39,
0xee1a15d0,0xf0230fbc,0xf4cf0908,0xfbbe02c5,0x042dfddb,0x0d12fae6,0x1543fa1e,0x1ba3fb53,
0x1f50fdf3,0x1fc7012b,0x1cf7040e,0x174605ba,0x0f7c058a,0x06ab0330,0xfdfefec7,0xf68cf8cf,
0xf130f220,0xee67ebc4,0xee3fe6ca,0xf05be41e,0xf405e45d,0xf850e7ba,0xfc43edf6,0xff04f664,
0x00000000,0xff04099c,0xfc43120a,0xf8501846,0xf4051ba3,0xf05b1be2,0xee3f1936,0xee67143c,
0xf1300de0,0xf68c0731,0xfdfe0139,0x06abfcd0,0x0f7cfa76,0x1746fa46,0x1cf7fbf2,0x1fc7fed5,
0x1f50020d,0x1ba304ad,0x154305e2,0x0d12051a,0x042d0225,0xfbbefd3b,0xf4cff6f8,0xf023f044,
0xee1aea30,0xeea2e5c7,0xf143e3e0,0xf533e4fe,0xf97ee935,0xfd2ff024,0xff7cf903,0xffec02be,
0xfe670c23,0xfb3e140a,0xf71b1986,0xf2e31c05,0xef931b69,0xee0a1804,0xeee9128c,0xf2710bfd,
0xf8740568,0x0057ffcf,0x092cfbef,0x11d2fa32,0x191efa94,0x1e12fcab,0x1ffcffbe,0x1e9802e3,
0x1a170530,0x131b05e1,0x0a9a047e,0x01b800f2,0xf99cfb94,0xf33ff517,0xef4cee75,0xee01e8bf,
0xef30e4f6,0xf246e3df,0xf669e5de,0xfaa0eae6,0xfdfff278,0xffcffbb3,0xffb00576,0xfda90e8c,
0xfa2515da,0xf5e41a8a,0xf1d41c28,0xeeee1ab7,0xee0516a7,0xefa110c7,0xf3e50a1a,0xfa8203b4,
0x02c4fe86,0x0baafb3a,0x140cfa19,0x1ac7fb04,0x1eeefd77,0x1fed00a7,0x1da003a7,0x18590592,
0x10d505b6,0x081a03b6,0xff53ff9b,0xf79ef9d6,0xf1e1f334,0xeeabecb8,0xee1be774,0xefe4e45c,
0xf35ee41d,0xf7a0e6fc,0xfbb0eccc,0xfeaff4ef,0xfffafe6f,0xff4d081f,0xfccd10d0,0xf8fe1775,
0xf4b11b4f,0xf0dc1c0d,0xee7219d0,0xee341526,0xf0900ef1,0xf588083d,0xfcb10218,0x053dfd64,
0x0e1dfab0,0x1624fa2a,0x1c3cfb94,0x1f8bfe53,0x1f9c018d,0x1c6c0455,0x166e05d0,0x0e760560,
0x059902c2,0xfd04fe21,0xf5c8f806,0xf0b6f153,0xee3feb13,0xee64e655,0xf0bbe3fc,0xf485e49a,
0xf8d2e855,0xfcabeee0,0xff3cf781,0xfffd012d,0xfec50ab5,0xfbd612eb,0xf7cc18d6,0xf3871bd5,
0xf0011bb5,0xee2218b8,0xee981386,0xf1b30d11,0xf758066b,0xfefd0099,0x07befc6b,0x107ffa53,
0x1816fa63,0x1d78fc3f,0x1fe6ff38,0x1f09026a,0x1b0004e9,0x145b05e7,0x0c0404dd,0x031d01a6,
0xfad0fc89,0xf41ef62a,0xefc0ef7c,0xee09e98d,0xeedae567,0xf1afe3d8,0xf5b7e556,0xf9fce9e8,
0xfd8cf11f,0xffa5fa28,0xffd703e9,0xfe1a0d30,0xfac814d7,0xf69519fd,0xf26c1c1c,0xef471b23,
0xee021773,0xef3111cc,0xf30a0b2e,0xf95104ab,0x015fff3d,0x0a3ffb9c,0x12cafa22,0x19dafac0,
0x1e78fd00,0x1ffe0021,0x1e350339,0x195e055e,0x122505d4,0x0988042d,0x00ae0063,0xf8bdfad7,
0xf2a3f448,0xef00edb3,0xee06e82c,0xef79e4ad,0xf2bbe3f2,0xf6eee651,0xfb17ebb0,0xfe4ef383,
0xffe6fcde,0xff8b069c,0xfd4e0f89,0xf9a81691,0xf55f1ae6,0xf1671c24,0xeeb41a5a,0xee131607,
0xf0010fff,0xf493094d,0xfb6e0300,0x03d2fe05,0x0cb9faf9,0x14f6fa1c,0x1b6dfb3e,0x1f3afdd4,
0x1fd3010a,0x1d2303f5,0x178c05b1,0x0fd30597,0x07070352,0xfe53fefd,0xf6cff911,0xf15bf265,
0xee76ec00,0xee34e6f3,0xf03ce42c,0xf3dbe44b,0xf824e789,0xfc1fedaa,0xfef0f606,0x0000ff9c,
0xff17093e,0xfc6611bd,0xf87c1813,0xf4301b90,0xf07a1bef,0xee4a195e,0xee581478,0xf1060e24,
0xf64a0774,0xfdaa0170,0x0650fcf4,0x0f25fa83,0x16fffa3e,0x1ccafbda,0x1fbafeb4,0x1f6501ed,
0x1bd70498,0x158f05df,0x0d6b052d,0x0487024d,0xfc0efd75,0xf50cf73c,0xf046f088,0xee22ea68,
0xee91e5e9,0xf120e3e5,0xf508e4e3,0xf953e8fb,0xfd0fefd2,0xff6ef8a2,0xfff2025a,0xfe800bc9,
0xfb6513c4,0xf747195c,0xf30c1bfb,0xefad1b7e,0xee0e1832,0xeed312cc,0xf2400c42,0xf82c05a9,
0x00000000,0x08d1fc0d,0x117efa39,0x18defa86,0x1dedfc8f,0x1ff8ff9c,0x1eb602c5,0x1a53051f,
0x136c05e4,0x0af50497,0x02110120,0xf9e8fbd2,0xf375f55c,0xef67eeb6,0xee01e8f1,0xef19e511,
0xf21fe3db,0xf63ce5ba,0xfa77eaa5,0xfde3f221,0xffc6fb50,0xffbb0513,0xfdc60e36,0xfa4f159b,
0xf6101a68,0xf1f91c27,0xef031ad4,0xee0316dc,0xef841109,0xf3ad0a5f,0xfa3503f1,0x026afeb3,
0x0b4ffb51,0x13bcfa1a,0x1a8efaf2,0x1ed3fd59,0x1ff40085,0x1dc7038c,0x189c0586,0x112a05bf,
0x087503d5,0xffaaffce,0xf7e4fa17,0xf210f379,0xeebeecf6,0xee14e7a0,0xefc8e46f,0xf334e410,
0xf773e6cf,0xfb8bec83,0xfe98f493,0xfff6fe0a,0xff5e07bf,0xfcee1080,0xf929173d,0xf4dc1b37,
0xf0fe1c15,0xee8119f4,0xee2a155f,0xf06a0f35,0xf5490881,0xfc600251,0x04e2fd8b,0x0dc5fac1,
0x15dafa25,0x1c0afb7d,0x1f79fe33,0x1fac016d,0x1c9c043e,0x16b705c9,0x0ece056f,0x05f402e8,
0xfd57fe59,0xf608f849,0xf0def197,0xee4beb4e,0xee57e67b,0xf09ae406,0xf45ae484,0xf8a7e820,
0xfc89ee91,0xff2af721,0xffff00c9,0xfedb0a58,0xfbfa12a1,0xf7f818a7,0xf3b11bc6,0xf01e1bc5,
0xee2b18e3,0xee8613c3,0xf1860d56,0xf71306ad,0xfea800ce,0x0762fc8c,0x1029fa5e,0x17d1fa58,
0x1d4efc25,0x1fddff17,0x1f22024b,0x1b3704d6,0x14a905e6,0x0c5f04f2,0x037801d1,0xfb1efcc5,
0xf458f66f,0xefe0efbe,0xee0de9c3,0xeec6e586,0xf18be3d9,0xf58be538,0xf9d2e9ab,0xfd6df0ca,
0xff98f9c6,0xffdf0386,0xfe340cd7,0xfaf01494,0xf6c219d6,0xf2941c16,0xef601b3c,0xee0317a4,
0xef18120d,0xf2d60b73,0xf90604e9,0x0106ff6d,0x09e3fbb7,0x1278fa27,0x199dfab0,0x1e57fce3,
0x1fff0000,0x1e57031d,0x199d0550,0x127805d9,0x09e30449,0x01060093,0xf906fb17,0xf2d6f48d,
0xef18edf3,0xee03e85c,0xef60e4c4,0xf294e3ea,0xf6c2e62a,0xfaf0eb6c,0xfe34f329,0xffdffc7a,
0xff98063a,0xfd6d0f36,0xf9d21655,0xf58b1ac8,0xf18b1c27,0xeec61a7a,0xee0d163d,0xefe01042,
0xf4580991,0xfb1e033b,0x0378fe2f,0x0c5ffb0e,0x14a9fa1a,0x1b37fb2a,0x1f22fdb5,0x1fdd00e9,
0x1d4e03db,0x17d105a8,0x102905a2,0x07620374,0xfea8ff32,0xf713f953,0xf186f2aa,0xee86ec3d,
0xee2be71d,0xf01ee43b,0xf3b1e43a,0xf7f8e759,0xfbfaed5f,0xfedbf5a8,0xffffff37,0xff2a08df,
0xfc89116f,0xf8a717e0,0xf45a1b7c,0xf09a1bfa,0xee571985,0xee4b14b2,0xf0de0e69,0xf60807b7,
0xfd5701a7,0x05f4fd18,0x0ecefa91,0x16b7fa37,0x1c9cfbc2,0x1facfe93,0x1f7901cd,0x1c0a0483,
0x15da05db,0x0dc5053f,0x04e20275,0xfc60fdaf,0xf549f77f,0xf06af0cb,0xee2aeaa1,0xee81e60c,
0xf0fee3eb,0xf4dce4c9,0xf929e8c3,0xfceeef80,0xff5ef841,0xfff601f6,0xfe980b6d,0xfb8b137d,
0xf7731931,0xf3341bf0,0xefc81b91,0xee141860,0xeebe130a,0xf2100c87,0xf7e405e9,0xffaa0032,
0x0875fc2b,0x112afa41,0x189cfa7a,0x1dc7fc74,0x1ff4ff7b,0x1ed302a7,0x1a8e050e,0x13bc05e6,
0x0b4f04af,0x026a014d,0xfa35fc0f,0xf3adf5a1,0xef84eef7,0xee03e924,0xef03e52c,0xf1f9e3d9,
0xf610e598,0xfa4fea65,0xfdc6f1ca,0xffbbfaed,0xffc604b0,0xfde30ddf,0xfa77155b,0xf63c1a46,
0xf21f1c25,0xef191aef,0xee01170f,0xef67114a,0xf3750aa4,0xf9e8042e,0x0211fee0,0x0af5fb69,
0x136cfa1c,0x1a53fae1,0x1eb6fd3b,0x1ff80064,0x1ded0371,0x18de057a,0x117e05c7,0x08d103f3,
0x00000000,0xf82cfa57,0xf240f3be,0xeed3ed34,0xee0ee7ce,0xefade482,0xf30ce405,0xf747e6a4,
0xfb65ec3c,0xfe80f437,0xfff2fda6,0xff6e075e,0xfd0f102e,0xf9531705,0xf5081b1d,0xf1201c1b,
0xee911a17,0xee221598,0xf0460f78,0xf50c08c4,0xfc0e028b,0x0487fdb3,0x0d6bfad3,0x158ffa21,
0x1bd7fb68,0x1f65fe13,0x1fba014c,0x1cca0426,0x16ff05c2,0x0f25057d,0x0650030c,0xfdaafe90,
0xf64af88c,0xf106f1dc,0xee58eb88,0xee4ae6a2,0xf07ae411,0xf430e470,0xf87ce7ed,0xfc66ee43,
0xff17f6c2,0x00000064,0xfef009fa,0xfc1f1256,0xf8241877,0xf3db1bb5,0xf03c1bd4,0xee34190d,
0xee761400,0xf15b0d9b,0xf6cf06ef,0xfe530103,0x0707fcae,0x0fd3fa69,0x178cfa4f,0x1d23fc0b,
0x1fd3fef6,0x1f3a022c,0x1b6d04c2,0x14f605e4,0x0cb90507,0x03d201fb,0xfb6efd00,0xf493f6b3,
0xf001f001,0xee13e9f9,0xeeb4e5a6,0xf167e3dc,0xf55fe51a,0xf9a8e96f,0xfd4ef077,0xff8bf964,
0xffe60322,0xfe4e0c7d,0xfb171450,0xf6ee19af,0xf2bb1c0e,0xef791b53,0xee0617d4,0xef00124d,
0xf2a30bb8,0xf8bd0529,0x00aeff9d,0x0988fbd3,0x1225fa2c,0x195efaa2,0x1e35fcc7,0x1ffeffdf,
0x1e780300,0x19da0540,0x12ca05de,0x0a3f0464,0x015f00c3,0xf951fb55,0xf30af4d2,0xef31ee34,
0xee02e88d,0xef47e4dd,0xf26ce3e4,0xf695e603,0xfac8eb29,0xfe1af2d0,0xffd7fc17,0xffa505d8,
0xfd8c0ee1,0xf9fc1618,0xf5b71aaa,0xf1af1c28,0xeeda1a99,0xee091673,0xefc01084,0xf41e09d6,
0xfad00377,0x031dfe5a,0x0c04fb23,0x145bfa19,0x1b00fb17,0x1f09fd96,0x1fe600c8,0x1d7803c1,
0x1816059d,0x107f05ad,0x07be0395,0xfefdff67,0xf758f995,0xf1b3f2ef,0xee98ec7a,0xee22e748,
0xf001e44b,0xf387e42b,0xf7cce72a,0xfbd6ed15,0xfec5f54b,0xfffdfed3,0xff3c087f,0xfcab1120,
0xf8d217ab,0xf4851b66,0xf0bb1c04,0xee6419ab,0xee3f14ed,0xf0b60ead,0xf5c807fa,0xfd0401df,
0x0599fd3e,0x0e76faa0,0x166efa30,0x1c6cfbab,0x1f9cfe73,0x1f8b01ad,0x1c3c046c,0x162405d6,
0x0e1d0550,0x053d029c,0xfcb1fde8,0xf588f7c3,0xf090f10f,0xee34eada,0xee72e630,0xf0dce3f3,
0xf4b1e4b1,0xf8fee88b,0xfccdef30,0xff4df7e1,0xfffa0191,0xfeaf0b11,0xfbb01334,0xf7a01904,
0xf35e1be3,0xefe41ba4,0xee1b188c,0xeeab1348,0xf1e10ccc,0xf79e062a,0xff530065,0x081afc4a,
0x10d5fa4a,0x1859fa6e,0x1da0fc59,0x1fedff59,0x1eee0289,0x1ac704fc,0x140c05e7,0x0baa04c6,
0x02c4017a,0xfa82fc4c,0xf3e5f5e6,0xefa1ef39,0xee05e959,0xeeeee549,0xf1d4e3d8,0xf5e4e576,
0xfa25ea26,0xfda9f174,0xffb0fa8a,0xffcf044d,0xfdff0d88,0xfaa0151a,0xf6691a22,0xf2461c21,
0xef301b0a,0xee011741,0xef4c118b,0xf33f0ae9,0xf99c046c,0x01b8ff0e,0x0a9afb82,0x131bfa1f,
0x1a17fad0,0x1e98fd1d,0x1ffc0042,0x1e120355,0x191e056c,0x11d205ce,0x092c0411,0x00570031,
0xf874fa98,0xf271f403,0xeee9ed74,0xee0ae7fc,0xef93e497,0xf2e3e3fb,0xf71be67a,0xfb3eebf6,
0xfe67f3dd,0xffecfd42,0xff7c06fd,0xfd2f0fdc,0xf97e16cb,0xf5331b02,0xf1431c20,0xeea21a39,
0xee1a15d0,0xf0230fbc,0xf4cf0908,0xfbbe02c5,0x042dfddb,0x0d12fae6,0x1543fa1e,0x1ba3fb53,
0x1f50fdf3,0x1fc7012b,0x1cf7040e,0x174605ba,0x0f7c058a,0x06ab0330,0xfdfefec7,0xf68cf8cf,
0xf130f220,0xee67ebc4,0xee3fe6ca,0xf05be41e,0xf405e45d,0xf850e7ba,0xfc43edf6,0xff04f664,
0x00000000,0xff04099c,0xfc43120a,0xf8501846,0xf4051ba3,0xf05b1be2,0xee3f1936,0xee67143c,
0xf1300de0,0xf68c0731,0xfdfe0139,0x06abfcd0,0x0f7cfa76,0x1746fa46,0x1cf7fbf2,0x1fc7fed5,
0x1f50020d,0x1ba304ad,0x154305e2,0x0d12051a,0x042d0225,0xfbbefd3b,0xf4cff6f8,0xf023f044,
0xee1aea30,0xeea2e5c7,0xf143e3e0,0xf533e4fe,0xf97ee935,0xfd2ff024,0xff7cf903,0xffec02be,
0xfe670c23,0xfb3e140a,0xf71b1986,0xf2e31c05,0xef931b69,0xee0a1804,0xeee9128c,0xf2710bfd,
0xf8740568,0x0057ffcf,0x092cfbef,0x11d2fa32,0x191efa94,0x1e12fcab,0x1ffcffbe,0x1e9802e3,
0x1a170530,0x131b05e1,0x0a9a047e,0x01b800f2,0xf99cfb94,0xf33ff517,0xef4cee75,0xee01e8bf,
0xef30e4f6,0xf246e3df,0xf669e5de,0xfaa0eae6,0xfdfff278,0xffcffbb3,0xffb00576,0xfda90e8c,
0xfa2515da,0xf5e41a8a,0xf1d41c28,0xeeee1ab7,0xee0516a7,0xefa110c7,0xf3e50a1a,0xfa8203b4,
0x02c4fe86,0x0baafb3a,0x140cfa19,0x1ac7fb04,0x1eeefd77,0x1fed00a7,0x1da003a7,0x18590592,
0x10d505b6,0x081a03b6,0xff53ff9b,0xf79ef9d6,0xf1e1f334,0xeeabecb8,0xee1be774,0xefe4e45c,
0xf35ee41d,0xf7a0e6fc,0xfbb0eccc,0xfeaff4ef,0xfffafe6f,0xff4d081f,0xfccd10d0,0xf8fe1775,
0xf4b11b4f,0xf0dc1c0d,0xee7219d0,0xee341526,0xf0900ef1,0xf588083d,0xfcb10218,0x053dfd64,
0x0e1dfab0,0x1624fa2a,0x1c3cfb94,0x1f8bfe53,0x1f9c018d,0x1c6c0455,0x166e05d0,0x0e760560,
0x059902c2,0xfd04fe21,0xf5c8f806,0xf0b6f153,0xee3feb13,0xee64e655,0xf0bbe3fc,0xf485e49a,
0xf8d2e855,0xfcabeee0,0xff3cf781,0xfffd012d,0xfec50ab5,0xfbd612eb,0xf7cc18d6,0xf3871bd5,
0xf0011bb5,0xee2218b8,0xee981386,0xf1b30d11,0xf758066b,0xfefd0099,0x07befc6b,0x107ffa53,
0x1816fa63,0x1d78fc3f,0x1fe6ff38,0x1f09026a,0x1b0004e9,0x145b05e7,0x0c0404dd,0x031d01a6,
0xfad0fc89,0xf41ef62a,0xefc0ef7c,0xee09e98d,0xeedae567,0xf1afe3d8,0xf5b7e556,0xf9fce9e8,
0xfd8cf11f,0xffa5fa28,0xffd703e9,0xfe1a0d30,0xfac814d7,0xf69519fd,0xf26c1c1c,0xef471b23,
0xee021773,0xef3111cc,0xf30a0b2e,0xf95104ab,0x015fff3d,0x0a3ffb9c,0x12cafa22,0x19dafac0,
0x1e78fd00,0x1ffe0021,0x1e350339,0x195e055e,0x122505d4,0x0988042d,0x00ae0063,0xf8bdfad7,
0xf2a3f448,0xef00edb3,0xee06e82c,0xef79e4ad,0xf2bbe3f2,0xf6eee651,0xfb17ebb0,0xfe4ef383,
0xffe6fcde,0xff8b069c,0xfd4e0f89,0xf9a81691,0xf55f1ae6,0xf1671c24,0xeeb41a5a,0xee131607,
0xf0010fff,0xf493094d,0xfb6e0300,0x03d2fe05,0x0cb9faf9,0x14f6fa1c,0x1b6dfb3e,0x1f3afdd4,
0x1fd3010a,0x1d2303f5,0x178c05b1,0x0fd30597,0x07070352,0xfe53fefd,0xf6cff911,0xf15bf265,
0xee76ec00,0xee34e6f3,0xf03ce42c,0xf3dbe44b,0xf824e789,0xfc1fedaa,0xfef0f606,0x0000ff9c,
0xff17093e,0xfc6611bd,0xf87c1813,0xf4301b90,0xf07a1bef,0xee4a195e,0xee581478,0xf1060e24,
0xf64a0774,0xfdaa0170,0x0650fcf4,0x0f25fa83,0x16fffa3e,0x1ccafbda,0x1fbafeb4,0x1f6501ed,
0x1bd70498,0x158f05df,0x0d6b052d,0x0487024d,0xfc0efd75,0xf50cf73c,0xf046f088,0xee22ea68,
0xee91e5e9,0xf120e3e5,0xf508e4e3,0xf953e8fb,0xfd0fefd2,0xff6ef8a2,0xfff2025a,0xfe800bc9,
0xfb6513c4,0xf747195c,0xf30c1bfb,0xefad1b7e,0xee0e1832,0xeed312cc,0xf2400c42,0xf82c05a9,
0x00000000,0x08d1fc0d,0x117efa39,0x18defa86,0x1dedfc8f,0x1ff8ff9c,0x1eb602c5,0x1a53051f,
0x136c05e4,0x0af50497,0x02110120,0xf9e8fbd2,0xf375f55c,0xef67eeb6,0xee01e8f1,0xef19e511,
0xf21fe3db,0xf63ce5ba,0xfa77eaa5,0xfde3f221,0xffc6fb50,0xffbb0513,0xfdc60e36,0xfa4f159b,
0xf6101a68,0xf1f91c27,0xef031ad4,0xee0316dc,0xef841109,0xf3ad0a5f,0xfa3503f1,0x026afeb3,
0x0b4ffb51,0x13bcfa1a,0x1a8efaf2,0x1ed3fd59,0x1ff40085,0x1dc7038c,0x189c0586,0x112a05bf,
0x087503d5,0xffaaffce,0xf7e4fa17,0xf210f379,0xeebeecf6,0xee14e7a0,0xefc8e46f,0xf334e410,
0xf773e6cf,0xfb8bec83,0xfe98f493,0xfff6fe0a,0xff5e07bf,0xfcee1080,0xf929173d,0xf4dc1b37,
0xf0fe1c15,0xee8119f4,0xee2a155f,0xf06a0f35,0xf5490881,0xfc600251,0x04e2fd8b,0x0dc5fac1,
0x15dafa25,0x1c0afb7d,0x1f79fe33,0x1fac016d,0x1c9c043e,0x16b705c9,0x0ece056f,0x05f402e8,
0xfd57fe59,0xf608f849,0xf0def197,0xee4beb4e,0xee57e67b,0xf09ae406,0xf45ae484,0xf8a7e820,
0xfc89ee91,0xff2af721,0xffff00c9,0xfedb0a58,0xfbfa12a1,0xf7f818a7,0xf3b11bc6,0xf01e1bc5,
0xee2b18e3,0xee8613c3,0xf1860d56,0xf71306ad,0xfea800ce,0x0762fc8c,0x1029fa5e,0x17d1fa58,
0x1d4efc25,0x1fddff17,0x1f22024b,0x1b3704d6,0x14a905e6,0x0c5f04f2,0x037801d1,0xfb1efcc5,
0xf458f66f,0xefe0efbe,0xee0de9c3,0xeec6e586,0xf18be3d9,0xf58be538,0xf9d2e9ab,0xfd6df0ca,
0xff98f9c6,0xffdf0386,0xfe340cd7,0xfaf01494,0xf6c219d6,0xf2941c16,0xef601b3c,0xee0317a4,
0xef18120d,0xf2d60b73,0xf90604e9,0x0106ff6d,0x09e3fbb7,0x1278fa27,0x199dfab0,0x1e57fce3,
0x1fff0000,0x1e57031d,0x199d0550,0x127805d9,0x09e30449,0x01060093,0xf906fb17,0xf2d6f48d,
0xef18edf3,0xee03e85c,0xef60e4c4,0xf294e3ea,0xf6c2e62a,0xfaf0eb6c,0xfe34f329,0xffdffc7a,
0xff98063a,0xfd6d0f36,0xf9d21655,0xf58b1ac8,0xf18b1c27,0xeec61a7a,0xee0d163d,0xefe01042,
0xf4580991,0xfb1e033b,0x0378fe2f,0x0c5ffb0e,0x14a9fa1a,0x1b37fb2a,0x1f22fdb5,0x1fdd00e9,
0x1d4e03db,0x17d105a8,0x102905a2,0x07620374,0xfea8ff32,0xf713f953,0xf186f2aa,0xee86ec3d,
0xee2be71d,0xf01ee43b,0xf3b1e43a,0xf7f8e759,0xfbfaed5f,0xfedbf5a8,0xffffff37,0xff2a08df,
0xfc89116f,0xf8a717e0,0xf45a1b7c,0xf09a1bfa,0xee571985,0xee4b14b2,0xf0de0e69,0xf60807b7,
0xfd5701a7,0x05f4fd18,0x0ecefa91,0x16b7fa37,0x1c9cfbc2,0x1facfe93,0x1f7901cd,0x1c0a0483,
0x15da05db,0x0dc5053f,0x04e20275,0xfc60fdaf,0xf549f77f,0xf06af0cb,0xee2aeaa1,0xee81e60c,
0xf0fee3eb,0xf4dce4c9,0xf929e8c3,0xfceeef80,0xff5ef841,0xfff601f6,0xfe980b6d,0xfb8b137d,
0xf7731931,0xf3341bf0,0xefc81b91,0xee141860,0xeebe130a,0xf2100c87,0xf7e405e9,0xffaa0032,
0x0875fc2b,0x112afa41,0x189cfa7a,0x1dc7fc74,0x1ff4ff7b,0x1ed302a7,0x1a8e050e,0x13bc05e6,
0x0b4f04af,0x026a014d,0xfa35fc0f,0xf3adf5a1,0xef84eef7,0xee03e924,0xef03e52c,0xf1f9e3d9,
0xf610e598,0xfa4fea65,0xfdc6f1ca,0xffbbfaed,0xffc604b0,0xfde30ddf,0xfa77155b,0xf63c1a46,
0xf21f1c25,0xef191aef,0xee01170f,0xef67114a,0xf3750aa4,0xf9e8042e,0x0211fee0,0x0af5fb69,
0x136cfa1c,0x1a53fae1,0x1eb6fd3b,0x1ff80064,0x1ded0371,0x18de057a,0x117e05c7,0x08d103f3,
0x00000000,0xf82cfa57,0xf240f3be,0xeed3ed34,0xee0ee7ce,0xefade482,0xf30ce405,0xf747e6a4,
0xfb65ec3c,0xfe80f437,0xfff2fda6,0xff6e075e,0xfd0f102e,0xf9531705,0xf5081b1d,0xf1201c1b,
0xee911a17,0xee221598,0xf0460f78,0xf50c08c4,0xfc0e028b,0x0487fdb3,0x0d6bfad3,0x158ffa21,
0x1bd7fb68,0x1f65fe13,0x1fba014c,0x1cca0426,0x16ff05c2,0x0f25057d,0x0650030c,0xfdaafe90,
0xf64af88c,0xf106f1dc,0xee58eb88,0xee4ae6a2,0xf07ae411,0xf430e470,0xf87ce7ed,0xfc66ee43,
0xff17f6c2,0x00000064,0xfef009fa,0xfc1f1256,0xf8241877,0xf3db1bb5,0xf03c1bd4,0xee34190d,
0xee761400,0xf15b0d9b,0xf6cf06ef,0xfe530103,0x0707fcae,0x0fd3fa69,0x178cfa4f,0x1d23fc0b,
0x1fd3fef6,0x1f3a022c,0x1b6d04c2,0x14f605e4,0x0cb90507,0x03d201fb,0xfb6efd00,0xf493f6b3,
0xf001f001,0xee13e9f9,0xeeb4e5a6,0xf167e3dc,0xf55fe51a,0xf9a8e96f,0xfd4ef077,0xff8bf964,
0xffe60322,0xfe4e0c7d,0xfb171450,0xf6ee19af,0xf2bb1c0e,0xef791b53,0xee0617d4,0xef00124d,
0xf2a30bb8,0xf8bd0529,0x00aeff9d,0x0988fbd3,0x1225fa2c,0x195efaa2,0x1e35fcc7,0x1ffeffdf,
0x1e780300,0x19da0540,0x12ca05de,0x0a3f0464,0x015f00c3,0xf951fb55,0xf30af4d2,0xef31ee34,
0xee02e88d,0xef47e4dd,0xf26ce3e4,0xf695e603,0xfac8eb29,0xfe1af2d0,0xffd7fc17,0xffa505d8,
0xfd8c0ee1,0xf9fc1618,0xf5b71aaa,0xf1af1c28,0xeeda1a99,0xee091673,0xefc01084,0xf41e09d6,
0xfad00377,0x031dfe5a,0x0c04fb23,0x145bfa19,0x1b00fb17,0x1f09fd96,0x1fe600c8,0x1d7803c1,
0x1816059d,0x107f05ad,0x07be0395,0xfefdff67,0xf758f995,0xf1b3f2ef,0xee98ec7a,0xee22e748,
0xf001e44b,0xf387e42b,0xf7cce72a,0xfbd6ed15,0xfec5f54b,0xfffdfed3,0xff3c087f,0xfcab1120,
0xf8d217ab,0xf4851b66,0xf0bb1c04,0xee6419ab,0xee3f14ed,0xf0b60ead,0xf5c807fa,0xfd0401df,
0x0599fd3e,0x0e76faa0,0x166efa30,0x1c6cfbab,0x1f9cfe73,0x1f8b01ad,0x1c3c046c,0x162405d6,
0x0e1d0550,0x053d029c,0xfcb1fde8,0xf588f7c3,0xf090f10f,0xee34eada,0xee72e630,0xf0dce3f3,
0xf4b1e4b1,0xf8fee88b,0xfccdef30,0xff4df7e1,0xfffa0191,0xfeaf0b11,0xfbb01334,0xf7a01904,
0xf35e1be3,0xefe41ba4,0xee1b188c,0xeeab1348,0xf1e10ccc,0xf79e062a,0xff530065,0x081afc4a,
0x10d5fa4a,0x1859fa6e,0x1da0fc59,0x1fedff59,0x1eee0289,0x1ac704fc,0x140c05e7,0x0baa04c6,
0x02c4017a,0xfa82fc4c,0xf3e5f5e6,0xefa1ef39,0xee05e959,0xeeeee549,0xf1d4e3d8,0xf5e4e576,
0xfa25ea26,0xfda9f174,0xffb0fa8a,0xffcf044d,0xfdff0d88,0xfaa0151a,0xf6691a22,0xf2461c21,
0xef301b0a,0xee011741,0xef4c118b,0xf33f0ae9,0xf99c046c,0x01b8ff0e,0x0a9afb82,0x131bfa1f,
0x1a17fad0,0x1e98fd1d,0x1ffc0042,0x1e120355,0x191e056c,0x11d205ce,0x092c0411,0x00570031,
0xf874fa98,0xf271f403,0xeee9ed74,0xee0ae7fc,0xef93e497,0xf2e3e3fb,0xf71be67a,0xfb3eebf6,
0xfe67f3dd,0xffecfd42,0xff7c06fd,0xfd2f0fdc,0xf97e16cb,0xf5331b02,0xf1431c20,0xeea21a39,
0xee1a15d0,0xf0230fbc,0xf4cf0908,0xfbbe02c5,0x042dfddb,0x0d12fae6,0x1543fa1e,0x1ba3fb53,
0x1f50fdf3,0x1fc7012b,0x1cf7040e,0x174605ba,0x0f7c058a,0x06ab0330,0xfdfefec7,0xf68cf8cf,
0xf130f220,0xee67ebc4,0xee3fe6ca,0xf05be41e,0xf405e45d,0xf850e7ba,0xfc43edf6,0xff04f664,
0x00000000,0xff04099c,0xfc43120a,0xf8501846,0xf4051ba3,0xf05b1be2,0xee3f1936,0xee67143c,
0xf1300de0,0xf68c0731,0xfdfe0139,0x06abfcd0,0x0f7cfa76,0x1746fa46,0x1cf7fbf2,0x1fc7fed5,
0x1f50020d,0x1ba304ad,0x154305e2,0x0d12051a,0x042d0225,0xfbbefd3b,0xf4cff6f8,0xf023f044,
0xee1aea30,0xeea2e5c7,0xf143e3e0,0xf533e4fe,0xf97ee935,0xfd2ff024,0xff7cf903,0xffec02be,
0xfe670c23,0xfb3e140a,0xf71b1986,0xf2e31c05,0xef931b69,0xee0a1804,0xeee9128c,0xf2710bfd,
0xf8740568,0x0057ffcf,0x092cfbef,0x11d2fa32,0x191efa94,0x1e12fcab,0x1ffcffbe,0x1e9802e3,
0x1a170530,0x131b05e1,0x0a9a047e,0x01b800f2,0xf99cfb94,0xf33ff517,0xef4cee75,0xee01e8bf,
0xef30e4f6,0xf246e3df,0xf669e5de,0xfaa0eae6,0xfdfff278,0xffcffbb3,0xffb00576,0xfda90e8c,
0xfa2515da,0xf5e41a8a,0xf1d41c28,0xeeee1ab7,0xee0516a7,0xefa110c7,0xf3e50a1a,0xfa8203b4,
0x02c4fe86,0x0baafb3a,0x140cfa19,0x1ac7fb04,0x1eeefd77,0x1fed00a7,0x1da003a7,0x18590592,
0x10d505b6,0x081a03b6,0xff53ff9b,0xf79ef9d6,0xf1e1f334,0xeeabecb8,0xee1be774,0xefe4e45c,
0xf35ee41d,0xf7a0e6fc,0xfbb0eccc,0xfeaff4ef,0xfffafe6f,0xff4d081f,0xfccd10d0,0xf8fe1775,
0xf4b11b4f,0xf0dc1c0d,0xee7219d0,0xee341526,0xf0900ef1,0xf588083d,0xfcb10218,0x053dfd64,
0x0e1dfab0,0x1624fa2a,0x1c3cfb94,0x1f8bfe53,0x1f9c018d,0x1c6c0455,0x166e05d0,0x0e760560,
0x059902c2,0xfd04fe21,0xf5c8f806,0xf0b6f153,0xee3feb13,0xee64e655,0xf0bbe3fc,0xf485e49a,
0xf8d2e855,0xfcabeee0,0xff3cf781,0xfffd012d,0xfec50ab5,0xfbd612eb,0xf7cc18d6,0xf3871bd5,
0xf0011bb5,0xee2218b8,0xee981386,0xf1b30d11,0xf758066b,0xfefd0099,0x07befc6b,0x107ffa53,
0x1816fa63,0x1d78fc3f,0x1fe6ff38,0x1f09026a,0x1b0004e9,0x145b05e7,0x0c0404dd,0x031d01a6,
0xfad0fc89,0xf41ef62a,0xefc0ef7c,0xee09e98d,0xeedae567,0xf1afe3d8,0xf5b7e556,0xf9fce9e8,
0xfd8cf11f,0xffa5fa28,0xffd703e9,0xfe1a0d30,0xfac814d7,0xf69519fd,0xf26c1c1c,0xef471b23,
0xee021773,0xef3111cc,0xf30a0b2e,0xf95104ab,0x015fff3d,0x0a3ffb9c,0x12cafa22,0x19dafac0,
0x1e78fd00,0x1ffe0021,0x1e350339,0x195e055e,0x122505d4,0x0988042d,0x00ae0063,0xf8bdfad7,
0xf2a3f448,0xef00edb3,0xee06e82c,0xef79e4ad,0xf2bbe3f2,0xf6eee651,0xfb17ebb0,0xfe4ef383,
0xffe6fcde,0xff8b069c,0xfd4e0f89,0xf9a81691,0xf55f1ae6,0xf1671c24,0xeeb41a5a,0xee131607,
0xf0010fff,0xf493094d,0xfb6e0300,0x03d2fe05,0x0cb9faf9,0x14f6fa1c,0x1b6dfb3e,0x1f3afdd4,
0x1fd3010a,0x1d2303f5,0x178c05b1,0x0fd30597,0x07070352,0xfe53fefd,0xf6cff911,0xf15bf265,
0xee76ec00,0xee34e6f3,0xf03ce42c,0xf3dbe44b,0xf824e789,0xfc1fedaa,0xfef0f606,0x0000ff9c,
0xff17093e,0xfc6611bd,0xf87c1813,0xf4301b90,0xf07a1bef,0xee4a195e,0xee581478,0xf1060e24,
0xf64a0774,0xfdaa0170,0x0650fcf4,0x0f25fa83,0x16fffa3e,0x1ccafbda,0x1fbafeb4,0x1f6501ed,
0x1bd70498,0x158f05df,0x0d6b052d,0x0487024d,0xfc0efd75,0xf50cf73c,0xf046f088,0xee22ea68,
0xee91e5e9,0xf120e3e5,0xf508e4e3,0xf953e8fb,0xfd0fefd2,0xff6ef8a2,0xfff2025a,0xfe800bc9,
0xfb6513c4,0xf747195c,0xf30c1bfb,0xefad1b7e,0xee0e1832,0xeed312cc,0xf2400c42,0xf82c05a9,
0x00000000,0x08d1fc0d,0x117efa39,0x18defa86,0x1dedfc8f,0x1ff8ff9c,0x1eb602c5,0x1a53051f,
0x136c05e4,0x0af50497,0x02110120,0xf9e8fbd2,0xf375f55c,0xef67eeb6,0xee01e8f1,0xef19e511,
0xf21fe3db,0xf63ce5ba,0xfa77eaa5,0xfde3f221,0xffc6fb50,0xffbb0513,0xfdc60e36,0xfa4f159b,
0xf6101a68,0xf1f91c27,0xef031ad4,0xee0316dc,0xef841109,0xf3ad0a5f,0xfa3503f1,0x026afeb3,
0x0b4ffb51,0x13bcfa1a,0x1a8efaf2,0x1ed3fd59,0x1ff40085,0x1dc7038c,0x189c0586,0x112a05bf,
0x087503d5,0xffaaffce,0xf7e4fa17,0xf210f379,0xeebeecf6,0xee14e7a0,0xefc8e46f,0xf334e410,
0xf773e6cf,0xfb8bec83,0xfe98f493,0xfff6fe0a,0xff5e07bf,0xfcee1080,0xf929173d,0xf4dc1b37,
0xf0fe1c15,0xee8119f4,0xee2a155f,0xf06a0f35,0xf5490881,0xfc600251,0x04e2fd8b,0x0dc5fac1,
0x15dafa25,0x1c0afb7d,0x1f79fe33,0x1fac016d,0x1c9c043e,0x16b705c9,0x0ece056f,0x05f402e8,
0xfd57fe59,0xf608f849,0xf0def197,0xee4beb4e,0xee57e67b,0xf09ae406,0xf45ae484,0xf8a7e820,
0xfc89ee91,0xff2af721,0xffff00c9,0xfedb0a58,0xfbfa12a1,0xf7f818a7,0xf3b11bc6,0xf01e1bc5,
0xee2b18e3,0xee8613c3,0xf1860d56,0xf71306ad,0xfea800ce,0x0762fc8c,0x1029fa5e,0x17d1fa58,
0x1d4efc25,0x1fddff17,0x1f22024b,0x1b3704d6,0x14a905e6,0x0c5f04f2,0x037801d1,0xfb1efcc5,
0xf458f66f,0xefe0efbe,0xee0de9c3,0xeec6e586,0xf18be3d9,0xf58be538,0xf9d2e9ab,0xfd6df0ca,
0xff98f9c6,0xffdf0386,0xfe340cd7,0xfaf01494,0xf6c219d6,0xf2941c16,0xef601b3c,0xee0317a4,
0xef18120d,0xf2d60b73,0xf90604e9,0x0106ff6d,0x09e3fbb7,0x1278fa27,0x199dfab0,0x1e57fce3};
#endif

////////////

